@@ -1,6 +1,6 @@
 <?php
 	$setup_info['activitycalendar']['name'] = 'activitycalendar';
-	$setup_info['activitycalendar']['version'] = '0.1.4';
+	$setup_info['activitycalendar']['version'] = '0.1.11';
 	$setup_info['activitycalendar']['app_order'] = 60;
 	$setup_info['activitycalendar']['enable'] = 1;
 	$setup_info['activitycalendar']['app_group']	= 'office';
@@ -8,7 +8,10 @@
 	$setup_info['activitycalendar']['tables'] = array 
 	(
 		'activity_activity',
-		'activity_arena'
+		'activity_arena',
+		'activity_organization',
+		'activity_group',
+		'activity_contact_person'
 	);
 
 	$setup_info['activitycalendar']['description'] = 'Bergen kommune activitycalendar';
@@ -27,7 +30,7 @@
 
 	$setup_info['activitycalendar']['depends'][] = array(
 		'appname' => 'booking',
-		'versions' => array('0.2.05','0.2.06','0.2.07','0.2.08')
+		'versions' => array('0.2.05','0.2.06','0.2.07','0.2.08','0.2.09','0.2.10', '0.2.11','0.2.12')
 	);
 
 	$setup_info['activitycalendar']['depends'][] = array(
@@ -37,7 +40,10 @@
 
 	$setup_info['activitycalendar']['tables'] = array(
 		'activity_activity',
-		'activity_arena'
+		'activity_arena',
+		'activity_organization',
+		'activity_group',
+		'activity_contact_person'
 	);
 
 
