@@ -10,7 +10,7 @@
   *  option) any later version.                                              *
   \**************************************************************************/
 
-  /* $Id: csv_import.php 17625 2006-11-29 14:39:38Z sigurdne $ */
+  /* $Id: csv_import.php 3266 2009-07-26 10:05:32Z sigurd $ */
 
 	$GLOBALS['phpgw_info']['flags'] = array(
 		'currentapp' => 'addressbook',
@@ -32,12 +32,21 @@
 	$GLOBALS['phpgw']->template->set_block('import','ffooter','ffooterhandle');
 	$GLOBALS['phpgw']->template->set_block('import','imported','importedhandle');
 
-	$csvfile  = isset($_POST['csvfile']) ? $_POST['csvfile'] : $_FILES['csvfile']['tmp_name'];
+	$csvfile  = $_FILES['csvfile']['tmp_name'];
 
 	if($_POST['action'] == 'download' && (!$_POST['fieldsep'] || !$csvfile || !($fp=fopen($csvfile,'rb'))))
 	{
 		$_POST['action'] = '';
 	}
+	if($_POST['action'] == 'import')
+	{
+		$csvfile = $GLOBALS['phpgw']->session->appsession('import_data', 'addressbook');
+		if(!file_exists($csvfile))
+		{
+			$_POST['action'] = '';
+		}
+	}
+
 	$GLOBALS['phpgw']->template->set_var('action_url',$GLOBALS['phpgw']->link('/addressbook/csv_import.php'));
 
 	$PSep = '||'; // Pattern-Separator, separats the pattern-replacement-pairs in trans
@@ -86,7 +95,7 @@
 			break;
 
 		case 'download':
-			$GLOBALS['phpgw']->preferences->read_repository();
+			$GLOBALS['phpgw']->preferences->read();
 			$defaults = $GLOBALS['phpgw_info']['user']['preferences']['addressbook']['cvs_import'];
 			if(!is_array($defaults))
 			{
@@ -113,7 +122,7 @@
 			$addr_names = $field_names + $comm_name + $loc_names;
 
 			$config = CreateObject('phpgwapi.config','addressbook');
-			$config->read_repository();
+			$config->read();
 			while(list($name,$descr) = @each($config->config_data['custom_fields']))
 			{
 				$addr_names[$name] = $descr;
@@ -176,9 +185,10 @@
 			$GLOBALS['phpgw']->template->set_var('max',200);
 			$GLOBALS['phpgw']->template->parse('ffooterhandle','ffooter'); 
 			fclose($fp);
-			$old = $csvfile; $csvfile = $GLOBALS['phpgw_info']['server']['temp_dir'].'/addrbook_import_'.basename($csvfile);
-			rename($old,$csvfile); 
-			$hiddenvars .= '<input type="hidden" name="csvfile" value="'.$csvfile.'">';
+			$old = $csvfile; $csvfile = $GLOBALS['phpgw_info']['server']['temp_dir'].'/addrbook_import_'.$GLOBALS['phpgw_info']['user']['account_id'].'_'.basename($csvfile);
+			rename($old,$csvfile);
+			$GLOBALS['phpgw']->session->appsession('import_data', 'addressbook', $csvfile);
+			//$hiddenvars .= '<input type="hidden" name="csvfile" value="'.$csvfile.'">';
 			$mktime_lotus = "${PSep}0?([0-9]+)[ .:-]+0?([0-9]*)[ .:-]+0?([0-9]*)[ .:-]+0?([0-9]*)[ .:-]+0?([0-9]*)[ .:-]+0?([0-9]*).*$ASep@mktime(${VPre}4,${VPre}5,${VPre}6,${VPre}2,${VPre}3,${VPre}1)";
 			$help_on_trans = "<a name=\"help\"></a><b>How to use Translation's</b><p>".
 				"Translations enable you to change / adapt the content of each CSV field for your needs. <br />".
@@ -241,7 +251,7 @@
 				}
 			}
 
-			$GLOBALS['phpgw']->preferences->read_repository();
+			$GLOBALS['phpgw']->preferences->read();
 			$GLOBALS['phpgw']->preferences->add('addressbook','cvs_import',$defaults);
 			$GLOBALS['phpgw']->preferences->save_repository(True);
 
