@@ -10,7 +10,7 @@
   *  option) any later version.                                              *
   \**************************************************************************/
 
-  /* $Id: functions.inc.php 15977 2005-05-15 13:34:30Z skwashd $ */
+  /* $Id: functions.inc.php 1906 2008-11-28 22:47:27Z sigurd $ */
 
 	function formatted_list($name,$list,$id='',$default=False,$java=False)
 	{
@@ -162,7 +162,7 @@
 
 	function save_custom_field($old='',$new='')
 	{
-		$GLOBALS['phpgw']->preferences->read_repository($GLOBALS['phpgw_info']['user']['account_id']);
+		$GLOBALS['phpgw']->preferences->read($GLOBALS['phpgw_info']['user']['account_id']);
 		if ($old)
 		{
 			$GLOBALS['phpgw']->preferences->delete("addressbook","extra_".$old);
