@@ -11,7 +11,7 @@
   * option) any later version.                                               *
 	\**************************************************************************/
 
-	/* $Id: class.admin.php 16400 2006-02-14 08:48:21Z skwashd $ */
+	/* $Id: class.admin.php 1442 2008-07-18 14:48:47Z sigurd $ */
 
 	class admin_admin
 	{
@@ -25,7 +25,7 @@
 			$args->set('isadmin', False, 'bool');
 			$args = $args->get(func_get_args(),__LINE__,__FILE__);
 
-			if(isset($args['username'])
+			if(isset($args['username']))
 			{
 				$account_info['account_lid'] = $args['username'];
 				$account_info['account_passwd'] = $args['passwd'];
