@@ -11,6 +11,7 @@
  	* @version $Id: class.soconfig.inc.php 3613 2009-09-18 16:19:49Z sigurd $
 	*/
 
+	phpgw::import_class('phpgwapi.datetime');
 	/**
 	 * Description
 	 * @package admin
@@ -21,6 +22,7 @@
 		public $config_data = array();
 		protected $db;
 		protected $location_id = 0;
+		protected $global_lock = false;
 
 		public function __construct($location_id = 0)
 		{
@@ -141,10 +143,29 @@
 
 		function add_section(array $values)
 		{
-			$this->db->transaction_begin();
+			if ( $this->db->get_transaction() )
+			{
+				$this->global_lock = true;
+			}
+			else
+			{
+				$this->db->transaction_begin();
+			}
+
 
 			$values['name'] = $this->db->db_addslashes($values['name']);
 			$values['descr'] = $this->db->db_addslashes($values['descr']);
+
+			$sql = "SELECT id FROM phpgw_config2_section WHERE location_id = {$this->location_id} AND descr = '{$values['descr']}'";
+
+			$this->db->query($sql,__LINE__,__FILE__);
+			if ($this->db->next_record())
+			{
+				$receipt['section_id']=  $this->db->f('id');
+				$receipt['message'][]=array('msg'=>lang('config section has not been saved'));
+				return $receipt;
+			}
+
 			$values['section_id'] = $this->db->next_id('phpgw_config2_section');
 
 			$insert_values = array
@@ -162,14 +183,25 @@
 			$receipt['message'][]=array('msg'=>lang('config section has been saved'));
 			$receipt['section_id']= $values['section_id'];
 
-			$this->db->transaction_commit();
+			if ( !$this->global_lock )
+			{
+				$this->db->transaction_commit();
+			}
 
 			return $receipt;
 		}
 
 		function edit_section(array $values)
 		{
-			$this->db->transaction_begin();
+			if ( $this->db->get_transaction() )
+			{
+				$this->global_lock = true;
+			}
+			else
+			{
+				$this->db->transaction_begin();
+			}
+
 
 			$value_set['name']		= $this->db->db_addslashes($values['name']);
 			$value_set['descr']		= $this->db->db_addslashes($values['descr']);
@@ -178,7 +210,10 @@
 
 			$this->db->query("UPDATE phpgw_config2_section set $value_set WHERE id=" . $values['section_id'],__LINE__,__FILE__);
 
-			$this->db->transaction_commit();
+			if ( !$this->global_lock )
+			{
+				$this->db->transaction_commit();
+			}
 
 			$receipt['message'][]=array('msg'=>lang('config section has been edited'));
 
@@ -189,12 +224,25 @@
 		function delete_section(int $id)
 		{
 			$id = (int)$id;
-			$this->db->transaction_begin();
+
+			if ( $this->db->get_transaction() )
+			{
+				$this->global_lock = true;
+			}
+			else
+			{
+				$this->db->transaction_begin();
+			}
+
 			$this->db->query("DELETE FROM phpgw_config2_value WHERE section_id = {$id}",__LINE__,__FILE__);
 			$this->db->query("DELETE FROM phpgw_config2_choice WHERE section_id = {$id}",__LINE__,__FILE__);
 			$this->db->query("DELETE FROM phpgw_config2_attrib WHERE section_id = {$id}",__LINE__,__FILE__);
 			$this->db->query("DELETE FROM phpgw_config2_section WHERE id = {$id}",__LINE__,__FILE__);
-			$this->db->transaction_commit();
+
+			if ( !$this->global_lock )
+			{
+				$this->db->transaction_commit();
+			}
 		}
 
 		function read_attrib(array $data)
@@ -226,7 +274,7 @@
 				$querymethod = " AND name $this->like '%$query%'";
 			}
 
-			$sql = "SELECT $attrib_table.id, $attrib_table.section_id, $value_table.id as value_id, $attrib_table.name, $attrib_table.input_type, $value_table.value"
+			$sql = "SELECT $attrib_table.id, $attrib_table.section_id, $value_table.id as value_id, $attrib_table.name, $attrib_table.descr, $attrib_table.input_type, $value_table.value"
 			. " FROM ($section_table {$this->join} $attrib_table ON  ($section_table.id = $attrib_table.section_id))"
 			. " {$this->left_join} $value_table ON ($attrib_table.section_id = $value_table.section_id AND $attrib_table.id = $value_table.attrib_id)"
 			. " WHERE location_id = {$this->location_id} AND $attrib_table.section_id = '$section_id' $querymethod";
@@ -242,17 +290,30 @@
 			{
 				$this->db->query($sql . $ordermethod,__LINE__,__FILE__);
 			}
+			$dateformat = $GLOBALS['phpgw_info']['user']['preferences']['common']['dateformat'];
 			$config_info = array();
 			while ($this->db->next_record())
 			{
 				$input_type	= $this->db->f('input_type');
+				switch($input_type)
+				{
+					case 'password':
+						$value = '****';
+						break;
+					case 'date':
+						$value = $GLOBALS['phpgw']->common->show_date($this->db->f('value'),$dateformat);
+						break;
+					default:
+						$value = $this->db->f('value', true);
+				}
 				$config_info[] = array
 				(
-					'id'		=> $this->db->f('id'),
+					'id'			=> $this->db->f('id'),
 					'section_id'	=> $this->db->f('section_id'),
-					'value_id'	=> $this->db->f('value_id'),
-					'name'		=> $this->db->f('name', true),
-					'value'		=> $input_type == 'password' && $this->db->f('value') ? '****' : $this->db->f('value', true)
+					'value_id'		=> $this->db->f('value_id'),
+					'name'			=> $this->db->f('name', true),
+					'value'			=> $value,
+					'descr'			=> $this->db->f('descr', true),
 				);
 			}
 			return $config_info;
@@ -308,10 +369,29 @@
 
 		function add_attrib(array $values)
 		{
-			$this->db->transaction_begin();
+			if ( $this->db->get_transaction() )
+			{
+				$this->global_lock = true;
+			}
+			else
+			{
+				$this->db->transaction_begin();
+			}
 
 			$values['name'] = $this->db->db_addslashes($values['name']);
 			$values['descr'] = $this->db->db_addslashes($values['descr']);
+
+			$sql = "SELECT id FROM phpgw_config2_attrib WHERE section_id = '{$values['section_id']}' AND name = '{$values['name']}'";
+
+			$this->db->query($sql,__LINE__,__FILE__);
+
+			if ($this->db->next_record())
+			{
+				$receipt['attrib_id']	= $this->db->f('id');
+				$receipt['error'][]=array('msg'=>lang('config attrib has been saved'));
+				return $receipt;
+			}
+
 			$values['attrib_id'] = $this->db->next_id('phpgw_config2_attrib',array('section_id'=>$values['section_id']));
 
 			$insert_values = array
@@ -327,17 +407,44 @@
 			$this->db->query("INSERT INTO phpgw_config2_attrib (section_id,id,input_type,name,descr) "
 				. "VALUES ($insert_values)",__LINE__,__FILE__);
 
+
+			$choice_map = array();
+			if(isset($values['choice']) && $values['choice'])
+			{
+				foreach ($values['choice'] as $choice)
+				{
+					$values['new_choice'] = $choice;
+					$this->edit_attrib($values);				
+				}
+			}
+
+			if(isset($values['value']) && $values['value'])
+			{
+				$this->add_value($values);
+			}
+
 			$receipt['message'][]=array('msg'=>lang('config attrib has been saved'));
 			$receipt['attrib_id']= $values['attrib_id'];
 
-			$this->db->transaction_commit();
+			if ( !$this->global_lock )
+			{
+				$this->db->transaction_commit();
+			}
 
 			return $receipt;
 		}
 
 		function edit_attrib(array $values)
 		{
-			$this->db->transaction_begin();
+			if ( $this->db->get_transaction() )
+			{
+				$this->global_lock = true;
+			}
+			else
+			{
+				$this->db->transaction_begin();
+			}
+
 
 			$value_set['name']	= $this->db->db_addslashes($values['name']);
 			$value_set['descr']	= $this->db->db_addslashes($values['descr']);
@@ -374,11 +481,15 @@
 				}
 			}
 
-			$this->db->transaction_commit();
+			if ( !$this->global_lock )
+			{
+				$this->db->transaction_commit();
+			}
 
 			$receipt['message'][]=array('msg'=>lang('config attrib has been edited'));
 
 			$receipt['attrib_id']= $values['attrib_id'];
+			$receipt['choice_id'] = $choice_id;
 			return $receipt;
 		}
 
@@ -387,11 +498,22 @@
 			$section_id	= (int) $section_id;
 			$id			= (int) $id;
 
-			$this->db->transaction_begin();
+			if ( $this->db->get_transaction() )
+			{
+				$this->global_lock = true;
+			}
+			else
+			{
+				$this->db->transaction_begin();
+			}
+
 			$this->db->query("DELETE FROM phpgw_config2_value WHERE section_id ={$section_id} AND attrib_id={$id}",__LINE__,__FILE__);
 			$this->db->query("DELETE FROM phpgw_config2_choice WHERE section_id ={$section_id} AND attrib_id={$id}",__LINE__,__FILE__);
 			$this->db->query("DELETE FROM phpgw_config2_attrib WHERE section_id ={$section_id} AND id={$id}",__LINE__,__FILE__);
-			$this->db->transaction_commit();
+			if ( !$this->global_lock )
+			{
+				$this->db->transaction_commit();
+			}
 		}
 
 		function read_value(array $data)
@@ -472,7 +594,20 @@
 
 		function add_value($values)
 		{
-			$this->db->transaction_begin();
+			if(isset($values['input_type']) && $values['input_type'] == 'date')
+			{
+				$values['value'] = phpgwapi_datetime::date_to_timestamp($values['value']);
+			}
+
+			if ( $this->db->get_transaction() )
+			{
+				$this->global_lock = true;
+			}
+			else
+			{
+				$this->db->transaction_begin();
+			}
+
 
 			$values['value'] = $this->db->db_addslashes($values['value']);
 			$id = $this->db->next_id('phpgw_config2_value',array('section_id'=>$values['section_id'],'attrib_id'=>$values['attrib_id']));
@@ -492,24 +627,44 @@
 			$receipt['message'][]=array('msg'=>lang('config value has been saved'));
 			$receipt['id']= $id;
 
-			$this->db->transaction_commit();
+			if ( !$this->global_lock )
+			{
+				$this->db->transaction_commit();
+			}
 
 			return $receipt;
 		}
 
 		function edit_value($values)
 		{
+			if(isset($values['input_type']) && $values['input_type'] == 'date')
+			{
+				$values['value'] = phpgwapi_datetime::date_to_timestamp($values['value']);
+			}
+
 			if(!$values['value'])
 			{
 				$this->delete_value($values['section_id'],$values['attrib_id'],$values['id']);
 			}
 			else
 			{
-				$this->db->transaction_begin();
+				if ( $this->db->get_transaction() )
+				{
+					$this->global_lock = true;
+				}
+				else
+				{
+					$this->db->transaction_begin();
+				}
+
 				$value_set['value']	= $this->db->db_addslashes($values['value']);
 				$value_set	= $this->db->validate_update($value_set);
 				$this->db->query("UPDATE phpgw_config2_value SET {$value_set} WHERE section_id =" . (int)$values['section_id'] . ' AND attrib_id=' . (int)$values['attrib_id'] . ' AND id=' . (int)$values['id'],__LINE__,__FILE__);
-				$this->db->transaction_commit();
+
+				if ( !$this->global_lock )
+				{
+					$this->db->transaction_commit();
+				}
 			}
 
 			$receipt['message'][]=array('msg'=>lang('config value has been edited'));
@@ -524,9 +679,20 @@
 			$attrib_id	= (int) $attrib_id;
 			$id			= (int) $id;
 
-			$this->db->transaction_begin();
+			if ( $this->db->get_transaction() )
+			{
+				$this->global_lock = true;
+			}
+			else
+			{
+				$this->db->transaction_begin();
+			}
+
 			$this->db->query("DELETE FROM phpgw_config2_value WHERE section_id ={$section_id} AND attrib_id={$attrib_id} AND id={$id}",__LINE__,__FILE__);
-			$this->db->transaction_commit();
+			if ( !$this->global_lock )
+			{
+				$this->db->transaction_commit();
+			}
 		}
 
 		function select_choice_list($section_id,$attrib_id)
