@@ -9,53 +9,49 @@
 	*  option) any later version.                                              *
 	\**************************************************************************/
 
-	/* $Id: class.uiaccess_history.inc.php 18358 2007-11-27 04:43:37Z skwashd $ */
+	/* $Id: class.uiaccess_history.inc.php 1276 2008-06-20 15:42:59Z sigurd $ */
 
-	class uiaccess_history
+	class admin_uiaccess_history
 	{
-		var $template;
-		var $public_functions = array(
+		public $public_functions = array
+		(
 			'list_history' => True
 		);
 
-		function uiaccess_history()
+		public function list_history()
 		{
 			if ($GLOBALS['phpgw']->acl->check('access_log_access',1,'admin'))
 			{
 				$GLOBALS['phpgw']->redirect_link('/index.php');
 			}
-			
-			$this->bo         = createobject('admin.boaccess_history');
-			$this->nextmatchs = createobject('phpgwapi.nextmatchs');
-			$this->template   = $GLOBALS['phpgw']->template;
-			$this->template->set_file(
-				Array(
-					'accesslog' => 'accesslog.tpl'
-				)
-			);
-			$this->template->set_block('accesslog','list');
-			$this->template->set_block('accesslog','row');
-			$this->template->set_block('accesslog','row_empty');
-		}
 
-		function list_history()
-		{
+			$bo         = createobject('admin.boaccess_history');
+			$nextmatches = createobject('phpgwapi.nextmatchs');
+
 			$account_id	= phpgw::get_var('account_id', 'int', 'REQUEST');
-			$start		= phpgw::get_var('start', 'int', 'POST', 0);
+			$start		= phpgw::get_var('start', 'int', 'GET', 0);
 			$sort		= phpgw::get_var('sort', 'int', 'POST', 0);
 			$order		= phpgw::get_var('order', 'int', 'POST', 0);
 			
 			$GLOBALS['phpgw_info']['flags']['app_header'] = lang('Admin').' - '.lang('View access log');
-			$GLOBALS['phpgw']->common->phpgw_header();
-			echo parse_navbar();
+			$GLOBALS['phpgw_info']['flags']['menu_selection'] = 'admin::admin::access_log';
 
-			$total_records = $this->bo->total($account_id);
+			$GLOBALS['phpgw']->common->phpgw_header(true);
+
+			$t   =& $GLOBALS['phpgw']->template;
+			$t->set_root(PHPGW_APP_TPL);
+			$t->set_file('accesslog', 'accesslog.tpl');
+			$t->set_block('accesslog','list');
+			$t->set_block('accesslog','row');
+			$t->set_block('accesslog','row_empty');
+
+			$total_records = $bo->total($account_id);
 
 			$var = array
 			(
-				'nextmatchs_left'  => $this->nextmatchs->left('/index.php',$start,$total_records,'&menuaction=admin.uiaccess_history.list_history&account_id=' . $account_id),
-				'nextmatchs_right' => $this->nextmatchs->right('/index.php',$start,$total_records,'&menuaction=admin.uiaccess_history.list_history&account_id=' . $account_id),
-				'showing'          => $this->nextmatchs->show_hits($total_records,$start),
+				'nextmatchs_left'  => $nextmatches->left('/index.php',$start,$total_records,'&menuaction=admin.uiaccess_history.list_history&account_id=' . $account_id),
+				'nextmatchs_right' => $nextmatches->right('/index.php',$start,$total_records,'&menuaction=admin.uiaccess_history.list_history&account_id=' . $account_id),
+				'showing'          => $nextmatches->show_hits($total_records,$start),
 				'lang_loginid'     => lang('LoginID'),
 				'lang_ip'     => lang('IP'),
 				'lang_login'  => lang('Login'),
@@ -78,14 +74,14 @@
 				$var['lang_last_x_logins'] = lang('Last %1 logins',$total_records);
 			}
 
-			$this->template->set_var($var);
+			$t->set_var($var);
 
-			$records = $this->bo->list_history($account_id, $start, $order, $sort);
+			$records = $bo->list_history($account_id, $start, $order, $sort);
 			if ( is_array($records) )
 			{
 				foreach ( $records as &$record )
 				{
-					$this->nextmatchs->template_alternate_row_class($this->template);
+					$nextmatches->template_alternate_row_class($t);
 
 					$var = array
 					(
@@ -95,19 +91,19 @@
 						'row_lo'      => $record['account_id'] ? $record['lo'] : '<b>' . lang($record['sessionid']) . '</b>',
 						'row_total'   => ($record['lo'] ? $record['total'] : '&nbsp;')
 					);
-					$this->template->set_var($var);
-					$this->template->fp('rows_access','row', true);
+					$t->set_var($var);
+					$t->fp('rows_access','row', true);
 				}
 			}
 
 			if (! $total_records && $account_id)
 			{
-				$this->nextmatchs->template_alternate_row_class($this->template);
-				$this->template->set_var('row_message',lang('No login history exists for this user'));
-				$this->template->fp('rows_access','row_empty', true);
+				$nextmatches->template_alternate_row_class($t);
+				$t->set_var('row_message',lang('No login history exists for this user'));
+				$t->fp('rows_access','row_empty', true);
 			}
 
-			$loggedout = $this->bo->return_logged_out($account_id);
+			$loggedout = $bo->return_logged_out($account_id);
 
 			if ($total_records)
 			{
@@ -122,6 +118,7 @@
 			(
 				'footer_total' => lang('Total records') . ': ' . $total_records
 			);
+
 			if ($account_id)
 			{
 				$var['lang_percent'] = lang('Percent this user has logged out') . ': ' . $percent . '%';
@@ -132,10 +129,9 @@
 			}
 
 			// create the menu on the left, if needed
-			$menuClass = CreateObject('admin.uimenuclass');
-			$var['rows'] = $menuClass->createHTMLCode('view_account');
+			$var['rows'] = createObject('admin.uimenuclass')->createHTMLCode('view_account');
 
-			$this->template->set_var($var);
-			$this->template->pfp('out','list');
+			$t->set_var($var);
+			$t->pfp('out','list');
 		}
 	}
