@@ -8,7 +8,7 @@
 	* @license http://www.gnu.org/licenses/ GNU General Public License v2 or later
 	* @package phpgroupware
 	* @subpackage admin
-	* @version $Id: class.uiaccounts.inc.php 6324 2010-09-10 12:51:59Z sigurd $
+	* @version $Id: class.uiaccounts.inc.php 6744 2011-01-10 14:36:50Z sigurdne $
 	*/
 
 	/*
@@ -333,7 +333,7 @@
 
 				$valid_users = array_unique($valid_users);
 
-				$allusers = $GLOBALS['phpgw']->accounts->get_list('accounts', -1,$this->sort, $this->order, $this->query);
+				$allusers = $GLOBALS['phpgw']->accounts->get_list('accounts', -1,$sort, $order, $query);
 				foreach($allusers as  $user)
 				{
 					if(!in_array($user->id, $valid_users))
@@ -346,7 +346,7 @@
 				$total = count($allusers);
 				$length = $GLOBALS['phpgw_info']['user']['preferences']['common']['maxmatchs'];
 
-				if ($this->allrows)
+				if ($allrows)
 				{
 					$start = 0;
 					$length = $total;
@@ -521,6 +521,9 @@
 										array('menuaction' => 'admin.uimainscreen.mainscreen'))
 			);
 
+			$link_data['sort']	= $sort;
+			$link_data['order']	= $order;
+
 			$nm = array
 			(
  				'start'				=> $start == -1 ? 0 : $start,
