@@ -9,11 +9,11 @@
   *  option) any later version.                                              *
   \**************************************************************************/
 
-  /* $Id: class.uiapplications.inc.php 18358 2007-11-27 04:43:37Z skwashd $ */
+  /* $Id: class.uiapplications.inc.php 1164 2008-06-06 08:41:04Z sigurd $ */
 
-	class uiapplications
+	class admin_uiapplications
 	{
-		var $public_functions = array
+		public $public_functions = array
 		(
 			'get_list'	=> true,
 			'add'		=> true,
@@ -22,21 +22,21 @@
 			'register_all_hooks' => true
 		);
 
-		var $bo;
-		var $nextmatchs;
+		private $bo;
+		private $nextmatchs;
 
-		function uiapplications()
+		public function __construct()
 		{
-			$this->bo =& CreateObject('admin.boapplications');
-			$this->nextmatchs =& CreateObject('phpgwapi.nextmatchs');
-			$GLOBALS['phpgw']->template->set_root(PHPGW_APP_TPL);
+			$GLOBALS['phpgw_info']['flags']['menu_selection'] = 'admin::admin';
+			$this->bo = createObject('admin.boapplications');
+			$this->nextmatchs = createObject('phpgwapi.nextmatchs', false);
 		}
 
-		function get_list()
+		public function get_list()
 		{
-			$GLOBALS['phpgw']->common->phpgw_header();
-			echo parse_navbar();
-			
+			$GLOBALS['phpgw_info']['flags']['menu_selection'] .= '::apps';
+			$GLOBALS['phpgw']->common->phpgw_header(true);
+
 			$GLOBALS['phpgw']->template->set_root(PHPGW_APP_TPL);
 			$GLOBALS['phpgw']->template->set_file(array('applications' => 'applications.tpl'));
 			$GLOBALS['phpgw']->template->set_block('applications','list','list');
@@ -65,11 +65,11 @@
 			{
 				$limit = $start + $offset;
 			}
-			elseif ($start && !$offset)
+			else if ($start && !$offset)
 			{
 				$limit = $start;
 			}
-			elseif(!$start && !$offset)
+			else if(!$start && !$offset)
 			{
 				$limit = $total;
 			}
@@ -86,9 +86,10 @@
 
 			$i = 0;
 			$applications = array();
-			while(list($app,$data) = @each($apps))
+			foreach ( $apps as $app => $data )
 			{
-				if($i >= $start && $i<= $limit)
+				if ( $i >= $start
+					&& $i<= $limit )
 				{
 					$applications[$app] = $data;
 				}
@@ -136,15 +137,15 @@
 
 				if ($app['status']==1)
 				{
-					$status = lang('Yes');
+					$status = lang('yes');
 				}
 				else if ($app['status']==2)
 				{
-					$status = lang('Hidden');
+					$status = lang('hidden');
 				}
 				else
 				{
-					$status = '<b>' . lang('No') . '</b>';
+					$status = '<b>' . lang('no') . '</b>';
 				}
 				$GLOBALS['phpgw']->template->set_var('status',$status);
 
@@ -154,7 +155,7 @@
 			$GLOBALS['phpgw']->template->pparse('out','list');
 		}
 
-		function display_row($label, $value)
+		private function display_row($label, $value)
 		{
 			$GLOBALS['phpgw']->template->set_var('tr_color',$this->nextmatchs->alternate_row_class());
 			$GLOBALS['phpgw']->template->set_var('label',$label);
@@ -162,8 +163,11 @@
 			$GLOBALS['phpgw']->template->parse('rows','row',True);
 		}
 
-		function add()
+		public function add()
 		{
+			$GLOBALS['phpgw_info']['flags']['menu_selection'] .= '::apps';
+
+			$GLOBALS['phpgw']->template->set_root(PHPGW_APP_TPL);
 			$GLOBALS['phpgw']->template->set_file(array('application' => 'application_form.tpl'));
 			$GLOBALS['phpgw']->template->set_block('application','form','form');
 			$GLOBALS['phpgw']->template->set_block('application','row','row');
@@ -244,10 +248,13 @@
 			$GLOBALS['phpgw']->template->pparse('out','form');
 		}
 
-		function edit()
+		public function edit()
 		{
+			$GLOBALS['phpgw_info']['flags']['menu_selection'] .= '::apps';
+
 			$app_name = phpgw::get_var('app_name', 'string', 'GET');
 
+			$GLOBALS['phpgw']->template->set_root(PHPGW_APP_TPL);
 			$GLOBALS['phpgw']->template->set_file(array('application' => 'application_form.tpl'));
 			$GLOBALS['phpgw']->template->set_block('application','form','form');
 			$GLOBALS['phpgw']->template->set_block('application','row','row');
@@ -274,7 +281,7 @@
 						$error[$totalerrors++] = lang('That application name already exists.');
 					}
 				}
- 
+
 				if (! $totalerrors)
 				{
 					$this->bo->save(array(
@@ -324,8 +331,10 @@
 			$GLOBALS['phpgw']->template->pparse('out','form');
 		}
 
-		function delete()
+		public function delete()
 		{
+			$GLOBALS['phpgw_info']['flags']['menu_selection'] .= '::apps';
+
 			$app_name = phpgw::get_var('app_name', 'string', 'GET');
 
 			if (!$app_name)
@@ -333,6 +342,7 @@
 				$GLOBALS['phpgw']->redirect_link('/index.php', array('menuaction' => 'admin.uiapplications.get_list') );
 			}
 
+			$GLOBALS['phpgw']->template->set_root(PHPGW_APP_TPL);
 			$GLOBALS['phpgw']->template->set_file(array('body' => 'delete_common.tpl'));
 
 			if ( phpgw::get_var('confirm', 'bool') )
@@ -343,24 +353,30 @@
 				exit;
 			}
 
-			$GLOBALS['phpgw']->common->phpgw_header();
-			echo parse_navbar();
+			$GLOBALS['phpgw']->common->phpgw_header(true);
 
 			$GLOBALS['phpgw']->template->set_var('messages',lang('Are you sure you want to delete this application ?'));
 			$GLOBALS['phpgw']->template->set_var('no','<a href="' . $GLOBALS['phpgw']->link('/index.php',array('menuaction'=>'admin.uiapplications.get_list')) . '">' . lang('No') . '</a>');
 			$GLOBALS['phpgw']->template->set_var('yes','<a href="' . $GLOBALS['phpgw']->link('/index.php',array('menuaction'=>'admin.uiapplications.delete','app_name'=> urlencode($app_name), 'confirm'=>'True')) . '">' . lang('Yes') . '</a>');
 			$GLOBALS['phpgw']->template->pparse('out','body');
 		}
-		
+
 		function register_all_hooks()
 		{
+			$GLOBALS['phpgw_info']['flags']['menu_selection'] .= '::hooks';
 			if ( !isset($GLOBALS['phpgw']->hooks) && !is_object($GLOBALS['phpgw']->hooks) )
 			{
 				$GLOBALS['phpgw']->hooks = CreateObject('phpgwapi.hooks');
 			}
 			$GLOBALS['phpgw']->hooks->register_all_hooks();
-			
-			$GLOBALS['phpgw']->redirect_link('/admin/index.php');
+
+			$GLOBALS['phpgw']->common->phpgw_header(true);
+			$updated = lang('hooks updated');
+			$detail = lang('the new hooks should be available to all users');
+			echo <<<HTML
+				<h1>$updated</h1>
+				<p>$detail</p>
+
+HTML;
 		}
 	}
-?>
