@@ -9,7 +9,7 @@
 	*  Free Software Foundation; either version 2 of the License, or (at your  *
 	*  option) any later version.                                              *
 	\**************************************************************************/
-	/* $Id: class.uicategories.inc.php 6957 2011-02-09 14:00:59Z sigurdne $ */
+	/* $Id: class.uicategories.inc.php 9383 2012-05-13 15:52:47Z sigurdne $ */
 	/* $Source$ */
 
 	class admin_uicategories
@@ -143,6 +143,7 @@
 				'lang_add_sub'			=> lang('add sub'),
 				'lang_name'				=> lang('name'),
 				'lang_descr'			=> lang('description'),
+				'lang_status'			=> lang('status'),
 				'lang_edit'				=> lang('edit'),
 				'lang_delete'			=> lang('delete'),
 				'lang_sort_statustext'	=> lang('sort the entries'),
@@ -156,8 +157,14 @@
 											))
 			);
 
+
+			$lang_add_sub_statustext	= lang('add a subcategory');
+			$lang_edit_statustext		= lang('edit this category');
+			$lang_delete_statustext		= lang('delete this category');
+			$lang_add_sub				= lang('add sub');
+
 			$content = array();
-			while (is_array($categories) && list(,$cat) = each($categories))
+			foreach ($categories as $cat)
 			{
 				$level		= $cat['level'];
 				$cat_name	= $GLOBALS['phpgw']->strip_html($cat['name']);
@@ -223,18 +230,20 @@
 
 				$content[] = array
 				(
-					'name'				=> $cat_name . $appendix,
-					'descr'				=> $descr,
-					'main'				=> $main,
-					'add_sub_url'			=> $add_sub_url,
-					'edit_url'			=> $edit_url,
-					'delete_url'			=> $delete_url,
-					'lang_add_sub_statustext'	=> lang('add a subcategory'),
-					'lang_edit_statustext'		=> lang('edit this category'),
-					'lang_delete_statustext'	=> lang('delete this category'),
-					'lang_add_sub'			=> lang('add sub'),
-					'lang_edit'			=> $lang_edit,
-					'lang_delete'			=> $lang_delete
+					'name'						=> $cat_name . $appendix,
+					'descr'						=> $descr,
+					'main'						=> $main,
+					'status'					=> $cat['active'],
+					'status_text'				=> $cat['active'] == 1 ? 'active' : 'disabled',
+					'add_sub_url'				=> $add_sub_url,
+					'edit_url'					=> $edit_url,
+					'delete_url'				=> $delete_url,
+					'lang_add_sub_statustext'	=> $lang_add_sub_statustext,
+					'lang_edit_statustext'		=> $lang_edit_statustext,
+					'lang_delete_statustext'	=> $lang_delete_statustext,
+					'lang_add_sub'				=> $lang_add_sub,
+					'lang_edit'					=> $lang_edit,
+					'lang_delete'				=> $lang_delete
 				);
 			}
 
@@ -348,6 +357,7 @@
 
 			$GLOBALS['phpgw']->xslttpl->add_file('cats');
 
+/*
 			if ( $appname )
 			{
 				$GLOBALS['phpgw']->template->set_var('title_categories',lang('Edit global category for %1',lang($appname) . $location?"::{$location}":''));
@@ -356,6 +366,30 @@
 			{
 				$GLOBALS['phpgw']->template->set_var('title_categories',lang('Edit global category'));
 			}
+*/
+			$active = array
+			(
+				array
+				(
+					'id'	=> 0,
+					'name'	=> lang('inactive')
+				),
+				array
+				(
+					'id'	=> 1,
+					'name'	=> lang('active')
+				),
+				array
+				(
+					'id'	=> 2,
+					'name'	=> lang('inactive and hidden')
+				)
+			);
+
+			foreach ($active as &$entry)
+			{
+				$entry['selected'] = $entry['id'] == $cats[0]['active'] ? 1 : 0;
+			}
 
 			$data = array
 			(
@@ -376,7 +410,8 @@
 				'lang_cancel_statustext'	=> lang('leave the category untouched and return back to the list'),
 				'lang_save_statustext'		=> lang('save the category and return back to the list'),
 				'lang_apply_statustext'		=> lang('save the category'),
-				'cat_select'			=> $this->bo->cats->formatted_xslt_list(array('select_name' => 'values[parent]', 'selected' => $parent,'self' => $this->cat_id,'globals' => $global_cats))
+				'cat_select'			=> $this->bo->cats->formatted_xslt_list(array('select_name' => 'values[parent]', 'selected' => $parent,'self' => $this->cat_id,'globals' => $global_cats)),
+				'active_list'			=> array('options' => $active)
 			);
 
 			$link_data['menuaction'] = 'admin.uicategories.edit';
