@@ -10,11 +10,11 @@
   *  option) any later version.                                              *
   \**************************************************************************/
 
-  /* $Id: class.uiconfig.inc.php 18358 2007-11-27 04:43:37Z skwashd $ */
+  /* $Id: class.uiconfig.inc.php 3535 2009-09-09 07:36:04Z sigurd $ */
 
-	class uiconfig
+	class admin_uiconfig
 	{
-		var $public_functions = array('index' => True);
+		public $public_functions = array('index' => True);
 
 		function index()
 		{
@@ -37,6 +37,7 @@
 			}
 						
 			$appname = phpgw::get_var('appname', 'string', 'GET');
+			$GLOBALS['phpgw_info']['flags']['menu_selection'] = "admin::{$appname}::index";
 
 			$GLOBALS['phpgw_info']['apps']['manual']['app'] = $appname; // override the appname fetched from the referer for the manual.
 
@@ -72,7 +73,7 @@
 			$t->set_block('config','body','body');
 
 			$c = CreateObject('phpgwapi.config',$config_appname);
-			$c->read_repository();
+			$c->read();
 
 			if ($c->config_data)
 			{
@@ -171,91 +172,95 @@
 				'title'			=> lang('Site Configuration'),
 			));
 
+	//		$t->unknown_regexp = 'loose';
 			$vars = $t->get_undefined('body');
+	//		$t->unknown_regexp = '';
 
 			$GLOBALS['phpgw']->hooks->single('config',$appname);
 
-			foreach ( $vars as $value )
+			if(is_array($vars))
 			{
-				$valarray = explode('_', $value);
-				$type = $valarray[0];
-				$new = $newval = '';
-
-				while($chunk = next($valarray))
+				foreach ( $vars as $value )
 				{
-					$new[] = $chunk;
-				}
-				$newval = implode(' ',$new);
+					$valarray = explode('_', $value);
+					$type = $valarray[0];
+					$new = $newval = '';
 
-				switch($type)
-				{
-					case 'lang':
-						$t->set_var($value,lang($newval));
-						break;
-					case 'value':
-						$newval = ereg_replace(' ','_',$newval);
-						/* Don't show passwords in the form */
-						if ( !isset($current_config[$newval]) || ereg('passwd',$value) || ereg('password',$value) || ereg('root_pw',$value))
-						{
+					while($chunk = next($valarray))
+					{
+						$new[] = $chunk;
+					}
+					$newval = implode(' ',$new);
+
+					switch($type)
+					{
+						case 'lang':
+							$t->set_var($value,$GLOBALS['phpgw']->translation->translate($newval, array(),false, $appname));
+							break;
+						case 'value':
+							$newval = ereg_replace(' ','_',$newval);
+							/* Don't show passwords in the form */
+							if ( !isset($current_config[$newval]) || ereg('passwd',$value) || ereg('password',$value) || ereg('root_pw',$value))
+							{
+								$t->set_var($value,'');
+							}
+							else
+							{
+								$t->set_var($value,(isset($current_config[$newval])?$current_config[$newval]:''));
+							}
+							break;
+						case 'checked':
+							/* '+' is used as a delimiter for the check value */
+							list($newvalue,$check) = split('\+',$newval);
+							$newval = ereg_replace(' ','_',$newvalue);
+							if($current_config[$newval] == $check)
+							{
+								$t->set_var($value, ' checked');
+							}
+							else
+							{
+								$t->set_var($value, '');
+							}
+							break;
+						case 'selected':
+							$configs = array();
+							$config  = '';
+							$newvals = explode(' ',$newval);
+							$setting = end($newvals);
+							for ($i=0;$i<(count($newvals) - 1); $i++)
+							{
+								$configs[] = $newvals[$i];
+							}
+							$config = implode('_',$configs);
+							/* echo $config . '=' . $current_config[$config]; */
+							if ( isset($current_config[$config]) 
+								&& $current_config[$config] == $setting)
+							{
+								$t->set_var($value,' selected');
+							}
+							else
+							{
+								$t->set_var($value,'');
+							}
+							break;
+						case 'hook':
+							$newval = ereg_replace(' ','_',$newval);
+							if(function_exists($newval))
+							{
+								$t->set_var($value,$newval($current_config));
+							}
+							else
+							{
+								$t->set_var($value,'');
+							}
+							break;
+						default:
 							$t->set_var($value,'');
-						}
-						else
-						{
-							$t->set_var($value,(isset($current_config[$newval])?$current_config[$newval]:''));
-						}
-						break;
-					case 'checked':
-						/* '+' is used as a delimiter for the check value */
-						list($newvalue,$check) = split('\+',$newval);
-						$newval = ereg_replace(' ','_',$newvalue);
-						if($current_config[$newval] == $check)
-						{
-							$t->set_var($value, ' checked');
-						}
-						else
-						{
-							$t->set_var($value, '');
-						}
-						break;
-					case 'selected':
-						$configs = array();
-						$config  = '';
-						$newvals = explode(' ',$newval);
-						$setting = end($newvals);
-						for ($i=0;$i<(count($newvals) - 1); $i++)
-						{
-							$configs[] = $newvals[$i];
-						}
-						$config = implode('_',$configs);
-						/* echo $config . '=' . $current_config[$config]; */
-						if ( isset($current_config[$config]) 
-							&& $current_config[$config] == $setting)
-						{
-							$t->set_var($value,' selected');
-						}
-						else
-						{
-							$t->set_var($value,'');
-						}
-						break;
-					case 'hook':
-						$newval = ereg_replace(' ','_',$newval);
-						if(function_exists($newval))
-						{
-							$t->set_var($value,$newval($current_config));
-						}
-						else
-						{
-							$t->set_var($value,'');
-						}
-						break;
-					default:
-						$t->set_var($value,'');
-						break;
+							break;
+					}
 				}
 			}
 			$GLOBALS['phpgw']->common->phpgw_header(true);
 			$t->pfp('out','config');
 		}
 	}
-?>
