@@ -9,7 +9,7 @@
 	*  option) any later version.                                              *
 	\**************************************************************************/
 
-	/* $Id: setup.inc.php 16932 2006-08-06 10:03:24Z skwashd $ */
+	/* $Id: setup.inc.php 690 2008-02-02 10:11:33Z dave $ */
 
 	$setup_info['admin']['name']		= 'admin';
 	$setup_info['admin']['version']		= '0.9.17.001';
@@ -40,14 +40,13 @@
 	(
 		'acl_manager',
 		'add_def_pref',
-		'admin',
 		'after_navbar',
 		'config',
 		'deleteaccount',
 		'manual',
-		'sidebox_menu',
 		'view_user'
 	);
+	$setup_info['admin']['hooks']['menu'] = 'admin.menu.get_menu';
 
 	/* Dependencies for this app to work */
 	$setup_info['admin']['depends'][] = array
