@@ -333,6 +333,7 @@
 			return $results;
 		}
 
+		
 		public function get_booking_id($booking)
         {
 			$table_name = $this->table_name;
@@ -433,6 +434,26 @@
             }
 		}
 
+		function get_organization($id)
+		{
+			$this->db->limit_query("SELECT name FROM bb_organization where id=(select organization_id from bb_group where id=($id))", 0, __LINE__, __FILE__, 1);
+			if(!$this->db->next_record())
+			{
+				return False;
+			}
+			return $this->db->f('name', false);
+		}
+
+		function get_resource($id)
+		{
+			$this->db->limit_query("SELECT name FROM bb_resource where id=" . intval($id), 0, __LINE__, __FILE__, 1);
+			if(!$this->db->next_record())
+			{
+				return False;
+			}
+			return $this->db->f('name', false);
+		}
+
 		function get_building($id)
 		{
 			$this->db->limit_query("SELECT name FROM bb_building where id=" . intval($id), 0, __LINE__, __FILE__, 1);
@@ -443,11 +464,45 @@
 			return $this->db->f('name', false);
 		}
 
+		function get_season($id)
+		{
+			$this->db->limit_query("SELECT id FROM bb_season where id=" . intval($id), 0, __LINE__, __FILE__, 1);
+			if(!$this->db->next_record())
+			{
+				return False;
+			}
+			return $this->db->f('id', false);
+		}
+
+		function get_group_of_organization($id)
+		{
+            $results = array();
+			$this->db->query("SELECT id FROM bb_group WHERE active = 1 and organization_id=". intval($id), __LINE__, __FILE__);
+			while ($this->db->next_record())
+			{
+				$results[] = $this->db->f('id', false);
+			}
+			return $results;
+		}
+
+		function get_organizations()
+		{
+            $results = array();
+			$results[] = array('id' =>  0,'name' => lang('Not selected'));
+			$this->db->query("SELECT id, name FROM bb_organization WHERE active = 1 ORDER BY name ASC", __LINE__, __FILE__);
+			while ($this->db->next_record())
+			{
+				$results[] = array('id' => $this->db->f('id', false),
+						           'name' => $this->db->f('name', false));
+			}
+			return $results;
+		}
+
 		public function find_expired() {
 			$table_name = $this->table_name;
 			$db = $this->db;
 			$expired_conditions = $this->find_expired_sql_conditions();
-			return $this->read(array('filters' => array('where' => $expired_conditions), 'results' => 1000));
+			return $this->read(array('filters' => array('where' => $expired_conditions), 'results' => 'all'));
 		}
 		
 		protected function find_expired_sql_conditions() {
@@ -456,11 +511,30 @@
 			return "({$table_name}.active != 0 AND {$table_name}.completed = 0 AND {$table_name}.to_ < '{$now}')";
 		}
 		
-		public function complete_expired(&$bookings) {
+		public function complete_expired(&$bookings)
+		{
 			$table_name = $this->table_name;
 			$db = $this->db;
 			$ids = join(', ', array_map(array($this, 'select_id'), $bookings));
 			$sql = "UPDATE $table_name SET completed = 1 WHERE {$table_name}.id IN ($ids);";
 			$db->query($sql, __LINE__, __FILE__);
+
+			//Avoid double invoices
+			if($ids)
+			{
+				$allocations = array();
+				$sql = "SELECT DISTINCT allocation_id FROM bb_booking WHERE id IN ($ids) AND allocation_id IS NOT NULL";
+				$db->query($sql, __LINE__, __FILE__);
+				while ($this->db->next_record())
+				{
+					$allocations[] = $db->f('allocation_id');
+				}
+
+				if($allocations)
+				{
+					$sql = 'UPDATE bb_allocation SET completed = 1 WHERE id IN (' . implode(',', $allocations) . ')';
+					$db->query($sql, __LINE__, __FILE__);
+				}
+			}
 		}
 	}
