@@ -122,7 +122,7 @@
 					|| count($reservation['resources']) <= 0) 
 			{
 				
-				//Note that the loggin is stupidly enough done in the database so if the transaction fails
+				//Note that if the transaction fails
 				//we may very well not get anything in the log
 				if(is_object($GLOBALS['phpgw']->log))
 				{
@@ -150,12 +150,10 @@
 				'season_id'				=> isset($reservation['season_id']) ? $reservation['season_id'] : null,
 			);
 			
-			//echo "$type\n";
-			//print_r($reservation);
-			
 			$method = "initialize_completed_{$type}";
 			$this->$method($reservation, $entity);
 			$this->set_description($type, $reservation, $entity);
+
 			$this->add($entity);
 		}
 		
@@ -251,9 +249,9 @@
 			//Remember that the default value of customer_type is already
 			//set to 'external' so we only have to adjust customer_type
 			//when dealing with an internal customer
-			if (strlen($customer_info['organization_number']) == 5) {
+			if ((strlen($customer_info['organization_number']) == 5) || (strlen($customer_info['organization_number']) == 6)) {
 				$entity['customer_type'] = self::CUSTOMER_TYPE_INTERNAL;
-			} else if (strlen($customer_info['customer_organization_number']) == 5) {
+			} else if ((strlen($customer_info['customer_organization_number']) == 6) || (strlen($customer_info['customer_organization_number']) == 5)){
 				$entity['customer_type'] = self::CUSTOMER_TYPE_INTERNAL;
 			} else if (intval($customer_info['customer_internal']) == 1) {
 				$entity['customer_type'] = self::CUSTOMER_TYPE_INTERNAL;
@@ -263,14 +261,24 @@
 		protected function set_organization(&$entity, &$organization) {
 			$entity['organization_id'] = $organization['id'];
             if (intval($organization['customer_internal']) == 1) {
-                if (strlen($organization['customer_number']) == 5) {
+                if ((strlen($organization['customer_number']) == 5) || (strlen($organization['customer_number']) == 6)) {
                     $entity['customer_organization_number'] = $organization['customer_number'];
+	                $entity['customer_identifier_type'] = 'organization_number';
+                } elseif ($organization['customer_identifier_type'] == 'ssn') {
+                    $entity['customer_ssn'] = $organization['customer_ssn'];
+ 	                $entity['customer_identifier_type'] = 'ssn';
+                } elseif ($organization['customer_identifier_type'] == 'organization_number') {
+                    $entity['customer_organization_number'] = $organization['customer_organization_number'];
+	                $entity['customer_identifier_type'] = 'organization_number';
                 } else {
                     $entity['customer_organization_number'] = '';
+ 	                $entity['customer_identifier_type'] = '';
                 }
             } else {
                 $entity['customer_organization_number'] = $organization['organization_number'];
-            }
+                $entity['customer_identifier_type'] = 'organization_number';
+			}
+			
 		}
 		
 		protected function initialize_completed_booking(&$booking, &$entity) {
@@ -311,8 +319,25 @@
 		}
 		
 		protected function initialize_completed_event(&$event, &$entity) {
-			$this->set_customer_type($entity, $event);
-			$this->copy_customer_identifier($event, $entity);
+
+			if($event['customer_organization_id'] > 0) {
+				static $soorg;
+				static $cache = array();
+
+				!$soorg AND $soorg = CreateObject('booking.soorganization');
+				if (isset($cache[$event['customer_organization_id']])) {
+					$org = $cache[$event['customer_organization_id']];
+				} else {
+					$org = $soorg->read_single($event['customer_organization_id']);
+					$cache[$event['customer_organization_id']] = $org;
+				}
+				$this->set_organization($entity, $org);				
+				$this->set_customer_type($entity, $org);
+				$this->copy_customer_identifier($event, $entity);
+			} else {
+				$this->set_customer_type($entity, $event);
+				$this->copy_customer_identifier($event, $entity);
+			}
 		}
 		
 		public function update_exported_state_of(&$reservations, $with_export_id) {
