@@ -45,6 +45,7 @@
 			if(phpgw::get_var('phpgw_return_as') == 'json') {
 				return $this->index_json();
 			}
+			self::add_javascript('booking', 'booking', 'allocation_list.js');
 			self::add_javascript('booking', 'booking', 'datatable.js');
 			phpgwapi_yui::load_widget('datatable');
 			phpgwapi_yui::load_widget('paginator');
@@ -52,6 +53,24 @@
 				'form' => array(
 					'toolbar' => array(
 						'item' => array(
+							array('type' => 'autocomplete', 
+								'name' => 'building',
+								'ui' => 'building',
+								'text' => lang('Building').':',
+								'onItemSelect' => 'updateBuildingFilter',
+								'onClearSelection' => 'clearBuildingFilter'
+							),
+							array('type' => 'autocomplete', 
+								'name' => 'season',
+								'ui' => 'season',
+								'text' => lang('Season').':',
+								'requestGenerator' => 'requestWithBuildingFilter',
+							),
+							array('type' => 'filter', 
+								'name' => 'organizations',
+                                'text' => lang('Organization').':',
+                                'list' => $this->bo->so->get_organizations(),
+							),
 							array('type' => 'text', 
 								'name' => 'query'
 							),
@@ -115,13 +134,49 @@
 						'href' => self::link(array('menuaction' => 'booking.uibooking.add'))
 				));
 			}
-			
+			$data['filters'] = $this->export_filters;
 			self::render_template('datatable', $data);
 		}
 
 		public function index_json()
 		{
-			$bookings = $this->bo->read();
+			if(isset($_SESSION['showall']))
+			{
+        		unset($filters['building_name']);
+                unset($filters['group_id']);
+                unset($filters['season_id']);
+			} else {
+                $testdata =  phpgw::get_var('filter_building_id', 'int', 'REQUEST', null);
+                if ($testdata != 0) {
+                    $filters['building_name'] = $this->bo->so->get_building(phpgw::get_var('filter_building_id', 'int', 'REQUEST', null));        
+                } else {
+                    unset($filters['building_name']);                
+                }
+                $testdata2 =  phpgw::get_var('organizations', 'int', 'REQUEST', null);
+                if ($testdata2 != 0) {
+                    $filters['group_id'] = $this->bo->so->get_group_of_organization(phpgw::get_var('organizations', 'int', 'REQUEST', null));        
+                } else {
+		            unset($filters['group_id']);
+                }
+                $testdata3 =  phpgw::get_var('filter_season_id', 'int', 'REQUEST', null);
+                if ($testdata3 != 0 and $testdata3 != '') {
+                    $filters['season_id'] = $this->bo->so->get_season(phpgw::get_var('filter_season_id', 'int', 'REQUEST', null));        
+                } else {
+                    unset($filters['season_id']);                
+                }
+            }
+            
+			$params = array(
+				'start' => phpgw::get_var('startIndex', 'int', 'REQUEST', 0),
+				'results' => phpgw::get_var('results', 'int', 'REQUEST', null),
+				'query'	=> phpgw::get_var('query'),
+				'sort'	=> phpgw::get_var('sort'),
+				'dir'	=> phpgw::get_var('dir'),
+				'filters' => $filters
+			);
+
+ 			$bookings = $this->bo->so->read($params);
+
 			foreach($bookings['results'] as &$booking) {
 				$building = $this->building_bo->read_single($booking['building_id']);
 				$booking['building_name'] = $building['name'];
@@ -184,6 +239,9 @@
 			$booking = array();
 			$booking['cost'] = 0;
 			$allocation_id = phpgw::get_var('allocation_id', 'int', 'GET');
+			if (isset($_POST['application_id'])) {
+				$application_id = phpgw::get_var('application_id', 'int', 'POST');
+			}	
 			$booking['building_id'] = phpgw::get_var('building_id', 'int', 'GET');
 			$booking['resources'] = phpgw::get_var('resources', 'int', 'GET');
             #The string replace is a workaround for a problem at Bergen Kommune 
@@ -196,8 +254,7 @@
 			if (! isset($allocation_id)) $noallocation = 1;
 			$invalid_dates = array();
 			$valid_dates = array();
-
-
+			
 			if(isset($allocation_id))
 			{
 				$allocation = $this->allocation_bo->read_single($allocation_id);
@@ -216,11 +273,12 @@
                 $noallocation = 1;
             }
 
+
 			if($_SERVER['REQUEST_METHOD'] == 'POST')
 			{
 				$today = getdate();
 				$booking = extract_values($_POST, $this->fields);
-                
+
 				if(strlen($_POST['from_']) < 6) 
 				{
 					$date_from = array($time_from[0], $_POST['from_']);
@@ -265,7 +323,7 @@
 
 				if (!$errors && $_POST['recurring'] != 'on' && $_POST['outseason'] != 'on')
 				{
-                    if( isset($noallocation)) {
+			        if( isset($noallocation)) {
                         $allocation['resources'] = $booking['resources'];
                         $allocation['cost'] = $booking['cost'];
                         $allocation['building_id'] = $booking['building_id'];
@@ -273,6 +331,9 @@
                         $allocation['season_id'] = $booking['season_id'];
                         $allocation['organization_id'] = $booking['organization_id'];
                         $allocation['organization_name'] = $booking['organization_name'];
+						if ($application_id != '0') {
+		                    $allocation['application_id'] = $application_id;
+						}
                         $allocation['from_'] = $booking['from_'];
                         $allocation['to_'] = $booking['to_'];
            				$allocation['active'] = '1';
@@ -332,17 +393,26 @@
                                     $allocation['season_id'] = $booking['season_id'];
                                     $allocation['organization_id'] = $booking['organization_id'];
                                     $allocation['organization_name'] = $booking['organization_name'];
+									if ($application_id != '0') {
+				                        $allocation['application_id'] = $application_id;
+									}
                                     $allocation['from_'] = $booking['from_'];
                                     $allocation['to_'] = $booking['to_'];
                        				$allocation['active'] = '1';
                     				$allocation['completed'] = '0';
                                     $receipt = $this->allocation_bo->add($allocation);
                                     $booking['allocation_id'] = $receipt['id'];
+									if ($application_id != '0') {
+										$booking['application_id'] = $application_id;
+									}
     								$booking['secret'] = $this->generate_secret();
     								$receipt = $this->bo->add($booking);
                                     $booking['allocation_id'] = '';
                                     $this->allocation_bo->so->update_id_string();
                                 } else {
+									if ($application_id != '0') {
+										$booking['application_id'] = $application_id;
+									}
     								$booking['secret'] = $this->generate_secret();
     								$receipt = $this->bo->add($booking);
                                 }
@@ -352,12 +422,20 @@
 					}
 					if ($step == 3) 
 					{
-						$this->redirect(array('menuaction' => 'booking.uimassbooking.schedule', 'id'=>$booking['building_id']));
+						if ($application_id != '0') {
+							$this->redirect(array('menuaction' => 'booking.uiapplication.show', 'id'=>$application_id));
+				
+						} else {
+							$this->redirect(array('menuaction' => 'booking.uimassbooking.schedule', 'id'=>$booking['building_id']));
+						}
 					}
 				}
 			}
-
+			if($allocation['cost'] > 0) {
+				$errors['cost'] = lang('There is a cost of %1 assosiated with the allocation you are useing',$allocation['cost']);
+			}
 			$this->flash_form_errors($errors);
+			unset($errors['cost']);
 			self::add_javascript('booking', 'booking', 'booking.js');
 			array_set_default($booking, 'resources', array());
 			$booking['resources_json'] = json_encode(array_map('intval', $booking['resources']));
@@ -387,7 +465,9 @@
 					'outseason' => $_POST['outseason'],
 					'date_from' => $time_from[0],
 					'date_to' => $time_to[0],
+					'application_id' => $application_id,
                     'noallocation' => $noallocation)
+					
 				);
 			} 
 			else if ($step == 2) 
@@ -406,6 +486,7 @@
 					'valid_dates' => $valid_dates,
 					'invalid_dates' => $invalid_dates,
 					'groups' => $groups,
+					'application_id' => $application_id,
                     'noallocation' => $noallocation)
 				);
 			}
