@@ -164,6 +164,14 @@ phpgw::import_class('booking.sopermission');
 							'label' => lang('Res. Type'),
 							'formatter' => 'YAHOO.booking.formatGenericLink()',
 						),
+						array(
+							'key' => 'event_id',
+							'label' => lang('Event id'),
+						),
+						array(
+							'key' => 'description',
+							'label' => lang('Description'),
+						),
 						array(
 							'key' => 'building_name',
 							'label' => lang('Building'),
@@ -172,6 +180,10 @@ phpgw::import_class('booking.sopermission');
 							'key' => 'organization_name',
 							'label' => lang('Organization'),
 						),
+						array(
+							'key' => 'contact_name',
+							'label' => lang('Contact'),
+						),
 						array(
 							'key' => 'customer_type',
 							'label' => lang('Cust. Type'),
@@ -308,7 +320,46 @@ phpgw::import_class('booking.sopermission');
 				if (empty($reservation['invoice_file_order_id'])) {
 					$reservation['invoice_file_order_id'] = lang("Not Generated");
 				}
-				
+
+				$this->db = & $GLOBALS['phpgw']->db;
+
+				if ($reservation['reservation_type']['label'] == 'Arrangement') {
+					$sql = "select description,contact_name from bb_event where id=".$reservation['reservation_id'];
+					$this->db->limit_query($sql, 0, __LINE__, __FILE__, 1);
+					$this->db->next_record();
+					$reservation['event_id'] = $reservation['reservation_id'];
+					$reservation['description'] = $this->db->f('description', false);
+					$reservation['contact_name'] = $this->db->f('contact_name', false);
+
+				} elseif ($reservation['reservation_type']['label'] == 'Booking') {
+					$sql = "select  application_id from bb_booking where id=".$reservation['reservation_id'];
+					$this->db->limit_query($sql, 0, __LINE__, __FILE__, 1);
+					$this->db->next_record();
+					if (!$this->db->f('application_id', false)) {
+						$reservation['contact_name'] = '';
+					 } else {
+						$sql = "select  contact_name from bb_application where id=".$this->db->f('application_id', false);
+						$this->db->limit_query($sql, 0, __LINE__, __FILE__, 1);
+						$this->db->next_record();
+						$reservation['contact_name'] = $this->db->f('contact_name', false);
+					}
+					$reservation['event_id'] = '';
+					$reservation['description'] = '';
+				} else {
+					$sql = "select  application_id from bb_allocation where id=".$reservation['reservation_id'];
+					$this->db->limit_query($sql, 0, __LINE__, __FILE__, 1);
+					$this->db->next_record();
+					if (!$this->db->f('application_id', false)) {
+						$reservation['contact_name'] = '';
+					 } else {
+						$sql = "select  contact_name from bb_application where id=".$this->db->f('application_id', false);
+						$this->db->limit_query($sql, 0, __LINE__, __FILE__, 1);
+						$this->db->next_record();
+						$reservation['contact_name'] = $this->db->f('contact_name', false);
+					}
+					$reservation['event_id'] = '';
+					$reservation['description'] = '';
+				}
 				$reservation['from_'] = substr($reservation['from_'], 0, -3);
 				$reservation['to_'] = substr($reservation['to_'], 0, -3);
 				$reservation['from_'] = pretty_timestamp($reservation['from_']);
