@@ -73,8 +73,8 @@
                                 'text' => lang('Status').':',
                                 'list' => array(
                                     array(
-                                        'id' => 'not',
-                                        'name' => lang('Not selected')
+                                        'id' => '',
+                                        'name' => lang('All')
                                     ), 
                                     array(
                                         'id' => 'NEW',
@@ -92,10 +92,6 @@
                                         'id' => 'ACCEPTED',
                                         'name' => lang('ACCEPTED')
                                     ),
-                                    array(
-                                        'id' => 'CLOSED',
-                                        'name' => lang('CLOSED')
-                                    )
                                 )
                             ),
 							array('type' => 'autocomplete', 
@@ -116,11 +112,6 @@
 								'value' => $this->show_all_dashboard_applications() ? lang('Show only applications assigned to me') : lang('Show all applications'),
 								'href' => self::link(array('menuaction' => $this->url_prefix.'.toggle_show_all_dashboard_applications'))
 							),
-							array(
-								'type' => 'link',
-								'value' => lang('Show messages'),
-								'href' => self::link(array('menuaction' => 'booking.uisystem_message.index'))
-							),
 						)
 					),
 				),
@@ -136,10 +127,6 @@
 							'key' => 'status',
 							'label' => lang('Status')
 						),
-						array(
-							'key' => 'type',
-							'label' => lang('Type')
-						),
 						array(
 							'key' => 'created',
 							'label' => lang('Created')
@@ -177,7 +164,7 @@
 		public function index_json()
 		{
 			$this->db = $GLOBALS['phpgw']->db;
-			$applications = $this->bo->read_dashboard_data($this->show_all_dashboard_applications() ? null : $this->current_account_id());
+			$applications = $this->bo->read_dashboard_data($this->show_all_dashboard_applications() ? array(null,$this->current_account_id()) : array(1,$this->current_account_id()));
 			foreach($applications['results'] as &$application)
 			{
 				$application['status'] = lang($application['status']);
@@ -205,19 +192,6 @@
 			}
 			array_walk($applications["results"], array($this, "_add_links"), "booking.uiapplication.show");
 
-#			$messages = $this->system_message_bo->read_message_data($this->show_all_dashboard_messages() ? null : $this->current_account_id());
-
-#			if ($this->show_all_dashboard_messages() || $this->show_all_dashboard_applications())
-#			{
-#				if ($this->show_all_dashboard_messages()) {
-#					$applications['results'] = $messages;
-#				}
-#			} else {
-#				foreach($messages as $message)
-#				{
-#					$applications['results'][] = $message;		
-#				} 
-#			}
 			return $this->yui_results($applications);
 		}
 
