@@ -315,6 +315,41 @@
 				$event['is_public'] = 1;
 				$event['building_name'] = $_POST['building_name'];
 
+				if ($_POST['organization_name'] || $_POST['org_id2']) {
+					if ($_POST['organization_name']) {
+						$event['customer_organization_name'] = $_POST['organization_name'];
+						$event['customer_organization_id'] = $_POST['organization_id'];
+						$organization = $this->organization_bo->read_single(intval(phpgw::get_var('organization_id', 'POST')));
+					} else {
+						$orgid = $this->bo->so->get_org($_POST['org_id2']);
+						$event['org_id2'] = $_POST['org_id2'];
+						$event['customer_organization_name'] = $orgid['name'];
+						$event['customer_organization_id'] = $orgid['id'];
+						$organization = $this->organization_bo->read_single(intval($orgid['id']));
+					}
+										
+					if ($organization['customer_internal'] == 0) {
+						$_POST['customer_identifier_type'] = $organization['customer_identifier_type'];
+						$_POST['customer_internal'] = $organization['customer_internal'];
+						if (strlen($organization['customer_organization_number']) == 9) {
+							$_POST['customer_organization_number'] = $organization['customer_organization_number'];
+						} else {
+							$errors['organization_number'] = lang('The organization number is wrong or not present');
+						}
+					} else {
+						$_POST['customer_identifier_type'] = 'organization_number';
+						$_POST['customer_internal'] = $organization['customer_internal'];
+						if ((strlen($organization['customer_number']) == 6) || (strlen($organization['customer_number']) == 5)) {
+ 							$_POST['customer_organization_number'] = $organization['customer_number'];
+						} else {
+							$errors['resource_number'] = lang('The resource number is wrong or not present');
+						}
+					}
+					$_POST['contact_name'] = $organization['contacts'][0]['name'];
+					$_POST['contact_email'] = $organization['contacts'][0]['email'];
+					$_POST['contact_phone'] = $organization['contacts'][0]['phone'];
+				} 
+
 				if (!$_POST['application_id'])
 				{
                     $temp_errors = array();
@@ -352,33 +387,14 @@
 						}
 					}  
 				}
-				if ($_POST['organization_name']) {
-					$event['customer_organization_name'] = $_POST['organization_name'];
-					$event['customer_organization_id'] = $_POST['organization_id'];
-					$organization = $this->organization_bo->read_single(intval(phpgw::get_var('organization_id', 'POST')));
-					if ($organization['customer_internal'] == 0) {
-						$event['customer_identifier_type'] = $organization['customer_identifier_type'];
-						$event['customer_internal'] = $organization['customer_internal'];
-						if (strlen($organization['customer_organization_number']) == 9) {
-							$event['customer_organization_number'] = $organization['customer_organization_number'];
-						} else {
-							$errors['organization_number'] = lang('The organization number is wrong or not present');
-						}
-					} else {
-						$event['customer_identifier_type'] = 'organization_number';
-						$event['customer_internal'] = $organization['customer_internal'];
-						if (strlen($organization['customer_number']) == 5) {
- 							$event['customer_organization_number'] = $organization['customer_number'];
-						} else {
-							$errors['resource_number'] = lang('The resource number is wrong or not present');
-						}
-					}
-				} 
 
 				if ($_POST['cost'] != 0 and !$event['customer_organization_number'] and !$event['customer_ssn']) {
 					$errors['invoice_data'] = lang('There is set a cost, but no invoice data is filled inn');
-				} 
-				if(!$errors['event'] && !$errors['from_'] && !$errors['time'] && !$errors['invoice_data'] && !$errors['resource_number'] && !$errors['organization_number'] && !$errors['contact_name'] && !$errors['cost'])
+				}
+				if(($_POST['organization_name'] != '' or $_POST['org_id2'] != '') and isset($errors['contact_name'])) {
+					$errors['contact_name'] = lang('Organization is missing booking charge');
+				}
+				if(!$errors['event'] && !$errors['from_'] && !$errors['time'] && !$errors['invoice_data'] && !$errors['resource_number'] && !$errors['organization_number'] && !$errors['contact_name'] && !$errors['cost'] && !$errors['activity_id'])
 				{
 					if (!$_POST['application_id'])
 					{
@@ -513,7 +529,7 @@
 					} else {
 						$event['customer_identifier_type'] = 'organization_number';
 						$event['customer_internal'] = $organization['customer_internal'];
-						if (strlen($organization['customer_number']) == 5) {
+						if ((strlen($organization['customer_number']) == 6) || (strlen($organization['customer_number']) == 5)) {
  							$event['customer_organization_number'] = $organization['customer_number'];
 						} else {
 							$errors['resource_number'] = lang('The resource number is wrong or not present');
@@ -533,8 +549,9 @@
 				} 
 
 				if(!$errors['event'] and !$errors['resource_number'] and !$errors['organization_number'] and !$errors['invoice_data']  && !$errors['contact_name'] && !$errors['cost'])
-				{
-					if (phpgw::get_var('mail', 'POST') || phpgw::get_var('sendtorbuilding', 'POST'))
+				{ 
+
+					if ((phpgw::get_var('mail', 'POST') || phpgw::get_var('sendtorbuilding', 'POST')) && phpgw::get_var('active', 'POST'))
 					{
 						if(phpgw::get_var('sendtocollision', 'POST') || phpgw::get_var('sendtocontact', 'POST') || phpgw::get_var('sendtorbuilding', 'POST'))
 						{
@@ -621,12 +638,47 @@
 								}
 								
 							}
-						}				
-						else 
-						{
-						$this->add_comment($event, phpgw::get_var('mail', 'POST'));
-						$this->send_mailnotification($event['contact_email'], lang('Event changed'), phpgw::get_var('mail', 'POST'));
+						} else {
+							$this->add_comment($event, phpgw::get_var('mail', 'POST'));
+							$this->send_mailnotification($event['contact_email'], lang('Event changed'), phpgw::get_var('mail', 'POST'));
 						}
+					} elseif (!phpgw::get_var('active', 'POST')) {
+						
+								if ($event['customer_organization_name']) {
+									$comment_text_log = $event['customer_organization_name'];
+								} else {
+									$comment_text_log = $event['contact_name'];
+								}
+								$comment_text_log = $comment_text_log.' sitt arrangement i '.$event['building_name'].' '.date('d-m-Y H:i', strtotime($event['from_']))." har blitt kansellert.\n For mer opplysinger slå opp i AktivBy.\n\n";
+								$comment_text_log .= phpgw::get_var('mail', 'POST');
+								$comment_text_log = html_entity_decode($comment_text_log);			
+								$sendt = 0;
+								$mail_sendt_to = '';
+
+								if($building_info['email']) {
+									$sendt++;
+									$mail_sendt_to = $mail_sendt_to.' '.$building_info['email'];
+									$this->send_mailnotification($building_info['email'], lang('Event changed'), $comment_text_log);
+								} 
+								if ($_POST['sendtorbuilding_email1']) {
+									$sendt++;
+									$mail_sendt_to = $mail_sendt_to.' '.$_POST['sendtorbuilding_email1'];
+									$this->send_mailnotification($_POST['sendtorbuilding_email1'], lang('Event changed'), $comment_text_log);
+		
+								} 
+								if ($_POST['sendtorbuilding_email2']) {
+									$sendt++;
+									$mail_sendt_to = $mail_sendt_to.' '.$_POST['sendtorbuilding_email2'];
+									$this->send_mailnotification($_POST['sendtorbuilding_email2'], lang('Event changed'), $comment_text_log);
+								}
+								if ($sendt > 0) {
+									$errors['mailtobuilding'] = lang('Unable to send warning, No mailadresses found');
+								} 
+								else 
+								{
+									$comment = $comment_text_log.'. Denne er sendt til '.$mail_sendt_to;
+									$this->add_comment($event,$comment);			
+								}
 					}
 					$receipt = $this->bo->update($event);
 					$this->redirect(array('menuaction' => 'booking.uievent.edit', 'id'=>$event['id']));
