@@ -1,5 +1,9 @@
 colors = ['color1', 'color2', 'color3', 'color4', 'color5', 'color6', 'color7', 'color8', 'color9', 'color10',
-		  'color11', 'color12', 'color13', 'color14', 'color15', 'color16', 'color17', 'color18', 'color19', 'color20'];
+		  'color11', 'color12', 'color13', 'color14', 'color15', 'color16', 'color17', 'color18', 'color19', 'color20',
+          'color21', 'color22', 'color23', 'color24', 'color25', 'color26', 'color27', 'color28', 'color29', 'color30',
+          'color31', 'color32', 'color33', 'color34', 'color35', 'color36', 'color37', 'color38', 'color39', 'color40',
+          'color41', 'color42', 'color43', 'color44', 'color45', 'color46', 'color47', 'color48', 'color49', 'color50',
+          'color51', 'color52', 'color53', 'color54', 'color55', 'color56', 'color57', 'color58', 'color59', 'color60',];
 colorMap = {};
 
 YAHOO.booking.shorten = function(text, max) {
@@ -30,7 +34,7 @@ YAHOO.booking.scheduleResourceColFormatter = function(elCell, oRecord, oColumn,
 YAHOO.booking.frontendScheduleColorFormatter = function(elCell, oRecord, oColumn, booking) { 
 	if(booking) {
 		if(!colorMap[booking.name]) {
-			colorMap[booking.name] = colors.length ? colors.shift() : 'color20';
+			colorMap[booking.name] = colors.length ? colors.shift() : 'color60';
 		}
 		var color = colorMap[booking.name];
 		YAHOO.util.Dom.addClass(elCell, 'info');
@@ -99,7 +103,7 @@ YAHOO.booking.bookingToHtml = function(booking) {
 YAHOO.booking.backendScheduleColorFormatter = function(elCell, oRecord, oColumn, booking) { 
 	if(booking) {
 		if(!colorMap[booking.name]) {
-			colorMap[booking.name] = colors.length ? colors.shift() : 'color20';
+			colorMap[booking.name] = colors.length ? colors.shift() : 'color60';
 		}
 		var color = colorMap[booking.name];
 		YAHOO.util.Dom.addClass(elCell, color);
@@ -114,7 +118,7 @@ YAHOO.booking.backendScheduleColorFormatter = function(elCell, oRecord, oColumn,
 YAHOO.booking.scheduleColorFormatter = function(elCell, oRecord, oColumn, booking) { 
 	if(booking) {
 		if(!colorMap[booking.name]) {
-			colorMap[booking.name] = colors.length ? colors.shift() : 'color20';
+			colorMap[booking.name] = colors.length ? colors.shift() : 'color60';
 		}
 		var color = colorMap[booking.name];
 		YAHOO.util.Dom.addClass(elCell, color);
