@@ -4,7 +4,7 @@
 			'fd' => array(
 				'id' => array('type' => 'auto', 'nullable' => FALSE),
 				'parent_id' => array('type' => 'int','precision' => '4','nullable' => TRUE),
-				'name' => array('type' => 'varchar','precision' => '50','nullable' => FALSE),
+				'name' => array('type' => 'varchar','precision' => '150','nullable' => FALSE),
 				'description' => array('type' => 'varchar','precision' => '10000','nullable' => FALSE),
 				'active' => array('type' => 'int', 'nullable' => False,'precision' => '4', 'default' => 1),
 			),
@@ -22,7 +22,7 @@
 				'deactivate_calendar' => array('type' => 'int', 'nullable' => False,'precision' => '4', 'default' => 0),
 				'deactivate_application' => array('type' => 'int', 'nullable' => False,'precision' => '4', 'default' => 0),
 				'deactivate_sendmessage' => array('type' => 'int', 'nullable' => False,'precision' => '4', 'default' => 0),
-				'name' => array('type' => 'varchar','precision' => '50','nullable' => False),
+				'name' => array('type' => 'varchar','precision' => '150','nullable' => False),
 				'homepage' => array('type' => 'text', 'nullable' => False),
 				'location_code' => array('type' => 'varchar','precision' => '50','nullable' => True),
 				'phone' => array('type' => 'varchar','precision' => '50','nullable' => True),
@@ -55,7 +55,7 @@
 			'fd' => array(
 				'id' => array('type' => 'auto', 'nullable' => false),
 				'ssn' => array('type' => 'varchar', 'precision' => '12', 'nullable' => True,),
-				'name' => array('type' => 'varchar','precision' => '50','nullable' => False),
+				'name' => array('type' => 'varchar','precision' => '150','nullable' => False),
 				'homepage' => array('type' => 'text', 'nullable' => True),
 				'phone' => array('type' => 'varchar','precision' => '50','nullable' => True),
 				'email' => array('type' => 'varchar','precision' => '50','nullable' => True),
@@ -71,7 +71,7 @@
 				'id' => array('type' => 'auto', 'nullable' => false),
 				'organization_number' => array('type' => 'varchar', 'precision' => '9', 'nullable' => False, 'default' => ''),
 				'active' => array('type' => 'int', 'nullable' => False,'precision' => '4', 'default' => 1),
-				'name' => array('type' => 'varchar','precision' => '50','nullable' => False),
+				'name' => array('type' => 'varchar','precision' => '150','nullable' => False),
 				'homepage' => array('type' => 'text', 'nullable' => True),
 				'phone' => array('type' => 'varchar','precision' => '50','nullable' => True),
 				'email' => array('type' => 'varchar','precision' => '50','nullable' => True),
@@ -100,7 +100,7 @@
 				'id' => array('type' => 'auto', 'nullable' => false),
 				'active' => array('type' => 'int', 'nullable' => False,'precision' => '4', 'default' => 1),
 				'building_id' => array('type' => 'int','precision' => '4','nullable' => False),
-				'name' => array('type' => 'varchar','precision' => '50','nullable' => False),
+				'name' => array('type' => 'varchar','precision' => '150','nullable' => False),
 				'type' => array('type' => 'varchar', 'precision' => '50', 'nullable' => False),
 				'description' => array('type' => 'text', 'nullable' => True),
 				'activity_id' => array('type' => 'int','precision' => '4','nullable' => False),
@@ -119,7 +119,7 @@
 				'active' => array('type' => 'int', 'nullable' => False,'precision' => '4', 'default' => 1),
 				'organization_id' => array('type' => 'int','precision' => '4','nullable' => False),
 				'description' => array('type' => 'text', 'nullable' => True),
-				'name' => array('type' => 'varchar','precision' => '50','nullable' => False),
+				'name' => array('type' => 'varchar','precision' => '150','nullable' => False),
 				'activity_id' => array('type' => 'int','precision' => '4','nullable' => True),
 				'shortname' => array('type' => 'varchar','precision' => '11', 'nullable' => True),			
 				'show_in_portal' => array('type' => 'int', 'nullable' => False,'precision' => '4', 'default' => 0),
@@ -137,7 +137,7 @@
 				'officer_id' => array('type' => 'int', 'precision'=> '4', 'nullable' => false),
 				'active' => array('type' => 'int', 'nullable' => False,'precision' => '4', 'default' => 1),
 				'building_id' => array('type' => 'int','precision' => '4','nullable' => False),
-				'name' => array('type' => 'varchar','precision' => '50','nullable' => False),
+				'name' => array('type' => 'varchar','precision' => '150','nullable' => False),
 				'status' => array('type' => 'varchar','precision' => '10','nullable' => False),
 				'from_' => array('type' => 'date','nullable' => False),
 				'to_' => array('type' => 'date','nullable' => False),
@@ -175,7 +175,7 @@
 				'created' => array('type' => 'timestamp', 'nullable'=> False, 'default' => 'current_timestamp'),
 				'modified' => array('type' => 'timestamp', 'nullable'=> False),
 				'frontend_modified' => array('type' => 'timestamp', 'nullable'=> True),
-				'building_name' => array('type' => 'varchar', 'precision' => 50,'nullable' => False),
+				'building_name' => array('type' => 'varchar', 'precision' => 150,'nullable' => False, 'default' => 'changeme'),
 				'activity_id' => array('type' => 'int','precision' => '4','nullable' => False),
 				'description' => array('type' => 'text', 'nullable' => False),
 				'contact_name' => array('type' => 'text', 'nullable' => False),
@@ -203,7 +203,7 @@
 				'id' => array('type' => 'auto', 'nullable' => False),
 				'id_string' => array('type' => 'varchar','precision' => '20', 'nullable' => False, 'default' => '0'),
 				'active' => array('type' => 'int', 'nullable' => False,'precision' => '4', 'default' => 1),
-				'building_name' => array('type' => 'varchar', 'precision' => 50,'nullable' => False),
+				'building_name' => array('type' => 'varchar', 'precision' => 150,'nullable' => False, 'default' => 'changeme'),
 				'application_id' => array('type' => 'int','precision' => '4','nullable' => True),
 				'organization_id' => array('type' => 'int','precision' => '4','nullable' => False),
 				'from_' => array('type' => 'timestamp','nullable' => False),
@@ -226,7 +226,7 @@
 				'group_id' => array('type' => 'int', 'precision' => 4,'nullable' => False),
 				'from_' => array('type' => 'timestamp','nullable' => False),
 				'to_' => array('type' => 'timestamp','nullable' => False),
-				'building_name' => array('type' => 'varchar', 'precision' => 50,'nullable' => False),
+				'building_name' => array('type' => 'varchar', 'precision' => 150,'nullable' => False, 'default' => 'changeme'),
 				'allocation_id' => array('type' => 'int', 'precision' => 4,'nullable' => True),
 				'season_id' => array('type' => 'int', 'precision' => 4,'nullable' => False),
 				'active' => array('type' => 'int', 'precision' => 4,'nullable' => False,'default' => '1'),
@@ -485,7 +485,7 @@
 		'bb_organization_contact' => array(
 			'fd' => array(
 				'id' => array('type' => 'auto', 'nullable' => false),
-				'name' => array('type' => 'varchar', 'precision' => '50', 'nullable' => True),
+				'name' => array('type' => 'varchar', 'precision' => '150', 'nullable' => True),
 				'ssn' => array('type' => 'varchar',  'precision' => '12', 'nullable' => True),
 				'phone' => array('type' => 'varchar', 'precision' => '50', 'nullable' => True),
 				'email' => array('type' => 'varchar', 'precision' => '50', 'nullable' => True),
@@ -501,7 +501,7 @@
 		'bb_group_contact' => array(
 			'fd' => array(
 				'id' => array('type' => 'auto', 'nullable' => false),
-				'name' => array('type' => 'varchar', 'precision' => '50', 'nullable' => True),
+				'name' => array('type' => 'varchar', 'precision' => '150', 'nullable' => True),
 				'phone' => array('type' => 'varchar', 'precision' => '50', 'nullable' => True),
 				'email' => array('type' => 'varchar', 'precision' => '50', 'nullable' => True),
 				'group_id' => array('type' => 'int', 'precision' => '4', 'nullable' => false),
@@ -523,12 +523,12 @@
 				'from_' => array('type' => 'timestamp','nullable' => False),
 				'to_' => array('type' => 'timestamp','nullable' => False),
 				'cost' => array('type' => 'decimal', 'precision' => 10, 'scale' => 2,'nullable' => True,'default' => '0.0'),
-				'building_name' => array('type' => 'varchar', 'precision' => 50,'nullable' => False),
-				'contact_name' => array('type' => 'varchar', 'precision' => 50,'nullable' => False),
+				'building_name' => array('type' => 'varchar', 'precision' => 150,'nullable' => False, 'default' => 'changeme'),
+				'contact_name' => array('type' => 'varchar', 'precision' => 150,'nullable' => False),
 				'contact_email' => array('type' => 'varchar', 'precision' => 50,'nullable' => False),
 				'contact_phone' => array('type' => 'varchar', 'precision' => 50,'nullable' => False),
 				'completed' => array('type' => 'int', 'precision' => 4,'nullable' => False,'default' => '0'),
-				'customer_organization_name' => array('type' => 'varchar', 'precision' => 50,'nullable' => True),
+				'customer_organization_name' => array('type' => 'varchar', 'precision' => 150,'nullable' => True),
 				'customer_organization_id' => array('type' => 'int', 'precision' => 4,'nullable' => True),
 				'customer_identifier_type' => array('type' => 'varchar', 'precision' => 255,'nullable' => True),
 				'customer_organization_number' => array('type' => 'varchar', 'precision' => 9,'nullable' => True),
@@ -640,6 +640,7 @@
 			'fd' => array(
 				'id' 							=> array('type' => 'auto', 'nullable' => False),
 				'filename'				  	=> array('type' => 'text'),
+				'log_filename'				  	=> array('type' => 'text'),
 				'type'				   	=> array('type' => 'text', 'nullable' => False),
 				'total_cost' 				=> array('type' => 'decimal','precision' => '10', 'scale'=>'2', 'nullable' => False),
 				'total_items' 				=> array('type' => 'int','precision' => '4','nullable' => False),
@@ -756,8 +757,8 @@
 				'created' => array('type' => 'timestamp', 'nullable' => False,'default' => 'current_timestamp'),
 				'display_in_dashboard' => array('type' => 'int', 'nullable' => False, 'precision' => '4', 'default' => 1),
 				'building_id' => array('type' => 'int', 'precision' => '4'),
-				'building_name' => array('type' => 'varchar', 'precision' => '50','nullable' => False),
-				'name' => array('type' => 'varchar','precision' => '50','nullable' => False),
+				'building_name' => array('type' => 'varchar', 'precision' => '150','nullable' => False),
+				'name' => array('type' => 'varchar','precision' => '150','nullable' => False),
 				'phone' => array('type' => 'varchar','precision' => '50','nullable' => true),
 				'email' => array('type' => 'varchar','precision' => '50','nullable' => true),
 				'message' => array('type' => 'text', 'nullable' => False),
@@ -769,6 +770,33 @@
 			'ix' => array(),
 			'uc' => array()
 		),
+		'bb_office' => array(
+			'fd' => array(
+				'id' => array('type' => 'auto', 'precision' => 4,'nullable' => False),
+				'name' => array('type' => 'varchar', 'precision' => 200,'nullable' => False),
+				'description' => array('type' => 'text', 'nullable' => true),
+				'user_id' => array('type' => 'int', 'precision' => 4,'nullable' => True),
+				'entry_date' => array('type' => 'int', 'precision' => 4,'nullable' => True),
+				'modified_date' => array('type' => 'int', 'precision' => 4,'nullable' => True),
+			),
+			'pk' => array('id'),
+			'fk' => array(),
+			'ix' => array(),
+			'uc' => array()
+		),
+		'bb_office_user' => array(
+			'fd' => array(
+				'id' => array('type' => 'auto', 'precision' => 4,'nullable' => False),
+				'office' => array('type' => 'int', 'precision' => 4,'nullable' => True),
+				'user_id' => array('type' => 'int', 'precision' => 4,'nullable' => True),
+				'entry_date' => array('type' => 'int', 'precision' => 4,'nullable' => True),
+				'modified_date' => array('type' => 'int', 'precision' => 4,'nullable' => True),
+			),
+			'pk' => array('id'),
+			'fk' => array('bb_office' => array('office' => 'id')),
+			'ix' => array(),
+			'uc' => array()
+		),
 		'bb_documentation' => array(
 			'fd' => array(
 				'id' => array('type' => 'auto', 'nullable' => false),
@@ -780,6 +808,5 @@
 			'fk' => array(),
 			'ix' => array(),
 			'uc' => array()
-		),
-
+		)
 	);
