@@ -9,20 +9,22 @@
   *  Free Software Foundation; either version 2 of the License, or (at your  *
   *  option) any later version.                                              *
   \**************************************************************************/
-	/* $Id: hook_deleteaccount.inc.php 17079 2006-09-05 10:53:10Z skwashd $ */
+	/* $Id: hook_deleteaccount.inc.php 1040 2008-05-26 10:27:54Z dave $ */
+
+	$account_id = phpgw::get_var('account_id', 'int');
+	$new_owner = phpgw::get_var('new_owner', 'int');
 
 	// Delete all records for a user
-	if ( (int)$_POST['new_owner'] == 0)
+	if ( !$new_owner )
 	{
-		ExecMethod('calendar.bocalendar.delete_calendar', $_POST['account_id']);
+		ExecMethod('calendar.bocalendar.delete_calendar', $account_id);
 	}
 	else
 	{
 		ExecMethod('calendar.bocalendar.change_owner',
 			array
 			(
-				'old_owner'	=> $_POST['account_id'],
-				'new_owner'	=> $_POST['new_owner']
+				'old_owner'	=> $account_id,
+				'new_owner'	=> $new_owner
 			));
 	}
-?>
