@@ -9,10 +9,10 @@
   *  Free Software Foundation; either version 2 of the License, or (at your  *
   *  option) any later version.                                              *
   \**************************************************************************/
-	/* $Id: accept_holiday.php 15968 2005-05-15 06:57:38Z skwashd $ */
+	/* $Id: accept_holiday.php 6407 2010-09-26 17:33:13Z sigurd $ */
 
-	$send_back_to = str_replace('submitlocale','holiday_admin',$HTTP_SERVER_VARS['HTTP_REFERER']);
-	$send_back_to = str_replace('submit','admin',$HTTP_SERVER_VARS['HTTP_REFERER']);	// 0.9.14.xxx
+	$send_back_to = str_replace('submitlocale','holiday_admin',$_SERVER['HTTP_REFERER']);
+	$send_back_to = str_replace('submit','admin',$_SERVER['HTTP_REFERER']);	// 0.9.14.xxx
 	if(!$locale)
 	{
 		Header('Location: '.$send_back_to);
@@ -46,8 +46,8 @@
 	<h1>There is already a holiday-file for '<?php echo $locale; ?>' !!!</h1>
 
 	<p>If you think your version of the holidays for '<?php echo $locale; ?>' should replace
-	the existing one, please <a href="<?php echo $HTTP_REFERER; ?>&download=1">download</a> the file
-	and <a href="mailto:phpgroupware-developers@gnu.org">mail it</a> to us.</p>
+	the existing one, please <a href="<?php echo $_SERVER['HTTP_REFERER']; ?>&download=1">download</a> the file
+	and <a href="mailto:fmsystem-developers@nongnu.org">mail it</a> to us.</p>
 
 	<p>To get back to your own phpGroupWare-install <a href="<?php echo $send_back_to; ?>">click here</a>.</p>
 </body>
