@@ -8,7 +8,7 @@
 	* @internal Development of this application was funded by http://www.bergen.kommune.no/bbb_/ekstern/
 	* @package catch
 	* @subpackage catch
- 	* @version $Id: tables_current.inc.php 7147 2011-03-28 14:27:33Z sigurdne $
+ 	* @version $Id: tables_current.inc.php 10797 2013-02-12 12:18:01Z sigurdne $
 	*/
 
 	/*
@@ -29,6 +29,7 @@
 	$phpgw_baseline = array(
 		'fm_catch' => array(
 			'fd' => array(
+				'location_id' => array('type' => 'int','precision' => '4','nullable' => False),
 				'id' => array('type' => 'int','precision' => '4','nullable' => False),
 				'name' => array('type' => 'varchar','precision' => '20','nullable' => False),
 				'descr' => array('type' => 'varchar','precision' => '50','nullable' => True),
@@ -43,6 +44,7 @@
 		),
 		'fm_catch_category' => array(
 			'fd' => array(
+				'location_id' => array('type' => 'int','precision' => '4','nullable' => False),
 				'entity_id' => array('type' => 'int','precision' => '4','nullable' => False),
 				'id' => array('type' => 'int','precision' => '4','nullable' => False),
 				'name' => array('type' => 'varchar','precision' => '100','nullable' => True),
@@ -56,6 +58,8 @@
 				'loc_link' => array('type' => 'int','precision' => '4','nullable' => True),
 				'start_project' => array('type' => 'int','precision' => '4','nullable' => True),
 				'start_ticket' => array('type' => 'int','precision' => '2','nullable' => True),
+				'is_eav' => array('type' => 'int','precision' => '2','nullable' => True),
+				'enable_bulk' => array('type' => 'int','precision' => '2','nullable' => True),
 				'jasperupload' => array('type' => 'int','precision' => 2,'nullable' => True),
 				'parent_id' => array('type' => 'int','precision' => '4','nullable' => True),
 				'level' => array('type' => 'int','precision' => '4','nullable' => True),
@@ -85,6 +89,7 @@
 				'history_owner' => array('type' => 'int','precision' => '4','nullable' => False),
 				'history_status' => array('type' => 'char','precision' => '2','nullable' => False),
 				'history_new_value' => array('type' => 'text','nullable' => False),
+				'history_old_value' => array('type' => 'text','nullable' => true),
 				'history_timestamp' => array('type' => 'timestamp','nullable' => False,'default' => 'current_timestamp')
 			),
 			'pk' => array('history_id'),
@@ -111,7 +116,7 @@
 				'input_type' => array('type' => 'varchar', 'precision' => 10,'nullable' => False),
 				'name' => array('type' => 'varchar', 'precision' => 50,'nullable' => False),
 				'descr' => array('type' => 'varchar', 'precision' => 200,'nullable' => true),
-				'value' => array('type' => 'varchar', 'precision' => 1000,'nullable' => False)
+				'value' => array('type' => 'varchar', 'precision' => 1000,'nullable' => true)
 			),
 			'pk' => array('type_id','id'),
 			'fk' => array(),
