@@ -8,7 +8,7 @@
 	* @internal Development of this application was funded by http://www.bergen.kommune.no/bbb_/ekstern/
 	* @package demo
 	* @subpackage setup
- 	* @version $Id: setup.inc.php 17559 2006-11-19 19:04:33Z sigurdne $
+ 	* @version $Id: setup.inc.php 732 2008-02-10 16:21:14Z sigurd $
 	*/
 
 	$setup_info['demo']['name']      = 'demo';
@@ -61,7 +61,7 @@
 		'preferences',
 		'admin',
 		'help',
-		'sidebox_menu'
+		'menu'	=> 'demo.menu.get_menu'
 	);
 
 	/* Dependencies for this app to work */
