@@ -8,7 +8,7 @@
 	* @copyright Copyright (C) 2003-2005 Free Software Foundation, Inc. http://www.fsf.org/
 	* @license http://www.gnu.org/licenses/gpl.html GNU General Public License
 	* @package email
-	* @version $Id: class.bopreferences.inc.php,v 1.27 2007/01/24 17:19:37 Caeies Exp $
+	* @version $Id: class.bopreferences.inc.php 4237 2009-11-27 23:17:21Z sigurd $
 	* @internal Based on AngleMail http://www.anglemail.org/
 	*/
 
@@ -21,7 +21,7 @@
 	* GLOBALS[phpgw]->msg->expire_session_cache_item("mailserver_callstr")
 	* @package email
 	*/	
-	class bopreferences
+	class email_bopreferences
 	{
 		var $public_functions = array(
 			'preferences' => True,
@@ -55,7 +55,7 @@
 		//var $debug_set_prefs = 4;
 		
 		
-		function bopreferences()
+		public function __construct()
 		{
 			if ($this->debug_set_prefs > 0) { echo 'email.bopreferences *constructor*: ENTERING <br />'; }
 			/*!
@@ -1712,11 +1712,12 @@
 							$accountname = 'unknown accountname on ('.__LINE__.')';
 						}
 						
-						$return_list[$next_pos]['go_there_url'] = $GLOBALS['phpgw']->link(
-														'/index.php',
-														 'menuaction=email.uiindex.index'
-														.'&fldball[folder]=INBOX'
-														.'&fldball[acctnum]='.$this_acctnum);
+						$return_list[$next_pos]['go_there_url'] = $GLOBALS['phpgw']->link('/index.php', array
+															(
+															'menuaction' => 'email.uiindex.index',
+															'fldball[folder]' => 'INBOX',
+															'fldball[acctnum]' => $this_acctnum
+															));
 						$return_list[$next_pos]['go_there_href'] = '<a href="'.$return_list[$next_pos]['go_there_url'].'">'.lang('go').'</a>';
 					}
 					// NEXT: html encode the acctname string
@@ -1730,15 +1731,18 @@
 					$return_list[$next_pos]['display_string'] = '['.$this_acctnum.'] '.$accountname;
 					
 					// NEXT: control action links
-					$return_list[$next_pos]['edit_url'] = $GLOBALS['phpgw']->link(														'/index.php',
-														 'menuaction=email.uipreferences.ex_accounts_edit'
-														.'&ex_acctnum='.$this_acctnum);
+					$return_list[$next_pos]['edit_url'] = $GLOBALS['phpgw']->link('/index.php', array
+														(
+														 	'menuaction' => 'email.uipreferences.ex_accounts_edit',
+															'ex_acctnum' => $this_acctnum
+														));
 					$return_list[$next_pos]['edit_href'] = '<a href="'.$return_list[$next_pos]['edit_url'].'">'.lang('Edit').'</a>';
 
-					$return_list[$next_pos]['delete_url'] = $GLOBALS['phpgw']->link(
-														'/index.php',
-														 'menuaction=email.bopreferences.ex_accounts_delete'
-														.'&ex_acctnum='.$this_acctnum);
+					$return_list[$next_pos]['delete_url'] = $GLOBALS['phpgw']->link('/index.php', array
+														 (
+														 	'menuaction' => 'email.bopreferences.ex_accounts_delete',
+															'ex_acctnum' => $this_acctnum
+														));
 					$return_list[$next_pos]['delete_href'] = '<a href="'.$return_list[$next_pos]['delete_url'].'">'.lang('Delete').'</a>';
 				}
 			}
