@@ -8,7 +8,7 @@
 	* @copyright Copyright (C) 2003-2005 Free Software Foundation, Inc. http://www.fsf.org/
 	* @license http://www.gnu.org/licenses/gpl.html GNU General Public License
 	* @package email
-	* @version $Id: class.bosend.inc.php,v 1.15 2006/12/18 11:02:13 sigurdne Exp $
+	* @version $Id: class.bosend.inc.php 4237 2009-11-27 23:17:21Z sigurd $
 	* @internal Based on AngleMail http://www.anglemail.org/
 	* @internal Server side attachment storage technique borrowed from Squirrelmail
 	*/
@@ -71,7 +71,8 @@
 		*/
 		function get_originating_ip()
 		{
-			$got_ip = '';
+			$got_ip = phpgw::get_var('HTTP_X_FORWARDED_FOR', 'ip', 'SERVER', phpgw::get_var('REMOTE_ADDR', 'ip', 'SERVER'));
+		/*
 			if (is_object($GLOBALS['phpgw']->session))
 			{
 				$got_ip = $GLOBALS['phpgw']->session->getuser_ip();
@@ -80,7 +81,7 @@
 			{
 				$got_ip = $_SERVER['REMOTE_ADDR'];
 			}
-			
+		*/	
 			// did we get anything useful ?
 			if (trim((string)$got_ip) == '')
 			{
@@ -188,10 +189,11 @@
 				$dh = dir($upload_dir);
 				while ( ($file = $dh->read() ) !== false )
 				{
-					if( $file != '.' && $file != '..' )
+					if( $file == '.' || $file == '..' )
 					{
-						unlink($upload_dir . SEP . $file);
+						continue;
 					}
+					unlink("{$upload_dir}/{$file}");
 				}
 				$dh->close();
 				rmdir($upload_dir);
@@ -329,7 +331,7 @@
 		function send()
 		{
 			
-			$this->smtp = createObject('email.mail_smtp');
+			$this->smtp = createObject('phpgwapi.mailer_smtp');
 			
 			$this->prepare_message();
 
@@ -365,6 +367,7 @@
 			if ($returnccode)
 			{
 				// Success
+				/*
 				if ($GLOBALS['phpgw']->mail_send->trace_flag > 0)
 				{
 					// for debugging
@@ -379,7 +382,7 @@
 					echo '</body></html>';
 					$this->send_message_cleanup();
 				}
-				else
+				else*/
 				{
 					// unset some vars (is this necessary?)
 					$this->send_message_cleanup();
@@ -505,7 +508,7 @@
 			i.e. with NO ENCODED HTML ENTITIES, so use > instead of $rt; and " instead of &quot; . etc...
 			it's up to the endusers MUA to handle any htmlspecialchars, whether to encode them or leave as it, the MUA should decide 
 			*/
-			$body = $GLOBALS['phpgw']->msg->htmlspecialchars_decode($body);
+			$this->smtp->Body = $GLOBALS['phpgw']->msg->htmlspecialchars_decode($this->smtp->Body);
 			
 			// ----  Add Email Sig to Body   -----
 			if (($GLOBALS['phpgw']->msg->get_isset_pref('email_sig'))
@@ -519,7 +522,7 @@
 				$user_sig = $GLOBALS['phpgw']->msg->get_pref_value('email_sig');
 				// html_quotes_decode may be obsoleted someday:  workaround for a preferences database issue (<=pgpgw ver 0.9.13)
 				$user_sig = $GLOBALS['phpgw']->msg->html_quotes_decode($user_sig);
-				$body = $body."\r\n"
+				$this->smtp->Body = $this->smtp->Body."\r\n"
 						."\r\n"
 						.'-- '."\r\n" 
 						.$user_sig ."\r\n";
@@ -723,9 +726,9 @@
 					&& ( strpos($file, '.info') )
 					)
 					{
-						$meta_data = explode("\n", file_get_contents($upload_dir . SEP . $file) );
+						$meta_data = explode("\n", file_get_contents("{$upload_dir}/{$file}") );
 						$real_file = substr($file, 0, strpos($file, '.info'));
-						$this->smtp->AddAttachment( $upload_dir .SEP. $real_file, 
+						$this->smtp->AddAttachment( "{$upload_dir}/{$real_file}", 
 								trim($meta_data[1]), 
 								'base64', 
 								trim($meta_data[0]) );
