@@ -8,10 +8,14 @@
 	* @copyright Copyright (C) 2001-2005 Free Software Foundation, Inc. http://www.fsf.org/
 	* @license http://www.gnu.org/licenses/lgpl.html GNU Lessser General Public License
 	* @package email
-	* @version $Id: class.mail_dcom_base_sock.inc.php,v 1.29 2005/05/11 19:15:34 powerstat Exp $
+	* @version $Id: class.mail_dcom_base_sock.inc.php 4237 2009-11-27 23:17:21Z sigurd $
 	* @internal Based on AngleMail http://www.anglemail.org/
 	*/
 
+	/**
+	 * Import the the network class which we extend
+	 */
+	phpgw::import_class('phpgwapi.network');
 
 	/**
 	 * Set status->messages to the number of messages in the mailbox
@@ -476,8 +480,8 @@
 			$this->network(True);
 			if (isset($GLOBALS['phpgw_info']))
 			{
-				$this->tempfile = $GLOBALS['phpgw_info']['server']['temp_dir'].SEP.$GLOBALS['phpgw_info']['user']['sessionid'].'.mhd';
-				$this->att_files_dir = $GLOBALS['phpgw_info']['server']['temp_dir'].SEP.$GLOBALS['phpgw_info']['user']['sessionid'];
+				$this->tempfile = "{$GLOBALS['phpgw_info']['server']['temp_dir']}/" . $GLOBALS['phpgw']->common->randomstring() . '.mhd';
+				$this->att_files_dir = "{$GLOBALS['phpgw_info']['server']['temp_dir']}/{$GLOBALS['phpgw_info']['user']['sessionid']}";
 			}
 			else
 			{
@@ -1366,4 +1370,3 @@
 			return $file;
 		}
 	}
-?>
