@@ -10,7 +10,7 @@
 	* Free Software Foundation; either version 2 of the License, or (at your    *
 	* option) any later version.                                                *
 	\***************************************************************************/
-	/* $Id: class.emailadmin_bo.inc.php 6237 2010-08-14 19:51:45Z sigurd $ */
+	/* $Id: class.emailadmin_bo.inc.php 7026 2011-02-21 07:59:06Z sigurdne $ */
 
 	class emailadmin_bo
 	{
@@ -488,7 +488,16 @@
 				// fetch the IMAP / incomming server data
 				$icClass = isset($this->IMAPServerType[$data['imapType']]) ? $this->IMAPServerType[$data['imapType']]['classname'] : 'defaultimap';
 
-				$icServer =& CreateObject('emailadmin.'.$icClass);
+				try
+				{
+					$icServer =& CreateObject('emailadmin.'.$icClass);
+				}
+				catch(Exception $e)
+				{
+					phpgwapi_cache::message_set($e->getMessage(), 'error');
+					return false;
+				}
+
 				$icServer->encryption	= ($data['imapTLSEncryption'] == 'yes' ? 1 : (int)$data['imapTLSEncryption']);
 				$icServer->host		= $data['imapServer'];
 				$icServer->port 	= $data['imapPort'];
