@@ -10,7 +10,11 @@
 	* under the terms of the GNU General Public License as published by the     *
 	* Free Software Foundation; version 2 of the License.                       *
 	\***************************************************************************/
-	/* $Id: class.uifelamimail.inc.php 4237 2009-11-27 23:17:21Z sigurd $ */
+	/* $Id: class.uifelamimail.inc.php 7026 2011-02-21 07:59:06Z sigurdne $ */
+	if(! is_file(PHPGW_INCLUDE_ROOT.'/felamimail/inc/egw-pear/Net/IMAP.php'))
+	{
+		throw new Exception('missing egw-pear package');
+	}
 
 	class uifelamimail
 	{
