@@ -1,9 +1,9 @@
 <?php
 	/***************************************************************************\
-	* phpGroupWare - FeLaMiMail                                                 *
+	* eGroupWare - FeLaMiMail                                                   *
 	* http://www.linux-at-work.de                                               *
 	* http://www.phpgw.de                                                       *
-	* http://www.phpgroupware.org                                               *
+	* http://www.egroupware.org                                                 *
 	* Written by : Lars Kneschke [lkneschke@linux-at-work.de]                   *
 	* -------------------------------------------------                         *
 	* This program is free software; you can redistribute it and/or modify it   *
@@ -11,7 +11,7 @@
 	* Free Software Foundation; either version 2 of the License, or (at your    *
 	* option) any later version.                                                *
 	\***************************************************************************/
-	/* $Id: class.uifilter.inc.php 17984 2007-02-22 10:43:10Z sigurdne $ */
+	/* $Id: class.uifilter.inc.php 4237 2009-11-27 23:17:21Z sigurd $ */
 
 	class uifilter
 	{
@@ -26,21 +26,26 @@
 		{
 			
 			// get posted variables
-			$this->urlMailbox	= isset($GLOBALS['HTTP_GET_VARS']['mailbox'])?urldecode($GLOBALS['HTTP_GET_VARS']['mailbox']):'';
-			$this->startMessage	= isset($GLOBALS['HTTP_GET_VARS']['startMessage'])?$GLOBALS['HTTP_GET_VARS']['startMessage']:'';
-			$this->sort		= isset($GLOBALS['HTTP_GET_VARS']['sort'])?$GLOBALS['HTTP_GET_VARS']['sort']:'';
+			$this->urlMailbox	= urldecode($_GET['mailbox']);
+			$this->startMessage	= $_GET['startMessage'];
+			$this->sort		= $_GET['sort'];
 			
-			$this->bofelamimail	= CreateObject('felamimail.bofelamimail',$this->urlMailbox);
-			$this->bofilter		= CreateObject('felamimail.bofilter');
+			$this->bofelamimail	=& CreateObject('felamimail.bofelamimail',$this->urlMailbox);
+			$this->bofilter		=& CreateObject('felamimail.bofilter');
 			$this->sessionData	= $this->bofelamimail->sessionData;
 
-			$this->t = CreateObject('phpgwapi.Template',PHPGW_APP_TPL);
+			$this->t =& CreateObject('phpgwapi.Template',PHPGW_APP_TPL);
 			$this->t->set_unknowns('remove');
+			
+			$this->rowColor[0] = $GLOBALS['phpgw_info']["theme"]["bg01"];
+			$this->rowColor[1] = $GLOBALS['phpgw_info']["theme"]["bg02"];
+
 		}
 		
 		function display_app_header()
 		{
-			$GLOBALS['phpgw']->common->phpgw_header();
+			$GLOBALS['phpgw_info']['flags']['include_xajax'] = True;
+			$GLOBALS['phpgw']->common->egw_header();
 			echo parse_navbar();
 		}
 
@@ -57,17 +62,17 @@
 			// translate most of the parts
 			$this->translate();
 			
-			switch(isset($GLOBALS['HTTP_GET_VARS']['action'])?$GLOBALS['HTTP_GET_VARS']['action']:'')
+			switch($_GET['action'])
 			{
 				case "deleteFilter":
-					$filterID = $GLOBALS['HTTP_GET_VARS']['filterID'];
+					$filterID = $_GET['filterID'];
 					$this->bofilter->deleteFilter($filterID);
 					$filterList = $this->bofilter->getFilterList();
-					$linkData = array
-					(
-						'menuaction'    => 'felamimail.uifilter.mainScreen',
-						'action'	=> 'updateFilter'
-					);
+														$linkData = array
+														(
+																		'menuaction'    => 'felamimail.uifilter.mainScreen',
+																		'action'	=> 'updateFilter'
+														);
 					$this->t->set_var('link_action',$GLOBALS['phpgw']->link('/index.php',$linkData));
 
 					$this->t->set_var("filterName",'');
@@ -78,63 +83,63 @@
 					break;
 					
 				case "editFilter":
-					$filterID = $GLOBALS['HTTP_GET_VARS']['filterID'];
+					$filterID = $_GET['filterID'];
 					$filterList = $this->bofilter->getFilterList();
 					
-					// set the default values for the sort links (sort by url)
-					$linkData = array
-        		    (
-						'menuaction'    => 'felamimail.uifilter.mainScreen',
-						'action'	=> 'updateFilter',
-						'filterID'	=> $filterID
-					);
+														// set the default values for the sort links (sort by url)
+														$linkData = array
+														(
+																		'menuaction'    => 'felamimail.uifilter.mainScreen',
+																		'action'	=> 'updateFilter',
+																		'filterID'	=> $filterID
+														);
 					$this->t->set_var('link_action',$GLOBALS['phpgw']->link('/index.php',$linkData));
 
 					$this->t->set_var("filterName",$filterList[$filterID]['filterName']);
-					$this->t->set_var("from",(isset($filterList[$filterID]['from'])?$filterList[$filterID]['from']:''));
-					$this->t->set_var("to",(isset($filterList[$filterID]['to'])?$filterList[$filterID]['to']:''));
-					$this->t->set_var("subject",(isset($filterList[$filterID]['subject'])?$filterList[$filterID]['subject']:''));
-					if(isset($filterList[$filterID]['filterActive']) && $filterList[$filterID]['filterActive'] == "true")
+					$this->t->set_var("from",$filterList[$filterID]['from']);
+					$this->t->set_var("to",$filterList[$filterID]['to']);
+					$this->t->set_var("subject",$filterList[$filterID]['subject']);
+					if($filterList[$filterID]['filterActive'] == "true")
 					{
 						$this->t->set_var("filter_checked","checked");
 					}
 					break;
 				case "updateFilter":
-					$filterID = isset($GLOBALS['HTTP_GET_VARS']['filterID'])?$GLOBALS['HTTP_GET_VARS']['filterID']:'';
-					$formData['from']		= $GLOBALS['HTTP_POST_VARS']['from'];
-					$formData['to']			= $GLOBALS['HTTP_POST_VARS']['to'];
-					$formData['subject']		= $GLOBALS['HTTP_POST_VARS']['subject'];
-					$formData['filterName']		= $GLOBALS['HTTP_POST_VARS']['filterName'];
-					if(isset($GLOBALS['HTTP_POST_VARS']['filter_active']) && $GLOBALS['HTTP_POST_VARS']['filter_active'] == "on")
+					$filterID = $_GET['filterID'];
+					$formData['from']		= $_POST['from'];
+					$formData['to']			= $_POST['to'];
+					$formData['subject']		= $_POST['subject'];
+					$formData['filterName']		= $_POST['filterName'];
+					if($_POST['filter_active'] == "on")
 					{
 						$formData['filterActive']	= "true";
 					}
 					$this->bofilter->saveFilter($formData, $filterID);
 					$filterList = $this->bofilter->getFilterList();
-					// set the default values for the sort links (sort by url)
-					$linkData = array
-					(
-						'menuaction'    => 'felamimail.uifilter.mainScreen',
-						'action'	=> 'updateFilter',
-						'filterID'	=> $filterID
-					);
+														// set the default values for the sort links (sort by url)
+														$linkData = array
+														(
+																		'menuaction'    => 'felamimail.uifilter.mainScreen',
+																		'action'	=> 'updateFilter',
+																		'filterID'	=> $filterID
+														);
 					$this->t->set_var('link_action',$GLOBALS['phpgw']->link('/index.php',$linkData));
 
-					$this->t->set_var("filterName",isset($filterList[$filterID]['filterName'])?$filterList[$filterID]['filterName']:'');
-					$this->t->set_var("from",isset($filterList[$filterID]['from'])?$filterList[$filterID]['from']:'');
-					$this->t->set_var("to",isset($filterList[$filterID]['to'])?$filterList[$filterID]['to']:'');
-					$this->t->set_var("subject",isset($filterList[$filterID]['subject'])?$filterList[$filterID]['subject']:'');
-					if(isset($filterList[$filterID]['filterActive']) && $filterList[$filterID]['filterActive'] == "true")
+					$this->t->set_var("filterName",$filterList[$filterID]['filterName']);
+					$this->t->set_var("from",$filterList[$filterID]['from']);
+					$this->t->set_var("to",$filterList[$filterID]['to']);
+					$this->t->set_var("subject",$filterList[$filterID]['subject']);
+					if($filterList[$filterID]['filterActive'] == "true")
 					{
 						$this->t->set_var("filter_checked","checked");
 					}
 					break;
 				default:
-        		    $linkData = array
-        		    (
-						'menuaction'    => 'felamimail.uifilter.mainScreen',
-						'action'	=> 'updateFilter'
-					);
+														$linkData = array
+														(
+																		'menuaction'    => 'felamimail.uifilter.mainScreen',
+																		'action'	=> 'updateFilter'
+														);
 					$this->t->set_var('link_action',$GLOBALS['phpgw']->link('/index.php',$linkData));
 
 					$this->t->set_var("filterName",'');
@@ -143,11 +148,12 @@
 					$this->t->set_var("subject",'');
 					$this->t->set_var("filter_checked",'');
 					break;
+					
 			}
-			$linkData = array
-			(
-				'menuaction'    => 'felamimail.uifilter.mainScreen'
-			);
+									$linkData = array
+									(
+													'menuaction'    => 'felamimail.uifilter.mainScreen'
+									);
 			$this->t->set_var('link_newFilter',$GLOBALS['phpgw']->link('/index.php',$linkData));
 			$this->t->set_var("filterrows",'');
 			$linkData = array
@@ -160,12 +166,8 @@
 			
 			$filterList = $this->bofilter->getFilterList();
 			
-			$i = 0;
 			while(list($key,$value)=@each($filterList))
 			{
-				$row_class = $i % 2 ? 'row_on' : 'row_off';
-				$i++;
-				$this->t->set_var("row_class",$row_class);
 				$this->t->set_var("id",$key);
 				$this->t->set_var("filtername",$value['filterName']);
 
@@ -218,7 +220,7 @@
 			$this->t->set_var("lang_new_filter",lang('new filter'));
 			$this->t->set_var("lang_no_filter",lang('no filter'));
 			$this->t->set_var("lang_activate",lang('activate'));
-			$this->t->set_var("lang_add",lang('add'));
+			$this->t->set_var("lang_save",lang('save'));
 
 			$this->t->set_var("bg01",$GLOBALS['phpgw_info']["theme"]["bg01"]);
 			$this->t->set_var("bg02",$GLOBALS['phpgw_info']["theme"]["bg02"]);
