@@ -11,7 +11,7 @@
 	*  Free Software Foundation; either version 2 of the License, or (at your  *
 	*  option) any later version.                                              *
 	\**************************************************************************/
-	/* $Id: index.php 4237 2009-11-27 23:17:21Z sigurd $ */
+	/* $Id: index.php 7026 2011-02-21 07:59:06Z sigurdne $ */
 
 	// this is to get css inclusion working
 	$_GET['menuaction']	= 'felamimail.uifelamimail.viewMainScreen';
@@ -26,5 +26,13 @@
 								
 	include('../header.inc.php');
 
-	execmethod('felamimail.uifelamimail.viewMainScreen');
+	try
+	{
+		execmethod('felamimail.uifelamimail.viewMainScreen');
+	}
+	catch(Exception $e)
+	{
+		phpgwapi_cache::message_set($e->getMessage(), 'error');
+		$GLOBALS['phpgw']->redirect_link('/home.php');
+	}
 ?>
