@@ -6,7 +6,7 @@
 	* @copyright Copyright (C) 2000-2005 Free Software Foundation, Inc http://www.fsf.org/
 	* @license http://www.gnu.org/licenses/gpl.html GNU General Public License
 	* @package filemanager
-	* @version $Id: class.uiaction_base.inc.php 1040 2008-05-26 10:27:54Z dave $
+	* @version $Id: class.uiaction_base.inc.php 7125 2011-03-15 10:30:56Z sigurdne $
 	*/
 
 	/**
@@ -41,7 +41,9 @@
 
 			//_debug_array($this->bofilemanager->help_info);
 
-			$key = $this->bofilemanager->help_name;
+			//$key = $this->bofilemanager->help_name;
+			$key = urldecode(phpgw::get_var('help_name', 'string'));
+
 			if($this->bofilemanager->help_info[$key])
 			{
 				$msg = $this->bofilemanager->help_info[$key];
