@@ -8,7 +8,7 @@
 	* @copyright Portions Copyright (C) 2000-2005 Free Software Foundation, Inc http://www.fsf.org/
 	* @license http://www.gnu.org/licenses/gpl.html GNU General Public License
 	* @package filemanager
-	* @version $Id: class.uifilemanager.inc.php,v 1.39 2007/01/24 17:15:53 Caeies Exp $
+	* @version $Id: class.uifilemanager.inc.php 1906 2008-11-28 22:47:27Z sigurd $
 	* @internal Based on phpWebhosting
 	*/
 
@@ -93,7 +93,7 @@
 			$this->bofilemanager->f_update();
 
 			$this->config = CreateObject('phpgwapi.config','filemanager');
-			$this->config->read_repository();
+			$this->config->read();
 			if ($this->config->config_data)
 			{
 				$this->config_items = $this->config->config_data;
@@ -158,7 +158,7 @@
 			$show_upload_box = get_var('show_upload_boxes', 'GET');
 			if($show_upload_box)
 			{
-				$GLOBALS['phpgw']->preferences->read_repository();
+				$GLOBALS['phpgw']->preferences->read();
 				$GLOBALS['phpgw']->preferences->change('filemanager','show_upload_boxes',$show_upload_box);
 				$GLOBALS['phpgw']->preferences->save_repository();
 				$this->bofilemanager->show_upload_boxes = $show_upload_box;
@@ -242,7 +242,7 @@
 
 								if(!$this->bofilemanager->settings['name'])
 								{
-									$GLOBALS['phpgw']->preferences->read_repository();
+									$GLOBALS['phpgw']->preferences->read();
 									$GLOBALS['phpgw']->preferences->change('filemanager','name','name');
 									$GLOBALS['phpgw']->preferences->save_repository();
 								}
@@ -276,7 +276,7 @@
 								
 								if(!$this->bofilemanager->settings['comment'])
 								{
-									$GLOBALS['phpgw']->preferences->read_repository();
+									$GLOBALS['phpgw']->preferences->read();
 									$GLOBALS['phpgw']->preferences->change('filemanager','comment','comment');
 									$GLOBALS['phpgw']->preferences->save_repository();
 								}
@@ -457,7 +457,7 @@
 						);
 
 						$ls_array = $GLOBALS['phpgw']->vfs->ls(array(
-						'string' => $this->bofilemanager->fakebase.SEP.$GLOBALS['phpgw']->accounts->id2lid($group_array['account_id']),
+						'string' => "{$this->bofilemanager->fakebase}/" . $GLOBALS['phpgw']->accounts->id2lid($group_array['account_id']),
 						'relatives' => Array(RELATIVE_NONE),
 						'checksubdirs'	=> True,
 						'mime_type' => 'Directory'
@@ -483,7 +483,7 @@
 
 						if($dir['directory'] != '/')
 						{
-							$dir['directory'] .= SEP;
+							$dir['directory'] .= '/';
 						}
 
 						// No point in displaying the current directory, or a directory that doesn't exist
@@ -1311,7 +1311,7 @@
 				$this->bofilemanager->path = $file_array['path'];
 				$this->bofilemanager->file = $file_array['file'];
 			}
-			$file = $this->bofilemanager->path.SEP.$this->bofilemanager->file;
+			$file = "{$this->bofilemanager->path}/{$this->bofilemanager->file}";
 			if($GLOBALS['phpgw']->vfs->file_exists(array('string' => $file,'relatives' => Array(RELATIVE_NONE))))
 			{
 				$ls_array = $GLOBALS['phpgw']->vfs->ls(array('string' => $file,'relatives' => array (RELATIVE_ALL),'checksubdirs' => False,'nofiles' => True));
@@ -1357,7 +1357,7 @@
 		
 				if(is_array($values))
 				{
-					$GLOBALS['phpgw']->preferences->read_repository();
+					$GLOBALS['phpgw']->preferences->read();
 					$GLOBALS['phpgw']->preferences->delete('filemanager','');
 
 					foreach($values as $key => $value)
@@ -1628,7 +1628,7 @@
 
 			if($_POST['save'] || $_GET['delete_script'])
 			{
-				$this->config->read_repository();
+				$this->config->read();
 				if ($this->config->config_data)
 				{
 					$this->config_items	= $this->config->config_data;
