@@ -6,7 +6,7 @@
 	* @license http://www.gnu.org/licenses/gpl.html GNU General Public License
 	* @package filemanager
 	* @subpackage setup
-	* @version $Id: setup.inc.php 690 2008-02-02 10:11:33Z dave $
+	* @version $Id: setup.inc.php 7121 2011-03-15 08:53:24Z sigurdne $
 	*/
 
 	$setup_info['filemanager'] = array
@@ -25,10 +25,11 @@
 		'hooks'				=> array
 		(
 			'add_def_pref',
-			'admin',
+//			'admin',
 			'deleteaccount',
-			'preferences',
-			'sidebox_menu'
+//			'preferences',
+//			'sidebox_menu'
+			'menu'	=> 'filemanager.menu.get_menu'
 		));
 
 	/* Dependencies for this app to work */
