@@ -7,7 +7,7 @@
 	 * @copyright Copyright (C) 2010 Free Software Foundation, Inc. http://www.fsf.org/
 	 * @license http://www.gnu.org/licenses/gpl.html GNU General Public License
 	 * @package Frontend
-	 * @version $Id: class.uientity.inc.php 7224 2011-04-15 11:48:27Z sigurdne $
+	 * @version $Id: class.uientity.inc.php 11387 2013-10-23 13:18:01Z sigurdne $
 	 */
 
 	/*
@@ -45,13 +45,14 @@
 
 		public function __construct()
 		{
+			$GLOBALS['phpgw']->translation->add_app('property');
 			$this->location_id			= phpgw::get_var('location_id', 'int', 'REQUEST', 0);
 			$location_info				= $GLOBALS['phpgw']->locations->get_name($this->location_id);
 			$this->acl_location			= $location_info['location'];
 			$location_arr				= explode('.', $this->acl_location);
 
 			$this->account				= $GLOBALS['phpgw_info']['user']['account_id'];
-			$this->bo					= CreateObject('property.boentity',true);
+			$this->bo					= CreateObject('property.boentity');
 			$this->bocommon				= & $this->bo->bocommon;
 			$this->soadmin_entity		= & $this->bo->soadmin_entity;
 
@@ -163,7 +164,6 @@
 			}
 
 			$datatable = array();
-			$values_combo_box = array();
 
 			if($this->cat_id)
 			{
@@ -198,10 +198,6 @@
 				// this array "$arr_filter_hide" indicate what filters are hidden or not
 				$arr_filter_hide = array();
 
-				$values_combo_box[0]  = $this->bo->get_criteria_list($this->criteria_id);
-				$default_value = array ('id'=>'','name'=>lang('no criteria'));
-				array_unshift ($values_combo_box[0],$default_value);
-
 				$datatable['actions']['form'] = array
 					(
 						array
@@ -317,17 +313,41 @@
 
 				$custom	= createObject('phpgwapi.custom_fields');
 				$attrib_data = $custom->find($this->type_app[$this->type],".{$this->type}.{$this->entity_id}.{$this->cat_id}", 0, '','','',true, true);
+
+				$button_def = array();
+				$code_inner = array();
+
+				$values_combo_box = array();
 /*
+				$values_combo_box[0]  = $this->bo->get_criteria_list($this->criteria_id);
+				$default_value = array ('id'=>'','name'=>lang('no criteria'));
+				array_unshift ($values_combo_box[0],$default_value);
+
+				$datatable['actions']['form'][0]['fields']['field'][] = array
+				(
+					'id' => 'btn_criteria_id',
+					'name' => 'criteria_id',
+					'value'	=> lang('search criteria'),
+					'type' => 'button',
+					'style' => 'filter',
+					'tab_index' => 0
+				);
+
+				$datatable['actions']['form'][0]['fields']['hidden_value'][] = array
+				(
+					'id' 	=> "values_combo_box_0",
+					'value'	=> $this->bocommon->select2String($values_combo_box[0])						
+				);
+
 				$button_def[] = "oMenuButton_0";
 				$code_inner[] = "{order:0, var_URL:'criteria_id',name:'btn_criteria_id',style:'genericbutton',dependiente:[]}";
 */
-
 				if($attrib_data)
 				{
 					$i = 0;
 					foreach ( $attrib_data as $attrib )
 					{
-						if($attrib['datatype'] == 'LB' || $attrib['datatype'] == 'CH' || $attrib['datatype'] == 'R')
+						if(($attrib['datatype'] == 'LB' || $attrib['datatype'] == 'CH' || $attrib['datatype'] == 'R') && $attrib['choice'])
 						{
 							$datatable['actions']['form'][0]['fields']['field'][] = array
 							(
@@ -368,8 +388,15 @@
 					}
 				}
 
-				$code = 'var ' . implode(',', $button_def)  . ";\n";
-				$code .= 'var selectsButtons = [' . "\n" . implode(",\n",$code_inner) . "\n];";
+				if($button_def)
+				{
+					$code = 'var ' . implode(',', $button_def)  . ";\n";
+					$code .= 'var selectsButtons = [' . "\n" . implode(",\n",$code_inner) . "\n];";
+				}
+				else
+				{
+					$code .= 'var selectsButtons = [];';
+				}
 
 				$GLOBALS['phpgw']->js->add_code('', $code);
 
@@ -400,6 +427,20 @@
 
 			$uicols = $this->bo->uicols;
 
+			$j	= count($uicols['name']);
+			for ($i=0;$i<$j;$i++)
+			{
+				switch ($uicols['name'][$i])
+				{
+					case 'entry_date':
+						$uicols['input_type'][$i] = 'hidden';
+						break;
+				
+				}
+			}
+
+
+
 			$uicols['name'][]		= 'img_id';
 			$uicols['descr'][]		= 'dummy';
 			$uicols['sortable'][]	= false;
@@ -429,11 +470,63 @@
 			$uicols['sortable'][]	= false;
 			$uicols['sort_field'][]	= '';
 			$uicols['format'][]		= '';
-			$uicols['formatter'][]	= 'show_picture';
+			/**
+			* def of next $uicols['formatter'][] is moved down
+			*
+			*/
 			$uicols['input_type'][]	= '';
 
-			$vfs = CreateObject('phpgwapi.vfs');
-			$vfs->override_acl = 1;
+
+			$location_id = $GLOBALS['phpgw']->locations->get_id('property', $this->acl_location);
+			$custom_config	= CreateObject('admin.soconfig',$location_id);
+			$_config = isset($custom_config->config_data) && $custom_config->config_data ? $custom_config->config_data : array();
+
+			$remote_image_in_table = false;
+			foreach ($_config as $_config_section => $_config_section_data)
+			{
+
+				if($_config_section_data['image_in_table'])
+				{
+			
+					$remote_image_in_table = true;
+					$js = <<<JS
+	var show_picture_remote = function(elCell, oRecord, oColumn, oData)
+	{
+		if(oRecord.getData('img_id'))
+		{
+			sUrl = '{$_config_section_data['url']}';
+			sUrl += '&{$_config_section_data['img_key_remote']}=' + oRecord.getData('img_id');
+			elCell.innerHTML =  "<a href=\""+sUrl+"\" title=\""+oRecord.getData('file_name')+"\" id=\""+oRecord.getData('img_id')+"\" rel=\"colorbox\" target=\"_blank\"><img src=\""+sUrl+"&{$_config_section_data['thumbnail_flag']}\" alt=\""+oRecord.getData('file_name')+"\" /></a>";
+		}
+	}
+JS;
+					$GLOBALS['phpgw']->js->add_code('', $js);
+
+					break;
+				}
+			}
+
+
+			if(!$remote_image_in_table)
+			{
+
+				$uicols['formatter'][]	= 'show_picture';
+
+				$vfs = CreateObject('phpgwapi.vfs');
+				$vfs->override_acl = 1;
+
+				$img_types = array
+				(
+					'image/jpeg',
+					'image/png',
+					'image/gif'
+				);
+			}
+			else
+			{
+				$uicols['formatter'][]	= 'show_picture_remote';			
+			}
+
 
 			$j	= count($ticket['files']);
 			for ($i=0;$i<$j;$i++)
@@ -441,12 +534,6 @@
 				$ticket['files'][$i]['file_name']=urlencode($ticket['files'][$i]['name']);
 			}
 
-			$img_types = array
-			(
-				'image/jpeg',
-				'image/png',
-				'image/gif'
-			);
 
 			$j=0;
 			if (isset($entity_list) && is_array($entity_list))
@@ -455,23 +542,34 @@
 				{
 					$_loc1 = isset($entity_entry['loc1']) && $entity_entry['loc1'] ? $entity_entry['loc1'] : 'dummy';
 
-					$_files = $vfs->ls(array(
-						'string' => "/property/{$this->category_dir}/{$_loc1}/{$entity_entry['id']}",
-						'relatives' => array(RELATIVE_NONE)));
-	
-					if(isset($_files[0]) && $_files[0] && in_array($_files[0]['mime_type'], $img_types))
+
+					if($remote_image_in_table)
 					{
-						$entity_entry['file_name']	= urlencode($_files[0]['name']);
-						$entity_entry['directory']	= urlencode($_files[0]['directory']);
-						$entity_entry['img_id']		= $_files[0]['file_id'];
+						$entity_entry['file_name']	= $entity_entry[$_config_section_data['img_key_local']];
+					//	$entity_entry['directory']	= urlencode('external_source');
+						$entity_entry['img_id']		= $entity_entry[$_config_section_data['img_key_local']];
 					}
-				
+					else
+					{
+						$_files = $vfs->ls(array(
+							'string' => "/property/{$this->category_dir}/{$_loc1}/{$entity_entry['id']}",
+							'relatives' => array(RELATIVE_NONE)));
+	
+						if(isset($_files[0]) && $_files[0] && in_array($_files[0]['mime_type'], $img_types))
+						{
+							$entity_entry['file_name']	= urlencode($_files[0]['name']);
+							$entity_entry['directory']	= urlencode($_files[0]['directory']);
+							$entity_entry['img_id']		= $_files[0]['file_id'];
+						}
+					}
+
 					for ($i=0;$i<count($uicols['name']);$i++)
 					{
 						switch ($uicols['name'][$i])
 						{
 							case 'num':
 							case 'loc1':
+							case 'loc2':
 							case 'loc1_name':
 								$uicols['input_type'][$i] = 'hidden';
 								break;
@@ -562,13 +660,13 @@
 						'action'		=> $GLOBALS['phpgw']->link('/index.php',array
 						(
 							'menuaction'	=> 'frontend.uientity.view',
-							'entity_id'		=> $this->entity_id,
-							'cat_id'		=> $this->cat_id,
-							'type'			=> $this->type
+							'location_id'	=>$location_id,
 						)),
 						'parameters'			=> $parameters
 					);
 			}
+
+/*
 			if($this->acl_edit)
 			{
 				$datatable['rowactions']['action'][] = array
@@ -585,7 +683,7 @@
 						'parameters'			=> $parameters
 					);
 			}
-
+*/
 			if(	$category['start_ticket'])
 			{
 				$datatable['rowactions']['action'][] = array
@@ -596,11 +694,11 @@
 						(
 							'menuaction'	=> 'frontend.uihelpdesk.add_ticket',
 							'noframework'	=> 1,
-							'target'		=> '_lightbox',
+//							'target'		=> '_blank',
+							'target'		=> '_tinybox',
 							'p_entity_id'	=> $this->entity_id,
 							'p_cat_id'		=> $this->cat_id,
 							'type'			=> $this->type,
-							'target'		=> '_blank',
 							'bypass'		=> true,
 							'origin'		=> ".{$this->type}.{$this->entity_id}.{$this->cat_id}",							
 						)),
@@ -608,6 +706,8 @@
 					);
 			}
 
+			$GLOBALS['phpgw']->js->validate_file('tinybox2', 'packed' , 'property');
+			$GLOBALS['phpgw']->css->add_external_file('phpgwapi/js/tinybox2/style.css');
 
 			$jasper = execMethod('property.sojasper.read', array('location_id' => $GLOBALS['phpgw']->locations->get_id($this->type_app[$this->type], $this->acl_location)));
 
@@ -867,7 +967,6 @@
 
 		public function view()
 		{
-			$GLOBALS['phpgw']->translation->add_app('property');
 			$bo	= & $this->bo;
 			$id = phpgw::get_var('id');
 			$values = $bo->read_single(array('id' => $id, 'entity_id' => $this->entity_id, 'cat_id' => $this->cat_id, 'view' => true));
@@ -894,6 +993,150 @@
 			}
 
 			
+// ---- START INTEGRATION -------------------------
+
+			$custom_config	= CreateObject('admin.soconfig',$GLOBALS['phpgw']->locations->get_id($this->type_app[$this->type], $this->acl_location));
+			$_config = isset($custom_config->config_data) && $custom_config->config_data ? $custom_config->config_data : array();
+//_debug_array($custom_config->config_data);die();
+			// required settings:
+/*
+			integration_tab
+			integration_height
+			integration_url
+			integration_parametres
+			integration_action
+			integration_action_view
+			integration_action_edit
+			integration_auth_key_name
+			integration_auth_url
+			integration_auth_hash_name
+			integration_auth_hash_value
+			integration_location_data
+ */
+			$tabs = array();
+			$tabs['info']	= array('label' => 'Info', 'link' => '#info');
+			$active_tab = $active_tab ? $active_tab : 'info';
+
+			$integration = array();
+			foreach ($_config as $_config_section => $_config_section_data)
+			{
+				if(isset($_config_section_data['tab']) && $values['id'])
+				{
+					if(!isset($_config_section_data['url']))
+					{
+						phpgwapi_cache::message_set("'url' is a required setting for integrations, '{$_config_section}' is disabled", 'error');
+						break;
+					}
+
+					//get session key from remote system
+					$arguments = array($_config_section_data['auth_hash_name'] => $_config_section_data['auth_hash_value']);
+					$query = http_build_query($arguments);
+					$auth_url = $_config_section_data['auth_url'];
+					$request = "{$auth_url}?{$query}";
+
+					$aContext = array
+					(
+						'http' => array
+						(
+							'request_fulluri' => true,
+						),
+					);
+
+					if(isset($GLOBALS['phpgw_info']['server']['httpproxy_server']))
+					{
+						$aContext['http']['proxy'] = "{$GLOBALS['phpgw_info']['server']['httpproxy_server']}:{$GLOBALS['phpgw_info']['server']['httpproxy_port']}";
+					}
+
+					$cxContext = stream_context_create($aContext);
+					$response = trim(file_get_contents($request, False, $cxContext));
+		
+					$_config_section_data['url']		= htmlspecialchars_decode($_config_section_data['url']);
+					$_config_section_data['parametres']	= htmlspecialchars_decode($_config_section_data['parametres']);
+
+					parse_str($_config_section_data['parametres'], $output);
+
+					foreach ($output as $_dummy => $_substitute)
+					{
+						$_keys[] = $_substitute;
+	
+						$__value = false;
+						if(!$__value = urlencode($values[str_replace(array('__','*'),array('',''), $_substitute)]))
+						{
+							foreach ($values['attributes'] as $_attribute)
+							{
+								if(str_replace(array('__','*'),array('',''), $_substitute) == $_attribute['name'])
+								{
+									$__value = urlencode($_attribute['value']);
+									break;
+								}
+							}
+						}
+
+						if($__value)
+						{
+							$_values[] = $__value;
+						}
+					}
+
+					//_debug_array($_config_section_data['parametres']);
+//					_debug_array($_values);
+//					_debug_array($output);
+					unset($output);
+					unset($__value);
+					$_sep = '?';
+					if (stripos($_config_section_data['url'],'?'))
+					{
+						$_sep = '&';
+					}
+					$_param = str_replace($_keys, $_values, $_config_section_data['parametres']);
+					unset($_keys);
+					unset($_values);
+	//				$integration_src = phpgw::safe_redirect("{$_config_section_data['url']}{$_sep}{$_param}");
+					$integration_src = "{$_config_section_data['url']}{$_sep}{$_param}";
+					if($_config_section_data['action'])
+					{
+						$_sep = '?';
+						if (stripos($integration_src,'?'))
+						{
+							$_sep = '&';
+						}
+						$integration_src .= "{$_sep}{$_config_section_data['action']}=" . $_config_section_data["action_{$mode}"];
+					}
+
+					$arguments = array($_config_section_data['auth_key_name'] => $response);
+
+					if(isset($_config_section_data['location_data']) && $_config_section_data['location_data'])
+					{
+						$_config_section_data['location_data']	= htmlspecialchars_decode($_config_section_data['location_data']);
+						parse_str($_config_section_data['location_data'], $output);
+						foreach ($output as $_dummy => $_substitute)
+						{
+							$_keys[] = $_substitute;
+							$_values[] = urlencode($values['location_data'][trim($_substitute, '_')]);
+						}
+						$integration_src .= '&' . str_replace($_keys, $_values, $_config_section_data['location_data']);
+					}
+
+					$integration_src .= "&{$_config_section_data['auth_key_name']}={$response}";
+					//_debug_array($values);
+					//_debug_array($integration_src);die();
+					$tabs[$_config_section]	= array('label' => $_config_section_data['tab'], 'link' => "#{$_config_section}", 'function' => "document.getElementById('{$_config_section}_content').src = '{$integration_src}';");
+
+					$integration[]	= array
+					(
+						'section'	=> $_config_section,
+						'height'	=> isset($_config_section_data['height']) && $_config_section_data['height'] ? $_config_section_data['height'] : 500,
+						'src'		=> $integration_src
+					);
+
+				}
+			}
+
+//_debug_array($integration);die();
+// ---- END INTEGRATION -------------------------
+
+
+
 			$link_file_data = array
 				(
 					'menuaction'	=> 'property.uientity.view_file',
@@ -926,6 +1169,8 @@
 				}
 			}									
 
+
+
 			$datavalues[0] = array
 				(
 					'name'					=> "0",
@@ -975,7 +1220,10 @@
 												"cat_id:'{$this->cat_id}',".
 												"type:'{$this->type}'}",
 						'datatable'			=> $datavalues,
-						'myColumnDefs'		=> $myColumnDefs,	
+						'myColumnDefs'		=> $myColumnDefs,
+						'tabs'				=> phpgwapi_yui::tabview_generate($tabs, $active_tab),
+						'active_tab'		=> $active_tab,
+						'integration'		=> $integration,
 					)
 			);
 			phpgwapi_yui::load_widget('dragdrop');
