@@ -7,7 +7,7 @@
 	 * @copyright Copyright (C) 2010 Free Software Foundation, Inc. http://www.fsf.org/
 	 * @license http://www.gnu.org/licenses/gpl.html GNU General Public License
 	 * @package Frontend
-	 * @version $Id: class.uihelpdesk.inc.php 7227 2011-04-15 11:51:34Z sigurdne $
+	 * @version $Id: class.uihelpdesk.inc.php 11387 2013-10-23 13:18:01Z sigurdne $
 	 */
 
 	/*
@@ -48,13 +48,14 @@
 			phpgwapi_cache::session_set('frontend','tab',$GLOBALS['phpgw']->locations->get_id('frontend','.ticket'));
 			parent::__construct();
 			$this->location_code = $this->header_state['selected_location'];
+			$GLOBALS['phpgw']->translation->add_app('property');
 		}
 
 		public function index()
 		{
 			$GLOBALS['phpgw_info']['apps']['manual']['section'] = 'helpdesk.index';
 			$this->insert_links_on_header_state();
-			$bo	= CreateObject('property.botts',true);
+			$bo	= CreateObject('property.botts');
 
 			$dry_run = false;
 			$second_display = phpgw::get_var('second_display', 'bool');
@@ -355,6 +356,8 @@
 
 			$GLOBALS['phpgw_info']['flags']['app_header'] = lang('frontend') . ' - ' . $appname . ': ' . $function_msg;
 
+			$GLOBALS['phpgw']->css->add_external_file('property/js/tinybox2/style.css');
+			$GLOBALS['phpgw']->js->validate_file('tinybox2', 'packed' , 'property');
 			$GLOBALS['phpgw']->js->validate_file('yahoo', 'helpdesk.list' , 'frontend');
 
 			$msglog = phpgwapi_cache::session_get('frontend','msgbox');
@@ -369,7 +372,6 @@
 
 			$GLOBALS['phpgw']->xslttpl->add_file(array('frontend', 'helpdesk', 'datatable'));
 			$GLOBALS['phpgw']->xslttpl->set_var('phpgw', array('app_data' => $data));
-			//print_r( $GLOBALS['phpgw']->xslttpl->get_vars());
 		}
 
 		private function cmp($a, $b)
@@ -517,12 +519,23 @@
 
 		public function add_ticket()
 		{
+			$values         = phpgw::get_var('values');
+			$p_entity_id	= phpgw::get_var('p_entity_id', 'int');
+			$p_cat_id		= phpgw::get_var('p_cat_id', 'int');
+			$p_num			= phpgw::get_var('p_num');
+			$origin			= phpgw::get_var('origin');
+
+			if($p_entity_id && $p_cat_id && $p_num)
+			{
+				$item = execMethod('property.boentity.read_single',(array('id' => $p_num, 'entity_id' => $p_entity_id, 'cat_id' => $p_cat_id, 'view' => true)));
+			}
+
 			$bo	= CreateObject('property.botts',true);
 			$boloc	= CreateObject('property.bolocation',true);
 
 			$location_details = $boloc->read_single($this->location_code, array('noattrib' => true));
 
-			$values         = phpgw::get_var('values');
+
 			$missingfields  = false;
 			$msglog         = array();
 
@@ -537,7 +550,9 @@
 				$GLOBALS['phpgw']->common->phpgw_exit();
 			}
 
-			if(isset($values['save']))
+			$cat_id = isset($values['cat_id']) && $values['cat_id'] ? $values['cat_id'] : $default_cat;
+
+ 			if(isset($values['save']))
 			{
 				foreach($values as $key => $value)
 				{
@@ -549,40 +564,44 @@
 
 				if(!$missingfields && !phpgw::get_var('added'))
 				{
-					$location  = array
-					(
-						'loc1'  => $location_details['loc1'],
-						'loc2'  => $location_details['loc2']
-					);
+					$location = array();
+					$_location_arr = explode('-', $this->location_code);
+					$i = 1;
+					foreach($_location_arr as $_loc)
+					{
+						$location["loc{$i}"] = $_loc;
+						$i++;
+					}
 
-					$assignedto = execMethod('property.boresponsible.get_responsible', array('location' => $location, 'cat_id' => $default_cat));
+					$assignedto = execMethod('property.boresponsible.get_responsible', array('location' => $location, 'cat_id' => $cat_id));
 
 					if(!$assignedto)
 					{
-						$default_group = $config->config_data['tts_default_group'];
+						$default_group = (int)$config->config_data['tts_default_group'];
 					}
 					else
 					{
 						$default_group = 0;
 					}
 
-					$ticket = array(
-						'origin'    => null,
-						'origin_id' => null,
-						'cat_id'    => $values['cat_id'],
-						'group_id'  => ($default_group ? $default_group : null),
-						'assignedto'=> $assignedto,
-						'priority'  => 3,
-						'status'    => 'O', // O = Open
-						'subject'   => $values['title'],
-						'details'   => $values['locationdesc'].":\n\n".$values['description'],
-						'apply'     => lang('Apply'),
-						'contact_id'=> 0,
-						'location'  => $location,
-						'street_name'   => $location_details['street_name'],
-						'street_number' => $location_details['street_number'],
-						'location_name' => $location_details['loc1_name'],
-						//'locationdesc'  => $values['locationdesc']
+					$ticket = array
+					(
+						'origin_id'			=> $GLOBALS['phpgw']->locations->get_id('property', $origin),
+						'origin_item_id'	=> $p_num,
+						'cat_id'			=> $cat_id,
+						'group_id'			=> ($default_group ? $default_group : null),
+						'assignedto'		=> $assignedto,
+						'priority'			=> 3,
+						'status'			=> 'O', // O = Open
+						'subject'			=> $values['title'],
+						'details'			=> $values['locationdesc'].":\n\n".$values['description'],
+						'apply'				=> lang('Apply'),
+						'contact_id'		=> 0,
+						'location'			=> $location,
+						'location_code'		=> $this->location_code,
+						'street_name'		=> $location_details['street_name'],
+						'street_number'		=> $location_details['street_number'],
+						'location_name'		=> $location_details['loc1_name'],
 					);
 
 					$result = $bo->add($ticket);
@@ -591,13 +610,12 @@
 						$msglog['message'][] = array('msg' => lang('Ticket added'));
 						$noform = true;
 
-
 						// Files
 						$values['file_name'] = @str_replace(' ','_',$_FILES['file']['name']);
-						if($values['file_name'] && $msglog['id'])
+						if($values['file_name'] && $result['id'])
 						{
 							$bofiles = CreateObject('property.bofiles');
-							$to_file = $bofiles->fakebase . '/fmticket/' . $msglog['id'] . '/' . $values['file_name'];
+							$to_file = $bofiles->fakebase . '/fmticket/' . $result['id'] . '/' . $values['file_name'];
 
 							if($bofiles->vfs->file_exists(array(
 								'string' => $to_file,
@@ -654,18 +672,29 @@
 				}
 			}
 
+			$form_action_data = array
+			(
+				'menuaction'	=> 'frontend.uihelpdesk.add_ticket',
+				'noframework'	=> '1',
+				'origin'    	=> $origin,
+				'p_entity_id'	=> $p_entity_id,
+				'p_cat_id'		=> $p_cat_id,
+				'p_num'			=> $p_num,
+			);
+
 			$data = array(
 				'redirect'			=> isset($redirect) ? $GLOBALS['phpgw']->link('/index.php', array('menuaction' => 'frontend.uihelpdesk.index')) : null,
 				'msgbox_data'   	=> $GLOBALS['phpgw']->common->msgbox($GLOBALS['phpgw']->common->msgbox_data($msglog)),
-				'form_action'		=> $GLOBALS['phpgw']->link('/index.php',array('menuaction' => 'frontend.uihelpdesk.add_ticket', 'noframework' => '1')),
+				'form_action'		=> $GLOBALS['phpgw']->link('/index.php',$form_action_data),
 				'title'         	=> $values['title'],
 				'locationdesc'  	=> $values['locationdesc'],
 				'description'   	=> $values['description'],
 				'noform'        	=> $noform,
-				'category_list'		=> $category_list
+				'category_list'		=> $category_list,
+				'custom_attributes'	=> array('attributes' => $item['attributes']),
 			);
 
-			$GLOBALS['phpgw']->xslttpl->add_file(array('frontend','helpdesk'));
+			$GLOBALS['phpgw']->xslttpl->add_file(array('frontend','helpdesk','attributes_view'));
 			$GLOBALS['phpgw']->xslttpl->set_var('phpgw', array('add_ticket' => $data));
 		}
 
