@@ -8,7 +8,7 @@
 	* @internal Development of this application was funded by http://www.bergen.kommune.no/bbb_/ekstern/
 	* @package frontend
 	* @subpackage setup
- 	* @version $Id: tables_update.inc.php 4859 2010-02-18 23:09:16Z sigurd $
+ 	* @version $Id: tables_update.inc.php 11387 2013-10-23 13:18:01Z sigurdne $
 	*/
 
 	/**
@@ -38,7 +38,7 @@
 	}
 	
 	/**
-	* Update frontend version from 0.1 to 0.2
+	* Update frontend version from 0.2 to 0.3
 	* Add new location as placeholders for functions and menues
 	* 
 	*/
@@ -51,7 +51,7 @@
 	}
 	
 	/**
-	* Update frontend version from 0.2 to 0.3
+	* Update frontend version from 0.3 to 0.4
 	* Add new location as placeholders for functions and menues
 	* 
 	*/
@@ -62,3 +62,16 @@
 		$GLOBALS['setup_info']['frontend']['currentver'] = '0.4';
 		return $GLOBALS['setup_info']['frontend']['currentver'];
 	}
+	
+	/**
+	* Update frontend version from 04 to 0.5
+	* Add new location as placeholders for functions and menues
+	* 
+	*/
+	$test[] = '0.4';
+	function frontend_upgrade0_4()
+	{
+		$GLOBALS['phpgw']->locations->add('.document.contracts','contract_documents','frontend', false);
+		$GLOBALS['setup_info']['frontend']['currentver'] = '0.5';
+		return $GLOBALS['setup_info']['frontend']['currentver'];
+	}
