@@ -8,7 +8,7 @@
 	* @internal Development of this application was funded by http://www.bergen.kommune.no/bbb_/ekstern/
 	* @package hrm
 	* @subpackage admin
- 	* @version $Id: class.bocategory.inc.php 18358 2007-11-27 04:43:37Z skwashd $
+ 	* @version $Id: class.bocategory.inc.php 978 2008-05-11 08:38:47Z sigurd $
 	*/
 
 	/**
@@ -27,11 +27,11 @@
 
 		var $public_functions = array
 		(
-			'read'				=> True,
-			'read_single'		=> True,
-			'save'				=> True,
-			'delete'			=> True,
-			'check_perms'		=> True
+			'read'				=> true,
+			'read_single'		=> true,
+			'save'				=> true,
+			'delete'			=> true,
+			'check_perms'		=> true
 		);
 
 		var $soap_functions = array(
@@ -53,7 +53,7 @@
 			)
 		);
 
-		function hrm_bocategory($session=False)
+		function hrm_bocategory($session=false)
 		{
 		//	$this->currentapp	= $GLOBALS['phpgw_info']['flags']['currentapp'];
 			$this->so 		= CreateObject('hrm.socategory');
@@ -62,7 +62,7 @@
 			if ($session)
 			{
 				$this->read_sessiondata();
-				$this->use_session = True;
+				$this->use_session = true;
 			}
 
 			$start	= phpgw::get_var('start', 'int', 'REQUEST', 0);
