@@ -8,7 +8,7 @@
 	* @internal Development of this application was funded by http://www.bergen.kommune.no/bbb_/ekstern/
 	* @package hrm
 	* @subpackage user
- 	* @version $Id: class.bouser.inc.php 18358 2007-11-27 04:43:37Z skwashd $
+ 	* @version $Id: class.bouser.inc.php 1906 2008-11-28 22:47:27Z sigurd $
 	*/
 
 	/**
@@ -29,11 +29,11 @@
 
 		var $public_functions = array
 		(
-			'read'			=> True,
-			'read_single'		=> True,
-			'save'			=> True,
-			'delete'		=> True,
-			'check_perms'		=> True
+			'read'			=> true,
+			'read_single'		=> true,
+			'save'			=> true,
+			'delete'		=> true,
+			'check_perms'		=> true
 		);
 
 		var $soap_functions = array(
@@ -55,7 +55,7 @@
 			)
 		);
 
-		function hrm_bouser($session=False)
+		function hrm_bouser($session=false)
 		{
 		//	$this->currentapp	= $GLOBALS['phpgw_info']['flags']['currentapp'];
 			$this->so 		= CreateObject('hrm.souser');
@@ -65,7 +65,7 @@
 			if ($session)
 			{
 				$this->read_sessiondata();
-				$this->use_session = True;
+				$this->use_session = true;
 			}
 
 			$this->start	= phpgw::get_var('start', 'int', 'REQUEST', 0);
@@ -222,4 +222,109 @@
 			$place_list = $this->bocommon->select_list($selected,$places);
 			return $place_list;
 		}
+
+		function get_user_data($user_id)
+		{
+			$account =& $GLOBALS['phpgw']->accounts;
+			$account->set_account($user_id, 'u');
+			$account_info = $account->read();
+			$membership = $account->membership($user_id);
+			$contacts = CreateObject('phpgwapi.contacts');
+
+			$qcols = array
+			(
+				'n_given'    => 'n_given',
+				'n_family'   => 'n_family',
+				'tel_work'   => 'tel_work',
+				'tel_home'   => 'tel_home',
+				'tel_cell'   => 'tel_cell',
+				'title'      => 'title',
+				'email'      => 'email',
+				'email_home' => 'email_home',
+			);
+
+			$fields = $contacts->are_users($account_info->person_id, $qcols);
+
+			$this->boaddressbook  = CreateObject('addressbook.boaddressbook');
+			$comms = $this->boaddressbook->get_comm_contact_data($fields[0]['contact_id']);
+
+			if(is_array($comms) && isset($comms[$fields[0]['contact_id']]) )
+			{
+				$fields[0]['tel_work'] = $comms[$fields[0]['contact_id']]['work phone'];
+				$fields[0]['tel_home'] = $comms[$fields[0]['contact_id']]['home phone'];
+				$fields[0]['tel_cell'] = $comms[$fields[0]['contact_id']]['mobile (cell) phone'];
+				$fields[0]['email_home'] = $comms[$fields[0]['contact_id']]['home email'];
+			}
+
+			if(!$account_info->person_id)
+			{
+				$sfields = rawurlencode(serialize($fields[0]));
+				$contact_link   = $GLOBALS['phpgw']->link('/index.php',
+					array
+					(
+						'menuaction'	=> 'addressbook.uiaddressbook.add_person',
+						'entry'			=> $sfields,
+					)
+				);
+			}
+			else
+			{
+				$contact_link   = $GLOBALS['phpgw']->link('/index.php',
+					array
+					(
+						'menuaction'	=> 'addressbook.uiaddressbook.view_person',
+						'ab_id'		=> $fields[0]['contact_id']
+					)
+				);
+			}
+
+			$prefs_user = $this->bocommon->create_preferences('email',$user_id);
+
+			$email_work = '';
+			if($fields[0]['email'] || $prefs_user['address'])
+			{
+				if(isset($prefs_user['address']) && $prefs_user['address'])
+				{
+					$email_work = $prefs_user['address'];
+				}
+				else
+				{
+					$email_work = $fields[0]['email'];
+				}
+			}
+
+			$email_home = '';
+			if($fields[0]['email_home'])
+			{
+				$email_home = $fields[0]['email_home'];
+			}
+
+			$qcols_extra = array
+			(
+				array('name' =>lang('first name'), 'type' => 'link', 'link_value' =>$contact_link),
+				array('name' =>lang('last name'), 'type' => 'text'),
+				array('name' =>lang('work phone'), 'type' => 'text'),
+				array('name' =>lang('home phone'), 'type' => 'text'),
+				array('name' =>lang('cellular phone'), 'type' => 'text'),
+				array('name' =>lang('title'), 'type' => 'text'),
+				array('name' =>lang('work email'), 'type' => 'mail', 'link_value' => $email_work),
+				array('name' =>lang('home email'), 'type' => 'mail', 'link_value' => $email_home),
+			);
+
+			if(is_array($fields))
+			{
+				$qcols = array_keys($qcols);
+				$j=0;
+				for ($i=0;$i<count($qcols);$i++)
+				{
+					$user_values[$j]['value'] = $fields[0][$qcols[$i]];
+					$user_values[$j]['name'] = $qcols_extra[$i]['name'];
+					$user_values[$j]['type'] = $qcols_extra[$i]['type'];
+					$user_values[$j]['link_value'] = isset($qcols_extra[$i]['link_value']) ? $qcols_extra[$i]['link_value'] : '';
+					$j++;
+				}
+			}
+
+			return $user_values;
+		}
 	}
