@@ -8,7 +8,7 @@
 	* @internal Development of this application was funded by http://www.bergen.kommune.no/bbb_/ekstern/
 	* @package hrm
 	* @subpackage job
- 	* @version $Id: class.sojob.inc.php 7130 2011-03-17 14:16:53Z sigurdne $
+ 	* @version $Id: class.sojob.inc.php 7719 2011-09-26 12:11:15Z sigurdne $
 	*/
 
 	/**
@@ -68,7 +68,7 @@
 
 			$sql = "SELECT * FROM $table ";
 
-			$this->db->query($sql . $parent_select . $where . $querymethod . $ordermethod,__LINE__,__FILE__);
+			$this->db->query($sql . $parent_select . $ordermethod,__LINE__,__FILE__);
 			$this->total_records = $this->db->num_rows();
 
 			$jobs = array();
