@@ -8,7 +8,7 @@
 	* @internal Development of this application was funded by http://www.bergen.kommune.no/bbb_/ekstern/
 	* @package hrm
 	* @subpackage place
- 	* @version $Id: class.uiplace.inc.php 18358 2007-11-27 04:43:37Z skwashd $
+ 	* @version $Id: class.uiplace.inc.php 978 2008-05-11 08:38:47Z sigurd $
 	*/
 
 	/**
@@ -28,29 +28,28 @@
 
 		var $public_functions = array
 		(
-			'index'  => True,
-			'view'   => True,
-			'training'=> True,
-			'edit'   => True,
-			'delete' => True
+			'index'  => true,
+			'view'   => true,
+			'training'=> true,
+			'edit'   => true,
+			'delete' => true
 		);
 
 		function hrm_uiplace()
 		{
-			$GLOBALS['phpgw_info']['flags']['xslt_app'] = True;
+			$GLOBALS['phpgw_info']['flags']['xslt_app'] = true;
 		//	$this->currentapp		= $GLOBALS['phpgw_info']['flags']['currentapp'];
 			$this->nextmatchs		= CreateObject('phpgwapi.nextmatchs');
 			$this->account			= $GLOBALS['phpgw_info']['user']['account_id'];
 			$this->bo			= CreateObject('hrm.boplace',true);
 			$this->bocommon			= CreateObject('hrm.bocommon');
-			$this->menu			= CreateObject('hrm.menu');
-			$this->menu->sub		='place';
 
 			$this->start			= $this->bo->start;
 			$this->query			= $this->bo->query;
 			$this->sort			= $this->bo->sort;
 			$this->order			= $this->bo->order;
 			$this->allrows			= $this->bo->allrows;
+			$GLOBALS['phpgw_info']['flags']['menu_selection'] = 'hrm::place';
 		}
 
 		function save_sessiondata()
@@ -70,8 +69,6 @@
 			$GLOBALS['phpgw']->xslttpl->add_file(array('place','nextmatchs','menu',
 										'search_field'));
 
-			$links = $this->menu->links();
-
 			$place_info = $this->bo->read();
 
 			while (is_array($place_info) && list(,$entry) = each($place_info))
@@ -143,8 +140,8 @@
 			$data = array
 			(
 				'msgbox_data'					=> $GLOBALS['phpgw']->common->msgbox($msgbox_data),
-				'links'						=> $links,
-				'allow_allrows'					=> True,
+				'menu'							=> execMethod('hrm.menu.links'),
+				'allow_allrows'					=> true,
 				'allrows'					=> $this->allrows,
 				'start_record'					=> $this->start,
 				'record_limit'					=> $record_limit,
