@@ -8,7 +8,7 @@
 	* @internal Development of this application was funded by http://www.bergen.kommune.no/bbb_/ekstern/
 	* @package hrm
 	* @subpackage setup
- 	* @version $Id: tables_update.inc.php 17049 2006-09-01 12:08:27Z sigurdne $
+ 	* @version $Id: tables_update.inc.php 4416 2009-12-25 17:33:44Z sigurd $
 	*/
 
 	/**
@@ -38,7 +38,7 @@
 		$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO hrm_acl_location (appname,id, descr) VALUES ('hrm', '.', 'Top')");
 		$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO hrm_acl_location (appname,id, descr, allow_grant) VALUES ('hrm', '.user', 'User',1)");
 		$GLOBALS['phpgw_setup']->oProc->query("INSERT INTO hrm_acl_location (appname,id, descr) VALUES ('hrm', '.job', 'Job description')");
-		
+
 		$GLOBALS['setup_info']['hrm']['currentver'] = '0.9.17.001';
 		$GLOBALS['phpgw_setup']->oProc->m_odb->transaction_commit();
 		return $GLOBALS['setup_info']['hrm']['currentver'];
@@ -67,7 +67,7 @@
 		$GLOBALS['phpgw_setup']->oProc->RenameTable('hrm_experience_category','phpgw_hrm_experience_category');
 		$GLOBALS['phpgw_setup']->oProc->RenameTable('hrm_skill_level','phpgw_hrm_skill_level');
 		$GLOBALS['phpgw_setup']->oProc->RenameTable('hrm_task_category','phpgw_hrm_task_category');
-		
+
 		$GLOBALS['setup_info']['hrm']['currentver'] = '0.9.17.002';
 		$GLOBALS['phpgw_setup']->oProc->m_odb->transaction_commit();
 		return $GLOBALS['setup_info']['hrm']['currentver'];
@@ -150,3 +150,19 @@
 		$GLOBALS['phpgw_setup']->oProc->m_odb->transaction_commit();
 		return $GLOBALS['setup_info']['hrm']['currentver'];
 	}
+
+	/**
+	* Update hrm version from 0.9.17.005 to 0.9.17.006
+	*/
+
+	$test[] = '0.9.17.005';
+	function hrm_upgrade0_9_17_005()
+	{
+		$GLOBALS['phpgw_setup']->oProc->m_odb->transaction_begin();
+		$GLOBALS['phpgw_setup']->oProc->AddColumn('phpgw_hrm_training','credits',array('type' => 'int','precision' => '4', 'nullable' => True));
+		if($GLOBALS['phpgw_setup']->oProc->m_odb->transaction_commit())
+		{
+			$GLOBALS['setup_info']['hrm']['currentver'] = '0.9.17.006';
+			return $GLOBALS['setup_info']['hrm']['currentver'];
+		}
+	}
