@@ -7,7 +7,7 @@
 	* @copyright Copyright (C) 2000-2008 Free Software Foundation, Inc. http://www.fsf.org/
 	* @license http://www.gnu.org/licenses/gpl.html GNU General Public License
 	* @package phpgroupware
-	* @version $Id: index.php 7159 2011-04-02 11:40:46Z sigurdne $
+	* @version $Id: index.php 11265 2013-08-13 11:26:34Z sigurdne $
 	*/
 
 	/*
@@ -116,6 +116,7 @@
 			if (isset($GLOBALS['phpgw_info']['user']['apps']['admin']) && DEBUG_TIMER && !phpgwapi_cache::session_get($app,'id_debug'))
 			{
 				$debug_timer_stop = perfgetmicrotime();
+				//BTW: wil not destroy the json output - click on the 'Debug-link' to view message
 				_debug_array(lang('page prepared in %1 seconds.', $debug_timer_stop - $GLOBALS['debug_timer_start'] ));
 			}
 
@@ -123,6 +124,11 @@
 		}
 		else
 		{
+			if(phpgw::get_var('phpgw_return_as', 'string', 'GET') =='noframes')
+			{
+				$GLOBALS['phpgw_info']['flags']['noframework'] = true;
+				$GLOBALS['phpgw_info']['flags']['headonly']=true;
+			}
 			$GLOBALS[$class]->$method();
 		}
 		unset($app);
