@@ -6,7 +6,7 @@
 	* @license http://www.gnu.org/licenses/gpl.html GNU General Public License
 	* @package manual
 	* @subpackage setup
- 	* @version $Id: tables_update.inc.php 690 2008-02-02 10:11:33Z dave $
+ 	* @version $Id: tables_update.inc.php 11488 2013-11-25 13:18:06Z sigurdne $
 	*/
 
 	/**
@@ -19,3 +19,12 @@
 		return $GLOBALS['setup_info']['manual']['currentver'] = '0.9.17.500';
 	}
 
+	$test[] = '0.9.17.500';
+	function manual_upgrade0_9_17_500()
+	{
+
+		$GLOBALS['phpgw']->locations->add('.documents', 'Documents', 'manual');
+
+		return $GLOBALS['setup_info']['manual']['currentver'] = '0.9.17.501';
+	}
+
