@@ -10,7 +10,7 @@
 	* @license http://www.gnu.org/licenses/lgpl.html GNU Lesser General Public License v2 or later
 	* @package phpgroupware
 	* @subpackage phpgwapi
-	* @version $Id: class.accounts_sql.inc.php 7215 2011-04-12 20:06:07Z sigurdne $
+	* @version $Id: class.accounts_sql.inc.php 10166 2012-10-09 07:54:03Z sigurdne $
 	*/
 
 	/*
@@ -738,7 +738,7 @@
 		*
 		* @return object phpgwapi_account derived object containing account data
 		*/
-		protected function read_repository()
+		public function read_repository()
 		{
 			$this->account = $this->get($this->account_id, false);
 			return $this->account;
