@@ -8,7 +8,7 @@
 	 * @license http://www.gnu.org/licenses/lgpl.html GNU Lesser General Public License v2 or later
 	 * @package phpgroupware
 	 * @subpackage phpgwapi
-	 * @version $Id: class.account.inc.php 7121 2011-03-15 08:53:24Z sigurdne $
+	 * @version $Id: class.account.inc.php 10166 2012-10-09 07:54:03Z sigurdne $
 	 */
 
 	/*
@@ -477,7 +477,8 @@
 		public function toArray()
 		{
 			$array = $this->_data;
-			unset($array['passwd'], $array['passwd_hash']);
+	//		unset($array['passwd'], $array['passwd_hash']);
+			unset($array['passwd']);
 			return $array;
 		}
 
