@@ -8,7 +8,7 @@
 	* @license http://www.gnu.org/licenses/lgpl.html GNU Lesser General Public License v2 or later
 	* @package phpgwapi
 	* @subpackage accounts
-	* @version $Id: class.acl.inc.php 7215 2011-04-12 20:06:07Z sigurdne $
+	* @version $Id: class.acl.inc.php 11573 2013-12-27 08:49:03Z sigurdne $
 	*/
 
 	/*
@@ -1321,6 +1321,12 @@
 		*/
 		public function get_grants($app = '', $location = '')
 		{
+			$grant_rights = phpgwapi_cache::session_get('phpgwapi', "get_grants_{$app}_{$location}");
+			if ( !is_null($grant_rights) )
+			{
+				return $grant_rights; // nothing more to do
+			}
+
 			$grant_rights	= $this->get_grants_type($app, $location, 0);
 			$grant_mask		= $this->get_grants_type($app, $location, 1);
 			if ( is_array($grant_mask) )
@@ -1337,6 +1343,7 @@
 					}
 				}
 			}
+			phpgwapi_cache::session_set('phpgwapi', "get_grants_{$app}_{$location}", $grant_rights);
 			return $grant_rights;
 		}
 		/**
@@ -1813,8 +1820,8 @@
 			else
 			{
 				$sql = "SELECT account_id, account_type FROM phpgw_accounts"
-					. " $this->_join phpgw_acl on phpgw_accounts.account_id = phpgw_acl.acl_account"
-					. " $this->_join phpgw_locations on phpgw_acl.location_id = phpgw_locations.location_id"
+					. " {$this->_join} phpgw_acl on phpgw_accounts.account_id = phpgw_acl.acl_account"
+					. " {$this->_join} phpgw_locations on phpgw_acl.location_id = phpgw_locations.location_id"
 					. " WHERE account_status = 'A' AND phpgw_locations.name = '{$location}'"
 					. " ORDER BY account_lastname ASC";
 
