@@ -3,11 +3,11 @@
 	* Category manager
 	* @author Joseph Engo <jengo@phpgroupware.org>
 	* @author Bettina Gille <ceb@phpgroupware.org>
-	* @copyright Copyright (C) 2000-2005 Free Software Foundation, Inc. http://www.fsf.org/
+	* @copyright Copyright (C) 2000-2012 Free Software Foundation, Inc. http://www.fsf.org/
 	* @license http://www.gnu.org/licenses/lgpl.html GNU Lesser General Public License
 	* @package phpgwapi
 	* @subpackage utilities
-	* @version $Id: class.categories.inc.php 7142 2011-03-24 14:09:35Z sigurdne $
+	* @version $Id: class.categories.inc.php 11539 2013-12-17 10:28:17Z sigurdne $
 	*/
 
 	/**
@@ -272,7 +272,8 @@
 						'name'			=> $this->db->f('cat_name'),
 						'description'	=> $this->db->f('cat_description'),
 						'data'			=> $this->db->f('cat_data'),
-						'last_mod'		=> $this->db->f('last_mod')
+						'last_mod'		=> $this->db->f('last_mod'),
+						'active'		=> (int)$this->db->f('active')
 					);
 				}
 			}
@@ -368,7 +369,8 @@
 					'parent'		=> (int)$this->db->f('cat_parent'),
 					'name'			=> $this->db->f('cat_name'),
 					'description'	=> $this->db->f('cat_description'),
-					'data'			=> $this->db->f('cat_data')
+					'data'			=> $this->db->f('cat_data'),
+					'active'		=> (int)$this->db->f('active')
 				);
 			}
 
@@ -413,7 +415,8 @@
 						'parent'		=> (int)$this->db->f('cat_parent'),
 						'name'			=> $this->db->f('cat_name'),
 						'description'	=> $this->db->f('cat_description'),
-						'data'			=> $this->db->f('cat_data')
+						'data'			=> $this->db->f('cat_data'),
+						'active'		=> (int)$this->db->f('active')
 					);
 				}
 
@@ -506,9 +509,11 @@
 					'parent'		=> $this->db->f('cat_parent'),
 					'name'			=> $this->db->f('cat_name', true),
 					'description'	=> $this->db->f('cat_description', true),
-					'data'			=> $this->db->f('cat_data')
+					'data'			=> $this->db->f('cat_data'),
+					'active'		=> (int)$this->db->f('active')
 				);
 			}
+
 			return $cats;
 		}
 
@@ -573,11 +578,17 @@
 					{
 						$s .= ' selected="selected"';
 					}
+
+/*
 					$s .= '>';
 					for ($j=0;$j<$cat['level'];++$j)
 					{
 						$s .= '&nbsp;';
 					}
+*/
+
+					$s .= '>' . str_repeat('&nbsp;' , (int)$cat['level'] ) . $GLOBALS['phpgw']->strip_html($cat['name']);
+
 					$s .= $GLOBALS['phpgw']->strip_html($cat['name']);
 					if ($cat['app_name'] == 'phpgw')
 					{
@@ -685,12 +696,7 @@
 					$sel_cat = 'selected';
 				}
 
-				$name = '';
-				for ($i=0;$i<$cat['level'];$i++)
-				{
-					$name .= ' . ';
-				}
-				$name .= $GLOBALS['phpgw']->strip_html($cat['name']);
+				$name = str_repeat(' . ' , (int)$cat['level'] ) . $GLOBALS['phpgw']->strip_html($cat['name']);
 
 				if ($cat['app_name'] == 'phpgw')
 				{
@@ -736,6 +742,7 @@
 
 			$values['level'] = 0;
 			$values['main'] = 0;
+			$values['active'] = (int) $values['active'];
 			if ($values['parent'] > 0)
 			{
 				$values['level']	= (int) $this->id2name($values['parent'],'level')+1;
@@ -754,9 +761,9 @@
 				$id_val = $values['id'] . ',';
 			}
 
-			$this->db->query("INSERT INTO phpgw_categories ($id_col cat_parent, cat_owner, cat_access, cat_appname, location_id, cat_name, cat_description, cat_data, cat_main ,cat_level, last_mod)"
+			$this->db->query("INSERT INTO phpgw_categories ($id_col cat_parent, cat_owner, cat_access, cat_appname, location_id, cat_name, cat_description, cat_data, cat_main ,cat_level, active, last_mod)"
 				. " VALUES ($id_val {$values['parent']}, {$this->account_id}, '{$values['access']}', '{$this->app_name}',{$this->location_id},"
-					."'{$values['name']}', '{$values['descr']}', '{$values['data']}', {$values['main']}, {$values['level']}," . time() . ')',__LINE__,__FILE__);
+					."'{$values['name']}', '{$values['descr']}', '{$values['data']}', {$values['main']}, {$values['level']}, {$values['active']}," . time() . ')',__LINE__,__FILE__);
 
 			if ($values['id'] > 0)
 			{
@@ -900,6 +907,7 @@
 			$sql = "UPDATE phpgw_categories SET cat_name='" . $values['name'] . "', cat_description='" . $values['descr']
 					. "', cat_data='" . $values['data'] . "', cat_parent=" . $values['parent'] . ", cat_access='"
 					. $values['access'] . "', cat_main=" . $values['main'] . ', cat_level=' . $values['level'] . ',last_mod=' . time()
+					. ', active = ' . (int) $values['active']
 					. " WHERE cat_appname='" . $this->app_name . "' AND cat_id=" . $values['id'];
 
 			$this->db->query($sql,__LINE__,__FILE__);
@@ -909,6 +917,7 @@
 				'cat_id'	=> $values['id'],
 				'cat_name'	=> $values['name'],
 				'cat_owner'	=> $this->account_id,
+				'active'	=> (int) $values['active'],
 				'location'	=> 'cat_edit',
 				'location_id' => $this->location_id
 			);
@@ -1046,4 +1055,38 @@
 			$this->location_id	= $GLOBALS['phpgw']->locations->get_id($appname, $location);
 			$this->grants		= $GLOBALS['phpgw']->acl->get_grants($appname, $location);
 		}
+
+		/**
+		 * used for retrive the path for a particular node from a hierarchy
+		 *
+		 * @param integer $cat_id is the id of the node we want the path of
+		 * @return array $path Path
+		 */
+
+		public function get_path($cat_id)
+		{
+			$cat_id = (int) $cat_id;
+			$sql = "SELECT cat_parent, cat_name FROM phpgw_categories WHERE cat_id = {$cat_id}";
+
+			$this->db->query($sql,__LINE__,__FILE__);
+			$this->db->next_record();
+
+			$parent_id = $this->db->f('cat_parent');
+			$name = $this->db->f('cat_name', true);
+			$path = array
+			(
+				array
+				(
+					'id' => $cat_id,
+					'name' => $name
+				)
+			);
+
+			if ($parent_id)
+			{
+				$path = array_merge($this->get_path($parent_id), $path);
+			}
+
+			return $path;
+		}
 	}
