@@ -8,7 +8,7 @@
 	* @license http://www.gnu.org/licenses/lgpl.html GNU Lesser General Public License
 	* @package phpgwapi
 	* @subpackage utilities
-	* @version $Id: class.common.inc.php 5820 2010-05-27 12:18:48Z sigurd $
+	* @version $Id: class.common.inc.php 10166 2012-10-09 07:54:03Z sigurdne $
 	*/
 
 	/**
@@ -1571,7 +1571,7 @@ HTML;
 
 			if(!isset($GLOBALS['phpgw']->xslttpl->xslfiles['msgbox']))
 			{
-				$GLOBALS['phpgw']->xslttpl->add_file($this->get_tpl_dir('phpgwapi','base') . '/msgbox');
+				$GLOBALS['phpgw']->xslttpl->add_file('msgbox',$this->get_tpl_dir('phpgwapi','base'));
 			}
 
 		//	$prev_helper = $GLOBALS['phpgw']->translation->translator_helper;
