@@ -9,7 +9,7 @@
 	 * @internal Development of this application was funded by http://www.bergen.kommune.no/bbb_/ekstern/
 	 * @package phpgroupware
 	 * @subpackage phpgwapi
-	 * @version $Id: class.custom_fields.inc.php 7484 2011-08-08 12:44:31Z sigurdne $
+	 * @version $Id: class.custom_fields.inc.php 11387 2013-10-23 13:18:01Z sigurdne $
 	 */
 
 	/*
@@ -77,6 +77,8 @@
 		protected $_total_records = 0;
 
 		protected $global_lock = false;
+		
+		protected $attribute_group_tree = array();
 
 		/**
 		 * Constructor
@@ -107,6 +109,7 @@
 				'C'		=> lang('char'),
 				'N'		=> lang('Float'),
 				'D'		=> lang('Date'),
+				'DT'	=> lang('Datetime'),
 				'T'		=> lang('Memo'),
 				'R'		=> lang('Muliple radio'),
 				'CH'	=> lang('Muliple checkbox'),
@@ -119,7 +122,10 @@
 				'pwd' 	=> lang('password'),
 				'user' 	=> 'phpgw_user',
 				'event'	=> lang('event'),
-				'bolean'	=> 'Bolean'
+				'bolean'=> 'Bolean',
+				'custom1'=> lang('Custom listbox'),//Custom listbox to generic lists
+				'custom2'=> lang('Custom lookup'),//Custom lookup to generic lists
+				'custom3'=> lang('Custom autocomplete::integer'),//Custom lookup to generic lists
 			);
 
 			$this->_oProc			= createObject('phpgwapi.schema_proc', $GLOBALS['phpgw_info']['server']['db_type']);
@@ -145,7 +151,7 @@
 
 		/**
 		 * Add a group for custom fields/attributes
-		 * 
+		 *
 		 * @param array $attrib the field data
 		 *
 		 * @return int the the new custom field db pk
@@ -168,17 +174,24 @@
 			(
 				'location_id'	=> $location_id,
 				'id'			=> 0,
-				'name'	=> $this->_db->db_addslashes(strtolower($group['group_name'])),
-				'descr'	=> $this->_db->db_addslashes($group['descr']),
-				'remark'	=> $this->_db->db_addslashes($group['remark']),
+				'name'			=> $this->_db->db_addslashes(strtolower($group['group_name'])),
+				'descr'			=> $this->_db->db_addslashes($group['descr']),
+				'remark'		=> $this->_db->db_addslashes($group['remark']),
 				'group_sort'	=> 0,
+				'parent_id'		=> $group['parent_id']
 			);
 
+			$filter_parent = '';
+			if($group['parent_id'])
+			{
+				$filter_parent = ' AND parent_id = ' . (int) $group['parent_id'];
+			}
 
 			unset($group);
 
 			$this->_db->transaction_begin();
 
+/*
 			$sql = "SELECT id FROM phpgw_cust_attribute_group"
 				. " WHERE location_id = {$values['location_id']}"
 					. " AND name = '{$values['name']}'";
@@ -187,14 +200,22 @@
 			{
 				return -1;
 			}
-
-			$sql = 'SELECT MAX(group_sort) AS max_sort, MAX(id) AS current_id'
+*/
+			
+			$sql = 'SELECT MAX(id) AS current_id'
 				. ' FROM phpgw_cust_attribute_group '
 				. " WHERE location_id ='{$values['location_id']}'";
 			$this->_db->query($sql, __LINE__, __FILE__);
 			$this->_db->next_record();
-			$values['group_sort']	= $this->_db->f('max_sort') + 1;
 			$values['id']	= $this->_db->f('current_id') + 1;		
+
+			$sql = 'SELECT MAX(group_sort) AS max_sort'
+				. ' FROM phpgw_cust_attribute_group '
+				. " WHERE location_id ='{$values['location_id']}'{$filter_parent}";
+
+			$this->_db->query($sql, __LINE__, __FILE__);
+			$this->_db->next_record();
+			$values['group_sort']	= $this->_db->f('max_sort') + 1;
 			
 			$cols = implode(', ', array_keys($values));
 			$vals = $this->_db->validate_insert($values);
@@ -215,7 +236,7 @@
 		}
 		/**
 		 * Add a custom field/attribute
-		 * 
+		 *
 		 * @param array $attrib the field data
 		 * @param string $attrib_table where to append the attrib
 		 * @param bool $doubled sometimes the attribute fits into a history-table as a double
@@ -241,11 +262,14 @@
 				$attrib_table = $GLOBALS['phpgw']->locations->get_attrib_table($appname, $location);
 			}
 
-			// Need a table to operate on
-			if ( !$attrib_table )
-			{
-				return -1;
-			}
+ 			if(isset($attrib['get_list_function_input']) &&  $attrib['get_list_function_input'])
+ 			{
+				$attrib['get_list_function_input'] = $this->_validate_function_input($attrib['get_list_function_input']);
+  			}
+ 			if(isset($attrib['get_single_function_input']) &&  $attrib['get_single_function_input'])
+ 			{
+				$attrib['get_single_function_input'] = $this->_validate_function_input($attrib['get_single_function_input']);
+  			}
 
 			$values = array
 			(
@@ -266,7 +290,12 @@
 				'precision_'	=> (int) $attrib['column_info']['precision'],
 				'scale'			=> (int) $attrib['column_info']['scale'],
 				'default_value'	=> '',
-				'nullable'		=> $attrib['column_info']['nullable']
+				'nullable'		=> $attrib['column_info']['nullable'],
+				'get_list_function'	=> $attrib['get_list_function'],
+				'get_list_function_input' => $attrib['get_list_function_input'] ? $this->_db->db_addslashes(serialize($attrib['get_list_function_input'])) : '',
+				'get_single_function'	=> $attrib['get_single_function'],
+				'get_single_function_input' => $attrib['get_single_function_input'] ? $this->_db->db_addslashes(serialize($attrib['get_single_function_input'])) : '',
+				'short_description'			=> isset($attrib['short_description']) && $attrib['short_description'] ? (int) $attrib['short_description'] : false
 			);
 
 			if ( isset($attrib['search']) )
@@ -366,6 +395,21 @@
 
 			$receipt['id'] = $values['id'];
 
+			// if no table: assume eav-model
+			if ( !$attrib_table )
+			{
+				if ( !$this->global_lock )
+				{
+					if ( $this->_db->transaction_commit() )
+					{
+						return $values['id'];
+					}
+				}
+
+				return 0;
+			}
+
+
 			if ( !$values['precision_'] > 0)
 			{
 				$precision = $this->_translate_datatype_precision($values['datatype']);
@@ -443,9 +487,22 @@
 						break;
 
 					case 'D':
-						$ts = phpgwapi_datetime::date_to_timestamp($attrib['value']);
+						$ts = phpgwapi_datetime::date_to_timestamp($attrib['value']) - phpgwapi_datetime::user_timezone();
 						$attrib['value'] = date($this->_dateformat, $ts);
 						break;
+
+					case 'DT':
+						if($attrib['value']['date'])
+						{
+							$date_array	= phpgwapi_datetime::date_array($attrib['value']['date']);
+							$ts = mktime ((int)$attrib['value']['hour'], (int)$attrib['value']['min'], 0, $date_array['month'], $date_array['day'], $date_array['year']) - phpgwapi_datetime::user_timezone();
+							$attrib['value'] = date($this->_datetimeformat, $ts);
+						}
+						else
+						{
+							$attrib['value'] = '';
+						}
+						break;
 				}
 			}
 			return $values_attribute;
@@ -453,7 +510,7 @@
 
 		/**
 		 * Delete a custom field/attribute group
-		 * 
+		 *
 		 * @param string $location within an application
 		 * @param string $appname where to delete the attrib
 		 * @param integer $group_id id of attrib to delete
@@ -494,7 +551,7 @@
 		}
 		/**
 		 * Delete a custom field/attribute
-		 * 
+		 *
 		 * @param string $location within an application
 		 * @param string $appname where to delete the attrib
 		 * @param integer $attrib_id id of attrib to delete
@@ -525,11 +582,14 @@
 
 			$column_name = $this->_db->f('column_name');
 
-			$this->_oProc->DropColumn($table, false, $column_name);
+			if($table)
+			{
+				$this->_oProc->DropColumn($table, false, $column_name);
+			}
 
 			if(!$doubled) // else: wait for it - another one is coming
 			{
-				$sql = "SELECT group_id FROM phpgw_cust_attribute " 
+				$sql = "SELECT group_id FROM phpgw_cust_attribute "
 					. " WHERE location_id = {$loc_id} AND id = {$attrib_id}";
 				$this->_db->query($sql, __LINE__, __FILE__);
 				$this->_db->next_record();
@@ -568,7 +628,7 @@
 
 		/**
 		 * Edit a group for custom fields
-		 * 
+		 *
 		 * @param array  $group  the field data
 		 *
 		 * @return integer the database id of the group
@@ -585,7 +645,8 @@
 			(
 				'name'		=> $this->_db->db_addslashes($group['group_name']),
 				'descr'		=> $this->_db->db_addslashes($group['descr']),
-				'remark'	=> $this->_db->db_addslashes($group['remark'])
+				'remark'	=> $this->_db->db_addslashes($group['remark']),
+				'parent_id'	=> $group['parent_id']
 			);
 
 			$value_set	= $this->_db->validate_update($value_set);
@@ -601,7 +662,7 @@
 		}
 		/**
 		 * Edit a custom field
-		 * 
+		 *
 		 * @param array  $attrib       the field data
 		 * @param string $attrib_table which table the attribute is part of
 		 * @param bool $doubled sometimes the attribute fits into a history-table as a double
@@ -610,6 +671,15 @@
 		 */
 		function edit($attrib, $attrib_table = '', $doubled = false)
 		{
+ 			if(isset($attrib['get_list_function_input']) &&  $attrib['get_list_function_input'])
+ 			{
+				$attrib['get_list_function_input'] = $this->_validate_function_input($attrib['get_list_function_input']);
+  			}
+ 			if(isset($attrib['get_single_function_input']) &&  $attrib['get_single_function_input'])
+ 			{
+				$attrib['get_single_function_input'] = $this->_validate_function_input($attrib['get_single_function_input']);
+  			}
+
 			// Checkboxes are only present if ticked, so we declare them here to stop errors
 			$attrib['search'] = isset($attrib['search']) ? !!$attrib['search'] : false;
 			$attrib['list'] = isset($attrib['list']) ? !!$attrib['list'] : false;
@@ -650,7 +720,7 @@
 				default: // all is good
 			}
 
-			$sql = "SELECT column_name, datatype, precision_, group_id FROM phpgw_cust_attribute " 
+			$sql = "SELECT column_name, datatype, precision_, group_id FROM phpgw_cust_attribute "
 				. " WHERE location_id  = {$location_id} AND id = {$attrib_id}";
 			$this->_db->query($sql, __LINE__, __FILE__);
 			if ( !$this->_db->next_record() )
@@ -662,9 +732,8 @@
 			$OldColumnName		= $this->_db->f('column_name');
 			$OldDataType		= $this->_db->f('datatype');
 			$OldPrecision		= $this->_db->f('precision_');
-			$OldGroup			= (int) $this->_db->f('group_id');			
-
-			$table_def = $this->get_table_def($attrib_table);	
+			$OldGroup			= (int) $this->_db->f('group_id');
+			$OldNullable		= $this->_db->f('nullable');		
 
 			$this->_db->transaction_begin();
 
@@ -672,21 +741,26 @@
 			{
 				$value_set = array
 				(
-					'input_text'	=> $attrib['input_text'],
-					'statustext'	=> $attrib['statustext'],
-					'search'		=> isset($attrib['search']) ? $attrib['search'] : '',
-					'list'			=> isset($attrib['list']) ? $attrib['list'] : '',
-					'history'		=> isset($attrib['history']) ? $attrib['history'] : '',
-					'nullable'		=> $attrib['column_info']['nullable'] == 'False' ? 'False' : 'True',
-					'disabled'		=> isset($attrib['disabled']) ? $attrib['disabled'] : '',
-					'helpmsg'		=> $attrib['helpmsg'],
-					'lookup_form'	=> isset($attrib['lookup_form']) ? $attrib['lookup_form'] : '',
-					'group_id'		=> $attrib['group_id']
+					'input_text'			=> $attrib['input_text'],
+					'statustext'			=> $attrib['statustext'],
+					'search'				=> isset($attrib['search']) ? $attrib['search'] : '',
+					'list'					=> isset($attrib['list']) ? $attrib['list'] : '',
+					'history'				=> isset($attrib['history']) ? $attrib['history'] : '',
+					'nullable'				=> $attrib['column_info']['nullable'] == 'False' ? 'False' : 'True',
+					'disabled'				=> isset($attrib['disabled']) ? $attrib['disabled'] : '',
+					'helpmsg'				=> $attrib['helpmsg'],
+					'lookup_form'			=> isset($attrib['lookup_form']) ? $attrib['lookup_form'] : '',
+					'group_id'				=> $attrib['group_id'],
+					'get_list_function'		=> $attrib['get_list_function'],
+					'get_list_function_input' => $attrib['get_list_function_input'] ? $this->_db->db_addslashes(serialize($attrib['get_list_function_input'])) : '',
+					'get_single_function'		=> $attrib['get_single_function'],
+					'get_single_function_input' => $attrib['get_single_function_input'] ? $this->_db->db_addslashes(serialize($attrib['get_single_function_input'])) : '',
+					'short_description'			=> isset($attrib['short_description']) && $attrib['short_description'] ? (int) $attrib['short_description'] : false
 				);
 
 				if($OldGroup != $attrib['group_id'])
 				{
-					$sql = "SELECT MAX(attrib_sort) AS max_sort FROM phpgw_cust_attribute " 
+					$sql = "SELECT MAX(attrib_sort) AS max_sort FROM phpgw_cust_attribute "
 						. " WHERE location_id = {$location_id} AND group_id = {$attrib['group_id']}";
 					$this->_db->query($sql,__LINE__,__FILE__);
 					$this->_db->next_record();
@@ -721,23 +795,32 @@
 
 			}
 
-			$this->_oProc->m_aTables = $table_def;
-
-			if($OldColumnName !=$attrib['column_name'])
+			if($attrib_table) // not eav
 			{
-				$value_set=array('column_name'	=> $attrib['column_name']);
+				$table_def = $this->get_table_def($attrib_table);	
+				$this->_oProc->m_aTables = $table_def;
 
-				if( !$doubled )
+				if($OldColumnName !=$attrib['column_name'])
 				{
-					$value_set	= $this->_db->validate_update($value_set);
-					$this->_db->query("UPDATE phpgw_cust_attribute set $value_set WHERE location_id = {$location_id} AND id=" . $attrib_id,__LINE__,__FILE__);
-				}
+					$value_set=array('column_name'	=> $attrib['column_name']);
 
-				$this->_oProc->RenameColumn($attrib_table, $OldColumnName, $attrib['column_name']);
+					if( !$doubled )
+					{
+						$value_set	= $this->_db->validate_update($value_set);
+						$this->_db->query("UPDATE phpgw_cust_attribute set $value_set WHERE location_id = {$location_id} AND id=" . $attrib_id,__LINE__,__FILE__);
+					}
+	
+					if($attrib_table)
+					{
+						$this->_oProc->RenameColumn($attrib_table, $OldColumnName, $attrib['column_name']);
+					}
+				}
 			}
 
 			if (($OldDataType != $attrib['column_info']['type'])
-				|| ($OldPrecision != $attrib['column_info']['precision']) )
+				|| ($OldPrecision != $attrib['column_info']['precision'])
+				|| ($OldNullable != $attrib['column_info']['nullable'])
+				 )
 			{
 				if( !$doubled )
 				{
@@ -769,14 +852,14 @@
 					unset($attrib['column_info']['default']);
 				}
 
-				$value_set=array(
-					'column_name'	=> $attrib['column_name'],
+				$value_set=array
+				(
 					'datatype'		=> $attrib['column_info']['type'],
 					'precision_'	=> $attrib['column_info']['precision'],
 					'scale'			=> $attrib['column_info']['scale'],
 					'default_value'	=> $attrib['column_info']['default'],
 					'nullable'		=> $attrib['column_info']['nullable']
-					);
+				);
 
 				if( !$doubled )
 				{
@@ -790,7 +873,52 @@
 				}
 
 				$attrib['column_info']['type']  = $this->_translate_datatype_insert($attrib['column_info']['type']);
-				$this->_oProc->AlterColumn($attrib_table,$attrib['column_name'],$attrib['column_info']);			
+				
+				$incompatible_char_types = array
+				(
+					'int'		=> true,
+					'decimal'	=> true,
+					'timestamp'	=> true
+				);
+
+				if($attrib_table)
+				{
+					$incompatible_type = false;
+					$OldDataType = $this->_translate_datatype_insert($OldDataType);
+					
+					if ($OldDataType == 'varchar' && isset($incompatible_char_types[$attrib['column_info']['type']]) && $incompatible_char_types[$attrib['column_info']['type']])
+					{
+						$incompatible_type = true;
+					}
+					else if ($OldDataType == 'char' && isset($incompatible_char_types[$attrib['column_info']['type']]) && $incompatible_char_types[$attrib['column_info']['type']])
+					{
+						$incompatible_type = true;
+					}
+					else if ($OldDataType == 'text' && isset($incompatible_char_types[$attrib['column_info']['type']]) && $incompatible_char_types[$attrib['column_info']['type']])
+					{
+						$incompatible_type = true;
+					}
+
+					if($incompatible_type)
+					{
+						$metadata = $this->_db->metadata($attrib_table);
+
+						$found_column = true;
+						$i = 0;
+						do
+						{
+							$backup_column_name = "{$attrib['column_name']}_backup_{$i}";
+							$i++;
+						}
+						while (isset($metadata[$backup_column_name]));
+						
+						$this->_oProc->RenameColumn($attrib_table,$attrib['column_name'], $backup_column_name);
+						$this->_oProc->AlterColumn($attrib_table,$backup_column_name,array('type' => $OldDataType, 'nullable' => true));
+						$this->_oProc->AddColumn($attrib_table, $attrib['column_name'], $attrib['column_info']);
+					}
+					
+					$this->_oProc->AlterColumn($attrib_table,$attrib['column_name'],$attrib['column_info']);
+				}
 			}
 			
 			if(isset($attrib['new_choice']) && $attrib['new_choice'] && !$doubled )
@@ -865,28 +993,49 @@
 
 		/**
 		 * Get a list of attributes
-		 * 
+		 *
 		 * @param string $appname      the name of the application
 		 * @param string $location     the name of the location
 		 * @param integer $start
-		 * @param string query         
-		 * @param string $sort         
-		 * @param string $order        
-		 * @param bool   $allrows      
-		 * @param bool   $inc_choices  
+		 * @param string query
+		 * @param string $sort
+		 * @param string $order
+		 * @param bool   $allrows
+		 * @param bool   $inc_choices
 		 * @param array $filtermethod
 		 *
 		 * @return array attributes at location
 		 */
-		public function find($appname, $location, $start = 0, $query = '', $sort = 'ASC', 
+		public function find($appname, $location, $start = 0, $query = '', $sort = 'ASC',
 				$order = 'attrib_sort', $allrows = false, $inc_choices = false, $filter = array())
 		{
 			$location_id	= $GLOBALS['phpgw']->locations->get_id($appname, $location);
+			return $this->find2($location_id, $start, $query, $sort, $order, $allrows, $inc_choices, $filter);
+		}
+
+		/**
+		 * Get a list of attributes
+		 *
+		 * @param integer $location_id   the system location
+		 * @param integer $start
+		 * @param string query
+		 * @param string $sort
+		 * @param string $order
+		 * @param bool   $allrows
+		 * @param bool   $inc_choices
+		 * @param array $filtermethod
+		 *
+		 * @return array attributes at location
+		 */
+
+		public function find2($location_id, $start = 0, $query = '', $sort = 'ASC',
+				$order = 'attrib_sort', $allrows = false, $inc_choices = false, $filter = array())
+		{
+			$location_id	= (int) $location_id;
 			$start			= (int) $start;
 			$query			= $this->_db->db_addslashes($query);
 			$order			= $this->_db->db_addslashes($order);
 			$allrows		= !!$allrows;
-
 			
 			$filtermethod	= '';
 			if ($filter && is_array($filter))
@@ -896,11 +1045,19 @@
 				{
 					if($value)
 					{
-						$condition[] = "$column = '{$value}'";
+						switch($value)
+						{
+							case 'IS NOT NULL':
+								$condition[] = "{$column} IS NOT NULL";
+								break;
+							default:
+								$condition[] = "{$column} = '{$value}'";							
+						}
+
 					}
 					else
 					{
-						$condition[] = "$column IS NULL";					
+						$condition[] = "{$column} IS NULL";					
 					}
 				}
 
@@ -959,28 +1116,34 @@
 				$id = $this->_db->f('id');
 				$attribs[$id] = array
 				(
-					'id'				=> $id,
+					'id'					=> $id,
 					//'attrib_id'			=> $this->_db->f('id'), // FIXME
-					'entity_type'		=> $this->_db->f('type_id'),
-					'group_id'			=> (int) $this->_db->f('group_id'),					
-					'attrib_sort'		=> (int) $this->_db->f('attrib_sort'),
-					'list'				=> $this->_db->f('list'),
-					'lookup_form'		=> $this->_db->f('lookup_form'),
-					'entity_form'		=> $this->_db->f('entity_form'),
-					'column_name'		=> $this->_db->f('column_name'),
-					'name'				=> $this->_db->f('column_name'),
-					'size'				=> $this->_db->f('size'),
-					'statustext'		=> $this->_db->f('statustext', true),
-					'input_text'		=> $this->_db->f('input_text', true),
-					'type_name'			=> $this->_db->f('type'),
-					'datatype'			=> $this->_db->f('datatype'),
-					'search'			=> $this->_db->f('search'),
-					'trans_datatype'	=> $this->translate_datatype($this->_db->f('datatype')),
-					'nullable'			=> ($this->_db->f('nullable') == 'True'),
-					//'allow_null'		=> ($this->_db->f('nullable') == 'True'), // FIXME
-					'history'			=> $this->_db->f('history'),
-					'disabled'			=> $this->_db->f('disabled'),
-					'helpmsg'			=> !!$this->_db->f('helpmsg')
+					'entity_type'			=> $this->_db->f('type_id'),
+					'group_id'				=> (int) $this->_db->f('group_id'),					
+					'attrib_sort'			=> (int) $this->_db->f('attrib_sort'),
+					'list'					=> $this->_db->f('list'),
+					'lookup_form'			=> $this->_db->f('lookup_form'),
+					'entity_form'			=> $this->_db->f('entity_form'),
+					'column_name'			=> $this->_db->f('column_name'),
+					'name'					=> $this->_db->f('column_name'),
+					'size'					=> $this->_db->f('size'),
+					'precision'				=> $this->_db->f('precision_'),
+					'statustext'			=> $this->_db->f('statustext', true),
+					'input_text'			=> $this->_db->f('input_text', true),
+					'type_name'				=> $this->_db->f('type'),
+					'datatype'				=> $this->_db->f('datatype'),
+					'search'				=> $this->_db->f('search'),
+					'trans_datatype'		=> $this->translate_datatype($this->_db->f('datatype')),
+					'nullable'				=> ($this->_db->f('nullable') == 'True'),
+					//'allow_null'			=> ($this->_db->f('nullable') == 'True'), // FIXME
+					'history'				=> $this->_db->f('history'),
+					'disabled'				=> $this->_db->f('disabled'),
+					'helpmsg'				=> !!$this->_db->f('helpmsg'),
+					'get_list_function'		=> $this->_db->f('get_list_function'),
+					'get_list_function_input' => $this->_db->f('get_list_function_input') ? unserialize($this->_db->f('get_list_function_input', true)) : '',
+					'get_single_function'		=> $this->_db->f('get_single_function'),
+					'get_single_function_input' => $this->_db->f('get_single_function_input') ? unserialize($this->_db->f('get_single_function_input', true)) : '',
+					'short_description'			=> $this->_db->f('short_description')
 
 				);
 			}
@@ -1004,9 +1167,11 @@
 
 			return $attribs;
 		}
+
+
 		/**
 		 * Get a list of groups availlable for attributes within a location
-		 * 
+		 *
 		 * @param string $appname      the name of the application
 		 * @param string $location     the name of the location
 		 * @param ?????? $start        ask sigurd
@@ -1017,7 +1182,8 @@
 		 *
 		 * @return ???? something
 		 */
-		public function find_group($appname, $location, $start = 0, $query = '', $sort = 'ASC', 
+
+		public function find_group($appname, $location, $start = 0, $query = '', $sort = 'ASC',
 				$order = 'group_sort', $allrows = false)
 		{
 			$location_id	= $GLOBALS['phpgw']->locations->get_id($appname, $location);
@@ -1043,45 +1209,107 @@
 				$querymethod = "AND (phpgw_cust_attribute_group.name {$this->_like} '%{$query}%'";
 			}
 
-			$sql = "FROM phpgw_cust_attribute_group "
-				. " WHERE location_id = {$location_id} {$querymethod}";
+			$sql = "SELECT * FROM phpgw_cust_attribute_group "
+				. " WHERE location_id = {$location_id} AND (parent_id = 0 OR parent_id IS NULL) {$querymethod} {$ordermethod}";
 
-			$this->_total_records = 0;
-			$this->_db->query("SELECT COUNT(*) AS cnt_rec {$sql}",__LINE__,__FILE__);
-			if ( !$this->_db->next_record() )
+
+			$this->_db->query($sql,__LINE__,__FILE__);
+
+			$this->attribute_group_tree = array();
+			while ($this->_db->next_record())
 			{
-				return array();
-			}
-
-			$this->_total_records = $this->_db->f('cnt_rec');
-
-			$sql = "SELECT * {$sql} {$ordermethod}";
-
-			if ( $allrows )
-			{
-				$this->_db->query($sql, __LINE__, __FILE__);
-			}
-			else
-			{
-				$this->_db->limit_query($sql, $start, __LINE__, __FILE__);
-			}
-
-			$attrib_groups = array();
-			while ( $this->_db->next_record() )
-			{
-				$attrib_groups[] = array
+				$id			= $this->_db->f('id');
+				$group_sort = (int) $this->_db->f('group_sort');
+				$groups[$id] = array
 				(
-					'id'				=> $this->_db->f('id'),
-					'group_sort'		=> (int) $this->_db->f('group_sort'),
-					'name'				=> $this->_db->f('name', true),
+					'id'				=> $id,
+					'name'				=> $this->_db->f('name',true),
+					'parent_id'			=> 0,
+					'group_sort'		=> $group_sort,
+					'group_sort_text'	=> $group_sort,
 					'descr'				=> $this->_db->f('descr', true),
-					'remark'			=> $this->_db->f('remark', true)
+					'remark'			=> $this->_db->f('remark', true),
 				);
 			}
 
-			return $attrib_groups;
+			foreach($groups as $group)
+			{
+				$this->attribute_group_tree[] = array
+				(
+					'id'				=> $group['id'],
+					'name'				=> $group['name'],
+					'parent_id'			=> 0,
+					'level'				=> 0,
+					'group_sort'		=> $group['group_sort'],
+					'group_sort_text'	=> $group['group_sort'],
+					'descr'				=> $group['descr'],
+					'remark'			=> $group['remark'],
+				);
+				$this->get_attribute_group_children($location_id, $group['id'],$group['group_sort'], 1, false);
+			}
+
+			$this->_total_records = count($this->attribute_group_tree);
+			$result = $this->attribute_group_tree;
+
+			if($this->_total_records == 0)
+			{
+				return $result;
+			}
+
+			if(!$allrows)
+			{
+				$num_rows = isset($GLOBALS['phpgw_info']['user']['preferences']['common']['maxmatchs']) ? (int) $GLOBALS['phpgw_info']['user']['preferences']['common']['maxmatchs']:15;
+
+				$page = ceil( ( $start / $this->_total_records ) * ($this->_total_records/ $num_rows) );
+
+				$out = array_chunk($result, $num_rows);
+
+				return $out[$page];
+			}
+			else
+			{
+				return $result;
+			}
+
+			return $this->attribute_group_tree;
 		}
 
+
+		function get_attribute_group_children($location_id, $parent, $parent_sort, $level, $reset = false)
+		{
+			if($reset)
+			{
+				$this->attribute_group_tree = array();
+			}
+
+			$filtermethod = 'WHERE location_id =' . (int)$location_id;			
+
+			$db = clone($this->_db);
+			$sql = "SELECT * FROM phpgw_cust_attribute_group $filtermethod AND parent_id = {$parent} ORDER BY group_sort ASC";
+
+			$db->query($sql,__LINE__,__FILE__);
+
+			while ($db->next_record())
+			{
+				$id					= $db->f('id');
+				$group_sort			= $db->f('group_sort');
+				$group_sort_text	= $parent_sort ? "{$parent_sort}::{$group_sort}" : $group_sort;
+				$this->attribute_group_tree[] = array
+				(
+					'id'				=> $id,
+					'name'				=> str_repeat('..',$level).$db->f('name'),
+					'parent_id'			=> $db->f('parent_id'),
+					'level'				=> $level,
+					'group_sort'		=> $group_sort,
+					'group_sort_text'	=> $group_sort_text,
+					'descr'				=> $db->f('descr'),
+					'remark'			=> $db->f('remark'),
+				);
+				$this->get_attribute_group_children($location_id, $id, $group_sort_text, $level+1);
+			}
+			return $this->attribute_group_tree;
+		} 
+
 		/**
 		* Read a single attribute group record
 		*
@@ -1111,7 +1339,8 @@
 				'group_name'	=> $this->_db->f('name', true),
 				'descr'			=> $this->_db->f('descr', true),
 				'remark'		=> $this->_db->f('remark', true),
-				'group_sort'	=> $this->_db->f('group_sort')
+				'group_sort'	=> $this->_db->f('group_sort'),
+				'parent_id'		=> $this->_db->f('parent_id'),
 			);
 
 			return $group;
@@ -1131,7 +1360,7 @@
 			$location_id = $GLOBALS['phpgw']->locations->get_id($appname, $location);
 			$id = (int) $id;
 
-			$sql = "SELECT phpgw_cust_attribute.* FROM phpgw_cust_attribute " 
+			$sql = "SELECT phpgw_cust_attribute.* FROM phpgw_cust_attribute "
 				. " WHERE location_id = {$location_id}"
 					. " AND phpgw_cust_attribute.id=$id";
 			$this->_db->query($sql, __LINE__, __FILE__);
@@ -1143,33 +1372,38 @@
 
 			$attrib = array
 			(
-				'id'			=> $this->_db->f('id'),
-				'group_id'		=> $this->_db->f('group_id'),
-				'column_name'	=> $this->_db->f('column_name', true),
-				'input_text'	=> $this->_db->f('input_text', true),
-				'statustext'	=> $this->_db->f('statustext', true),
-				'type_id'		=> $this->_db->f('type_id'),
-				'type_name'		=> $this->_db->f('type_name'),
-				'lookup_form'	=> $this->_db->f('lookup_form'),
-				'list'			=> !!$this->_db->f('list'),
-				'search'		=> !!$this->_db->f('search'),
-				'history'		=> !!$this->_db->f('history'),
-				'location_id'	=> $this->_db->f('location_id'),
+				'id'					=> $this->_db->f('id'),
+				'group_id'				=> $this->_db->f('group_id'),
+				'column_name'			=> $this->_db->f('column_name', true),
+				'input_text'			=> $this->_db->f('input_text', true),
+				'statustext'			=> $this->_db->f('statustext', true),
+				'type_id'				=> $this->_db->f('type_id'),
+				'type_name'				=> $this->_db->f('type_name'),
+				'lookup_form'			=> $this->_db->f('lookup_form'),
+				'list'					=> !!$this->_db->f('list'),
+				'search'				=> !!$this->_db->f('search'),
+				'history'				=> !!$this->_db->f('history'),
+				'location_id'			=> $this->_db->f('location_id'),
 				// FIXME this is broken it should be a small int and used as a bool
-				'nullable'		=> $this->_db->f('nullable') == 'True',
+				'nullable'				=> $this->_db->f('nullable') == 'True',
 				// FIXME this isn't needed
-				//'allow_null'	=> $this->_db->f('nullable') == 'True',
-				'disabled'		=> !!$this->_db->f('disabled'),
-				'helpmsg'		=> $this->_db->f('helpmsg', true),
-				'column_info'	=> array
-									(
-										'precision'	=> $this->_db->f('precision_'),
-										'scale'		=> $this->_db->f('scale'),
-										'default'	=> $this->_db->f('default_value', true),
-										// more duplicated values
-										'nullable'	=> $this->_db->f('nullable'),
-										'type'		=> $this->_db->f('datatype')
-									)
+				//'allow_null'			=> $this->_db->f('nullable') == 'True',
+				'disabled'				=> !!$this->_db->f('disabled'),
+				'helpmsg'				=> $this->_db->f('helpmsg', true),
+				'get_list_function'		=>$this->_db->f('get_list_function',true),
+				'get_list_function_input' => $this->_db->f('get_list_function_input') ? unserialize($this->_db->f('get_list_function_input', true)) : '',
+				'get_single_function'		=>$this->_db->f('get_single_function',true),
+				'get_single_function_input' => $this->_db->f('get_single_function_input') ? unserialize($this->_db->f('get_single_function_input', true)) : '',
+				'short_description'			=> $this->_db->f('short_description'),
+				'column_info'				=> array
+											(
+												'precision'	=> $this->_db->f('precision_'),
+												'scale'		=> $this->_db->f('scale'),
+												'default'	=> $this->_db->f('default_value', true),
+												// more duplicated values
+												'nullable'	=> $this->_db->f('nullable'),
+												'type'		=> $this->_db->f('datatype')
+											)
 			);
 
 			if ( $inc_choices )
@@ -1236,7 +1470,7 @@
 		 */
 		public function get_table_def($table = '', $table_def = array())
 		{
-			if( !$GLOBALS['phpgw_setup']->oProc 
+			if( !$GLOBALS['phpgw_setup']->oProc
 				|| !is_object($GLOBALS['phpgw_setup']->oProc) )
 			{
 				$GLOBALS['phpgw_setup']->oProc =& $this->_oProc;
@@ -1325,7 +1559,7 @@
 
 		/**
 		 * Resort an attribute's position in relation to other attributes
-		 * 
+		 *
 		 * @param int $id the attribute db pk
 		 * @param string $resort the direction to move the field [up|down]
 		 */
@@ -1346,14 +1580,24 @@
 
 			$this->_db->transaction_begin();
 
-			$sql = "SELECT group_sort FROM phpgw_cust_attribute_group " 
+			$sql = "SELECT group_sort,parent_id FROM phpgw_cust_attribute_group "
 				. " WHERE location_id = {$location_id} AND id = {$id}";
 			$this->_db->query($sql, __LINE__, __FILE__);
 			$this->_db->next_record();
 			$attrib_sort	= $this->_db->f('group_sort');
+			$parent_id		= (int)$this->_db->f('parent_id');
+			if($parent_id)
+			{
+				$filter_parent = "AND parent_id = {$parent_id}";
+			}
+			else
+			{
+				$filter_parent = "AND (parent_id = 0 OR parent_id IS NULL)";
+			}
+
+			$sql = "SELECT MAX(group_sort) AS max_sort FROM phpgw_cust_attribute_group "
+				. " WHERE location_id = {$location_id} {$filter_parent}";
 
-			$sql = "SELECT MAX(group_sort) AS max_sort FROM phpgw_cust_attribute_group " 
-				. " WHERE location_id = {$location_id}";
 			$this->_db->query($sql,__LINE__,__FILE__);
 			$this->_db->next_record();
 			$max_sort	= $this->_db->f('max_sort');
@@ -1386,7 +1630,7 @@
 			}
 
 			$sql = "UPDATE phpgw_cust_attribute_group SET group_sort = {$attrib_sort}"
-				. " WHERE location_id = {$location_id} AND group_sort = {$new_sort}";
+				. " WHERE location_id = {$location_id} AND group_sort = {$new_sort} {$filter_parent}";
 			$this->_db->query($sql, __LINE__, __FILE__);
 
 			$sql = "UPDATE phpgw_cust_attribute_group SET group_sort = {$new_sort}"
@@ -1398,7 +1642,7 @@
 
 		/**
 		 * Resort an attribute's position in relation to other attributes
-		 * 
+		 *
 		 * @param int $id the attribute db pk
 		 * @param string $resort the direction to move the field [up|down]
 		 */
@@ -1419,19 +1663,19 @@
 
 			$this->_db->transaction_begin();
 
-			$sql = "SELECT group_id FROM phpgw_cust_attribute " 
+			$sql = "SELECT group_id FROM phpgw_cust_attribute "
 				. " WHERE location_id = {$location_id} AND id = {$id}";
 			$this->_db->query($sql, __LINE__, __FILE__);
 			$this->_db->next_record();
 			$group_id	= (int) $this->_db->f('group_id');
 
-			$sql = "SELECT attrib_sort FROM phpgw_cust_attribute " 
+			$sql = "SELECT attrib_sort FROM phpgw_cust_attribute "
 				. " WHERE location_id = {$location_id} AND id = {$id} AND group_id = {$group_id}";
 			$this->_db->query($sql, __LINE__, __FILE__);
 			$this->_db->next_record();
 			$attrib_sort	= $this->_db->f('attrib_sort');
 
-			$sql = "SELECT MAX(attrib_sort) AS max_sort FROM phpgw_cust_attribute " 
+			$sql = "SELECT MAX(attrib_sort) AS max_sort FROM phpgw_cust_attribute "
 				. " WHERE location_id = {$location_id} AND group_id = {$group_id}";
 			$this->_db->query($sql,__LINE__,__FILE__);
 			$this->_db->next_record();
@@ -1502,7 +1746,7 @@
 			$location_id	= (int) $location_id;
 			$attrib_id		= (int) $attrib_id;
 			
-			$sql = "SELECT * FROM phpgw_cust_choice " 
+			$sql = "SELECT * FROM phpgw_cust_choice "
 				. " WHERE location_id = {$location_id}"
 					. " AND attrib_id = {$attrib_id}"
 				. " ORDER BY choice_sort ASC, value";
@@ -1525,7 +1769,7 @@
 
 		/**
 		 * Finds the next ID for a record at a table
-		 * 
+		 *
 		 * @param string $table tablename in question
 		 * @param array  $key   conditions for finding the next id
 		 *
@@ -1582,6 +1826,7 @@
 				'C'			=> 'char',
 				'N'			=> 'decimal',
 				'D'			=> 'timestamp',
+				'DT'		=> 'timestamp',
 				'T'			=> 'text',
 				'R'			=> 'int',
 				'CH'		=> 'text',
@@ -1594,7 +1839,10 @@
 				'pwd' 		=> 'varchar',
 				'user' 		=> 'int',
 				'event'		=> 'int',
-				'bolean'	=> 'int'
+				'bolean'	=> 'int',
+				'custom1'	=> 'int',
+				'custom2'	=> 'int',
+				'custom3'	=> 'int',
 			);
 
 			if ( !isset($datatype_text[$datatype]) )
@@ -1627,7 +1875,10 @@
 				'pwd' 		=> 32,
 				'user' 		=> 4,
 				'event'		=> 4,
-				'bolean'	=> 2
+				'bolean'	=> 2,
+				'custom1'	=> 4,
+				'custom2'	=> 4,
+				'custom3'	=> 4
 			);
 
 			if ( !isset($datatype_precision[$datatype]) )
@@ -1636,4 +1887,38 @@
 			}
 			return $datatype_precision[$datatype];
 		}
+
+		/**
+		 * validate and translate function input
+		 *
+		 * @param string $data the data to validate
+		 *
+		 * @return input in appropriate format: array or single value
+		 */
+		protected function _validate_function_input($data)
+		{
+			if(ctype_digit($data))
+ 			{
+				return $data;
+			}
+			else
+ 			{
+ 				$_test_input = str_replace(array("\n","\r","\t", 'Array', 'array', '[', ']', '(', ')', ' ', '&gt;'), array(',','','','','','','','','','',''), stripslashes($data));
+				$_test_input= explode(',', $_test_input);
+				if(is_array($_test_input))
+				{
+					foreach($_test_input as $set)
+					{
+						$_set = explode('=', $set);
+						if(!$_set[1])
+						{
+							continue;
+						}
+						$_set[0] = str_replace(array("'", '"'), '', $_set[0]);
+						$data_set[$_set[0]] = trim(str_replace(array('"', "'"), '', $_set[1]));
+					}
+				}
+				return $data_set;
+			}
+		}
 	}
