@@ -10,7 +10,7 @@
 	* @link http://www.sanisoft.com/phplib/manual/DB_sql.php
 	* @package phpgwapi
 	* @subpackage database
-	* @version $Id: class.db.inc.php 7215 2011-04-12 20:06:07Z sigurdne $
+	* @version $Id: class.db.inc.php 11387 2013-10-23 13:18:01Z sigurdne $
 	*/
 
 	if ( empty($GLOBALS['phpgw_info']['server']['db_type']) )
@@ -54,10 +54,10 @@
 		/**
 		 * @var string $join the sql syntax to use for JOIN
 		 */
-		 var $join = ' INNER JOIN ';
+		 var $join = 'INNER JOIN';
 		 
 
-		 var $left_join = ' LEFT JOIN ';
+		 var $left_join = 'LEFT JOIN';
 		/**
 		 * @var string $like the sql syntax to use for a case insensitive LIKE
 		 */
@@ -83,15 +83,20 @@
 		*/
 		var $Password;
 
+		/**
+		* @var integer $Port Port used to connect to database
+		*/
+		var $Port;
+
 		/**
 		* @var bool $debug enable debugging
 		*/
 		var $debug = false;
 
 		/**
-		* @var string $Halt_On_Error should connection and script be terminated on error?
+		* @var string $Halt_On_Error "yes" (halt with message), "no" (ignore errors quietly), "report" (ignore errror, but spit a warning)
 		*/
-		var $Halt_On_Error = 'yes'; // should be true or false
+		var $Halt_On_Error = 'yes';
 
 		/*
 		 * @var boolean $Exception_On_Error should SQL throw exception on error ?
@@ -138,7 +143,7 @@
 			switch ( $this->Type )
 			{
 				case 'postgres':
-					$this->join = " JOIN ";
+					$this->join = "JOIN";
 					$this->like = "ILIKE";
 					break;
 				default:
@@ -193,6 +198,7 @@
 			return true;
 		}
 	
+
 		/**
 		* Open a connection to a database
 		*
@@ -200,8 +206,17 @@
 		* @param string $Host database host to connect to (optional)
 		* @param string $User name of database user (optional)
 		* @param string $Password password for database user (optional)
+		* @param int    $Port Port for database host (optional)
 		*/
-		abstract public function connect($Database = null, $Host = null, $User = null, $Password = null);
+		abstract public function connect($Database = null, $Host = null, $User = null, $Password = null, $Port = null);
+
+		/**
+		* set_fetch_single:fetch single record from pdo-object, no inpact on adodb
+		*
+		* @param bool    $value true/false
+		*/
+		abstract public function set_fetch_single($value = false);
+
 
 
 		/**
@@ -246,7 +261,7 @@
 		/**
 		* Discard the current query result
 		*/
-		public function free()
+		final public function free()
 		{
 			//unset($this->resultSet);
 			$this->resultSet = array();
@@ -349,7 +364,7 @@
 		 * @param array $value_set array of values to insert into the database
 		 * @return string the prepared sql, empty string for invalid input
 		 */
-		public function validate_insert($values)
+		final public function validate_insert($values)
 		{
 			if ( !is_array($values) || !count($values) )
 			{
@@ -384,7 +399,7 @@
 		 * @param array $value_set associative array of values to update the database with
 		 * @return string the prepared sql, empty string for invalid input
 		 */
-		public function validate_update($value_set)
+		final public function validate_update($value_set)
 		{
 			if ( !is_array($value_set) || !count($value_set) )
 			{
@@ -552,7 +567,7 @@
 		* @internal the string is compatiable with PHP's date()
 		* @return string the date format string
 		*/
-		public static function date_format()
+		final public static function date_format()
 		{
 			static $date_format = null;
 			if ( is_null($date_format) )
@@ -578,7 +593,7 @@
 		* @internal the string is compatiable with PHP's date()
 		* @return string the date format string
 		*/
-		public static function datetime_format()
+		final public static function datetime_format()
 		{
 			static $datetime_format = null;
 			if ( is_null($datetime_format) )
@@ -603,7 +618,7 @@
 		*
 		* @return string the formatted string
 		*/
-		public static function money_format($amount)
+		final public static function money_format($amount)
 		{
 			if ($GLOBALS['phpgw_info']['server']['db_type']=='mssql')
 			{
@@ -644,7 +659,7 @@
 		* @return int the next id
 		*/
 
-		public function next_id($table='',$key='')
+		final public function next_id($table='',$key='')
 		{
 			$where = '';
 			$condition = array();
@@ -670,7 +685,7 @@
 			return $next_id;
 		}
 
-		public function get_transaction()
+		final public function get_transaction()
 		{
 			return $this->Transaction;
 		}
