@@ -9,7 +9,7 @@
 	* @link http://www.sanisoft.com/phplib/manual/DB_sql.php
 	* @package phpgwapi
 	* @subpackage database
-	* @version $Id$
+	* @version $Id: class.db_adodb.inc.php 11612 2014-01-20 08:43:56Z sigurdne $
 	*/
 
 	if ( empty($GLOBALS['phpgw_info']['server']['db_type']) )
@@ -41,6 +41,17 @@
 			parent::__construct($query, $db_type, $delay_connect);
 		}
 
+
+		/**
+		* set_fetch_single:fetch single record from pdo-object, no inpact on adodb
+		*
+		* @param bool    $value true/false
+		*/
+		public function set_fetch_single($value = false)
+		{
+			$this->fetch_single = $value;
+		}
+
 		/**
 		* Called when object is cloned
 		*/
@@ -64,7 +75,7 @@
 		*/
 		function link_id()
 		{
-			if(!$this->adodb->isConnected())
+			if(!$this->adodb || $this->adodb->IsConnected())
 			{
 				$this->connect();
 			}
@@ -88,7 +99,7 @@
 		* @param string $User name of database user (optional)
 		* @param string $Password password for database user (optional)
 		*/
-		public function connect($Database = null, $Host = null, $User = null, $Password = null)
+		public function connect($Database = null, $Host = null, $User = null, $Password = null, $Port = null)
 		{
 			if ( !is_null($Database) )
 			{
@@ -113,9 +124,10 @@
 			$type = $this->Type;
 			if ( $type == 'mysql' )
 			{
-				$type = 'mysqlt';
+			//	$type = 'mysqlt';
+				$type = 'mysqli';
 			}
-			$this->adodb = newADOConnection($this->Type);
+			$this->adodb = newADOConnection($type);
 
 			if($this->fetchmode == 'ASSOC')
 			{
@@ -181,6 +193,11 @@
 				return '';
 			}
 
+			if ( !$this->adodb || $this->adodb->IsConnected() )
+			{
+				$this->connect();
+			}
+
 			if ( !is_object($this->adodb) )  //workaround
 			{
 				return addslashes($str);
@@ -220,7 +237,7 @@
 		*/
 		public function query($sql, $line = '', $file = '',$exec = false, $fetch_single = false)
 		{
-			if ( !$this->adodb->isConnected() )
+			if ( !$this->adodb || $this->adodb->IsConnected() )
 			{
 				$this->connect();
 			}
@@ -267,12 +284,15 @@
 		*/
 		public function limit_query($Query_String, $offset, $line = '', $file = '', $num_rows = 0)
 		{
-			if ( (int) $num_rows <= 0 )
+			$offset		= (int)$offset;
+			$num_rows	= (int)$num_rows;
+
+			if ( $num_rows <= 0 )
 			{
 				$num_rows = $GLOBALS['phpgw_info']['user']['preferences']['common']['maxmatchs'];
 			}
 			
-			if ( !$this->adodb->isConnected() )
+			if ( !$this->adodb || $this->adodb->IsConnected() )
 			{
 				$this->connect();
 			}
@@ -355,7 +375,12 @@
 		*/
 		public function transaction_begin()
 		{
-			$this->Transaction =  $this->adodb->StartTrans();
+			if(!$this->adodb || $this->adodb->IsConnected())
+			{
+				$this->connect();
+			}
+
+			$this->Transaction =  $this->adodb->BeginTrans();
 			return $this->Transaction;
 		}
 		
@@ -366,8 +391,8 @@
 		*/ 
 		public function transaction_commit()
 		{
-			$this->Transaction = false;
-			return $this->adodb->CompleteTrans();
+			$this->Transaction =  $this->adodb->CommitTrans();
+			return $this->Transaction;
 		}
 		
 		/**
@@ -381,7 +406,7 @@
 			$this->Transaction = false;
 			try
 			{
-				$this->adodb->FailTrans();
+				$this->adodb->RollbackTrans();
 				$ret = $this->adodb->HasFailedTrans();
 			}
 			catch(Exception $e)
@@ -552,7 +577,7 @@
 				{
 					if ($strip_slashes || ($this->auto_stripslashes && ! $strip_slashes))
 					{
-						return stripslashes($this->resultSet->fields[$name]);
+						return htmlspecialchars_decode(stripslashes($this->resultSet->fields[$name]));
 					}
 					else
 					{
@@ -600,7 +625,7 @@
 				//echo "depi: metadata";
 			}
 			
-			if(!$this->adodb->IsConnected())
+			if(!$this->adodb || $this->adodb->IsConnected())
 			{
 				$this->connect();
 			}
@@ -621,7 +646,7 @@
 		*/  
 		public function MetaForeignKeys($table, $owner=false, $upper=false)
 		{
-			if(!$this->adodb->IsConnected())
+			if(!$this->adodb || $this->adodb->IsConnected())
 			{
 				$this->connect();
 			}
@@ -642,7 +667,7 @@
 
 		public function metaindexes($table, $primary = false)
 		{
-			if(!$this->adodb->IsConnected())
+			if(!$this->adodb || $this->adodb->IsConnected())
 			{
 				$this->connect();
 			}
@@ -672,7 +697,7 @@
 		*/
 		public function table_names()
 		{
-			if(!$this->adodb->IsConnected())
+			if(!$this->adodb || $this->adodb->IsConnected())
 			{
 				$this->connect();
 			}
@@ -696,7 +721,7 @@
 		public function create_database($adminname = '', $adminpasswd = '')
 		{
 			//THIS IS CALLED BY SETUP DON'T KILL IT!
-			if ( $this->adodb->IsConnected() )
+			if ( $this->adodb && $this->adodb->IsConnected() )
 			{
 				$this->adodb->Disconnect(); //close the dead connection to be safe
 			}
@@ -704,7 +729,7 @@
 			$this->adodb = newADOConnection($GLOBALS['phpgw_info']['server']['db_type']);
 			$this->adodb->NConnect($this->Host, $adminname, $adminpasswd);
 			
-			if ( !$this->adodb->IsConnected() )
+			if ( !$this->adodb || $this->adodb->IsConnected() )
 			{
 				echo 'Connection FAILED<br />';
 				return False;
@@ -725,6 +750,7 @@
 					$this->adodb->Execute("GRANT ALL ON {$this->Database}.*"
 							. " TO {$this->User}@{$_SERVER['SERVER_NAME']}"
 							. " IDENTIFIED BY '{$this->Password}'");
+					break;
 				default:
 					//do nothing
 			}
