@@ -10,7 +10,7 @@
 	* @link http://www.sanisoft.com/phplib/manual/DB_sql.php
 	* @package phpgwapi
 	* @subpackage database
-	* @version $Id: class.db.inc.php 3450 2009-08-30 16:46:12Z sigurd $
+	* @version $Id: class.db_pdo.inc.php 11054 2013-04-11 11:32:15Z sigurdne $
 	*/
 
 	if ( empty($GLOBALS['phpgw_info']['server']['db_type']) )
@@ -48,6 +48,17 @@
 
 		}
 
+
+		/**
+		* set_fetch_single:fetch single record from pdo-object
+		*
+		* @param bool    $value true/false
+		*/
+		public function set_fetch_single($value = false)
+		{
+			$this->fetch_single = $value;
+		}
+
 		/**
 		* Destructor
 		*/
@@ -76,8 +87,9 @@
 		* @param string $Host database host to connect to (optional)
 		* @param string $User name of database user (optional)
 		* @param string $Password password for database user (optional)
+		* @param int    $Port Port for database host (optional)
 		*/
-		public function connect($Database = null, $Host = null, $User = null, $Password = null)
+		public function connect($Database = null, $Host = null, $User = null, $Password = null, $Port = null)
 		{
 			if ( !is_null($Database) )
 			{
@@ -99,6 +111,11 @@
 				$this->Password = $Password;
 			}
 
+			if ( !is_null($Port) )
+			{
+				$this->Port = $Port;
+			}
+
 			switch ( $this->Type )
 			{
 				case 'postgres':
@@ -131,9 +148,27 @@
 				case 'oracle':
 					try
 					{
+
+/*
+						$this->debug = true;
+						$tns = " 
+							(DESCRIPTION =
+							    (ADDRESS_LIST =
+							      (ADDRESS = (PROTOCOL = TCP)(HOST = {$this->Host})(PORT = 21521))
+							    )
+							    (CONNECT_DATA =
+							      (SERVICE_NAME = FELPROD)
+							    )
+							  )
+				       ";
+
+					    $this->db = new PDO("oci:dbname=".$tns,$this->User,$this->Password);
+*/
+						$port = $this->Port ? $this->Port : 1521;
+
 						$_charset = ';charset=AL32UTF8';
 				//		$_charset = '';
-						$this->db = new PDO("oci:dbname={$this->Host}/{$this->Database}{$_charset}", $this->User, $this->Password);
+						$this->db = new PDO("oci:dbname={$this->Host}:{$port}/{$this->Database}{$_charset}", $this->User, $this->Password);
 						unset($_charset);
 					}
 					catch(PDOException $e){}
@@ -213,9 +248,16 @@
 				return false;
 			}
 
-			if($this->Halt_On_Error == 'yes')
+			switch ( $this->Halt_On_Error )
 			{
-				$this->db->setAttribute(PDO::ATTR_ERRMODE, PDO::ERRMODE_EXCEPTION);
+				case 'yes':
+					$this->db->setAttribute(PDO::ATTR_ERRMODE, PDO::ERRMODE_EXCEPTION);
+					break;
+				case 'report':
+					$this->db->setAttribute(PDO::ATTR_ERRMODE, PDO::ERRMODE_WARNING);
+					break;
+				default:
+					$this->db->setAttribute(PDO::ATTR_ERRMODE, PDO::ERRMODE_SILENT);
 			}
 		}
 
@@ -306,11 +348,12 @@
 		* @param bool $fetch_single true for using fetch, false for fetchAll
 		* @return integer current query id if sucesful and null if fails
 		*/
-		public function query($sql, $line = '', $file = '', $exec = false, $fetch_single = false)
+		public function query($sql, $line = '', $file = '', $exec = false, $_fetch_single = false)
 		{
-//_Debug_Array($sql);
-			$this->_get_fetchmode();
-			$this->fetch_single = $fetch_single;
+			self::_get_fetchmode();
+			self::set_fetch_single($_fetch_single);
+
+			$fetch_single = $this->fetch_single;
 
 			if ( !$this->db )
 			{
@@ -343,22 +386,22 @@
 						$this->fetch_single = $fetch_single;
 					}
 */
-					if(!$fetch_single)
-					{
-						$this->resultSet = $statement_object->fetchAll($this->pdo_fetchmode);
-					}
-					else
+					if($fetch_single)
 					{
 						$this->resultSet = $statement_object->fetch($this->pdo_fetchmode);
 						$this->statement_object = $statement_object;
 						unset($statement_object);
 					}
+					else
+					{
+						$this->resultSet = $statement_object->fetchAll($this->pdo_fetchmode);
+					}
 				}
 			}
 
 			catch(PDOException $e)
 			{
-				if ( $e && $this->Halt_On_Error == 'yes' )
+				if ( $e && !$this->Exception_On_Error && $this->Halt_On_Error == 'yes' )
 				{
 					$this->transaction_abort();
 
@@ -372,7 +415,12 @@
 					}
 					exit;
 				}
-				else if($this->Exception_On_Error)
+				else if($this->Exception_On_Error && $this->Halt_On_Error == 'yes')
+				{
+					$this->transaction_abort();
+					throw $e;
+				}
+				else if($this->Exception_On_Error && $this->Halt_On_Error != 'yes')
 				{
 					throw $e;
 				}
@@ -444,7 +492,7 @@
 
 			catch(PDOException $e)
 			{
-				if ( $e && $this->Halt_On_Error == 'yes' )
+				if ( $e && !$this->Exception_On_Error && $this->Halt_On_Error == 'yes' )
 				{
 					$this->transaction_abort();
 
@@ -458,7 +506,12 @@
 					}
 					exit;
 				}
-				else if($this->Exception_On_Error)
+				else if($this->Exception_On_Error && $this->Halt_On_Error == 'yes')
+				{
+					$this->transaction_abort();
+					throw $e;
+				}
+				else if($this->Exception_On_Error && $this->Halt_On_Error != 'yes')
 				{
 					throw $e;
 				}
@@ -536,6 +589,11 @@
 			echo "<b>db::{$bt[0]['function']} Called from file: {$bt[0]['file']} line: {$bt[0]['line']}</b><br/>";
 			unset($bt);
 */
+			if(!$this->db)
+			{
+				$this->connect();
+			}
+			
 			$this->Transaction = $this->db->beginTransaction();
 			return $this->Transaction;
 		}
@@ -563,6 +621,11 @@
 		*/
 		public function transaction_abort()
 		{
+/*
+			$bt = debug_backtrace();
+			echo "<b>db::{$bt[0]['function']} Called from file: {$bt[0]['file']} line: {$bt[0]['line']}</b><br/>";
+			unset($bt);
+*/
 			$ret = false;
 
 			if($this->Transaction)
@@ -747,7 +810,7 @@
 				{
 					if ($strip_slashes || ($this->auto_stripslashes && ! $strip_slashes))
 					{
-						return stripslashes($this->Record[$name]);
+						return htmlspecialchars_decode(stripslashes($this->Record[$name]));
 					}
 					else
 					{
@@ -961,12 +1024,34 @@
 				$this->db = null; //close the dead connection to be safe
 			}
 
-			$this->connect();
-			
+			switch ($GLOBALS['phpgw_info']['server']['db_type'])
+			{
+				case 'postgres':
+					$_database = 'postgres';
+					break;
+				default:
+					$_database = null;
+			}
+
+			$database = $this->Database;
+			try
+			{
+				$this->connect($_database);
+			}
+			catch(Exception $e)
+			{
+				if($e)
+				{
+					throw $e;
+					return false;
+				}
+			}
+
+			$this->Database = $database;
+
 			if ( !$this->db )
 			{
-				echo 'Connection FAILED<br />';
-				return False;
+				throw new Exception('ERROR: Connection FAILED');
 			}
 
 			if( !preg_match('/^[a-z0-9_]+$/i', $this->Database) )
@@ -975,8 +1060,20 @@
 			}
 
 			//create the db
-			$this->db->exec("CREATE DATABASE {$this->Database}");
-		
+			$ok = false;
+			try
+			{
+				$ok = $this->db->exec("CREATE DATABASE {$this->Database}");
+			}
+
+			catch(PDOException $e)
+			{
+				if ( $e )
+				{
+					throw $e;
+				}
+			}
+
 			//Grant rights on the db
 			switch ($GLOBALS['phpgw_info']['server']['db_type'])
 			{
@@ -984,11 +1081,12 @@
 					$this->db->exec("GRANT ALL ON {$this->Database}.*"
 							. " TO {$this->User}@{$_SERVER['SERVER_NAME']}"
 							. " IDENTIFIED BY '{$this->Password}'");
+					break;
 				default:
 					//do nothing
 			}
 			$this->db = null;
-			return True;
+			return true;
 		}
 
 		/**
