@@ -7,7 +7,7 @@
 	* @license http://www.fsf.org/licenses/gpl.html GNU General Public License
 	* @package phpgroupware
 	* @subpackage phpgwapi
-	* @version $Id: class.js.inc.php 7026 2011-02-21 07:59:06Z sigurdne $
+	* @version $Id: class.js.inc.php 11130 2013-05-24 11:33:12Z sigurdne $
 	*/
 
 	/*
@@ -63,6 +63,15 @@
 		*/
 		protected $files = array();
 
+
+		/**
+		 *
+		 * @var array list of "external files to be included in the head section of a page
+		 * Some times while using libs and such its not fesable to move js files to /app/js/package/
+		 * because the js files are using relative paths
+		 */
+		protected $external_files;
+
 		/**
 		* Constructor
 		*/
@@ -119,6 +128,12 @@
 		public function get_script_links()
 		{
 			$combine = true;
+			
+			if (isset($GLOBALS['phpgw_info']['server']['no_jscombine']) && $GLOBALS['phpgw_info']['server']['no_jscombine'])
+			{
+				$combine = false;			
+			}
+			
 			if(ini_get('suhosin.get.max_value_length') && ini_get('suhosin.get.max_value_length') < 2000)
 			{
 				$combine = false;
@@ -161,6 +176,25 @@
 				}
 			}
 
+			if ( !empty($this->external_files) && is_array($this->external_files) )
+			{
+				foreach($this->external_files as $file)
+				{					
+					if($combine)
+					{
+						// Add file path to array and replace path separator with "--" for URL-friendlyness
+						$jsfiles[] = str_replace('/', '--', ltrim($file,'/'));
+					}
+					else
+					{
+						$links .= <<<HTML
+						<script type="text/javascript" src="{$GLOBALS['phpgw_info']['server']['webserver_url']}/{$file}" >
+						</script>
+HTML;
+					}
+				}
+			}
+
 			if($combine)
 			{
 				$cachedir = urlencode($GLOBALS['phpgw_info']['server']['temp_dir']);
@@ -277,4 +311,17 @@
 				. '//]]' ."\n"
 				. "</script>\n";
 		}
+
+		/**
+		 * Adds js file to external files.
+		 *
+		 * @param string $file Full path to js file relative to root of phpgw install 
+		 */
+		function add_external_file($file)
+		{
+			if ( is_file(PHPGW_SERVER_ROOT . "/$file") )
+			{
+				$this->external_files[] = $file;
+			}
+		}
 	}
