@@ -9,7 +9,7 @@
 	* @license http://www.fsf.org/licenses/lgpl.html GNU Lesser General Public License
 	* @package phpgroupware
 	* @subpackage phpgwapi
-	* @version $Id: class.phpgw.inc.php 7488 2011-08-10 18:26:48Z sigurdne $
+	* @version $Id: class.phpgw.inc.php 11109 2013-05-15 08:03:03Z sigurdne $
 	*/
 
 	/*
@@ -174,15 +174,16 @@
 		 * will use PHP_SELF. Wrapper to session->link()
 		 *
 		 * @access public
-		 * @param string $string The url the link is for
-		 * @param string $extravars	Extra params to be passed to the url
-		 * @param string $redirect is the resultant link being used in a header('Location:' ... redirect?
+		 * @param string  $string The url the link is for
+		 * @param array   $extravars	Extra params to be passed to the url
+		 * @param boolean $redirect is the resultant link being used in a header('Location:' ... redirect?
+		 * @param boolean $external is the resultant link being used as external access (i.e url in emails..)
 		 * @return string The full url after processing
 		 * @see	session->link()
 		 */
-		public function link($url = '', $extravars = array(), $redirect = false)
+		public function link($url = '', $extravars = array(), $redirect = false, $external = false)
 		{
-			return $this->session->link($url, $extravars, $redirect);
+			return $this->session->link($url, $extravars, $redirect, $external);
 		}
 
 		/**
@@ -407,6 +408,7 @@
 						$value = htmlspecialchars($value, ENT_COMPAT, 'UTF-8');
 						break;
 
+					case 'boolean':
 					case 'bool':
 						if ( preg_match('/^[false|0|no]$/', $value) )
 						{
@@ -416,6 +418,7 @@
 
 					case 'float':
 					case 'double':
+						$value = str_replace(array(' ',','),array('','.'), $value);
 						if ( (float) $value == $value )
 						{
 								return (float) $value;
@@ -423,6 +426,7 @@
 						return (float) $default;
 					
 					case 'int':
+					case 'integer':
 					case 'number':
 						if ( (int) $value == $value )
 						{
