@@ -8,7 +8,7 @@
 	* @license http://www.fsf.org/licenses/gpl.html GNU General Public License
 	* @package phpgwapi
 	* @subpackage database
-	* @version $Id: class.schema_proc.inc.php 7349 2011-06-06 09:23:43Z sigurdne $
+	* @version $Id: class.schema_proc.inc.php 10522 2012-11-20 10:24:32Z sigurdne $
 	*/
 
 	/**
@@ -32,7 +32,7 @@
 				case 'mysql':
 				$this->m_oTranslator	= createObject('phpgwapi.schema_proc_mysql');
 				break;
-				
+
 				case 'postgres':
 				$this->m_oTranslator	= createObject('phpgwapi.schema_proc_pgsql');
 				break;
@@ -44,13 +44,13 @@
 				case 'sapdb':
 				$this->m_oTranslator	= createObject('phpgwapi.schema_proc_sapdb');
 				break;
-				
+
 				case 'mssql':
 				$this->m_oTranslator	= createObject('phpgwapi.schema_proc_mssql');
 				break;
 
 				default:
-				//what now?				
+				//what now?
 			}
 			$this->m_oDeltaProc		= createObject('phpgwapi.schema_proc_array');
 			$this->m_aTables		= array();
@@ -72,44 +72,49 @@
 				$sSequenceSQL = '';
 				$sTriggerSQL = '';
 				$this->m_oTranslator->indexes_sql = array();
-				if($this->_GetTableSQL($sTableName, $aTableDef, $sTableSQL, $sSequenceSQL, $sTriggerSQL))
+
+				try
 				{
-					$sTableSQL = "CREATE TABLE $sTableName (\n$sTableSQL\n)"
-						. $this->m_oTranslator->m_sStatementTerminator;
-					if($sSequenceSQL != '')
-					{
-						$sAllTableSQL .= $sSequenceSQL . "\n";
-					}
-
-					if($sTriggerSQL != '')
-					{
-						$sAllTableSQL .= $sTriggerSQL . "\n";
-					}
-					
-					$sAllTableSQL .= $sTableSQL . "\n\n";
-
-					// postgres and mssql
-					if(isset($this->m_oTranslator->indexes_sql) && is_array($this->m_oTranslator->indexes_sql) && count($this->m_oTranslator->indexes_sql)>0)
-					{
-						foreach($this->m_oTranslator->indexes_sql as $key => $sIndexSQL)
-						{
-							$ix_name = $key.'_'.$sTableName.'_idx';
-							$IndexSQL = str_replace(array('__index_name__','__table_name__'), array($ix_name,$sTableName), $sIndexSQL);
-							$sAllTableSQL .= $IndexSQL . "\n\n";
-						}
-					}
+					$this->_GetTableSQL($sTableName, $aTableDef, $sTableSQL, $sSequenceSQL, $sTriggerSQL);
 				}
-				else
+
+				catch(Exception $e)
 				{
 					if($bOutputHTML)
 					{
 						print('<br>SQL:<pre>' . $sAllTableSQL . '</pre><br>');
-						print('<br>Failed generating script for <b>' . $sTableName . '</b><br>');
-						echo '<pre style="text-align: left;">'.$sTableName.' = '; print_r($aTableDef); echo "</pre>\n";
 					}
 
+					print('<br>Error: Failed generating script for <b>' . $sTableName . '</b><br>');
+					echo '<pre style="text-align: left;">'.$sTableName.' = '; print_r($aTableDef); echo "</pre>\n";
+					echo $e->getMessage();
 					return false;
 				}
+
+				$sTableSQL = "CREATE TABLE $sTableName (\n$sTableSQL\n)"
+					. $this->m_oTranslator->m_sStatementTerminator;
+				if($sSequenceSQL != '')
+				{
+					$sAllTableSQL .= $sSequenceSQL . "\n";
+				}
+
+				if($sTriggerSQL != '')
+				{
+					$sAllTableSQL .= $sTriggerSQL . "\n";
+				}
+
+				$sAllTableSQL .= $sTableSQL . "\n\n";
+
+				// postgres and mssql
+				if(isset($this->m_oTranslator->indexes_sql) && is_array($this->m_oTranslator->indexes_sql) && count($this->m_oTranslator->indexes_sql)>0)
+				{
+					foreach($this->m_oTranslator->indexes_sql as $key => $sIndexSQL)
+					{
+						$ix_name = $key.'_'.$sTableName.'_idx';
+						$IndexSQL = str_replace(array('__index_name__','__table_name__'), array($ix_name,$sTableName), $sIndexSQL);
+						$sAllTableSQL .= $IndexSQL . "\n\n";
+					}
+				}
 			}
 
 			if($bOutputHTML)
@@ -321,29 +326,34 @@
 			while(list($sFieldName, $aFieldAttr) = each($aTableDef['fd']))
 			{
 				$sFieldSQL = '';
-				if($this->_GetFieldSQL($aFieldAttr, $sFieldSQL))
+
+				try
 				{
-					if($sTableSQL != '')
-					{
-						$sTableSQL .= ",\n";
-					}
-
-					$sTableSQL .= "$sFieldName $sFieldSQL";
-
-					if($aFieldAttr['type'] == 'auto')
-					{
-						$sbufTriggerFD[] = $sFieldName;
-						if($this->m_oTranslator->GetSequenceSQL($sTableName, $sSequenceSQL))
-						{
-							$sTableSQL .= sprintf(" DEFAULT nextval('seq_%s')", $sTableName);
-						}
-					}
+					$this->_GetFieldSQL($aFieldAttr, $sFieldSQL);
 				}
-				else
+				catch(Exception $e)
 				{
-					if($DEBUG) { echo 'GetFieldSQL failed for ' . $sFieldName; }
+					$_message = "Error: GetFieldSQL failed for <b>{$sTableName}::{$sFieldName}</b>. ";
+					$_message .=  $e->getMessage();
+					throw new Exception($_message);
 					return False;
 				}
+
+				if($sTableSQL != '')
+				{
+					$sTableSQL .= ",\n";
+				}
+
+				$sTableSQL .= "$sFieldName $sFieldSQL";
+
+				if($aFieldAttr['type'] == 'auto')
+				{
+					$sbufTriggerFD[] = $sFieldName;
+					if($this->m_oTranslator->GetSequenceSQL($sTableName, $sSequenceSQL))
+					{
+						$sTableSQL .= sprintf(" DEFAULT nextval('seq_%s')", $sTableName);
+					}
+				}
 			}
 
 			$sUCSQL = '';
@@ -478,9 +488,10 @@
 			// Translate the type for the DBMS
 			$sBufNullable = '';
 			$sBufDefault = '';
+
 			if($sFieldSQL = $this->m_oTranslator->TranslateType($sType, $iPrecision, $iScale))
 			{
-				if($bNullable == False)
+				if($bNullable === false || $bNullable === 'False')
 				{
 					$sBufNullable = ' NOT NULL';
 					//$sFieldSQL .= ' NOT NULL';
@@ -490,12 +501,12 @@
 					$sBufNullable = ' NULL';
 					//$sFieldSQL .= ' NULL';
 				}
-				
+
 				if($sDefault === '0' || $sDefault === 0)
 				{
 					$sBufDefault = ' DEFAULT 0';
 					//$sFieldSQL .= ' DEFAULT 0';
-				}								
+				}
 				elseif(!is_numeric($sDefault) && $sDefault != '')
 				{
 					if($DEBUG) { echo '<br>_GetFieldSQL(): Calling TranslateDefault for "' . $sDefault . '"'; }
@@ -509,7 +520,7 @@
 					$sBufDefault .= " DEFAULT $sDefault";
 					//$sFieldSQL .= " DEFAULT $sDefault";
 				}
-				
+
 				if($this->dbms == 'oracle')
 				{
 					$sFieldSQL .= "{$sBufDefault}{$sBufNullable}";
@@ -521,8 +532,10 @@
 				if($DEBUG) { echo '<br>_GetFieldSQL(): Outgoing SQL:   ' . $sFieldSQL; }
 				return true;
 			}
-
-			if($DEBUG) { echo '<br>Failed to translate field: type[' . $sType . '] precision[' . $iPrecision . '] scale[' . $iScale . ']<br>'; }
+			else
+			{
+				throw new Exception( 'Failed to translate field: type[' . $sType . '] precision[' . $iPrecision . '] scale[' . $iScale . ']');
+			}
 
 			return False;
 		}
@@ -567,7 +580,7 @@
 				{
 					$sFields .= ',';
 				}
-				
+
 				if(is_array($sField))
 				{
 					$sField = implode(',', $sField);
@@ -632,17 +645,17 @@
 			{
 				$sFKSQL = implode(",\n",$sFKSQLarr);
 			}
-			
+
 			return True;
 		}
-		
+
 		/**
 		* Create Index on tables from tables_update
 		*
 		* @param string|array $aFields fields hold by the index
 		* @param string $sTableName table affected
 		*/
-		
+
 		function CreateIndex($aFields, $sTableName)
 		{
 			if (count($aFields) < 1 || !$sTableName)
@@ -674,12 +687,12 @@
 				}
 				++$i;
 			}
-			
+
 			if($this->dbms == 'mysql' && $sIXSQL)
 			{
 				$this->query($sIXSQL, __LINE__, __FILE__);
 			}
-			
+
 			// postgres and mssql
 			if(isset($this->m_oTranslator->indexes_sql) && is_array($this->m_oTranslator->indexes_sql) && count($this->m_oTranslator->indexes_sql)>0)
 			{
@@ -689,7 +702,7 @@
 					$IndexSQL = str_replace(array('__index_name__','__table_name__'), array($ix_name,$sTableName), $sIndexSQL);
 					$this->query($IndexSQL, __LINE__, __FILE__);
 				}
-			}			
+			}
 		}
 
 		/**
