@@ -8,7 +8,7 @@
 	* @license http://www.fsf.org/licenses/gpl.html GNU General Public License
 	* @package phpgwapi
 	* @subpackage database
-	* @version $Id: class.schema_proc_mysql.inc.php 7333 2011-05-31 05:59:50Z sigurdne $
+	* @version $Id: class.schema_proc_mysql.inc.php 11345 2013-09-30 13:47:35Z sigurdne $
 	*/
  
 	/**
@@ -151,7 +151,7 @@
 			}
 			else if ($sDefault == 'current_date' || $sDefault == 'current_timestamp')
 			{
-				$ret= 'now()';
+				$ret= 'CURRENT_TIMESTAMP';
 			}
 			else
 			{
