@@ -8,7 +8,7 @@
 	* @license http://www.fsf.org/licenses/lgpl.html GNU Lesser General Public License
 	* @package phpgwapi
 	* @subpackage communication
-	* @version $Id: class.send.inc.php 6465 2010-10-10 17:22:31Z sigurdne $
+	* @version $Id: class.send.inc.php 11296 2013-09-17 06:31:57Z sigurdne $
 	*/
 
 	/**
@@ -42,7 +42,7 @@
 			}
 			if ($sender == '')
 			{
-				$sender = $GLOBALS['phpgw_info']['user']['fullname'].' <'.$GLOBALS['phpgw_info']['user']['preferences']['email']['address'].'>';
+				$sender = $GLOBALS['phpgw_info']['user']['fullname'];
 			}
 
 			switch( $service )
@@ -56,6 +56,7 @@
 		function send_email($to, $subject, $body, $msgtype, $cc, $bcc, $from, $sender, $content_type, $ignored,$attachments, $receive_notification)
 		{
 			$smtp = createObject('phpgwapi.mailer_smtp');
+			$from = str_replace(array('[',']'),array('<','>'),$from);
 			$from_array = split('<', $from);
 			unset($from);
 			if ( count($from_array) == 2 )
@@ -66,8 +67,9 @@
 			else
 			{
 				$smtp->From = $from_array[0];
+				$smtp->FromName = $sender;
 			}
-			
+/*			
 			if(strpos($to,','))
 			{
 				$delimiter = ',';
@@ -76,10 +78,13 @@
 			{
 				$delimiter = ';';
 			}
+*/
+			$delimiter = ';';
 			$to = explode($delimiter, $to);
 			
 			foreach ($to as $entry)
 			{
+				$entry = str_replace(array('[',']'),array('<','>'),$entry);
 				$to_array = split('<', $entry);
 				if ( count($to_array) == 2 )
 				{
@@ -93,6 +98,7 @@
 
 			if($cc)
 			{
+/*
 				if(strpos($cc,','))
 				{
 					$delimiter = ',';
@@ -101,10 +107,13 @@
 				{
 					$delimiter = ';';
 				}
+*/
+				$delimiter = ';';
 				$cc = explode($delimiter, $cc);
 			
 				foreach ($cc as $entry)
 				{
+					$entry = str_replace(array('[',']'),array('<','>'),$entry);
 					$cc_array = split('<', $entry);
 					if ( count($cc_array) == 2 )
 					{
@@ -118,6 +127,7 @@
 			}
 			if($bcc)
 			{
+/*
 				if(strpos($bcc,','))
 				{
 					$delimiter = ',';
@@ -126,10 +136,13 @@
 				{
 					$delimiter = ';';
 				}
+*/
+				$delimiter = ';';
 				$bcc = explode($delimiter, $bcc);
 			
 				foreach ($bcc as $entry)
 				{
+					$entry = str_replace(array('[',']'),array('<','>'),$entry);
 					$bcc_array = split('<', $entry);
 					if ( count($bcc_array) == 2 )
 					{
@@ -144,16 +157,11 @@
 			$smtp->IsSMTP();
 			$smtp->Subject = $subject;
 			$smtp->Body    = $body;
-			$smtp->AddCustomHeader('X-Mailer: phpGroupWare (http://www.phpgroupware.org)');
+			$smtp->AddCustomHeader('X-Mailer: fmsystem (http://www.fmsystem.no)');
 			if($receive_notification)
 			{
 				$smtp->AddCustomHeader("Disposition-Notification-To: {$smtp->From}");
 			}
-			$smtp->Port = $GLOBALS['phpgw_info']['server']['smtp_port'] ? $GLOBALS['phpgw_info']['server']['smtp_port'] : 25;
-			$smtp->Host 	= $GLOBALS['phpgw_info']['server']['smtp_server'];
-			$smtp->Encoding = '8bit';
-			$smtp->CharSet = 'utf-8';
-			$smtp->PluginDir = PHPGW_SERVER_ROOT."/phpgwapi/inc/phpmailer/";
 
 			if($content_type =='html')
 			{
@@ -179,13 +187,6 @@
 				}
 			}
 
-			if ( $GLOBALS['phpgw_info']['server']['smtp_auth'] == 'True' )
-			{
-				$smtp->SMTPAuth	= true;
-				$smtp->Username	= $GLOBALS['phpgw_info']['server']['smtp_user'];
-				$smtp->Password	= $GLOBALS['phpgw_info']['server']['smtp_password'];
-			}
-
 			// set a higher timeout for big messages
 			@set_time_limit(120);
 			#$smtp->SMTPDebug = 10;
