@@ -10,7 +10,7 @@
 	* @license http://www.fsf.org/licenses/lgpl.html GNU Lesser General Public License
 	* @package phpgroupware
 	* @subpackage phpgwapi
-	* @version $Id: class.sessions.inc.php 7103 2011-03-10 10:23:40Z sigurdne $
+	* @version $Id: class.sessions.inc.php 11303 2013-09-18 18:59:11Z sigurdne $
 	*/
 
 	/*
@@ -535,11 +535,20 @@
 		* @param string  $url       a url relative to the phpgroupware install root
 		* @param array   $extravars query string arguements
 		* @param boolean $redirect  is this for a redirect link ?
+		* @param boolean $external is the resultant link being used as external access (i.e url in emails..)
 		*
 		* @return string generated url
 		*/
-		public function link($url, $extravars = array(), $redirect=false)
+		public function link($url, $extravars = array(), $redirect=false, $external = false)
 		{
+
+			$custom_frontend = isset($GLOBALS['phpgw_info']['flags']['custom_frontend']) && $GLOBALS['phpgw_info']['flags']['custom_frontend'] ? $GLOBALS['phpgw_info']['flags']['custom_frontend'] : '';
+
+			if($custom_frontend && substr($url, 0, 4) != 'http')
+			{
+				$url = '/' . $custom_frontend . '/' . ltrim($url, '/');
+			}
+
 			//W3C Compliant in markup	
 			$term = '&amp;'; 
 			if ( $redirect )
@@ -582,6 +591,14 @@
 				}
 			}
 
+			if($external)
+			{
+				if(substr($url, 0, 4) != 'http')
+				{
+					$url = "http://{$GLOBALS['phpgw_info']['server']['hostname']}{$url}";
+				}
+			}
+
 			if ( isset($GLOBALS['phpgw_info']['server']['enforce_ssl'])
 				&& $GLOBALS['phpgw_info']['server']['enforce_ssl'])
 			{
@@ -625,29 +642,32 @@
 				}
 			}
 
-			/* add session params if not using cookies */
-			if ( !isset($GLOBALS['phpgw_info']['server']['usecookies'])
-				|| !$GLOBALS['phpgw_info']['server']['usecookies'])
+			if(!$external)
 			{
-				if ( is_array($extravars) )
+				/* add session params if not using cookies */
+				if ( !isset($GLOBALS['phpgw_info']['server']['usecookies'])
+					|| !$GLOBALS['phpgw_info']['server']['usecookies'])
 				{
-					$extravars = array_merge($extravars, $this->_get_session_vars());
+					if ( is_array($extravars) )
+					{
+						$extravars = array_merge($extravars, $this->_get_session_vars());
+					}
+					else
+					{
+						$extravars = $this->_get_session_vars();
+					}
 				}
-				else
+
+				//used for repost prevention
+				$extravars['click_history'] = $this->generate_click_history();
+
+				/* enable easy use of xdebug */
+				if ( isset($_REQUEST['XDEBUG_PROFILE']) )
 				{
-					$extravars = $this->_get_session_vars();
+					$extravars['XDEBUG_PROFILE'] = 1;
 				}
 			}
 
-			//used for repost prevention
-			$extravars['click_history'] = $this->generate_click_history();
-
-			/* enable easy use of xdebug */
-			if ( isset($_REQUEST['XDEBUG_PROFILE']) )
-			{
-				$extravars['XDEBUG_PROFILE'] = 1;
-			}
-
 			if ( is_array($extravars) ) //we have something to append
 			{
 				$url .= '?' . http_build_query($extravars, null, $term);
@@ -1111,6 +1131,10 @@
 			$this->_sessionid = $sessionid;
 
 			$session = $this->read_session($sessionid);
+			$this->_session_flags = $session['session_flags'];
+
+			$lid_data = explode('#', $session['session_lid']);
+			$this->_account_lid = $lid_data[0];
 
 			if ($GLOBALS['phpgw_info']['server']['auth_type'] != 'ntlm') //Timeout make no sense for SSO
 			{
@@ -1120,16 +1144,30 @@
 				{
 					if(isset($session['session_dla']))
 					{
+						if(is_object($GLOBALS['phpgw']->log))
+						{
+							$GLOBALS['phpgw']->log->message(array(
+								'text' => 'W-VerifySession, session for %1 is expired by %2 sec, inactive for %3 sec',
+								'p1'   => $this->_account_lid,
+								'p2'   => ($timeout - $session['session_dla']),
+								'p3'   => (time() - $session['session_dla']),
+								'line' => __LINE__,
+								'file' => __FILE__
+							));
+							$GLOBALS['phpgw']->log->commit();
+						}
+						if(is_object($GLOBALS['phpgw']->crypto))
+						{
+							$GLOBALS['phpgw']->crypto->cleanup();
+							unset($GLOBALS['phpgw']->crypto);
+						}
+
 						$this->cd_reason = 10;
 					}
 					return false;
 				}
 			}
 
-			$this->_session_flags = $session['session_flags'];
-
-			$lid_data = explode('#', $session['session_lid']);
-			$this->_account_lid = $lid_data[0];
 
 			if ( isset($lid_data[1]) )
 			{
@@ -1447,17 +1485,21 @@
 			$block_time = time() - $GLOBALS['phpgw_info']['server']['block_time'] * 60;
 			$ip			= $this->_db->db_addslashes($ip);
 
-			$sql = 'SELECT COUNT(*) AS cnt FROM phpgw_access_log'
+			if ( isset($GLOBALS['phpgw_info']['server']['sessions_checkip']) && $GLOBALS['phpgw_info']['server']['sessions_checkip'] )
+			{
+				$sql = 'SELECT COUNT(*) AS cnt FROM phpgw_access_log'
 							. " WHERE account_id = 0 AND ip = '{$ip}' AND li > {$block_time}";
 
-			$this->_db->query($sql, __LINE__, __FILE__);
-			$this->_db->next_record();
+				$this->_db->query($sql, __LINE__, __FILE__);
+				$this->_db->next_record();
 
-			$false_ip = $this->_db->f('cnt');
-			if ( $false_ip > $GLOBALS['phpgw_info']['server']['num_unsuccessful_ip'] )
-			{
-				$blocked = true;
+				$false_ip = $this->_db->f('cnt');
+				if ( $false_ip > $GLOBALS['phpgw_info']['server']['num_unsuccessful_ip'] )
+				{
+					$blocked = true;
+				}
 			}
+
 			$login	= $this->_db->db_addslashes($login);
 			$sql	= 'SELECT COUNT(*) AS cnt FROM phpgw_access_log'
 					. " WHERE account_id = 0 AND (loginid='{$login}' OR loginid LIKE '$login#%')"
