@@ -9,7 +9,7 @@
 	* @license http://www.fsf.org/licenses/lgpl.html GNU Lesser General Public License
 	* @package phpgwapi
 	* @subpackage application
-	* @version $Id: class.translation.inc.php 7227 2011-04-15 11:51:34Z sigurdne $
+	* @version $Id: class.translation.inc.php 10166 2012-10-09 07:54:03Z sigurdne $
 	*/
 
 	/**
@@ -347,8 +347,7 @@
 
 				if ($upgrademethod == 'dumpold')
 				{
-					// dont delete the custom main- & loginscreen messages every time
-					$GLOBALS['phpgw']->db->query("DELETE FROM phpgw_lang where app_name != 'mainscreen' AND app_name != 'loginscreen'",__LINE__,__FILE__);
+					$GLOBALS['phpgw']->db->query('DELETE FROM phpgw_lang',__LINE__,__FILE__);
 					$GLOBALS['phpgw_info']['server']['lang_ctimes'] = array();
 				}
 
@@ -372,7 +371,7 @@
 
 						if ($GLOBALS['phpgw']->db->f('cnt') != 0)
 						{
-							$error .= "Lang code '{$lang}' already installed: skipping<br>\n";
+							echo "<div class=\"error\">Lang code '{$lang}' already installed: skipping</div>\n";
 							continue;
 						}
 					}
@@ -429,7 +428,7 @@
 							}
 						}
 
-						$GLOBALS['phpgw_info']['server']['lang_ctimes'][$lang][$app['name']] = filectime($appfile);
+						$GLOBALS['phpgw_info']['server']['lang_ctimes'][$lang][$app] = filectime($appfile);
 					}
 
 					foreach($raw as $app_name => $ids)
