@@ -8,7 +8,7 @@
 	* @license http://www.fsf.org/licenses/lgpl.html GNU Lesser General Public License
 	* @package phpgwapi
 	* @subpackage vfs
-	* @version $Id: class.vfs_sql.inc.php 7200 2011-04-08 10:12:03Z sigurdne $
+	* @version $Id: class.vfs_sql.inc.php 11335 2013-09-26 18:18:24Z sigurdne $
 	*/
 
 	/**
@@ -110,7 +110,14 @@
 		 */
 		function in_docroot($path)
 		{
-			$docroots = array(PHPGW_SERVER_ROOT, $_SERVER['DOCUMENT_ROOT']);
+			//$docroots = array(PHPGW_SERVER_ROOT, $_SERVER['DOCUMENT_ROOT']);
+			$docroots = array(PHPGW_SERVER_ROOT);
+			//in case vfs is called from cli (cron-job)
+
+			if($_SERVER['DOCUMENT_ROOT'])
+			{
+				$docroots[] = $_SERVER['DOCUMENT_ROOT'];
+			}
 
 			foreach ($docroots as $docroot)
 			{
@@ -1066,6 +1073,11 @@
 		 */
 		function cp ($data)
 		{
+			if(!$data['from'])
+			{
+				throw new Exception('nothing to copy from');
+			}
+
 			if (!is_array ($data))
 			{
 				$data = array ();
