@@ -8,7 +8,7 @@
 	* @copyright Copyright (C) 2000-2005 Free Software Foundation, Inc. http://www.fsf.org/
 	* @license http://www.gnu.org/licenses/gpl.html GNU General Public License
 	* @package phpgroupware
-	* @version $Id: include_login.inc.php 6840 2011-01-25 08:03:38Z sigurdne $
+	* @version $Id: include_login.inc.php 11324 2013-09-25 16:23:28Z sigurdne $
 	*/
 
 	/* 
@@ -143,14 +143,7 @@
 				case 10:
 					$GLOBALS['phpgw']->session->phpgw_setcookie('kp3');
 					$GLOBALS['phpgw']->session->phpgw_setcookie('domain');
-
-					// fix for bug php4 expired sessions bug
-					if($GLOBALS['phpgw_info']['server']['sessions_type'] == 'php')
-					{
-//						$GLOBALS['phpgw']->session->phpgw_setcookie('phpgwsessid');
-					}
-
-					return lang('Your session could not be verified.');
+					return lang('sorry, your session has expired');
 				default:
 					return '&nbsp;';
 			}
@@ -284,6 +277,7 @@
 				foreach($GLOBALS['phpgw_domain'] as $domain_name => $domain_vars)
 				{
 					$this->tmpl->set_var('domain_name', $domain_name);
+					$this->tmpl->set_var('domain_display_name', str_replace('_', ' ', $domain_name));
 
 					if (isset($_COOKIE['last_domain']) && $_COOKIE['last_domain'] == $domain_name)
 					{
@@ -419,8 +413,17 @@
 			}
 
 			$system_name = isset($GLOBALS['phpgw_info']['server']['system_name']) ? $GLOBALS['phpgw_info']['server']['system_name'] : 'Portico Estate';
-			$this->tmpl->set_var('login_url', $GLOBALS['phpgw_info']['server']['webserver_url'] . '/'.$variables['partial_url'].'?' . http_build_query($extra_vars) );
-			$this->tmpl->set_var('registration_url',$GLOBALS['phpgw_info']['server']['webserver_url'] . '/registration/');
+			
+			if($variables['lang_frontend'])
+			{
+				$system_name .= "::{$variables['lang_frontend']}";
+			}
+
+			$webserver_url = rtrim($GLOBALS['phpgw_info']['server']['webserver_url'], '/');
+			$partial_url = ltrim($variables['partial_url'], '/');
+
+			$this->tmpl->set_var('login_url', $webserver_url . '/'.$partial_url.'?' . http_build_query($extra_vars) );
+			$this->tmpl->set_var('registration_url',$webserver_url . '/registration/');
 			$this->tmpl->set_var('system', $system_name);
 			$this->tmpl->set_var('version', isset($GLOBALS['phpgw_info']['server']['versions']['system']) ? $GLOBALS['phpgw_info']['server']['versions']['system'] : $GLOBALS['phpgw_info']['server']['versions']['phpgwapi']);
 			$this->tmpl->set_var('instruction', lang('use a valid username and password to gain access to %1', $system_name));
@@ -472,6 +475,19 @@ JS;
 				$this->tmpl->set_var('return_sso_login_url', $variables['additional_url']);
 			}
 
+			$this->tmpl->set_var('lang_new_user', lang('new user'));
+			$this->tmpl->set_var('lang_forgotten_password', lang('forgotten password'));
+
+			$url_new_user = "{$webserver_url}/registration/main.php";
+
+			$this->tmpl->set_var('url_new_user', $url_new_user);
+
+			$url_lost_password = "{$webserver_url}/registration/main.php?" . http_build_query(array(
+						'menuaction'	=>'registration.uireg.lostpw1')
+						);
+			
+			$this->tmpl->set_var('url_lost_password', $url_lost_password);
+
 			$this->tmpl->set_var('website_title', isset($GLOBALS['phpgw_info']['server']['site_title'])
 								? $GLOBALS['phpgw_info']['server']['site_title'] 
 								: 'phpGroupWare'
@@ -481,24 +497,37 @@ JS;
 
 			if( is_file("{$GLOBALS['phpgw_info']['server']['template_dir']}/css/base.css") )
 			{
-				$base_css = "phpgwapi/templates/{$GLOBALS['phpgw_info']['server']['template_set']}/css/base.css";
+				$base_css = "{$webserver_url}/phpgwapi/templates/{$GLOBALS['phpgw_info']['server']['template_set']}/css/base.css";
 			}
 			else
 			{
-				$base_css = 'phpgwapi/templates/base/css/base.css';
+				$base_css = "{$webserver_url}/phpgwapi/templates/base/css/base.css";
 			}
 
+			$system_css = "{$webserver_url}/phpgwapi/templates/base/css/system.css";
+
+
 			if( is_file("{$GLOBALS['phpgw_info']['server']['template_dir']}/css/login.css") )
 			{
-				$login_css = "phpgwapi/templates/{$GLOBALS['phpgw_info']['server']['template_set']}/css/login.css";
+				$login_css = "{$webserver_url}/phpgwapi/templates/{$GLOBALS['phpgw_info']['server']['template_set']}/css/login.css";
 			}
 			else
 			{
-				$login_css = 'phpgwapi/templates/base/css/login.css';
+				$login_css = "{$webserver_url}/phpgwapi/templates/base/css/login.css";
 			}
 
+			$rounded_css = "{$webserver_url}/phpgwapi/templates/base/css/rounded.css";
+			
+			$flag_no = "{$webserver_url}/phpgwapi/templates/base/images/flag_no.gif";
+			$flag_en = "{$webserver_url}/phpgwapi/templates/base/images/flag_en.gif";
+
+
+			$this->tmpl->set_var('system_css', $system_css);
 			$this->tmpl->set_var('base_css', $base_css);
 			$this->tmpl->set_var('login_css', $login_css);
+			$this->tmpl->set_var('rounded_css', $rounded_css);
+			$this->tmpl->set_var('flag_no', $flag_no);
+			$this->tmpl->set_var('flag_en', $flag_en);
 
 			$autocomplete = '';
 			if ( isset($GLOBALS['phpgw_info']['server']['autocomplete_login'])
