@@ -1,18 +1,16 @@
 /*
-Copyright (c) 2010, Yahoo! Inc. All rights reserved.
-Code licensed under the BSD License:
-http://developer.yahoo.com/yui/license.html
-version: 3.3.0
-build: 3167
+YUI 3.7.3 (build 5687)
+Copyright 2012 Yahoo! Inc. All rights reserved.
+Licensed under the BSD License.
+http://yuilibrary.com/license/
 */
-YUI.add('imageloader', function(Y) {
+YUI.add('imageloader', function (Y, NAME) {
 
 /**
  * The ImageLoader Utility is a framework to dynamically load images according to certain triggers,
  * enabling faster load times and a more responsive UI.
  *
  * @module imageloader
- * @requires base-base, node-style, node-screen
  */
 
 
@@ -72,6 +70,17 @@ YUI.add('imageloader', function(Y) {
 			value: null,
 			setter: function(name) { this._className = name; return name; },
 			lazyAdd: false
+		}, 
+        
+        /**
+         * Determines how to act when className is used as the way to delay load images. The "default" action is to just
+         * remove the class name. The "enhanced" action is to remove the class name and also set the src attribute if
+         * the element is an img.
+         * @attribute classNameAction
+         * @type String
+         */
+        classNameAction: {
+            value: "default"
 		}
 
 	};
@@ -346,7 +355,8 @@ YUI.add('imageloader', function(Y) {
 						continue;
 					}
 					if (els[i].y && els[i].y <= hLimit) {
-						els[i].el.removeClass(this._className);
+						//els[i].el.removeClass(this._className);
+						this._updateNodeClassName(els[i].el);
 						els[i].fetched = true;
 						Y.log('Image with id "' + els[i].el.get('id') + '" is within distance of the fold. Fetching image. (Image registered by class name with the group - may not have an id.)', 'info', 'imageloader');
 					}
@@ -363,6 +373,32 @@ YUI.add('imageloader', function(Y) {
 			}
 		},
 
+		/**
+         * Updates a given node, removing the ImageLoader class name. If the
+         * node is an img and the classNameAction is "enhanced", then node
+         * class name is removed and also the src attribute is set to the 
+         * image URL as well as clearing the style background image.
+         * @method _updateNodeClassName
+         * @param node {Node} The node to act on.
+         * @private
+         */
+        _updateNodeClassName: function(node){
+            var url;
+            
+            if (this.get("classNameAction") == "enhanced"){
+                
+                if (node.get("tagName").toLowerCase() == "img"){
+                    url = node.getStyle("backgroundImage");
+                    /url\(["']?(.*?)["']?\)/.test(url);
+                    url = RegExp.$1;
+                    node.set("src", url);
+                    node.setStyle("backgroundImage", "");
+                }
+            }
+            
+            node.removeClass(this._className);        
+        },
+
 		/**
 		 * Finds all elements in the DOM with the class name specified in the group. Removes the class from the element in order to let the style definitions trigger the image fetching.
 		 * @method _fetchByClass
@@ -375,7 +411,7 @@ YUI.add('imageloader', function(Y) {
 
 			Y.log('Fetching all images with class "' + this._className + '" in group "' + this.get('name') + '".', 'info', 'imageloader');
 
-			Y.all('.' + this._className).removeClass(this._className);
+			Y.all('.' + this._className).each(Y.bind(this._updateNodeClassName, this));
 		}
 
 	};
@@ -632,4 +668,4 @@ YUI.add('imageloader', function(Y) {
 
 
 
-}, '3.3.0' ,{requires:['base-base', 'node-style', 'node-screen']});
+}, '3.7.3', {"requires": ["base-base", "node-style", "node-screen"]});
