@@ -5,14 +5,14 @@
 	* @license http://www.gnu.org/licenses/gpl.html GNU General Public License
 	* @package phpgwapi
 	* @subpackage setup
-	* @version $Id: setup.inc.php 7197 2011-04-07 12:17:22Z sigurdne $
+	* @version $Id: setup.inc.php 10373 2012-10-30 07:43:54Z sigurdne $
 	* @internal $Source$
 	*/
 
 	// Basic information about this app
 	$setup_info['phpgwapi']['name']      = 'phpgwapi';
 	$setup_info['phpgwapi']['title']     = 'phpgwapi';
-	$setup_info['phpgwapi']['version']   = '0.9.17.534';
+	$setup_info['phpgwapi']['version']   = '0.9.17.542';
 	$setup_info['phpgwapi']['versions']['current_header'] = '1.31';
 	$setup_info['phpgwapi']['versions']['system'] = '1.0';
 	$setup_info['phpgwapi']['enable']    = 3;
@@ -66,7 +66,8 @@
 		'phpgw_config2_section',
 		'phpgw_config2_attrib',
 		'phpgw_config2_choice',
-		'phpgw_config2_value'
+		'phpgw_config2_value',
+		'phpgw_notification'
 	);
 
 	$setup_info['phpgwapi']['hooks'] = array
