@@ -5,7 +5,7 @@
 	* @license http://www.gnu.org/licenses/gpl.html GNU General Public License
 	* @package phpgwapi
 	* @subpackage setup
-	* @version $Id: tables_current.inc.php 7349 2011-06-06 09:23:43Z sigurdne $
+	* @version $Id: tables_current.inc.php 11345 2013-09-30 13:47:35Z sigurdne $
 	* @internal $Source$
 	*/
 
@@ -227,6 +227,7 @@
 				'cat_data' => array('type' => 'text'),
 				'last_mod' => array('type' => 'int','precision' => 4,'default' => '0','nullable' => False),
 				'location_id' => array('type' => 'int','precision' => 4,'default' => '0','nullable' => True),
+				'active' => array('type' => 'int','precision' => '2','default' => '1','nullable' => True),
 			),
 			'pk' => array('cat_id'),
 			'fk' => array(),
@@ -276,8 +277,8 @@
 				'owner_id' => array('type' => 'int','precision' => 4,'nullable' => False),
 				'createdby_id' => array('type' => 'int','precision' => 4,'nullable' => True),
 				'modifiedby_id' => array('type' => 'int','precision' => 4,'nullable' => True),
-				'created' => array('type' => 'date','nullable' => False,'default' => 'current_date'),
-				'modified' => array('type' => 'date','nullable' => True),
+				'created' => array('type' => 'timestamp','nullable' => False,'default' => 'current_timestamp'),
+				'modified' => array('type' => 'timestamp','nullable' => True),
 				'size' => array('type' => 'int','precision' => 4,'nullable' => True),
 				'mime_type' => array('type' => 'varchar','precision' => '150','nullable' => True),
 				'deleteable' => array('type' => 'char','precision' => 1,'nullable' => True,'default' => 'Y'),
@@ -544,6 +545,7 @@
 			(
 				'location_id'	=> array('type' => 'int','precision' => 4,'nullable' => false),
 				'id'			=> array('type' => 'int','precision' => 4,'nullable' => false),
+				'parent_id'			=> array('type' => 'int','precision' => 4,'nullable' => true),
 				'name'			=> array('type' => 'varchar','precision' => 100,'nullable' => false),
 				'group_sort'	=> array('type' => 'int','precision' => 2,'nullable' => false),
 				'descr'			=> array('type' => 'varchar','precision' => 150,'nullable' => true),
@@ -558,12 +560,12 @@
 		(
 			'fd' => array
 			(
-				'location_id' => array('type' => 'int','precision' => 2,'nullable' => false),
-				'group_id' => array('type' => 'int','precision' => 2,'nullable' => true, 'default' => 0),
-				'id' => array('type' => 'int','precision' => 2,'nullable' => false),
+				'location_id' => array('type' => 'int','precision' => 4,'nullable' => false),
+				'group_id' => array('type' => 'int','precision' => 4,'nullable' => true, 'default' => 0),
+				'id' => array('type' => 'int','precision' => 4,'nullable' => false),
 				'column_name' => array('type' => 'varchar','precision' => 50,'nullable' => false),
-				'input_text' => array('type' => 'varchar','precision' => 50,'nullable' => false),
-				'statustext' => array('type' => 'varchar','precision' => '150','nullable' => false),
+				'input_text' => array('type' => 'varchar','precision' => 255,'nullable' => false),
+				'statustext' => array('type' => 'varchar','precision' => '255','nullable' => false),
 				'datatype' => array('type' => 'varchar','precision' => '10','nullable' => false),
 				'search' => array('type' => 'int','precision' => 2,'nullable' => true),
 				'history' => array('type' => 'int','precision' => 2,'nullable' => true),
@@ -577,7 +579,12 @@
 				'disabled' => array('type' => 'int','precision' => 2,'nullable' => true),
 				'lookup_form' => array('type' => 'int','precision' => 2,'nullable' => true),
 				'custom' => array('type' => 'int','precision' => 2,'nullable' => true,'default' => 1),
-				'helpmsg' => array('type' => 'text','nullable' => true)
+				'helpmsg' => array('type' => 'text','nullable' => true),
+				'get_list_function' => array('type' => 'varchar','precision' => 255,'nullable' => true),
+				'get_list_function_input' => array('type' => 'varchar','precision' => 255,'nullable' => true),
+				'get_single_function' => array('type' => 'varchar','precision' => 255,'nullable' => true),
+				'get_single_function_input' => array('type' => 'varchar','precision' => 255,'nullable' => true),
+				'short_description' => array('type' => 'int','precision' => 2,'nullable' => true)
 			),
 			'pk' => array('location_id', 'id'),
 			'fk' => array(),
@@ -608,8 +615,9 @@
 				'location_id' => array('type' => 'int','precision' => 4,'nullable' => false),
 				'id' => array('type' => 'int','precision' => 4,'nullable' => false),
 				'descr' => array('type' => 'text','nullable' => true),
-				'file_name ' => array('type' => 'varchar','precision' => 50,'nullable' => false),
+				'file_name' => array('type' => 'varchar','precision' => 255,'nullable' => false),
 				'active' => array('type' => 'int','precision' => 2,'nullable' => true),
+				'client_side' => array('type' => 'int','precision' => 2,'nullable' => true),//otherwise: server-side
 				'custom_sort' => array('type' => 'int','precision' => 4,'nullable' => true)
 			),
 			'pk' => array('location_id', 'id'),
@@ -694,5 +702,21 @@
 			'fk' => array(),
 			'ix' => array(),
 			'uc' => array()
+		),
+		'phpgw_notification' => array(
+			'fd' => array(
+				'id' => array('type' => 'auto','precision' => 4,'nullable' => False),
+				'location_id' => array('type' => 'int','precision' => 4,'nullable' => False),
+				'location_item_id' => array('type' => 'int','precision' => 8,'nullable' => False),//bigint
+				'contact_id' => array('type' => 'int','precision' => 4,'nullable' => False),
+				'is_active' => array('type' => 'int', 'precision' => 2,'nullable' => true),
+				'notification_method' => array('type' => 'varchar', 'precision' => 20,'nullable' => true),
+				'user_id' => array('type' => 'int','precision' => 4,'nullable' => False),
+				'entry_date' => array('type' => 'int','precision' => 4,'nullable' => False)
+			),
+			'pk' => array('id'),
+			'fk' => array('phpgw_contact' => array('contact_id' => 'contact_id')),
+			'ix' => array(),
+			'uc' => array()
 		)
 	);
