@@ -9,7 +9,7 @@
  * @author    Michael Cramer <BigMichi1@users.sourceforge.net>
  * @copyright 2009 phpSysInfo
  * @license   http://opensource.org/licenses/gpl-2.0.php GNU General Public License
- * @version   SVN: $Id: class.PSI_Interface_OS.inc.php 4429 2010-01-04 15:22:10Z sigurd $
+ * @version   SVN: $Id: class.PSI_Interface_OS.inc.php 11404 2013-10-29 08:52:25Z sigurdne $
  * @link      http://phpsysinfo.sourceforge.net
  */
  /**
@@ -32,20 +32,19 @@ interface PSI_Interface_OS
      *
      * @return string
      */
-    function getEncoding();
+    public function getEncoding();
     
     /**
      * build the os information
      *
      * @return void
      */
-    function build();
+    public function build();
     
     /**
      * get the filled or unfilled (with default values) system object
      *
      * @return System
      */
-    function getSys();
+    public function getSys();
 }
-?>
