@@ -9,7 +9,7 @@
  * @author    Michael Cramer <BigMichi1@users.sourceforge.net>
  * @copyright 2009 phpSysInfo
  * @license   http://opensource.org/licenses/gpl-2.0.php GNU General Public License
- * @version   SVN: $Id: class.PSI_Interface_Plugin.inc.php 4429 2010-01-04 15:22:10Z sigurd $
+ * @version   SVN: $Id: class.PSI_Interface_Plugin.inc.php 11404 2013-10-29 08:52:25Z sigurdne $
  * @link      http://phpsysinfo.sourceforge.net
  */
  /**
@@ -32,13 +32,12 @@ interface PSI_Interface_Plugin
      *
      * @return void
      */
-    function execute();
+    public function execute();
     
     /**
      * build the xml
      *
      * @return SimpleXMLObject entire XML content for the plugin which than can be appended to the main XML
      */
-    function xml();
+    public function xml();
 }
-?>
