@@ -5,11 +5,11 @@
  * PHP version 5
  *
  * @category  PHP
- * @package   PSI_OS
+ * @package   PSI WINNT OS class
  * @author    Michael Cramer <BigMichi1@users.sourceforge.net>
  * @copyright 2009 phpSysInfo
  * @license   http://opensource.org/licenses/gpl-2.0.php GNU General Public License
- * @version   SVN: $Id: class.WINNT.inc.php 4429 2010-01-04 15:22:10Z sigurd $
+ * @version   SVN: $Id: class.WINNT.inc.php 11404 2013-10-29 08:52:25Z sigurdne $
  * @link      http://phpsysinfo.sourceforge.net
  */
  /**
@@ -18,7 +18,7 @@
  * information are retrieved through the WMI interface
  *
  * @category  PHP
- * @package   PSI_OS
+ * @package   PSI WINNT OS class
  * @author    Michael Cramer <BigMichi1@users.sourceforge.net>
  * @copyright 2009 phpSysInfo
  * @license   http://opensource.org/licenses/gpl-2.0.php GNU General Public License
@@ -32,7 +32,7 @@ class WINNT extends OS
      *
      * @var Object
      */
-    private $_wmi;
+    private $_wmi = null;
     
     /**
      * holds all devices, which are in the system
@@ -46,7 +46,14 @@ class WINNT extends OS
      *
      * @var string
      */
-    private $_charset = "";
+    private $_codepage = null;
+
+    /**
+     * store language of the system
+     *
+     * @var string
+     */
+    private $_syslang = null;
     
     /**
      * build the global Error object and create the WMI connection
@@ -58,14 +65,18 @@ class WINNT extends OS
         $strHostname = '';
         $strUser = '';
         $strPassword = '';
-        
+        try {
         // initialize the wmi object
         $objLocator = new COM('WbemScripting.SWbemLocator');
         if ($strHostname == "") {
             $this->_wmi = $objLocator->ConnectServer();
+
         } else {
             $this->_wmi = $objLocator->ConnectServer($strHostname, 'rootcimv2', $strHostname.'\\'.$strUser, $strPassword);
         }
+        } catch (Exception $e) {
+            $this->error->addError("WMI connect error", "PhpSysInfo can not connect to the WMI interface for security reasons.\nCheck an authentication mechanism for the directory where phpSysInfo is installed.");
+        }
         $this->_getCodeSet();
     }
     
@@ -76,52 +87,21 @@ class WINNT extends OS
      */
     private function _getCodeSet()
     {
-        $buffer = $this->_getWMI('Win32_OperatingSystem', array('CodeSet'));
-        $this->_charset = 'windows-'.$buffer[0]['CodeSet'];
-    }
-    
-    /**
-     * function for getting a list of values in the specified context
-     * optionally filter this list, based on the list from second parameter
-     *
-     * @param string $strClass name of the class where the values are stored
-     * @param array  $strValue filter out only needed values, if not set all values of the class are returned
-     *
-     * @return array content of the class stored in an array
-     */
-    private function _getWMI($strClass, $strValue = array())
-    {
-        $arrData = array();
-        $value = "";
-        try {
-            $objWEBM = $this->_wmi->Get($strClass);
-            $arrProp = $objWEBM->Properties_;
-            $arrWEBMCol = $objWEBM->Instances_();
-            foreach ($arrWEBMCol as $objItem) {
-                if (is_array($arrProp)) {
-                    reset($arrProp);
+        $buffer = CommonFunctions::getWMI($this->_wmi, 'Win32_OperatingSystem', array('CodeSet','OSLanguage'));
+        if ($buffer) {
+            $this->_codepage = 'windows-'.$buffer[0]['CodeSet'];
+            $lang = "";
+            if (is_readable(APP_ROOT.'/data/languages.ini') && ($langdata = @parse_ini_file(APP_ROOT.'/data/languages.ini', true))) {
+                if (isset($langdata['WINNT'][$buffer[0]['OSLanguage']])) {
+                    $lang = $langdata['WINNT'][$buffer[0]['OSLanguage']];
                 }
-                $arrInstance = array();
-                foreach ($arrProp as $propItem) {
-                    eval("\$value = \$objItem->".$propItem->Name.";");
-                    if ( empty($strValue)) {
-                        $arrInstance[$propItem->Name] = trim($value);
-                    } else {
-                        if (in_array($propItem->Name, $strValue)) {
-                            $arrInstance[$propItem->Name] = trim($value);
-                        }
-                    }
-                }
-                $arrData[] = $arrInstance;
+            }
+            if ($lang == "") {
+                $lang = 'Unknown';
+        }
+            $this->_syslang = $lang.' ('.$buffer[0]['OSLanguage'].')';
             }
         }
-        catch(Exception $e) {
-            if (PSI_DEBUG) {
-                $this->error->addError($e->getCode(), $e->getMessage());
-            }
-        }
-        return $arrData;
-    }
     
     /**
      * retrieve different device types from the system based on selector
@@ -133,7 +113,7 @@ class WINNT extends OS
     private function _devicelist($strType)
     {
         if ( empty($this->_wmidevices)) {
-            $this->_wmidevices = $this->_getWMI('Win32_PnPEntity', array('Name', 'PNPDeviceID'));
+            $this->_wmidevices = CommonFunctions::getWMI($this->_wmi, 'Win32_PnPEntity', array('Name', 'PNPDeviceID'));
         }
         $list = array();
         foreach ($this->_wmidevices as $device) {
@@ -141,6 +121,7 @@ class WINNT extends OS
                 $list[] = $device['Name'];
             }
         }
+
         return $list;
     }
     
@@ -152,14 +133,18 @@ class WINNT extends OS
     private function _hostname()
     {
         if (PSI_USE_VHOST === true) {
-            $this->sys->setHostname(getenv('SERVER_NAME'));
+            if ($hnm = getenv('SERVER_NAME')) $this->sys->setHostname($hnm);
         } else {
-            $buffer = $this->_getWMI('Win32_ComputerSystem', array('Name'));
+            $buffer = CommonFunctions::getWMI($this->_wmi, 'Win32_ComputerSystem', array('Name'));
+            if ($buffer) {
             $result = $buffer[0]['Name'];
             $ip = gethostbyname($result);
             if ($ip != $result) {
                 $this->sys->setHostname(gethostbyaddr($ip));
             }
+            } else {
+                if ($hnm = getenv('COMPUTERNAME')) $this->sys->setHostname($hnm);
+            }
         }
     }
     
@@ -171,11 +156,17 @@ class WINNT extends OS
     private function _ip()
     {
         if (PSI_USE_VHOST === true) {
-            $this->sys->setIp(gethostbyname($this->_hostname()));
+            if ( (($hnm=$this->sys->getHostname()) != 'localhost') &&
+                 (($hip=gethostbyname($hnm)) != $hnm) ) $this->sys->setIp($hip);
         } else {
-            $buffer = $this->_getWMI('Win32_ComputerSystem', array('Name'));
+            $buffer = CommonFunctions::getWMI($this->_wmi, 'Win32_ComputerSystem', array('Name'));
+            if ($buffer) {
             $result = $buffer[0]['Name'];
             $this->sys->setIp(gethostbyname($result));
+            } else {
+            if ( (($hnm=$this->sys->getHostname()) != 'localhost') &&
+                 (($hip=gethostbyname($hnm)) != $hnm) ) $this->sys->setIp($hip);
+            }
         }
     }
     
@@ -189,7 +180,8 @@ class WINNT extends OS
     {
         $result = 0;
         date_default_timezone_set('UTC');
-        $buffer = $this->_getWMI('Win32_OperatingSystem', array('LastBootUpTime', 'LocalDateTime'));
+        $buffer = CommonFunctions::getWMI($this->_wmi, 'Win32_OperatingSystem', array('LastBootUpTime', 'LocalDateTime'));
+        if ($buffer) {
         $byear = intval(substr($buffer[0]['LastBootUpTime'], 0, 4));
         $bmonth = intval(substr($buffer[0]['LastBootUpTime'], 4, 2));
         $bday = intval(substr($buffer[0]['LastBootUpTime'], 6, 2));
@@ -207,6 +199,7 @@ class WINNT extends OS
         $result = $localtime - $boottime;
         $this->sys->setUptime($result);
     }
+    }
     
     /**
      * Number of Users
@@ -216,7 +209,7 @@ class WINNT extends OS
     private function _users()
     {
         $users = 0;
-        $buffer = $this->_getWMI('Win32_Process', array('Caption'));
+        $buffer = CommonFunctions::getWMI($this->_wmi, 'Win32_Process', array('Caption'));
         foreach ($buffer as $process) {
             if (strtoupper($process['Caption']) == strtoupper('explorer.exe')) {
                 $users++;
@@ -232,22 +225,41 @@ class WINNT extends OS
      */
     private function _distro()
     {
-        $buffer = $this->_getWMI('Win32_OperatingSystem', array('Version', 'ServicePackMajorVersion'));
+        $buffer = CommonFunctions::getWMI($this->_wmi, 'Win32_OperatingSystem', array('Version', 'ServicePackMajorVersion', 'Caption'));
+        if ($buffer) {
         $kernel = $buffer[0]['Version'];
         if ($buffer[0]['ServicePackMajorVersion'] > 0) {
             $kernel .= ' SP'.$buffer[0]['ServicePackMajorVersion'];
         }
         $this->sys->setKernel($kernel);
-        
-        $buffer = $this->_getWMI('Win32_OperatingSystem', array('Caption'));
         $this->sys->setDistribution($buffer[0]['Caption']);
         
-        if ($kernel[0] == 6) {
-            $icon = 'vista.png';
+            if ((($kernel[1] == ".") && ($kernel[0] <5)) || (substr($kernel,0,4) == "5.0."))
+                $icon = 'Win2000.png';
+            elseif ((substr($kernel,0,4) == "6.0.") || (substr($kernel,0,4) == "6.1."))
+                $icon = 'WinVista.png';
+            elseif (substr($kernel,0,4) == "6.2.")
+                $icon = 'Win8.png';
+            else
+                $icon = 'WinXP.png';
+            $this->sys->setDistributionIcon($icon);
+        } elseif (CommonFunctions::executeProgram("cmd", "/c ver 2>nul", $ver_value, false)) {
+                if (preg_match("/ReactOS\nVersion\s+(.+)/", $ver_value, $ar_temp)) {
+                    $this->sys->setDistribution("ReactOS");
+                    $this->sys->setKernel($ar_temp[1]);
+                    $this->sys->setDistributionIcon('ReactOS.png');
+                } elseif (preg_match("/^(Microsoft [^\[]*)\s*\[\D*\s*(.+)\]/", $ver_value, $ar_temp)) {
+                    $this->sys->setDistribution($ar_temp[1]);
+                    $this->sys->setKernel($ar_temp[2]);
+                    $this->sys->setDistributionIcon('Win2000.png');
         } else {
-            $icon = 'xp.png';
+                    $this->sys->setDistribution("WinNT");
+                    $this->sys->setDistributionIcon('Win2000.png');
+                }
+        } else {
+            $this->sys->setDistribution("WinNT");
+            $this->sys->setDistributionIcon('Win2000.png');
         }
-        $this->sys->setDistributionIcon($icon);
     }
     
     /**
@@ -260,7 +272,7 @@ class WINNT extends OS
     {
         $loadavg = "";
         $sum = 0;
-        $buffer = $this->_getWMI('Win32_Processor', array('LoadPercentage'));
+        $buffer = CommonFunctions::getWMI($this->_wmi, 'Win32_Processor', array('LoadPercentage'));
         foreach ($buffer as $load) {
             $value = $load['LoadPercentage'];
             $loadavg .= $value.' ';
@@ -279,7 +291,7 @@ class WINNT extends OS
      */
     private function _cpuinfo()
     {
-        $allCpus = $this->_getWMI('Win32_Processor', array('Name', 'L2CacheSize', 'CurrentClockSpeed', 'ExtClock', 'NumberOfCores'));
+        $allCpus = CommonFunctions::getWMI($this->_wmi, 'Win32_Processor', array('Name', 'L2CacheSize', 'CurrentClockSpeed', 'ExtClock', 'NumberOfCores', 'MaxClockSpeed'));
         foreach ($allCpus as $oneCpu) {
             $coreCount = 1;
             if (isset($oneCpu['NumberOfCores'])) {
@@ -291,6 +303,7 @@ class WINNT extends OS
                 $cpu->setCache($oneCpu['L2CacheSize'] * 1024);
                 $cpu->setCpuSpeed($oneCpu['CurrentClockSpeed']);
                 $cpu->setBusSpeed($oneCpu['ExtClock']);
+                if ($oneCpu['CurrentClockSpeed'] < $oneCpu['MaxClockSpeed']) $cpu->setCpuSpeedMax($oneCpu['MaxClockSpeed']);
                 $this->sys->setCpus($cpu);
             }
         }
@@ -335,25 +348,55 @@ class WINNT extends OS
      */
     private function _network()
     {
-        foreach ($this->_getWMI('Win32_PerfRawData_Tcpip_NetworkInterface') as $device) {
+        $allDevices = CommonFunctions::getWMI($this->_wmi, 'Win32_PerfRawData_Tcpip_NetworkInterface', array('Name', 'BytesSentPersec', 'BytesTotalPersec', 'BytesReceivedPersec', 'PacketsReceivedErrors', 'PacketsReceivedDiscarded'));
+        if (defined('PSI_SHOW_NETWORK_INFOS') && PSI_SHOW_NETWORK_INFOS)
+           $allNetworkAdapterConfigurations = CommonFunctions::getWMI($this->_wmi, 'Win32_NetworkAdapterConfiguration', array('Description', 'MACAddress', 'IPAddress'));
+
+        foreach ($allDevices as $device) {
             $dev = new NetDevice();
-            $dev->setName($device['Name']);
+           $name=$device['Name'];
+
+           $cname=preg_replace('/[^A-Za-z0-9]/', '_', $name); //convert to canonical
+           if (preg_match('/\s-\s([^-]*)$/', $name, $ar_name))
+                $name=substr($name,0,strlen($name)-strlen($ar_name[0]));
+           $dev->setName($name);
+
+           if (defined('PSI_SHOW_NETWORK_INFOS') && PSI_SHOW_NETWORK_INFOS) foreach ($allNetworkAdapterConfigurations as $NetworkAdapterConfiguration) {
+                   if ( preg_replace('/[^A-Za-z0-9]/', '_', $NetworkAdapterConfiguration['Description']) == $cname ) {
+                       $dev->setInfo(preg_replace('/:/', '-', $NetworkAdapterConfiguration['MACAddress']));
+                       if (isset($NetworkAdapterConfiguration['IPAddress'])) 
+                           foreach( $NetworkAdapterConfiguration['IPAddress'] as $ipaddres)
+                               if (($ipaddres!="0.0.0.0") && !preg_match('/^fe80::/i',$ipaddres))
+                                     $dev->setInfo(($dev->getInfo()?$dev->getInfo().';':'').$ipaddres);
+
+                       break;
+                   }
+            }
+
             // http://msdn.microsoft.com/library/default.asp?url=/library/en-us/wmisdk/wmi/win32_perfrawdata_tcpip_networkinterface.asp
             // there is a possible bug in the wmi interfaceabout uint32 and uint64: http://www.ureader.com/message/1244948.aspx, so that
             // magative numbers would occour, try to calculate the nagative value from total - positive number
             $txbytes = $device['BytesSentPersec'];
-            if ($txbytes < 0) {
-                $txbytes = $device['BytesTotalPersec'] - $device['BytesReceivedPersec'];
-                
+            $rxbytes = $device['BytesReceivedPersec'];
+            if (($txbytes < 0) && ($rxbytes < 0)) {
+                $txbytes += 4294967296;
+                $rxbytes += 4294967296;
+            } elseif ($txbytes < 0) {
+                if ($device['BytesTotalPersec'] > $rxbytes)
+                   $txbytes = $device['BytesTotalPersec'] - $rxbytes;
+                else
+                   $txbytes += 4294967296;
+            } elseif ($rxbytes < 0) {
+                if ($device['BytesTotalPersec'] > $txbytes)
+                   $rxbytes = $device['BytesTotalPersec'] - $txbytes;
+                else
+                   $rxbytes += 4294967296;
             }
             $dev->setTxBytes($txbytes);
-            $rxbytes = $device['BytesReceivedPersec'];
-            if ($rxbytes < 0) {
-                $rxbytes = $device['BytesTotalPersec'] - $device['BytesSentPersec'];
-            }
             $dev->setRxBytes($rxbytes);
             $dev->setErrors($device['PacketsReceivedErrors']);
             $dev->setDrops($device['PacketsReceivedDiscarded']);
+
             $this->sys->setNetDevices($dev);
         }
     }
@@ -367,12 +410,13 @@ class WINNT extends OS
      */
     private function _memory()
     {
-        $buffer = $this->_getWMI("Win32_OperatingSystem", array('TotalVisibleMemorySize', 'FreePhysicalMemory'));
+        $buffer = CommonFunctions::getWMI($this->_wmi, "Win32_OperatingSystem", array('TotalVisibleMemorySize', 'FreePhysicalMemory'));
+        if ($buffer) {
         $this->sys->setMemTotal($buffer[0]['TotalVisibleMemorySize'] * 1024);
         $this->sys->setMemFree($buffer[0]['FreePhysicalMemory'] * 1024);
         $this->sys->setMemUsed($this->sys->getMemTotal() - $this->sys->getMemFree());
-        
-        $buffer = $this->_getWMI('Win32_PageFileUsage');
+        }
+        $buffer = CommonFunctions::getWMI($this->_wmi, 'Win32_PageFileUsage');
         foreach ($buffer as $swapdevice) {
             $dev = new DiskDevice();
             $dev->setName("SWAP");
@@ -394,7 +438,7 @@ class WINNT extends OS
     {
         $typearray = array('Unknown', 'No Root Directory', 'Removable Disk', 'Local Disk', 'Network Drive', 'Compact Disc', 'RAM Disk');
         $floppyarray = array('Unknown', '5 1/4 in.', '3 1/2 in.', '3 1/2 in.', '3 1/2 in.', '3 1/2 in.', '5 1/4 in.', '5 1/4 in.', '5 1/4 in.', '5 1/4 in.', '5 1/4 in.', 'Other', 'HD', '3 1/2 in.', '3 1/2 in.', '5 1/4 in.', '5 1/4 in.', '3 1/2 in.', '3 1/2 in.', '5 1/4 in.', '3 1/2 in.', '3 1/2 in.', '8 in.');
-        $buffer = $this->_getWMI('Win32_LogicalDisk', array('Name', 'Size', 'FreeSpace', 'FileSystem', 'DriveType', 'MediaType'));
+        $buffer = CommonFunctions::getWMI($this->_wmi, 'Win32_LogicalDisk', array('Name', 'Size', 'FreeSpace', 'FileSystem', 'DriveType', 'MediaType'));
         foreach ($buffer as $filesystem) {
             $dev = new DiskDevice();
             $dev->setMountPoint($filesystem['Name']);
@@ -411,6 +455,27 @@ class WINNT extends OS
             }
             $this->sys->setDiskDevices($dev);
         }
+        if (!$buffer && ($this->sys->getDistribution()=="ReactOS")) {
+            // test for command 'free' on current disk
+            if (CommonFunctions::executeProgram("cmd", "/c free 2>nul", $out_value, true)) {
+                for ($letter='A'; $letter!='AA'; $letter++) if (CommonFunctions::executeProgram("cmd", "/c free ".$letter.": 2>nul", $out_value, false)) {
+                   if (preg_match('/\n\s*([\d\.\,]+).*\n\s*([\d\.\,]+).*\n\s*([\d\.\,]+).*$/',$out_value, $out_dig )) {
+                       $size = preg_replace('/(\.)|(\,)/', '', $out_dig[1]);
+                       $used = preg_replace('/(\.)|(\,)/', '', $out_dig[2]);
+                       $free = preg_replace('/(\.)|(\,)/', '', $out_dig[3]);
+                       if ($used + $free == $size) {
+                           $dev = new DiskDevice();
+                           $dev->setMountPoint($letter.":");
+                           $dev->setFsType('Unknown');
+                           $dev->setTotal($size);
+                           $dev->setFree($free);
+                           $dev->setUsed($used);
+                           $this->sys->setDiskDevices($dev);
+                       }
+                   }
+                }
+            }
+        }
     }
     
     /**
@@ -420,9 +485,21 @@ class WINNT extends OS
      *
      * @return string
      */
-    function getEncoding()
+    public function getEncoding()
     {
-        return $this->_charset;
+        return $this->_codepage;
+    }
+
+    /**
+     * get os specific language
+     *
+     * @see OS::getLanguage()
+     *
+     * @return string
+     */
+    public function getLanguage()
+    {
+        return $this->_syslang;
     }
     
     /**
@@ -432,11 +509,14 @@ class WINNT extends OS
      *
      * @return Void
      */
-    function build()
+    public function build()
     {
-        $this->_ip();
         $this->_hostname();
+        $this->_ip();
         $this->_distro();
+        if ($this->sys->getDistribution()=="ReactOS") {
+            $this->error->addError("WARN", "The ReactOS version of phpSysInfo is a work in progress, some things currently don't work");
+        }
         $this->_users();
         $this->_uptime();
         $this->_cpuinfo();
@@ -447,4 +527,3 @@ class WINNT extends OS
         $this->_loadavg();
     }
 }
-?>
