@@ -9,7 +9,7 @@
  * @author    Michael Cramer <BigMichi1@users.sourceforge.net>
  * @copyright 2009 phpSysInfo
  * @license   http://opensource.org/licenses/gpl-2.0.php GNU General Public License
- * @version   SVN: $Id: class.System.inc.php 4429 2010-01-04 15:22:10Z sigurd $
+ * @version   SVN: $Id: class.System.inc.php 11404 2013-10-29 08:52:25Z sigurdne $
  * @link      http://phpsysinfo.sourceforge.net
  */
  /**
@@ -231,6 +231,7 @@ class System
                 }
             }
         }
+
         return $result;
     }
     
@@ -262,7 +263,7 @@ class System
     public function getMemPercentApplication()
     {
         if ($this->_memApplication !== null) {
-            if ($this->_memApplication > 0) {
+            if (($this->_memApplication > 0) && ($this->_memTotal > 0)) {
                 return ceil($this->_memApplication / $this->_memTotal * 100);
             } else {
                 return 0;
@@ -283,7 +284,7 @@ class System
     public function getMemPercentCache()
     {
         if ($this->_memCache !== null) {
-            if ($this->_memCache > 0) {
+            if (($this->_memCache > 0) && ($this->_memTotal > 0)) {
                 return ceil($this->_memCache / $this->_memTotal * 100);
             } else {
                 return 0;
@@ -304,7 +305,7 @@ class System
     public function getMemPercentBuffer()
     {
         if ($this->_memBuffer !== null) {
-            if ($this->_memBuffer > 0) {
+            if (($this->_memBuffer > 0) && ($this->_memTotal > 0)) {
                 return ceil($this->_memBuffer / $this->_memTotal * 100);
             } else {
                 return 0;
@@ -329,8 +330,10 @@ class System
             foreach ($this->_swapDevices as $dev) {
                 $free += $dev->getFree();
             }
+
             return $free;
         }
+
         return null;
     }
     
@@ -349,6 +352,7 @@ class System
             foreach ($this->_swapDevices as $dev) {
                 $total += $dev->getTotal();
             }
+
             return $total;
         } else {
             return null;
@@ -370,6 +374,7 @@ class System
             foreach ($this->_swapDevices as $dev) {
                 $used += $dev->getUsed();
             }
+
             return $used;
         } else {
             return null;
@@ -658,7 +663,6 @@ class System
         array_push($this->_cpus, $cpus);
     }
 
-    
     /**
      * Returns $_pciDevices.
      *
@@ -686,7 +690,6 @@ class System
         array_push($this->_pciDevices, $pciDevices);
     }
 
-    
     /**
      * Returns $_netDevices.
      *
@@ -714,7 +717,6 @@ class System
         array_push($this->_netDevices, $netDevices);
     }
 
-    
     /**
      * Returns $_ideDevices.
      *
@@ -796,7 +798,6 @@ class System
         array_push($this->_usbDevices, $usbDevices);
     }
 
-    
     /**
      * Returns $_diskDevices.
      *
@@ -824,7 +825,6 @@ class System
         array_push($this->_diskDevices, $diskDevices);
     }
 
-    
     /**
      * Returns $_memApplication.
      *
@@ -1008,4 +1008,3 @@ class System
         array_push($this->_swapDevices, $swapDevices);
     }
 }
-?>
