@@ -9,7 +9,7 @@
  * @author    Michael Cramer <BigMichi1@users.sourceforge.net>
  * @copyright 2009 phpSysInfo
  * @license   http://opensource.org/licenses/gpl-2.0.php GNU General Public License
- * @version   SVN: $Id: class.XML.inc.php 5012 2010-03-11 17:50:28Z sigurd $
+ * @version   SVN: $Id: class.XML.inc.php 11404 2013-10-29 08:52:25Z sigurdne $
  * @link      http://phpsysinfo.sourceforge.net
  */
  /**
@@ -105,7 +105,7 @@ class XML
         } else {
             $this->_complete_request = false;
         }
-        $os = PHP_OS;
+        $os = PSI_OS;
         $this->_sysinfo = new $os();
         $this->_plugins = CommonFunctions::getPlugins();
         $this->_xmlbody();
@@ -130,6 +130,12 @@ class XML
         if ($this->_sys->getLoadPercent() !== null) {
             $vitals->addAttribute('CPULoad', $this->_sys->getLoadPercent());
         }
+        if ($this->_sysinfo->getLanguage() !== null) {
+            $vitals->addAttribute('SysLang', $this->_sysinfo->getLanguage());
+        }
+        if ($this->_sysinfo->getEncoding() !== null) {
+            $vitals->addAttribute('CodePage', $this->_sysinfo->getEncoding());
+        }
     }
     
     /**
@@ -140,7 +146,15 @@ class XML
     private function _buildNetwork()
     {
         $network = $this->_xml->addChild('Network');
-        $hideDevices = preg_split("/[\s]?,[\s]?/", PSI_HIDE_NETWORK_INTERFACE, -1, PREG_SPLIT_NO_EMPTY);
+        if ( defined('PSI_HIDE_NETWORK_INTERFACE') && is_string(PSI_HIDE_NETWORK_INTERFACE) ) {
+            if (preg_match(ARRAY_EXP, PSI_HIDE_NETWORK_INTERFACE)) {
+                $hideDevices = eval(PSI_HIDE_NETWORK_INTERFACE);
+            } else {
+                $hideDevices = array(PSI_HIDE_NETWORK_INTERFACE);
+            }
+        } else {
+            $hideDevices = array();
+        }
         foreach ($this->_sys->getNetDevices() as $dev) {
             if (!in_array(trim($dev->getName()), $hideDevices)) {
                 $device = $network->addChild('NetDevice');
@@ -149,6 +163,8 @@ class XML
                 $device->addAttribute('TxBytes', $dev->getTxBytes());
                 $device->addAttribute('Err', $dev->getErrors());
                 $device->addAttribute('Drops', $dev->getDrops());
+                if ( defined('PSI_SHOW_NETWORK_INFOS') && PSI_SHOW_NETWORK_INFOS && $dev->getInfo() )
+                    $device->addAttribute('Info', $dev->getInfo());
             }
         }
     }
@@ -197,7 +213,15 @@ class XML
         foreach ($this->_sys->getCpus() as $oneCpu) {
             $tmp = $cpu->addChild('CpuCore');
             $tmp->addAttribute('Model', $oneCpu->getModel());
+            if ($oneCpu->getCpuSpeed() !== 0) {
             $tmp->addAttribute('CpuSpeed', $oneCpu->getCpuSpeed());
+            }
+            if ($oneCpu->getCpuSpeedMax() !== 0) {
+                $tmp->addAttribute('CpuSpeedMax', $oneCpu->getCpuSpeedMax());
+            }
+            if ($oneCpu->getCpuSpeedMin() !== 0) {
+                $tmp->addAttribute('CpuSpeedMin', $oneCpu->getCpuSpeedMin());
+            }
             if ($oneCpu->getTemp() !== null) {
                 $tmp->addAttribute('CpuTemp', $oneCpu->getTemp());
             }
@@ -207,6 +231,9 @@ class XML
             if ($oneCpu->getCache() !== null) {
                 $tmp->addAttribute('Cache', $oneCpu->getCache());
             }
+            if ($oneCpu->getVirt() !== null) {
+                $tmp->addAttribute('Virt', $oneCpu->getVirt());
+            }
             if ($oneCpu->getBogomips() !== null) {
                 $tmp->addAttribute('Bogomips', $oneCpu->getBogomips());
             }
@@ -264,7 +291,7 @@ class XML
      *
      * @return Void
      */
-    private function _fillDevice($mount, $dev, $i)
+    private function _fillDevice(SimpleXMLExtended $mount, DiskDevice $dev, $i)
     {
         $mount->addAttribute('MountPointID', $i);
         $mount->addAttribute('FSType', $dev->getFsType());
@@ -275,7 +302,7 @@ class XML
         $mount->addAttribute('Percent', $dev->getPercentUsed());
         if (PSI_SHOW_MOUNT_OPTION === true) {
             if ($dev->getOptions() !== null) {
-                $mount->addAttribute('MountOptions', $dev->getOptions());
+                $mount->addAttribute('MountOptions', preg_replace("/,/",", ",$dev->getOptions()));
             }
         }
         if ($dev->getPercentInodesUsed() !== null) {
@@ -295,14 +322,26 @@ class XML
     {
         $hideMounts = $hideFstypes = $hideDisks = array();
         $i = 1;
-        if (PSI_HIDE_MOUNTS !== "") {
-            $hideMounts = preg_split('/,/', PSI_HIDE_MOUNTS, -1, PREG_SPLIT_NO_EMPTY);
+        if ( defined('PSI_HIDE_MOUNTS') && is_string(PSI_HIDE_MOUNTS) ) {
+            if (preg_match(ARRAY_EXP, PSI_HIDE_MOUNTS)) {
+                $hideMounts = eval(PSI_HIDE_MOUNTS);
+            } else {
+                $hideMounts = array(PSI_HIDE_MOUNTS);
         }
-        if (PSI_HIDE_FS_TYPES !== "") {
-            $hideFstypes = preg_split('/,/', PSI_HIDE_FS_TYPES, -1, PREG_SPLIT_NO_EMPTY);
         }
-        if (PSI_HIDE_DISKS !== "") {
-            $hideDisks = preg_split('/,/', PSI_HIDE_DISKS, -1, PREG_SPLIT_NO_EMPTY);
+        if ( defined('PSI_HIDE_FS_TYPES') && is_string(PSI_HIDE_FS_TYPES) ) {
+            if (preg_match(ARRAY_EXP, PSI_HIDE_FS_TYPES)) {
+                $hideFstypes = eval(PSI_HIDE_FS_TYPES);
+            } else {
+                $hideFstypes = array(PSI_HIDE_FS_TYPES);
+            }
+        }
+        if ( defined('PSI_HIDE_DISKS') && is_string(PSI_HIDE_DISKS) ) {
+            if (preg_match(ARRAY_EXP, PSI_HIDE_DISKS)) {
+                $hideDisks = eval(PSI_HIDE_DISKS);
+            } else {
+                $hideDisks = array(PSI_HIDE_DISKS);
+            }
         }
         $fs = $this->_xml->addChild('FileSystem');
         foreach ($this->_sys->getDiskDevices() as $disk) {
@@ -321,18 +360,21 @@ class XML
     private function _buildMbinfo()
     {
         $mbinfo = $this->_xml->addChild('MBInfo');
-        if (PSI_MBINFO || PSI_HDDTEMP) {
+        if ((sizeof(unserialize(PSI_MBINFO))>0) || PSI_HDDTEMP) {
             $temp = $mbinfo->addChild('Temperature');
-            if (PSI_MBINFO) {
-                $mbinfoclass = PSI_SENSOR_PROGRAM;
+            if (sizeof(unserialize(PSI_MBINFO))>0) {
+                foreach(unserialize(PSI_MBINFO) as $mbinfoclass) {
                 $mbinfo_data = new $mbinfoclass();
                 $mbinfo_detail = $mbinfo_data->getMBInfo();
                 foreach ($mbinfo_detail->getMbTemp() as $dev) {
                     $item = $temp->addChild('Item');
                     $item->addAttribute('Label', $dev->getName());
                     $item->addAttribute('Value', $dev->getValue());
+                        if ($dev->getMax() !== null) {
                     $item->addAttribute('Max', $dev->getMax());
                 }
+            }
+                }
             }
             if (PSI_HDDTEMP) {
                 $hddtemp = new HDDTemp();
@@ -341,30 +383,49 @@ class XML
                     $item = $temp->addChild('Item');
                     $item->addAttribute('Label', $dev->getName());
                     $item->addAttribute('Value', $dev->getValue());
+                    if ($dev->getMax() !== null) {
                     $item->addAttribute('Max', $dev->getMax());
                 }
             }
         }
-        if (PSI_MBINFO) {
+        }
+        if (sizeof(unserialize(PSI_MBINFO))>0) {
             $fan = $mbinfo->addChild('Fans');
             foreach ($mbinfo_detail->getMbFan() as $dev) {
                 $item = $fan->addChild('Item');
                 $item->addAttribute('Label', $dev->getName());
                 $item->addAttribute('Value', $dev->getValue());
+                if ($dev->getMin() !== null) {
                 $item->addAttribute('Min', $dev->getMin());
             }
         }
-        if (PSI_MBINFO) {
+        }
+        if (sizeof(unserialize(PSI_MBINFO))>0) {
             $volt = $mbinfo->addChild('Voltage');
             foreach ($mbinfo_detail->getMbVolt() as $dev) {
                 $item = $volt->addChild('Item');
                 $item->addAttribute('Label', $dev->getName());
                 $item->addAttribute('Value', $dev->getValue());
+                if ($dev->getMin() !== null) {
                 $item->addAttribute('Min', $dev->getMin());
+                }
+                if ($dev->getMax() !== null) {
                 $item->addAttribute('Max', $dev->getMax());
             }
         }
     }
+        if (sizeof(unserialize(PSI_MBINFO))>0) {
+            $volt = $mbinfo->addChild('Power');
+            foreach ($mbinfo_detail->getMbPower() as $dev) {
+                $item = $volt->addChild('Item');
+                $item->addAttribute('Label', $dev->getName());
+                $item->addAttribute('Value', $dev->getValue());
+                if ($dev->getMax() !== null) {
+                    $item->addAttribute('Max', $dev->getMax());
+                }
+            }
+        }
+    }
     
     /**
      * generate the ups information
@@ -374,6 +435,9 @@ class XML
     private function _buildUpsinfo()
     {
         $upsinfo = $this->_xml->addChild('UPSInfo');
+        if ( defined('PSI_UPS_APCUPSD_CGI_ENABLE') && PSI_UPS_APCUPSD_CGI_ENABLE) {
+            $upsinfo->addAttribute('ApcupsdCgiLinks', true);
+        }
         if (PSI_UPSINFO) {
             $upsinfoclass = PSI_UPS_PROGRAM;
             $upsinfo_data = new $upsinfoclass();
@@ -403,6 +467,9 @@ class XML
                 if ($ups->getLoad() !== null) {
                     $item->addAttribute('LoadPercent', $ups->getLoad());
                 }
+                if ($ups->getBatteryDate() !== null) {
+                    $item->addAttribute('BatteryDate', $ups->getBatteryDate());
+                }
                 if ($ups->getBatteryVoltage() !== null) {
                     $item->addAttribute('BatteryVoltage', $ups->getBatteryVoltage());
                 }
@@ -425,6 +492,28 @@ class XML
     {
         if (!$this->_plugin_request || $this->_complete_request) {
             if ($this->_sys === null) {
+                if (PSI_DEBUG === true) {
+                    // Safe mode check
+                    $safe_mode = @ini_get("safe_mode") ? TRUE : FALSE;
+                    if ($safe_mode) {
+                        $this->_errors->addError("WARN", "PhpSysInfo requires to set off 'safe_mode' in 'php.ini'");
+                    }
+                    // Include path check
+                    $include_path = @ini_get("include_path");
+                    if ($include_path && ($include_path!="")) {
+                        $include_path = preg_replace("/(:)|(;)/", "\n", $include_path);
+                        if (preg_match("/^\.$/m", $include_path)) {
+                            $include_path = ".";
+                        }
+                    }
+                    if ($include_path != ".") {
+                        $this->_errors->addError("WARN", "PhpSysInfo requires '.' inside the 'include_path' in php.ini");
+                    }
+                    // popen mode check
+                    if (defined("PSI_MODE_POPEN") && PSI_MODE_POPEN === true) {
+                        $this->_errors->addError("WARN", "Installed version of PHP does not support proc_open() function, popen() is used");
+                    }
+                }
                 $this->_sys = $this->_sysinfo->getSys();
             }
             $this->_buildVitals();
@@ -447,6 +536,7 @@ class XML
     public function getXml()
     {
         $this->_buildXml();
+
         return $this->_xml->getSimpleXmlElement();
     }
     
@@ -490,12 +580,31 @@ class XML
         $this->_xml = new SimpleXMLExtended(simplexml_import_dom($dom), $this->_sysinfo->getEncoding());
         
         $generation = $this->_xml->addChild('Generation');
-        $generation->addAttribute('version', CommonFunctions::PSI_VERSION);
+        $generation->addAttribute('version', PSI_VERSION_STRING);
         $generation->addAttribute('timestamp', time());
         $options = $this->_xml->addChild('Options');
-        $options->addAttribute('tempFormat', defined('PSI_TEMP_FORMAT') ? PSI_TEMP_FORMAT : 'c');
-        $options->addAttribute('byteFormat', defined('PSI_BYTE_FORMAT') ? PSI_BYTE_FORMAT : 'auto_binary');
-        $options->addAttribute('refresh', defined('PSI_REFRESH') ? PSI_REFRESH : 0);
+        $options->addAttribute('tempFormat', defined('PSI_TEMP_FORMAT') ? strtolower(PSI_TEMP_FORMAT) : 'c');
+        $options->addAttribute('byteFormat', defined('PSI_BYTE_FORMAT') ? strtolower(PSI_BYTE_FORMAT) : 'auto_binary');
+        if ( defined('PSI_REFRESH') ) {
+            if (PSI_REFRESH === false) {
+                $options->addAttribute('refresh', 0);
+            } elseif (PSI_REFRESH === true) {
+                $options->addAttribute('refresh', 1);
+            } else {
+                $options->addAttribute('refresh', PSI_REFRESH);
+            }
+        } else {
+            $options->addAttribute('refresh', 60000);
+        }
+        if ( defined('PSI_FS_USAGE_THRESHOLD') ) {
+            if (PSI_FS_USAGE_THRESHOLD === true) {
+                $options->addAttribute('threshold', 1);
+            } elseif ((PSI_FS_USAGE_THRESHOLD !== false) && (PSI_FS_USAGE_THRESHOLD >= 1) && (PSI_FS_USAGE_THRESHOLD <= 99) ) {
+                $options->addAttribute('threshold', PSI_FS_USAGE_THRESHOLD);
+            }
+        } else {
+            $options->addAttribute('threshold', 90);
+        }
         $options->addAttribute('showPickListTemplate', defined('PSI_SHOW_PICKLIST_TEMPLATE') ? (PSI_SHOW_PICKLIST_TEMPLATE ? 'true' : 'false') : 'false');
         $options->addAttribute('showPickListLang', defined('PSI_SHOW_PICKLIST_LANG') ? (PSI_SHOW_PICKLIST_LANG ? 'true' : 'false') : 'false');
         $plug = $this->_xml->addChild('UsedPlugins');
@@ -508,4 +617,3 @@ class XML
         }
     }
 }
-?>
