@@ -5,7 +5,7 @@
 	* @copyright Copyright (C) 2000-2005 Free Software Foundation, Inc. http://www.fsf.org/
 	* @license http://www.gnu.org/licenses/gpl.html GNU General Public License
 	* @package preferences
-	* @version $Id: hook_settings.inc.php 6406 2010-09-25 16:30:36Z sigurd $
+	* @version $Id: hook_settings.inc.php 11265 2013-08-13 11:26:34Z sigurdne $
 	*/
 
 	phpgw::import_class('phpgwapi.country');
@@ -73,6 +73,7 @@
 		'Y/m/d' => 'Y/m/d',
 		'Y-m-d' => 'Y-m-d',
 		'Y.m.d' => 'Y.m.d',
+		'd/m-Y' => 'd/m-Y',
 		'd/m/Y' => 'd/m/Y',
 		'd-m-Y' => 'd-m-Y',
 		'd.m.Y' => 'd.m.Y',
@@ -154,11 +155,13 @@
 	$menu_formats = array(
 		'sidebox' => lang('Sidebox'),
 		'jsmenu' => lang('JS-menu'),
+		'ajax_menu' => lang('ajax menu'),
 		'no_sidecontent' => lang('No SideContent')
 	);
 	create_select_box('SideContent','sidecontent',$menu_formats,
 		'Do you want your menues as sidecontent');
 	create_check_box('Show breadcrumbs','show_breadcrumbs',
 			'Should history navigation urls as breadcrumbs');
-
+	create_check_box('activate nowrap in YUI-tables','yui_table_nowrap',
+			'activate nowrap in YUI-tables');
 
