@@ -5,7 +5,7 @@
 	* @copyright Copyright (C) 2000-2006 Free Software Foundation, Inc. http://www.fsf.org/
 	* @license http://www.gnu.org/licenses/gpl.html GNU General Public License
 	* @package preferences
-	* @version $Id: preferences.php 18358 2007-11-27 04:43:37Z skwashd $
+	* @version $Id: preferences.php 6158 2010-06-28 11:32:38Z sigurd $
 	*/
 
 	$GLOBALS['phpgw_info']['flags'] = array
@@ -147,7 +147,7 @@
 		$default = '';
 		if (isset($prefs[$name]) || $GLOBALS['type'] != 'user')
 		{
-			$default = $prefs[$name];
+			$default = isset($prefs[$name]) && $prefs[$name] ? $prefs[$name] : ''; 
 		}
 		
 		if ($GLOBALS['type'] == 'user')
@@ -162,7 +162,7 @@
 			}
 			$def_text = ($def_text != '') ? lang('default') . " $def_text" : '';
 		}
-		$t->set_var('row_value',"<input name=\"${GLOBALS['type']}[$name]\" value=\"" . htmlentities($default) . "\"$options />$def_text");
+		$t->set_var('row_value',"<input name=\"${GLOBALS['type']}[$name]\" value=\"" . htmlentities($default, ENT_COMPAT, 'UTF-8') . "\"$options />$def_text");
 		$t->set_var('row_name',lang($label));
 		$GLOBALS['phpgw']->nextmatchs->template_alternate_row_class($t);
 
@@ -318,7 +318,7 @@
 		$vars = $GLOBALS['phpgw']->preferences->vars;
 		if (is_array($vars2))
 		{
-			$vars += $vars2;
+			$vars = array_merge($vars, $vars2);
 		}
 		$prefs[$name] = $GLOBALS['phpgw']->preferences->lang_notify($prefs[$name],$vars);
 
@@ -507,7 +507,7 @@
 	$session_data = $GLOBALS['phpgw']->session->appsession('session_data','preferences');
 
 	$prefix = phpgw::get_var('prefix', 'string', 'GET');
-	if ( !$prefix && (isset($session_data['appname']) && $session_data['appname'] == $_GET['appname']) )
+	if ( !$prefix && (isset($session_data['appname']) && $session_data['appname'] == phpgw::get_var('appname', 'string', 'GET') ) )
 	{
 		$prefix = $session_data['prefix'];
 	}
@@ -551,11 +551,18 @@
 	$error = '';
 	if ( phpgw::get_var('submit', 'bool', 'POST') )
 	{
+//_debug_array($_POST);die();
 		if ( !isset($session_data['notifys']) )
 		{
 			$session_data['notifys'] = array();
 		}
-		
+
+		$account_id = phpgw::get_var('account_id', 'int', 'POST');
+		if(is_admin() && $account_id)
+		{
+			$GLOBALS['phpgw']->preferences->set_account_id($account_id, true);
+		}		
+
 		/* Don't use a switch here, we need to check some permissions durring the ifs */
 		if ($GLOBALS['type'] == 'user' || !($GLOBALS['type']))
 		{
@@ -572,6 +579,11 @@
 			$error = process_array($GLOBALS['phpgw']->preferences->forced, $forced,$session_data['notifys']);
 		}
 
+		if(is_admin() && $account_id)
+		{
+			$GLOBALS['phpgw']->preferences->set_account_id($GLOBALS['phpgw_info']['user']['account_id'], true);
+		}		
+
 		if (!is_admin() || $error)
 		{
 			$GLOBALS['phpgw']->redirect_link('/preferences/index.php');
@@ -595,7 +607,15 @@
 		&& $GLOBALS['type'] == 'user' 
 		&& $appname == 'preferences')
 	{
-		$GLOBALS['phpgw']->redirect_link('/preferences/preferences.php', array('appname' => $appname) );
+		$GLOBALS['phpgw']->redirect_link('/preferences/preferences.php', array('appname' => $appname, 'account_id' => $account_id) );
+	}
+	if(is_admin())
+	{
+		$account_id = phpgw::get_var('account_id', 'int');
+		if($account_id)
+		{
+			$GLOBALS['phpgw']->preferences->set_account_id($account_id, true);
+		}
 	}
 
 	$GLOBALS['phpgw_info']['flags']['app_header'] = $appname == 'preferences' ?
@@ -603,7 +623,7 @@
 	$GLOBALS['phpgw']->common->phpgw_header(true);
 
 	$t->set_var('messages',$error);
-	$t->set_var('action_url',$GLOBALS['phpgw']->link('/preferences/preferences.php', array('appname'=> $appname)));
+	$t->set_var('action_url',$GLOBALS['phpgw']->link('/preferences/preferences.php', array('appname'=> $appname, 'type' => $GLOBALS['type'])));
 
 	switch ($GLOBALS['type'])	// set up some globals to be used by the hooks
 	{
@@ -665,11 +685,71 @@
 
 		switch($GLOBALS['type'])
 		{
-			case 'user':    $selected = 0; break;
-			case 'default': $selected = 1; break;
-			case 'forced':  $selected = 2; break;
+			case 'user':
+				$accounts = array();
+				$selected = 0;
+				$account_id = phpgw::get_var('account_id', 'int', 'REQUEST', 0);
+				if( $appname == 'preferences')	// All users
+				{
+					$_accounts = $GLOBALS['phpgw']->accounts->get_list('accounts',-1,'','account_lastname');
+					foreach($_accounts as $_account)
+					{
+						$accounts[] = array
+						(
+							'id' 	=> $_account->id,
+							'name'	=> $_account->__toString()
+						);
+					}
+					unset($_accounts);
+				}
+				else // only users which has access to the app
+				{
+					$_accounts = $GLOBALS['phpgw']->acl->get_user_list_right(1, 'run', $appname);
+					foreach($_accounts as $_account)
+					{
+						$__account = $GLOBALS['phpgw']->accounts->get($_account['account_id']);
+						$accounts[] = array
+						(
+							'id' 	=>$__account->id,
+							'name'	=> $__account->__toString()
+						);
+					}
+				}
+
+				$account_list = "<form method='POST' action=''>";
+				$account_list .= '<table><tr><td><select name="account_id" onChange="this.form.submit();">';
+				$account_list .= "<option value=''>" . lang('select user') . '</option>';
+				foreach ( $accounts as $account )
+				{
+					$account_list .= "<option value='{$account['id']}'";
+					if ($account['id'] == $account_id)
+					{
+						$account_list .= ' selected';
+					}
+					$account_list .= "> {$account['name']}</option>";
+				}
+				$account_list .= '</select>';
+				$account_list .= '<noscript><input type="submit" name="user" value="Select"></noscript>';
+				$account_list .= '</td></tr></table></form>';
+
+				$t->set_var('select_user', $account_list);
+
+				if($account_id)
+				{
+					$t->set_var('account_id', "<input type='hidden' name='account_id' value='{$account_id}'>");
+				}
+
+			    break;
+
+			case 'default':
+				$selected = 1;
+				break;
+			case 'forced':
+				$selected = 2;
+				break;
 		}
 		$t->set_var('tabs',$GLOBALS['phpgw']->common->create_tabs($tabs,$selected));
+
 	}
 	$t->set_var('lang_submit', lang('save'));
 	$t->set_var('lang_cancel', lang('cancel'));
