@@ -24,7 +24,7 @@
 	* @internal Development of this application was funded by http://www.bergen.kommune.no/bbb_/ekstern/
 	* @package property
 	* @subpackage entity
- 	* @version $Id: class.boentity.inc.php 7434 2011-06-27 13:36:06Z sigurdne $
+ 	* @version $Id: class.boentity.inc.php 11534 2013-12-15 15:39:08Z sigurdne $
 	*/
 
 	/**
@@ -43,6 +43,9 @@
 		var $allrows;
 		var $part_of_town_id;
 		var $location_code;
+		var $results;
+		var $acl_location;
+		protected $xsl_rootdir;
 
 		/**
 		 * @var object $custom reference to custom fields object
@@ -60,8 +63,9 @@
 
 		var $type_app = array();
 		var $type;
+		private $location_relation_data = array();
 
-		function property_boentity($session=false, $type = '', $entity_id = 0, $cat_id = 0)
+		function __construct($session=false, $type = '', $entity_id = 0, $cat_id = 0)
 		{
 			$this->solocation 				= CreateObject('property.solocation');
 			$this->bocommon 				= CreateObject('property.bocommon');
@@ -84,6 +88,7 @@
 			$order							= phpgw::get_var('order');
 			$filter							= phpgw::get_var('filter', 'int');
 			$district_id					= phpgw::get_var('district_id', 'int');
+			$part_of_town_id				= phpgw::get_var('part_of_town_id', 'int');
 			$status							= phpgw::get_var('status');
 			$start_date						= phpgw::get_var('start_date');
 			$end_date						= phpgw::get_var('end_date');
@@ -98,6 +103,9 @@
 			$this->type_app					= $this->so->get_type_app();
 
 			$this->type						= isset($type)  && $type && $this->type_app[$type] ? $type : 'entity';
+
+			$this->acl_location				= ".{$type}.{$entity_id}.{$cat_id}";
+
 			$this->location_code			= isset($location_code)  && $location_code ? $location_code : '';
 
 			$this->soadmin_entity 			= CreateObject('property.soadmin_entity',$entity_id,$cat_id);
@@ -147,6 +155,10 @@
 			{
 				$this->district_id = $district_id;
 			}
+			if(isset($_POST['part_of_town_id']) || isset($_GET['part_of_town_id']))
+			{
+				$this->part_of_town_id = $part_of_town_id;
+			}
 			if(isset($_POST['criteria_id']) || isset($_GET['criteria_id']))
 			{
 				$this->criteria_id = $criteria_id;
@@ -175,6 +187,7 @@
 			{
 				$this->allrows = $allrows;
 			}
+			$this->xsl_rootdir = PHPGW_SERVER_ROOT . '/property/templates/base';
 		}
 
 		function save_sessiondata($data)
@@ -212,6 +225,10 @@
 			$filter = array('list' => ''); // translates to "list IS NULL"
 			$columns = $this->custom->find($this->type_app[$this->type],".{$this->type}.{$entity_id}.{$cat_id}", 0, '','','',true, false, $filter);
 			$columns = array_merge( $columns, $this->get_column_list() );
+			foreach ($columns as &$column)
+			{
+				$column['name'] = $column['descr'] ? $column['descr'] : $column['input_text'];
+			}
 			$column_list=$this->bocommon->select_multi_list($selected,$columns);
 			return $column_list;
 		}
@@ -219,6 +236,34 @@
 		function get_column_list()
 		{
 			$columns = array();
+
+			// defined i property_bocommon::generate_sql()
+			$location_relation_data = phpgwapi_cache::system_get('property', 'location_relation_data');
+			
+			$this->location_relation_data = $location_relation_data && is_array($location_relation_data) ? $location_relation_data : array();
+			
+			if( $this->location_relation_data && is_array($this->location_relation_data))
+			{
+				foreach ($this->location_relation_data as $entry)
+				{
+					$columns[$entry['name']] = array
+					(
+						'id'			=> $entry['name'],
+						'input_type'	=> 'text',
+						'name'			=> $entry['name'],
+						'descr'			=> $entry['descr'],
+						'statustext'	=> $entry['descr'],
+						'align' 		=> '',
+						'datatype'		=> $entry['datatype'],
+						'sortable'		=> false,
+						'exchange'		=> false,
+						'formatter'		=> '',
+						'classname'		=> ''
+					);
+				
+				}
+			}
+/*
 			$columns['user_id'] = array
 			(
 				'id'			=> 'user_id',
@@ -233,7 +278,7 @@
 				'formatter'		=> '',
 				'classname'		=> ''
 			);
-
+*/
 			return $columns;
 		}
 
@@ -242,10 +287,10 @@
 			switch($format)
 			{
 			case 'select':
-				$GLOBALS['phpgw']->xslttpl->add_file(array('cat_select'));
+				$GLOBALS['phpgw']->xslttpl->add_file(array('cat_select'),$this->xsl_rootdir);
 				break;
 			case 'filter':
-				$GLOBALS['phpgw']->xslttpl->add_file(array('cat_filter'));
+				$GLOBALS['phpgw']->xslttpl->add_file(array('cat_filter'),$this->xsl_rootdir);
 				break;
 			}
 
@@ -260,10 +305,10 @@
 			switch($format)
 			{
 			case 'select':
-				$GLOBALS['phpgw']->xslttpl->add_file(array('status_select'));
+				$GLOBALS['phpgw']->xslttpl->add_file(array('status_select'),$this->xsl_rootdir);
 				break;
 			case 'filter':
-				$GLOBALS['phpgw']->xslttpl->add_file(array('status_filter'));
+				$GLOBALS['phpgw']->xslttpl->add_file(array('status_filter'),$this->xsl_rootdir);
 				break;
 			}
 
@@ -297,7 +342,7 @@
 
 		function read($data= array())
 		{
-			if(isset($this->allrows))
+			if(isset($this->allrows) && $this->allrows)
 			{
 				$data['allrows'] = true;
 			}
@@ -305,6 +350,8 @@
 			$custom	= createObject('phpgwapi.custom_fields');
 			$attrib_data = $custom->find($this->type_app[$this->type],".{$this->type}.{$this->entity_id}.{$this->cat_id}", 0, '','','',true, true);
 
+			$category = $this->soadmin_entity->read_single_category($this->entity_id,$this->cat_id);
+
 			$attrib_filter = array();
 			if($attrib_data)
 			{
@@ -314,50 +361,102 @@
 					{
 						if($_attrib_filter_value = phpgw::get_var($attrib['column_name'], 'int'))
 						{
-							$attrib_filter[] = "fm_{$this->type}_{$this->entity_id}_{$this->cat_id}.{$attrib['column_name']} = '{$_attrib_filter_value}'";
+							if($category['is_eav'])
+							{
+								$attrib_filter[] = "xmlexists('//{$attrib['column_name']}[text() = ''$_attrib_filter_value'']' PASSING BY REF xml_representation)";
+							}
+							else
+							{
+								$attrib_filter[] = "fm_{$this->type}_{$this->entity_id}_{$this->cat_id}.{$attrib['column_name']} = '{$_attrib_filter_value}'";
+							}
 						}
 					}
 					else if($attrib['datatype'] == 'CH')
 					{
 						if($_attrib_filter_value = phpgw::get_var($attrib['column_name'], 'int'))
 						{
-							$attrib_filter[] = "fm_{$this->type}_{$this->entity_id}_{$this->cat_id}.{$attrib['column_name']} {$GLOBALS['phpgw']->db->like} '%,{$_attrib_filter_value},%'";
+							if($category['is_eav'])
+							{
+								$attrib_filter[] = "xmlexists('//{$attrib['column_name']}[contains(.,'',$_attrib_filter_value,'')]' PASSING BY REF xml_representation)";
+							}
+							else
+							{
+								$attrib_filter[] = "fm_{$this->type}_{$this->entity_id}_{$this->cat_id}.{$attrib['column_name']} {$GLOBALS['phpgw']->db->like} '%,{$_attrib_filter_value},%'";
+							}
 						}
 					}
 				}
 			}
 
 			$entity = $this->so->read(array('start' => $this->start,'query' => $this->query,'sort' => $this->sort,'order' => $this->order,
-				'filter' => $this->filter,'cat_id' => $this->cat_id,'district_id' => $this->district_id,
-				'lookup'=>isset($data['lookup'])?$data['lookup']:'','allrows'=>isset($data['allrows'])?$data['allrows']:'',
+				'filter' => $this->filter,'cat_id' => $this->cat_id,'district_id' => $this->district_id, 'part_of_town_id' => $this->part_of_town_id,
+				'lookup'=>isset($data['lookup'])?$data['lookup']:'','allrows'=>isset($data['allrows'])?$data['allrows']:'', 'results' => $this->results,
 				'entity_id'=>$this->entity_id,'cat_id'=>$this->cat_id,'status'=>$this->status,
 				'start_date'=>$this->bocommon->date_to_timestamp($data['start_date']),
 				'end_date'=>$this->bocommon->date_to_timestamp($data['end_date']),
 				'dry_run'=>$data['dry_run'], 'type'=>$data['type'], 'location_code' => $this->location_code,
-				'criteria_id' => $this->criteria_id, 'attrib_filter' => $attrib_filter, 'p_num' => $this->p_num));
+				'criteria_id' => $this->criteria_id, 'attrib_filter' => $attrib_filter, 'p_num' => $this->p_num,
+				'control_registered'=>isset($data['control_registered'])?$data['control_registered']:'','control_id'=>isset($data['control_id'])?$data['control_id']:''));
 
 			$this->total_records = $this->so->total_records;
 			$this->uicols	= $this->so->uicols;
 
 			$user_columns = isset($GLOBALS['phpgw_info']['user']['preferences'][$this->type_app[$this->type]]["{$this->type}_columns_{$this->entity_id}_{$this->cat_id}"])?$GLOBALS['phpgw_info']['user']['preferences'][$this->type_app[$this->type]]["{$this->type}_columns_{$this->entity_id}_{$this->cat_id}"]:array();
 			$custom_cols = $this->get_column_list();
+
 //_debug_array($user_columns);
 //_debug_array($column_list);
-/*
+
+			$cols_extra		= $this->so->cols_extra;
+			$cols_return_lookup		= $this->so->cols_return_lookup;
+
+
 			foreach ($custom_cols as $col_id => $col_info)
 			{
 				if( in_array( $col_id, $user_columns ) )
 				{
-					$cols_extra[] = array
-					(
-						'name'		=> $col_id,
-						'datatype'	=> $column_list[$col_id]['datatype']
-					);
+					$this->uicols['input_type'][]	= 'text';
+					$this->uicols['name'][]			= $col_id;
+					$this->uicols['descr'][]		= $custom_cols[$col_id]['descr'];
+					$this->uicols['statustext'][]	= $custom_cols[$col_id]['descr'];
+					$this->uicols['exchange'][]		= false;
+					$this->uicols['align'][] 		= '';
+					$this->uicols['datatype'][]		= $custom_cols[$col_id]['datatype'];
+					$this->uicols['formatter'][]	= '';
+					$this->uicols['classname'][]	= '';
+					$this->uicols['sortable'][]		= false;
+					$cols_extra[] 					= $col_id;
 				}
 			}
+
+//_debug_array($cols_extra);
+//_debug_array($this->uicols);die();
+/*
+			$location_relation_data = 	$this->location_relation_data;
+			
+			if ($location_relation_data && is_array($location_relation_data))
+			{
+				foreach ($location_relation_data as $entry)
+				{
+					$this->uicols['input_type'][]	= 'text';
+					$this->uicols['name'][]			= $entry['name'];
+					$this->uicols['descr'][]		= $entry['descr'];
+					$this->uicols['statustext'][]	= $entry['descr'];
+					$this->uicols['exchange'][]		= false;
+					$this->uicols['align'][] 		= '';
+					$this->uicols['datatype'][]		= '';
+					$this->uicols['formatter'][]	= '';
+					$this->uicols['classname'][]	= '';
+					$this->uicols['sortable'][]		= false;
+
+					$cols_extra[] 				= $entry['name'];
+
+				}
+			}
+			
+			unset($entry);
 */
-			$cols_extra		= $this->so->cols_extra;
-			$cols_return_lookup		= $this->so->cols_return_lookup;
+
 			//_debug_array($entity);
 //			_debug_array($cols_extra);
 			//_debug_array($cols_return_lookup);
@@ -409,19 +508,30 @@
 				}
 			}
 
+			//old
 			if($values['p_num'])
 			{
 				$soadmin_entity 			= CreateObject('property.soadmin_entity');
 				$soadmin_entity->type		= 'entity';
 				$soadmin_entity->type_app	= 'property';
 				$category = $soadmin_entity->read_single_category($values['p_entity_id'],$values['p_cat_id']);
-//				$category = $this->soadmin_entity->read_single_category($values['p_entity_id'],$values['p_cat_id']);
 				$values['p'][$values['p_entity_id']]['p_num']=$values['p_num'];
 				$values['p'][$values['p_entity_id']]['p_entity_id']=$values['p_entity_id'];
 				$values['p'][$values['p_entity_id']]['p_cat_id']=$values['p_cat_id'];
 				$values['p'][$values['p_entity_id']]['p_cat_name'] = $category['name'];
 			}
 
+			//new
+			if($values['p_id'] && $values['p_location_id'])
+			{
+				$p_location = $GLOBALS['phpgw']->locations->get_name($values['p_location_id']);
+				$p__location = explode('.', $p_location['location']);
+				$values['p'][$p__location[2]]['p_num']=$values['p_id'];
+				$values['p'][$p__location[2]]['p_entity_id']=$p__location[2];
+				$values['p'][$p__location[2]]['p_cat_id']=$p__location[3];
+				$values['p'][$p__location[2]]['p_cat_name'] = $p_location['descr'];
+			}
+
 			$vfs = CreateObject('phpgwapi.vfs');
 			$vfs->override_acl = 1;
 
@@ -528,7 +638,7 @@
 
 				$file = PHPGW_SERVER_ROOT . "/{$this->type_app[$this->type]}/inc/custom/{$GLOBALS['phpgw_info']['user']['domain']}/{$entry['file_name']}";
 
-				if ( $entry['active'] && is_file($file) )
+				if ( $entry['active'] && !$entry['client_side'] && is_file($file) )
 				{
 					require_once $file;
 				}
@@ -640,4 +750,40 @@
 			return $this->so->read_entity_to_link($data);
 		}
 
+		/**
+		*  array('id' => $id, 'location_id' => $location_id, 'inventory_id' => $inventory_id)
+		*/
+
+		public function get_inventory($data)
+		{
+			$values = $this->so->get_inventory( $data );
+
+			$interlink 	= CreateObject('property.interlink');
+
+			foreach ($values as &$entry)
+			{
+				$link_info = $interlink->get_location_link($entry['p_location_id'], $entry['p_id'],'view');
+				$entry['where'] = "<a href='{$link_info['link']}'>{$link_info['name']}</a>";
+				$entry['where_name'] = $link_info['name'];
+				$entry['location_id'] = $data['location_id'];
+				$entry['id'] = $data['id'];
+			}
+
+			return $values;
+		}
+
+		public function add_inventory($values)
+		{
+			$values['active_from']	= $this->bocommon->date_to_timestamp($values['active_from']);
+			$values['active_to']	= $this->bocommon->date_to_timestamp($values['active_to']);
+			return $this->so->add_inventory($values);
+		}
+
+		public function edit_inventory($values)
+		{
+			$values['active_from']	= $this->bocommon->date_to_timestamp($values['active_from']);
+			$values['active_to']	= $this->bocommon->date_to_timestamp($values['active_to']);
+			return $this->so->edit_inventory($values);
+		}
+
 	}
