@@ -24,9 +24,10 @@
 	* @internal Development of this application was funded by http://www.bergen.kommune.no/bbb_/ekstern/
 	* @package property
 	* @subpackage eco
- 	* @version $Id: class.boinvoice.inc.php 7379 2011-06-14 11:51:29Z sigurdne $
+ 	* @version $Id: class.boinvoice.inc.php 11532 2013-12-15 15:17:13Z sigurdne $
 	*/
 
+	phpgw::import_class('phpgwapi.datetime');
 	/**
 	 * Description
 	 * @package property
@@ -36,6 +37,8 @@
 	{
 		public $total_records = 0;
 		public $sum_amount = 0;
+		public $results = 0;
+		public $allrows = false;
 
 		function property_boinvoice($session=false)
 		{
@@ -61,16 +64,40 @@
 			$district_id			= phpgw::get_var('district_id', 'int');
 			$b_account				= phpgw::get_var('b_account');
 
-			$this->start			= $start ? $start : 0;
+	//		$this->start			= $start ? $start : (int)$this->start;
+
+			$this->start			= isset($_REQUEST['start']) 		? $start			: $this->start;
+
+			if(phpgw::get_var('workorder_id', 'int'))
+			{
+				$this->start = 0;
+			}
+
+			$this->query			= isset($query) ? $query : $query;
+
+			if(!phpgw::get_var('paid', 'bool'))
+			{
+	//			$voucher_id 	= $this->query && ctype_digit($this->query) ? $this->query : 0;
+			}
+	//		else
+			{
+				$user_lid = isset($_REQUEST['user_lid']) ? $user_lid : 'all';
+			}
+
+			if($voucher_id)
+			{
+				$this->start 	= 0;
+			}
+
+
 			$this->b_account		= isset($b_account) ? $b_account : $b_account;
 			$this->district_id		= isset($district_id) ? $district_id : $district_id;
 			$this->b_account_class	= isset($b_account_class) ? $b_account_class : $b_account_class;
-			$this->query			= isset($query) ? $query : $query;
 			$this->filter			= isset($filter) ? $filter : $filter;
 			$this->sort				= isset($sort) ? $sort : $sort;
 			$this->order			= isset($order) ? $order : $order;
 			$this->cat_id			= isset($cat_id) ? $cat_id : $cat_id;
-			$this->user_lid			= isset($user_lid) ? $user_lid : $user_lid;
+			$this->user_lid			= $user_lid ? $user_lid : $this->user_lid;
 			$this->allrows			= isset($allrows) ? $allrows : $allrows;
 		}
 
@@ -87,7 +114,7 @@
 		{
 			$data = $GLOBALS['phpgw']->session->appsession('session_data','invoice');
 
-			//	_debug_array($data);
+//_debug_array($data);
 
 			$this->start			= isset($data['start'])?$data['start']:'';
 			$this->query			= isset($data['query'])?$data['query']:'';
@@ -95,15 +122,20 @@
 			$this->sort				= isset($data['sort'])?$data['sort']:'';
 			$this->order			= isset($data['order'])?$data['order']:'';
 			$this->cat_id			= isset($data['cat_id'])?$data['cat_id']:'';
-			$this->user_lid			= isset($data['user_lid'])?$data['user_lid']:'';
+			$this->user_lid			= $data['user_lid']?$data['user_lid']:'';
 			$this->sub				= isset($data['sub'])?$data['sub']:'';
 			$this->allrows			= isset($data['allrows'])?$data['allrows']:'';
 			$this->b_account_class	= isset($data['b_account_class'])?$data['b_account_class']:'';
 			$this->district_id		= isset($data['district_id'])?$data['district_id']:'';
 		}
 
-		function read_invoice($paid='',$start_date='',$end_date='',$vendor_id='',$loc1='',$workorder_id='',$voucher_id='')
+		function read_invoice($paid='',$start_date='',$end_date='',$vendor_id='',$loc1='',$workorder_id='',$voucher_id='', $invoice_id = '',$ecodimb = '',$project_id = 0)
 		{
+			if(!phpgw::get_var('paid', 'bool'))
+			{
+//				$voucher_id 	= $this->query && ctype_digit($this->query) ? $this->query : 0;
+			}
+
 			$start_date	= $this->bocommon->date_to_timestamp($start_date);
 			$end_date	= $this->bocommon->date_to_timestamp($end_date);
 
@@ -112,7 +144,7 @@
 				'start_date'=>$start_date,'end_date'=>$end_date,'vendor_id'=>$vendor_id,
 				'loc1'=>$loc1,'workorder_id'=>$workorder_id,'allrows'=>$this->allrows,
 				'voucher_id'=>$voucher_id,'b_account_class' =>$this->b_account_class,
-				'district_id' => $this->district_id));
+				'district_id' => $this->district_id, 'invoice_id' => $invoice_id, 'ecodimb' => $ecodimb, 'project_id' => $project_id));
 
 			$soXport    = CreateObject('property.soXport');
 			$soworkorder = CreateObject('property.soworkorder');
@@ -151,10 +183,10 @@
 			return $invoice;
 		}
 
-		function read_invoice_sub($voucher_id='',$paid='')
+		function read_invoice_sub($voucher_id=0,$paid = false)
 		{
 			$invoice = $this->so->read_invoice_sub(array('start' => $this->start,'query' => $this->query,'sort' => $this->sort,'order' => $this->order,
-				'user_lid' => $this->user_lid,'cat_id' => $this->cat_id,'voucher_id'=>$voucher_id,'paid' => $paid));
+				'user_lid' => $this->user_lid,'cat_id' => $this->cat_id,'voucher_id'=>$voucher_id,'paid' => $paid, 'results' => $this->results,'allrows'=>$this->allrows));
 			$this->total_records = $this->so->total_records;
 			return $invoice;
 		}
@@ -169,7 +201,49 @@
 			return $this->so->read_single_voucher($voucher_id);
 		}
 
-		function read_consume($start_date='',$end_date='',$vendor_id='',$loc1='',$workorder_id='',$b_account_class='',$district_id='')
+
+		function read_single_line($line_id)
+		{
+
+			$invoice = $this->so->read_single_voucher(0, $line_id);
+			
+			$soXport    = CreateObject('property.soXport');
+			$soworkorder = CreateObject('property.soworkorder');
+			$sos_agreement = CreateObject('property.sos_agreement');
+			foreach ( $invoice as & $entry )
+			{
+				if( $entry['order_id'] )
+				{
+					if($order_type = $soXport->check_order($entry['order_id']))
+					{
+						if($order_type == 'workorder')
+						{
+							$workorder	= $soworkorder->read_single($entry['order_id']);
+
+							if($workorder['vendor_id'] && ($workorder['vendor_id'] != $entry['vendor_id']))
+							{
+						//		$entry['vendor']	=  $this->get_vendor_name($workorder['vendor_id']) . ' => ' . $entry['vendor'];
+								$entry['vendor']	= $workorder['vendor_id'] . ' [' .$this->get_vendor_name($workorder['vendor_id']) . "] =>  {$entry['vendor_id']} [{$entry['vendor']}]";
+							}
+						}
+
+						if($order_type == 's_agreement')
+						{
+							$s_agreement = $sos_agreement->read_single($entry['order_id']);
+
+							if($s_agreement['vendor_id'] && ($s_agreement['vendor_id'] != $entry['vendor_id']))
+							{
+								$entry['vendor']	= $s_agreement['vendor_id'] . ' [' .$this->get_vendor_name($s_agreement['vendor_id']) . "] =>  {$entry['vendor_id']} [{$entry['vendor']}]";
+							}
+						}
+					}
+				}
+			}
+
+			return $invoice;
+		}
+
+		function read_consume($start_date='',$end_date='',$vendor_id='',$loc1='',$workorder_id='',$b_account_class='',$district_id='',$ecodimb = '')
 		{
 			$start_date	= $this->bocommon->date_to_timestamp($start_date);
 			$end_date	= $this->bocommon->date_to_timestamp($end_date);
@@ -178,7 +252,7 @@
 				'user_lid' => $this->user_lid,'cat_id' => $this->cat_id,
 				'start_date'=>$start_date,'end_date'=>$end_date,'vendor_id'=>$vendor_id,
 				'loc1'=>$loc1,'workorder_id'=>$workorder_id,'b_account_class' =>$b_account_class,
-				'district_id' => $district_id, 'b_account' => $this->b_account ));
+				'district_id' => $district_id, 'b_account' => $this->b_account,'ecodimb' => $ecodimb ));
 
 			$this->total_records = $this->so->total_records;
 
@@ -197,9 +271,9 @@
 			return $this->so->update_invoice_sub($values);
 		}
 
-		function update_single_line($values)
+		function update_single_line($values, $paid = false)
 		{
-			return $this->so->update_single_line($values);
+			return $this->so->update_single_line($values, $paid);
 		}
 
 		function select_account_class($selected='')
@@ -210,46 +284,110 @@
 
 		function period_list($selected='')
 		{
-			for ($i=1; $i<=12; $i++)
+			
+			$sogeneric		= CreateObject('property.sogeneric','period_transition');
+			$config			= $sogeneric->read(array('allrows' => true));
+			
+			$period_transition = array();
+			foreach($config as $entry)
 			{
-				$period_list[$i]['id'] = $i;
-				$period_list[$i]['name'] = $i;
-				if($i==$selected)
+				$period_transition[$entry['month']] = $entry;
+			}
+			
+			$current_month = date('n');
+			
+			if(isset($period_transition[$current_month]))
+			{
+				$_lag_day = (int)$period_transition[$current_month]['day'];
+				$_lag_hour = (int)$period_transition[$current_month]['hour'];
+				$_lag_seconds = ($_lag_day * 24 * 3600) + ($_lag_hour * 3600);
+			}
+			else if(isset($period_transition[13]))
+			{
+				$_lag_day = (int)$period_transition[13]['day'];
+				$_lag_hour = (int)$period_transition[13]['hour'];
+				$_lag_seconds = ($_lag_day * 24 * 3600) + ($_lag_hour * 3600);
+			}
+			else
+			{
+				$_lag			= date('n') == 1 ? 11 : 7;//6 days into next month, 10 days into next year
+				$_lag_seconds	= $_lag * 24 * 3600;
+			}
+			
+			$_lag_seconds -= phpgwapi_datetime::user_timezone();
+			
+//_debug_array($period_transition);			
+			$time = time();
+			$timestamp_at_start_month =  mktime( $hour = 0, $minute = 0, $second = 0, $month = date("n"), $day = 0, $year = date("Y") );
+
+
+			if(($time - $timestamp_at_start_month) < $_lag_seconds)
+			{
+				$time = $time - $_lag_seconds;			
+			}
+
+			$month = date('n', $time);
+			$year = date('Y',$time);
+			$check_year = true;
+			$period_list = array();
+			for ($i=$month; $i<=12; $i++)
+			{
+				$period = sprintf("%s%02d",$year,$i);
+				$period_list[] = array
+				(
+					'id'	=> $period,
+					'name'	=> $period
+				);
+
+				if($check_year = true && $year != date('Y'))
 				{
-					$period_list[$i]['selected'] = 'selected';
+					$i = 0;
+					$year++;
+					$check_year = false;
 				}
 			}
+
+			if(count($period_list) == 1) //last month in year
+			{
+				$year++;
+				$period = sprintf("%s%02d",$year,1);
+				$period_list[] = array
+				(
+					'id'	=> $period,
+					'name'	=> $period
+				);
+			
+			}
+
+			foreach ($period_list as &$_period)
+			{
+				$_period['selected'] = $_period['id'] == $selected ? 1 : 0;
+			}
+
 			return $period_list;
 		}
 
-		function tax_code_list($selected='')
+		function tax_code_list($selected='', $tax_codes = array())
 		{
-			$tax_codes=$this->so->tax_code_list();
-
-			while (is_array($tax_codes) && list(,$code) = each($tax_codes))
+			if(!$selected && $selected !== '0' )
 			{
-				$sel_code = '';
-				if ($code['id']==$selected)
-				{
-					$sel_code = 'selected';
-				}
-
-				$tax_code_list[] = array
-					(
-						'id'			=> $code['id'],
-						'selected'		=> $sel_code
-					);
+				$selected = '#';
+			}
+			else
+			{
+				$selected = (int)$selected;
 			}
 
-			for ($i=0;$i<count($tax_code_list);$i++)
+			if(! $tax_codes)
 			{
-				if ($tax_code_list[$i]['selected'] != 'selected')
-				{
-					unset($tax_code_list[$i]['selected']);
-				}
+				$tax_codes = $this->so->tax_code_list();
 			}
-
-			return $tax_code_list;
+			
+			foreach ($tax_codes as &$tax_code)
+			{
+				$tax_code['selected'] = (int)$tax_code['id'] === $selected ? 1 : 0;
+			}
+			return $tax_codes;
 		}
 
 		function update_period($voucher_id='',$period='')
@@ -257,11 +395,19 @@
 			return $this->so->update_period($voucher_id,$period);
 		}
 
+		function update_periodization($voucher_id='',$periodization='')
+		{
+			return $this->so->update_periodization($voucher_id,$periodization);
+		}
+
+		function update_periodization_start($voucher_id='',$period='')
+		{
+			return $this->so->update_periodization_start($voucher_id,$period);
+		}
+
 		function increment_bilagsnr()
 		{
-
 			return $this->so->increment_bilagsnr();
-
 		}
 
 		function next_bilagsnr()
@@ -327,7 +473,7 @@
 
 		function select_dimb_list($selected='')
 		{
-			$dimbs=$this->so->select_dimb_list();
+			$dimbs=$this->so->select_dimb_list($selected);
 			return $this->bocommon->select_list($selected,$dimbs);
 		}
 
@@ -355,6 +501,118 @@
 			}
 		}
 
+		public function add_manual_invoice($values)
+		{
+			$receipt = array();
+			$config	= CreateObject('admin.soconfig',$GLOBALS['phpgw']->locations->get_id('property', '.invoice'));
+
+			$buffer = array();
+			$soXport    = CreateObject('property.soXport');
+			if($values['loc1']=$values['location']['loc1'])
+			{
+				$values['dima']=implode('',$values['location']);
+				$values['location_code']	= explode('-', $values['location']);
+			}
+			$values['spbudact_code']	= $values['b_account_id'];
+			$values['fakturanr']		= $values['invoice_id'];
+			$values['spvend_code']		= $values['vendor_id'];
+			$values['belop'] 			= $values['amount'];
+			$values['godkjentbelop']	= $values['amount'];
+
+			$_dateformat = $GLOBALS['phpgw']->db->date_format();
+
+			$invoice_date 	= $values['invoice_date'] ? phpgwapi_datetime::date_to_timestamp($values['invoice_date']) : time();
+			$payment_date 	= $values['payment_date'] ? phpgwapi_datetime::date_to_timestamp($values['payment_date']) : time();
+			$paid_date		= $values['paid_date'] ? phpgwapi_datetime::date_to_timestamp($values['paid_date']) : time();
+
+			$values['fakturadato'] 		= date($_dateformat, $invoice_date);
+			$values['forfallsdato'] 	= date($_dateformat, $payment_date);
+			$values['periode']			= date('Ym', $paid_date);
+
+			$values['kildeid'] 			= 1;
+			$values['pmwrkord_code']	= $values['order_id'];
+
+			if(isset($config->config_data['common']['manual_voucher_id']) && $config->config_data['common']['manual_voucher_id'])
+			{
+				if( $soXport->check_voucher_id($values['voucher_out_id']))
+				{
+					$receipt['error'][] = array('msg'=>lang('voucher id already taken'));
+				}
+				$skip_update_voucher_id = true;
+				$values['bilagsnr']		= $values['voucher_out_id'];
+				$values['bilagsnr_ut']	= '';
+			}
+			else
+			{
+				$skip_update_voucher_id = false;
+				$values['bilagsnr']		= execMethod('property.socommon.increment_id','Bilagsnummer');
+				$values['bilagsnr_ut']	= $values['voucher_out_id'];			
+			}
+
+			if( $soXport->check_invoice_id($values['vendor_id'], $values['invoice_id']))
+			{
+				$receipt['error'][] = array('msg'=>lang('invoice id already taken for this vendor'));
+			}
+
+			if(isset($receipt['error']))
+			{
+				return $receipt;
+			}
+
+			$values['kostra_id'] 		= $soXport->get_kostra_id($values['loc1']);
+			$values['mvakode'] 			= (int)$values['tax_code'];
+			$values['project_id']		= $values['project_group'];			
+
+			$values['oppsynsmannid']		= $values['janitor'];
+			$values['saksbehandlerid']		= $values['supervisor'];
+			$values['budsjettansvarligid']	= $values['budget_responsible'];
+
+			if($values['order_id'] && $order_type = $soXport->check_order($values['order_id']))
+			{
+				if($order_type=='workorder')
+				{
+					$buffer[0]=$values;
+				}
+
+				if($order_type=='s_agreement')
+				{
+					$sos_agreement = CreateObject('property.sos_agreement');
+					$s_agreement = $sos_agreement->read_single($values['order_id']);
+			//		$values = $this->set_responsible($values,$s_agreement['user_id'],$s_agreement['b_account_id']);
+					$s_agreement_detail = $sos_agreement->read(array('allrows'=>true,'s_agreement_id'=>$values['order_id'],'detail'=>true));
+
+					$sum_agreement=0;
+					for ($i=0;$i<count($s_agreement_detail);$i++)
+					{
+						$s_agreement_detail[$i]['cost'] = abs($s_agreement_detail[$i]['cost']) > 0 ? $s_agreement_detail[$i]['cost'] : 1;
+						$sum_agreement = $sum_agreement + $s_agreement_detail[$i]['cost'];
+					}
+
+					for ($i=0;$i<count($s_agreement_detail);$i++)
+					{
+						$_location = explode('-', $s_agreement_detail[$i]['location_code']);
+						$buffer[$i]						= $values;
+						$buffer[$i]['location_code']	= $s_agreement_detail[$i]['location_code'];
+						$buffer[$i]['loc1']				= $_location[0];
+						$buffer[$i]['dima']				= str_replace('-','',$s_agreement_detail[$i]['location_code']);
+						$buffer[$i]['belop']			= round($values['belop'] / $sum_agreement * $s_agreement_detail[$i]['cost'],2);
+						$buffer[$i]['godkjentbelop']	= $buffer[$i]['belop'];
+					}
+				}
+
+				if($soXport->add_manual_invoice($buffer,$skip_update_voucher_id))
+				{
+					$receipt['message'][] = array('msg'=>lang('Invoice %1 is added',$soXport->voucher_id));
+					$receipt['voucher_id'] = $soXport->voucher_id;
+				}
+				else
+				{
+					$receipt['error'][] = array('msg'=>lang('Invoice is NOT added!'));
+				}
+			}
+			return $receipt;
+		}
+
 		function add($values,$debug='')
 		{
 			$this->soXport    = CreateObject('property.soXport');
@@ -369,15 +627,15 @@
 			$values['belop'] 			= $values['amount'];
 			$values['godkjentbelop']	= $values['amount'];
 
-			$values['fakturadato'] = date($this->bocommon->dateformat,mktime(2,0,0,$values['smonth'],$values['sday'],$values['syear']));
+			$values['fakturadato'] = date($GLOBALS['phpgw']->db->date_format(),mktime(2,0,0,$values['smonth'],$values['sday'],$values['syear']));
 
 			if($values['num_days'])
 			{
-				$values['forfallsdato'] = date($this->bocommon->dateformat,mktime(2,0,0,$values['smonth'],$values['sday'],$values['syear'])+(86400*$values['num_days']));
+				$values['forfallsdato'] = date($GLOBALS['phpgw']->db->date_format(),mktime(2,0,0,$values['smonth'],$values['sday'],$values['syear'])+(86400*$values['num_days']));
 			}
 			else
 			{
-				$values['forfallsdato'] = date($this->bocommon->dateformat,mktime(2,0,0,$values['emonth'],$values['eday'],$values['eyear']));
+				$values['forfallsdato'] = date($GLOBALS['phpgw']->db->date_format(),mktime(2,0,0,$values['emonth'],$values['eday'],$values['eyear']));
 			}
 
 			$values['artid'] 			= $values['art'];
@@ -452,7 +710,6 @@
 						$buffer[$i]['location_code']	=$s_agreement_detail[$i]['location_code'];
 						$buffer[$i]['dima']				=str_replace('-','',$s_agreement_detail[$i]['location_code']);
 
-
 						$buffer[$i]['belop']	=	round($values['belop'] / $sum_agreement * $s_agreement_detail[$i]['cost'],2);
 						$buffer[$i]['godkjentbelop'] =$buffer[$i]['belop'];
 
@@ -526,7 +783,7 @@
 			}
 		}
 
-		function set_responsible($values,$user_id='',$b_account_id='')
+		function set_responsible($values, $user_id=0, $b_account_id='')
 		{
 			$config				= CreateObject('phpgwapi.config','property');
 			$config->read();
@@ -537,26 +794,29 @@
 			if (!$values['budget_responsible'])
 			{
 				$criteria_budget_responsible		= array('ecodimb' => $values['dimb'], 'cat_id' => $responsible_responsible);
-				$budget_responsible_contact_id		= $responsible->get_responsible($criteria_budget_responsible);
-				$budget_responsible_user_id			= $responsible->get_contact_user_id($budget_responsible_contact_id);
-				$values['budget_responsible']		= $GLOBALS['phpgw']->accounts->get($budget_responsible_user_id)->lid;
-				$values['budsjettansvarligid']		= $values['budget_responsible'];
+				if($budget_responsible_contact_id = $responsible->get_responsible($criteria_budget_responsible))
+				{
+					$budget_responsible_user_id			= $responsible->get_contact_user_id($budget_responsible_contact_id);
+					$values['budget_responsible']		= $GLOBALS['phpgw']->accounts->get($budget_responsible_user_id)->lid;
+					$values['budsjettansvarligid']		= $values['budget_responsible'];
+				}
 			}
 
 			if (!$values['budget_responsible'])
 			{
-				$values['budget_responsible'] = $this->soXport->get_responsible($b_account_id);
+				$values['budget_responsible'] = execMethod('property.soXport.get_responsible',$b_account_id);
 				$values['budsjettansvarligid'] = $values['budget_responsible'];
 			}
 
-
 			if(!$values['supervisor'])
 			{
 				$criteria_supervisor				= array('ecodimb' => $values['dimb'], 'cat_id' => $responsible_supervisor);
-				$supervisor_contact_id				= $responsible->get_responsible($criteria_supervisor);
-				$supervisor_user_id					= $responsible->get_contact_user_id($supervisor_contact_id);
-				$values['supervisor']				= $GLOBALS['phpgw']->accounts->get($supervisor_user_id)->lid;
-				$values['saksbehandlerid']			= $values['supervisor'];
+				if($supervisor_contact_id = $responsible->get_responsible($criteria_supervisor))
+				{
+					$supervisor_user_id					= $responsible->get_contact_user_id($supervisor_contact_id);
+					$values['supervisor']				= $GLOBALS['phpgw']->accounts->get($supervisor_user_id)->lid;
+					$values['saksbehandlerid']			= $values['supervisor'];
+				}
 			}
 
 			$values['janitor']				= $GLOBALS['phpgw']->accounts->get($user_id)->lid;
@@ -579,9 +839,9 @@
 			return $values;
 		}
 
-		public function get_single_line($id)
+		public function get_single_line($id, $paid = false)
 		{
-			$line = $this->so->get_single_line($id);
+			$line = $this->so->get_single_line($id, $paid);
 
 			$soXport    = CreateObject('property.soXport');
 			$soworkorder = CreateObject('property.soworkorder');
@@ -617,9 +877,88 @@
 			return $line;
 		}
 
-		function check_role()
+		function check_role($dimb = 0)
 		{
-			return $this->so->check_role();
+			return $this->so->check_role($dimb);
 		}
 
+		public function get_dimb_role_user($role_id, $dimb = '', $selected = '')
+		{
+			return $this->so->get_dimb_role_user($role_id, $dimb, $selected);
+		}
+
+		public function get_historical_accounting_periods()
+		{
+			return $this->so->get_historical_accounting_periods();
+		}
+
+
+		public function export_historical_transactions_at_periods($data = array())
+		{
+			$values =  $this->so->get_historical_transactions_at_periods($data);
+			
+			if($values)
+			{
+				$names = $descr = array_keys($values[0]);
+				$this->bocommon->download($values,$names,$descr);
+			}
+		}
+
+		public function export_deposition()
+		{
+			$values =  $this->so->get_deposition();
+			
+			if($values)
+			{
+				$names = $descr = array_keys($values[0]);
+				$this->bocommon->download($values,$names,$descr);
+			}
+		}
+
+		public function forward($data)
+		{
+			return $this->so->forward($data);
+		}
+
+		public function get_vouchers($data)
+		{
+			return $this->so->get_vouchers($data);
+		}
+
+		public function update_voucher2($data)
+		{
+			return $this->so->update_voucher2($data);
+		}
+
+		function get_approve_role($dimb = 0)
+		{
+			$role_check = array
+			(
+				'is_janitor' 				=> lang('janitor'),
+				'is_supervisor' 			=> lang('supervisor'),
+				'is_budget_responsible' 	=> lang('b - responsible')
+			);
+
+			$roles 	= $this->check_role($dimb);
+
+			$approve = array();
+			foreach ($roles as $role => $role_value)
+			{
+				if ($role_value && isset($role_check[$role]))
+				{
+					$approve[] = array
+					(
+						'id'		=> $role,
+						'name'		=> $role_check[$role],
+						'selected'	=> 0
+					);
+				}
+			}
+			return $approve;
+		}
+
+		public function get_auto_generated_invoice_num($vendor_id)
+		{
+			return $this->so->get_auto_generated_invoice_num($vendor_id);
+		}
 	}
