@@ -24,7 +24,7 @@
 	* @internal Development of this application was funded by http://www.bergen.kommune.no/bbb_/ekstern/
 	* @package property
 	* @subpackage project
- 	* @version $Id: class.boproject.inc.php 7112 2011-03-11 12:46:45Z sigurdne $
+ 	* @version $Id: class.boproject.inc.php 11133 2013-05-28 08:07:12Z sigurdne $
 	*/
 
 	/**
@@ -38,9 +38,12 @@
 		var $start;
 		var $query;
 		var $filter;
+		var $filter_year;
 		var $sort;
 		var $order;
 		var $cat_id;
+		var $allrows;
+		var $project_type_id;
 
 		var $public_functions = array
 			(
@@ -66,19 +69,28 @@
 				$this->use_session = true;
 			}
 
+
+
+			$default_filter_year 	= isset($GLOBALS['phpgw_info']['user']['preferences']['property']['default_project_filter_year']) && $GLOBALS['phpgw_info']['user']['preferences']['property']['default_project_filter_year'] == 'current_year' ? date('Y') : 'all';
+
 			$start					= phpgw::get_var('start', 'int', 'REQUEST', 0);
 			$query					= phpgw::get_var('query');
 			$sort					= phpgw::get_var('sort');
 			$order					= phpgw::get_var('order');
 			$filter					= phpgw::get_var('filter', 'int');
+			$filter_year			= phpgw::get_var('filter_year', 'string', 'REQUEST', $default_filter_year);
 			$cat_id					= phpgw::get_var('cat_id', 'int');
 			$status_id				= phpgw::get_var('status_id');
 			$user_id				= phpgw::get_var('user_id', 'int');
 			$wo_hour_cat_id			= phpgw::get_var('wo_hour_cat_id', 'int');
 			$district_id			= phpgw::get_var('district_id', 'int');
 			$criteria_id			= phpgw::get_var('criteria_id', 'int');
+			$project_type_id		= phpgw::get_var('project_type_id', 'int');
+
+			$this->allrows			= phpgw::get_var('allrows', 'bool');
 
 			$this->start			= $start ? $start : 0;
+			$this->filter_year		= $filter_year;
 
 			if(isset($_POST['query']) || isset($_GET['query']))
 			{
@@ -120,6 +132,10 @@
 			{
 				$this->criteria_id = $criteria_id;
 			}
+			if(isset($_POST['project_type_id']) || isset($_GET['project_type_id']))
+			{
+				$this->project_type_id = $project_type_id;
+			}
 		}
 
 		function save_sessiondata($data)
@@ -145,6 +161,7 @@
 			$this->wo_hour_cat_id	= isset($data['wo_hour_cat_id'])?$data['wo_hour_cat_id']:'';
 			$this->district_id		= isset($data['district_id'])?$data['district_id']:'';
 			$this->criteria_id		= isset($data['criteria_id'])?$data['criteria_id']:'';
+			$this->project_type_id	= isset($data['project_type_id'])?$data['project_type_id']:'';
 		}
 
 		function column_list($selected = array())
@@ -153,13 +170,16 @@
 			{
 				$selected = isset($GLOBALS['phpgw_info']['user']['preferences']['property']['project_columns']) ? $GLOBALS['phpgw_info']['user']['preferences']['property']['project_columns'] : '';
 			}
-			$columns	= $this->get_column_list();
+			$filter = array('list' => ''); // translates to "list IS NULL"
+			$columns = $this->custom->find('property','.project', 0, '','','',true, false, $filter);
+			$columns = array_merge( $columns, $this->get_column_list() );
 			return $this->bocommon->select_multi_list($selected,$columns);
 		}
 
 		function get_column_list()
 		{
 			$columns = array();
+/*
 			$columns['planned_cost'] = array
 				(
 					'id'		=> 'planned_cost',
@@ -168,6 +188,7 @@
 					'formatter'	=> 'myFormatCount2',
 					'classname'	=> 'rightClasss'
 				);
+*/
 			$columns['ecodimb'] = array
 				(
 					'id'		=> 'ecodimb',
@@ -202,6 +223,30 @@
 			return $columns;
 		}
 
+		public function get_project_types($selected)
+		{
+			$values = array
+			(
+				array
+				(
+					'id'	=> 1,
+					'name'	=> lang('operation')
+				),
+				array
+				(
+					'id'	=> 2,
+					'name'	=> lang('investment')
+				),
+				array
+				(
+					'id'	=> 3,
+					'name'	=> lang('buffer')
+				),
+
+			);
+			return $this->bocommon->select_list($selected, $values);
+		}
+
 		function select_status_list($format='',$selected='')
 		{
 			switch($format)
@@ -384,7 +429,7 @@
 			else
 			{
 				return $criteria;
-			}			
+			}
 		}
 
 		function select_key_location_list($selected='')
@@ -397,13 +442,20 @@
 
 		function read($data = array())
 		{
+			if(isset($this->allrows) && $this->allrows)
+			{
+				$data['allrows'] = true;
+			}
+
 			$start_date	= $this->bocommon->date_to_timestamp($data['start_date']);
 			$end_date	= $this->bocommon->date_to_timestamp($data['end_date']);
 
 			$project = $this->so->read(array('start' => $this->start,'query' => $this->query,'sort' => $this->sort,'order' => $this->order,
 				'filter' => $this->filter,'cat_id' => $this->cat_id,'status_id' => $this->status_id,'wo_hour_cat_id' => $this->wo_hour_cat_id,
 				'start_date'=>$start_date,'end_date'=>$end_date,'allrows'=>isset($data['allrows']) ? $data['allrows'] : '','dry_run' => $data['dry_run'],
-				'district_id' => $this->district_id, 'criteria' => $this->get_criteria($this->criteria_id)));
+				'district_id' => $this->district_id, 'criteria' => $this->get_criteria($this->criteria_id),
+				'project_type_id'	=> $this->project_type_id, 'filter_year' => $this->filter_year));
+
 			$this->total_records = $this->so->total_records;
 
 			$dateformat = $GLOBALS['phpgw_info']['user']['preferences']['common']['dateformat'];
@@ -415,16 +467,19 @@
 
 			foreach ($custom_cols as $col_id)
 			{
-				$this->uicols['input_type'][]	= 'text';
-				$this->uicols['name'][]			= $col_id;
-				$this->uicols['descr'][]		= $column_list[$col_id]['name'];
-				$this->uicols['statustext'][]	= $column_list[$col_id]['name'];
-				$this->uicols['exchange'][]		= false;
-				$this->uicols['align'][] 		= '';
-				$this->uicols['datatype'][]		= false;
-				$this->uicols['sortable'][]		= $column_list[$col_id]['sortable'];
-				$this->uicols['formatter'][]	= $column_list[$col_id]['formatter'];
-				$this->uicols['classname'][]	= $column_list[$col_id]['classname'];
+				if(!ctype_digit($col_id))
+				{
+					$this->uicols['input_type'][]	= 'text';
+					$this->uicols['name'][]			= $col_id;
+					$this->uicols['descr'][]		= $column_list[$col_id]['name'];
+					$this->uicols['statustext'][]	= $column_list[$col_id]['name'];
+					$this->uicols['exchange'][]		= false;
+					$this->uicols['align'][] 		= '';
+					$this->uicols['datatype'][]		= false;
+					$this->uicols['sortable'][]		= $column_list[$col_id]['sortable'];
+					$this->uicols['formatter'][]	= $column_list[$col_id]['formatter'];
+					$this->uicols['classname'][]	= $column_list[$col_id]['classname'];
+				}
 			}
 
 			if(!isset($data['skip_origin']) || !$data['skip_origin'])
@@ -436,6 +491,9 @@
 				$this->uicols['exchange'][]		= false;
 				$this->uicols['align'][] 		= '';
 				$this->uicols['datatype'][]		= 'link';
+				$this->uicols['sortable'][]		= '';
+				$this->uicols['formatter'][]	= '';
+				$this->uicols['classname'][]	= '';
 			}
 
 			$cols_extra		= $this->so->cols_extra;
@@ -459,7 +517,7 @@
 								)
 							),
 							'text'			=> $origin[0]['data'][0]['id'],
-							'statustext'	=> $origin[0]['data'][0]['statustext'],											
+							'statustext'	=> $origin[0]['data'][0]['statustext'],
 						);
 					}
 				}
@@ -469,13 +527,6 @@
 
 		function read_single($project_id = 0, $values = array(), $view = false)
 		{
-			$contacts	= CreateObject('property.sogeneric');
-			$contacts->get_location_info('vendor',false);
-
-			$config				= CreateObject('phpgwapi.config','property');
-			$config->read();
-			$tax = 1+(isset($config->config_data['fm_tax'])?$config->config_data['fm_tax']:0)/100;
-
 			$values['attributes'] = $this->custom->find('property', '.project', 0, '', 'ASC', 'attrib_sort', true, true);
 			if($project_id)
 			{
@@ -490,54 +541,8 @@
 			}
 
 			$dateformat				= $GLOBALS['phpgw_info']['user']['preferences']['common']['dateformat'];
-			$values['start_date']			= $GLOBALS['phpgw']->common->show_date($values['start_date'],$dateformat);
-			$values['end_date']			= isset($values['end_date']) && $values['end_date'] ? $GLOBALS['phpgw']->common->show_date($values['end_date'],$dateformat) : '';
-			$workorder_data				= $this->so->project_workorder_data($project_id);
-
-			$sum_workorder_budget = 0;
-			$sum_deviation = 0;
-			$sum_workorder_calculation = 0;
-			$sum_workorder_actual_cost = 0;
-
-			for ($i=0;$i<count($workorder_data);$i++)
-			{
-				$sum_workorder_budget= $sum_workorder_budget+$workorder_data[$i]['budget'];
-				$sum_deviation= $sum_deviation+$workorder_data[$i]['deviation'];
-				$sum_workorder_calculation= $sum_workorder_calculation+$workorder_data[$i]['calculation'];
-				$sum_workorder_actual_cost= $sum_workorder_actual_cost+$workorder_data[$i]['act_mtrl_cost']+$workorder_data[$i]['act_vendor_cost'];
-
-				$values['workorder_budget'][$i]['title']=$workorder_data[$i]['title'];
-				$values['workorder_budget'][$i]['workorder_id']=$workorder_data[$i]['workorder_id'];
-				$values['workorder_budget'][$i]['contract_sum']=number_format($workorder_data[$i]['contract_sum'], 2, ',', '');
-				$values['workorder_budget'][$i]['budget']=number_format($workorder_data[$i]['budget'], 2, ',', '');
-				$values['workorder_budget'][$i]['calculation']=number_format($workorder_data[$i]['calculation']*$tax, 2, ',', '');
-				$values['workorder_budget'][$i]['charge_tenant'] = $workorder_data[$i]['charge_tenant'];
-				$values['workorder_budget'][$i]['status'] = $workorder_data[$i]['status'];
-				$values['workorder_budget'][$i]['actual_cost'] = $workorder_data[$i]['act_mtrl_cost']+$workorder_data[$i]['act_vendor_cost'];
-				$values['workorder_budget'][$i]['b_account_id'] = $workorder_data[$i]['b_account_id'];
-
-				if(isset($workorder_data[$i]['vendor_id']) && $workorder_data[$i]['vendor_id'])
-				{
-					$vendor['attributes'] = $this->custom->find('property','.vendor', 0, '', 'ASC', 'attrib_sort', true, true);
-
-					$vendor	= $contacts->read_single(array('id' => $workorder_data[$i]['vendor_id']), $vendor);
-					foreach($vendor['attributes'] as $attribute)
-					{
-						if($attribute['name']=='org_name')
-						{
-							$values['workorder_budget'][$i]['vendor_name']=$attribute['value'];
-							break;
-						}
-					}
-				}
-			}
-			if($workorder_data)
-			{
-				$values['sum_workorder_budget']= number_format($sum_workorder_budget, 2, ',', '');
-				$values['deviation']= $sum_deviation;
-				$values['sum_workorder_calculation']= number_format($sum_workorder_calculation*$tax, 2, ',', '');
-				$values['sum_workorder_actual_cost']= number_format($sum_workorder_actual_cost, 2, ',', '');
-			}
+			$values['start_date']	= $GLOBALS['phpgw']->common->show_date($values['start_date'],$dateformat);
+			$values['end_date']		= isset($values['end_date']) && $values['end_date'] ? $GLOBALS['phpgw']->common->show_date($values['end_date'],$dateformat) : '';
 
 			if($values['location_code'])
 			{
@@ -578,12 +583,56 @@
 			return $values;
 		}
 
+		public function get_orders($data)
+		{
+			$contacts	= CreateObject('property.sogeneric');
+			$contacts->get_location_info('vendor',false);
+
+			static $vendor_name = array();
+			$values	= $this->so->project_workorder_data($data);
+
+			$sum_deviation = 0;
+			foreach ($values as &$entry)
+			{
+				$sum_deviation+= $entry['deviation'];
+
+				$entry['cost'] = $entry['combined_cost'];
+		//		$entry['title']=htmlspecialchars_decode($entry['title']);
+
+				if(isset($entry['vendor_id']) && $entry['vendor_id'])
+				{
+					if(isset($vendor_name[$entry['vendor_id']]) && $vendor_name[$entry['vendor_id']])
+					{
+						$entry['vendor_name'] = $vendor_name[$entry['vendor_id']];
+					}
+					else
+					{
+						$vendor['attributes'] = $this->custom->find('property','.vendor', 0, '', 'ASC', 'attrib_sort', true, true);
+
+						$vendor	= $contacts->read_single(array('id' => $entry['vendor_id']), $vendor);
+						foreach($vendor['attributes'] as $attribute)
+						{
+							if($attribute['name']=='org_name')
+							{
+								$entry['vendor_name'] = $attribute['value'];
+								$vendor_name[$entry['vendor_id']] = $attribute['value'];
+								break;
+							}
+						}
+					}
+				}
+			}
+			return $values;
+		}
+
 		function read_single_mini($project_id)
 		{
-			$project						= $this->so->read_single($project_id);
-			$dateformat						= $GLOBALS['phpgw_info']['user']['preferences']['common']['dateformat'];
-			$project['start_date']			= $GLOBALS['phpgw']->common->show_date($project['start_date'],$dateformat);
-			$project['end_date']			= isset($project['end_date']) && $project['end_date'] ? $GLOBALS['phpgw']->common->show_date($project['end_date'],$dateformat) : '';
+			if($project	= $this->so->read_single($project_id))
+			{
+				$dateformat						= $GLOBALS['phpgw_info']['user']['preferences']['common']['dateformat'];
+				$project['start_date']			= $GLOBALS['phpgw']->common->show_date($project['start_date'],$dateformat);
+				$project['end_date']			= isset($project['end_date']) && $project['end_date'] ? $GLOBALS['phpgw']->common->show_date($project['end_date'],$dateformat) : '';
+			}
 
 			if($project['location_code'])
 			{
@@ -616,7 +665,7 @@
 			$historylog	= CreateObject('property.historylog','project');
 			$history_array = $historylog->return_array(array('O'),array(),'','',$id);
 			$i=0;
-			foreach ($history_array as $value) 
+			foreach ($history_array as $value)
 			{
 
 				$record_history[$i]['value_date']	= $GLOBALS['phpgw']->common->show_date($value['datetime']);
@@ -675,6 +724,9 @@
 				case 'ON':
 					$type = lang('Owner notified');
 					break;
+				case 'MS':
+					$type = lang('Sent by sms');
+					break;
 				default:
 					break;
 				}
@@ -753,6 +805,26 @@
 			return $record_history;
 		}
 
+		public function get_files($id = 0)
+		{
+			$vfs = CreateObject('phpgwapi.vfs');
+			$vfs->override_acl = 1;
+
+			$files = $vfs->ls(array(
+				'string' => "/property/project/{$id}",
+				'relatives' => array(RELATIVE_NONE)
+			));
+
+			$vfs->override_acl = 0;
+
+			$j	= count($files);
+			for ($i=0;$i<$j;$i++)
+			{
+				$files[$i]['file_name']=urlencode($files[$i]['name']);
+			}
+			return $files;
+		}
+
 
 		function next_project_id()
 		{
@@ -761,7 +833,6 @@
 
 		function save($project,$action='',$values_attribute = array())
 		{
-
 			//_debug_array($project);
 			while (is_array($project['location']) && list(,$value) = each($project['location']))
 			{
@@ -783,7 +854,18 @@
 
 			if ($action=='edit')
 			{
-				$receipt = $this->so->edit($project, $values_attribute);
+				try
+				{
+					$receipt = $this->so->edit($project, $values_attribute);
+				}
+				catch(Exception $e)
+				{
+					if ( $e )
+					{
+						phpgwapi_cache::message_set($e->getMessage(), 'error');
+						$receipt['id'] = $project['id'];
+					}
+				}
 			}
 			else
 			{
@@ -803,4 +885,50 @@
 			$this->so->delete($project_id);
 		}
 
+		function bulk_update_status($start_date, $end_date, $status_filter, $status_new, $execute, $type, $user_id,$ids,$paid,$closed_orders,$ecodimb,$transfer_budget,$new_budget)
+		{
+			return $this->so->bulk_update_status($start_date, $end_date, $status_filter, $status_new, $execute, $type, $user_id,$ids,$paid,$closed_orders,$ecodimb,$transfer_budget,$new_budget);
+		}
+
+		public function get_user_list($selected = 0)
+		{
+			$ser_list = $this->so->get_user_list();
+			foreach($ser_list as &$user)
+			{
+				$user['selected'] = $user['id'] == $selected ? true : false;
+			}
+			return $ser_list;
+		}
+
+		public function get_budget($project_id)
+		{
+			return $this->so->get_budget($project_id);
+		}
+
+		public function get_buffer_budget($project_id)
+		{
+			return $this->so->get_buffer_budget($project_id);
+		}
+
+		public function get_periodizations_with_outline()
+		{
+			return $this->so->get_periodizations_with_outline();
+		}
+		public function get_filter_year_list($selected)
+		{
+			$values = $this->so->get_filter_year_list();
+			return $this->bocommon->select_list($selected, $values);
+		}
+
+		public function get_order_time_span($id)
+		{
+			$values = $this->so->get_order_time_span($id);
+			return $this->bocommon->select_list(date('Y'), $values);
+		}
+
+		public function get_missing_project_budget()
+		{
+			return $this->so->get_missing_project_budget();
+		}
+		
 	}
