@@ -24,7 +24,7 @@
 	* @internal Development of this application was funded by http://www.bergen.kommune.no/bbb_/ekstern/
 	* @package property
 	* @subpackage project
- 	* @version $Id: class.borequest.inc.php 7484 2011-08-08 12:44:31Z sigurdne $
+ 	* @version $Id: class.borequest.inc.php 11298 2013-09-17 11:49:14Z sigurdne $
 	*/
 
 	phpgw::import_class('phpgwapi.datetime');
@@ -41,6 +41,12 @@
 		var $sort;
 		var $order;
 		var $cat_id;
+		public $sum_investment = 0;
+		public $sum_operation = 0;
+		public $sum_potential_grants = 0;
+		public $sum_consume = 0;
+		public $acl_location = '.project.request';
+		public $responsible_unit;
 
 		var $public_functions = array
 			(
@@ -57,26 +63,36 @@
 			$this->bocommon 			= CreateObject('property.bocommon');
 			$this->solocation 			= CreateObject('property.solocation');
 			$this->historylog			= CreateObject('property.historylog','request');
-			$this->cats					= CreateObject('phpgwapi.categories', -1,  'property', '.project');
+			$this->cats					= CreateObject('phpgwapi.categories', -1,  'property', '.project.request');
 			$this->cats->supress_info	= true;
 			$this->custom 				= & $this->so->custom;
-
+//			$this->acl_location			= '.project.request';
 			if ($session)
 			{
 				$this->read_sessiondata();
 				$this->use_session = true;
 			}
 
-			$start			= phpgw::get_var('start', 'int', 'REQUEST', 0);
-			$query			= phpgw::get_var('query');
-			$sort			= phpgw::get_var('sort');
-			$order			= phpgw::get_var('order');
-			$filter			= phpgw::get_var('filter', 'int');
-			$district_id	= phpgw::get_var('district_id', 'int');
-			$cat_id			= phpgw::get_var('cat_id', 'int');
-			$status_id		= phpgw::get_var('status_id');
-			$allrows		= phpgw::get_var('allrows', 'bool');
-			$this->p_num	= phpgw::get_var('p_num');
+			$start				= phpgw::get_var('start', 'int', 'REQUEST', 0);
+			$query				= phpgw::get_var('query');
+			$sort				= phpgw::get_var('sort');
+			$order				= phpgw::get_var('order');
+			$filter				= phpgw::get_var('filter', 'int');
+			$property_cat_id	= phpgw::get_var('property_cat_id', 'int');
+			$district_id		= phpgw::get_var('district_id', 'int');
+			$cat_id				= phpgw::get_var('cat_id', 'int');
+			$status_id			= phpgw::get_var('status_id');
+			$degree_id			= phpgw::get_var('degree_id', 'int');
+			$allrows			= phpgw::get_var('allrows', 'bool');
+			$this->p_num		= phpgw::get_var('p_num');
+
+			$start_date			= phpgw::get_var('start_date');
+			$end_date			= phpgw::get_var('end_date');
+			$building_part		= phpgw::get_var('building_part');
+			$responsible_unit	= phpgw::get_var('responsible_unit', 'int');
+			$recommended_year	= phpgw::get_var('recommended_year', 'int');
+
+			$this->condition_survey_id = phpgw::get_var('condition_survey_id', 'int', 'REQUEST', 0);
 
 			if(isset($_POST['start']) || isset($_GET['start']))
 			{
@@ -102,6 +118,11 @@
 			{
 				$this->district_id = $district_id;
 			}
+
+			if(isset($_POST['property_cat_id']) || isset($_GET['property_cat_id']))
+			{
+				$this->property_cat_id = $property_cat_id;
+			}
 			if(isset($_POST['cat_id']) || isset($_GET['cat_id']))
 			{
 				$this->cat_id = $cat_id;
@@ -110,36 +131,73 @@
 			{
 				$this->status_id = $status_id;
 			}
+			if(isset($_POST['degree_id']) || isset($_GET['degree_id']))
+			{
+				$this->degree_id = $degree_id;
+			}
 			if(isset($_POST['criteria_id']) || isset($_GET['criteria_id']))
 			{
 				$this->criteria_id = $criteria_id;
 			}
+			if(isset($_POST['building_part']) || isset($_GET['building_part']))
+			{
+				$this->building_part = $building_part;
+			}
+
+			if(isset($_POST['responsible_unit']) || isset($_GET['responsible_unit']))
+			{
+				$this->responsible_unit = $responsible_unit;
+			}
+
+			if(isset($_POST['recommended_year']) || isset($_GET['recommended_year']))
+			{
+				$this->recommended_year = $recommended_year;
+			}
+
+
 			if($allrows)
 			{
 				$this->allrows = $allrows;
 			}
+
+			if(array_key_exists('start_date',$_POST) || array_key_exists('start_date',$_GET))
+			{
+				$this->start_date = $start_date;
+			}
+			if(array_key_exists('end_date',$_POST) || array_key_exists('end_date',$_GET))
+			{
+				$this->end_date = $end_date;
+			}
+
 		}
 
 		function save_sessiondata($data)
 		{
 			if ($this->use_session)
 			{
-				$GLOBALS['phpgw']->session->appsession('session_data','request',$data);
+				phpgwapi_cache::session_set('property.request','session_data', $data);
 			}
 		}
 
 		function read_sessiondata()
 		{
-			$data = $GLOBALS['phpgw']->session->appsession('session_data','request');
+			$data =	phpgwapi_cache::session_get('property.request','session_data', $data);
 
-			$this->start		= $data['start'];
-			$this->query		= $data['query'];
-			$this->filter		= $data['filter'];
-			$this->sort			= $data['sort'];
-			$this->order		= $data['order'];
-			$this->district_id	= $data['district_id'];
-			$this->cat_id		= $data['cat_id'];
-			$this->status_id	= $data['status_id'];
+			$this->start			= $data['start'];
+			$this->query			= $data['query'];
+			$this->filter			= $data['filter'];
+			$this->sort				= $data['sort'];
+			$this->order			= $data['order'];
+			$this->district_id		= $data['district_id'];
+			$this->cat_id			= $data['cat_id'];
+			$this->property_cat_id 	= $data['property_cat_id'];
+			$this->status_id		= $data['status_id'];
+			$this->degree_id		= $data['degree_id'];
+			$this->building_part	= $data['building_part'];
+			$this->responsible_unit	= $data['responsible_unit'];
+			$this->recommended_year	= $data['recommended_year'];
+			$this->start_date		= isset($data['start_date']) ? $data['start_date']: '';
+			$this->end_date			= isset($data['end_date']) ? $data['end_date']: '';
 		}
 
 
@@ -202,7 +260,8 @@
 			$degree_comment[1]=' - '.lang('minor symptoms');
 			$degree_comment[2]=' - '.lang('medium symptoms');
 			$degree_comment[3]=' - '.lang('serious symptoms');
-			for ($i=0; $i<=3; $i++)
+			$degree_comment[4]=' - '.lang('condition not assessed');
+			for ($i=0; $i<=4; $i++)
 			{
 				$degree_list[$i]['id'] = $i;
 				$degree_list[$i]['name'] = $i . $degree_comment[$i];
@@ -304,7 +363,7 @@
 					'degree' 				=> array('options' => $this->select_degree_list($conditions[$i]['degree'])),
 					'probability' 			=> array('options' => $this->select_probability_list($conditions[$i]['probability'])),
 					'consequence' 			=> array('options' => $this->select_consequence_list($conditions[$i]['consequence'])),
-					'condition_type'		=> $condition_type_list[$i]['id'],
+					'condition_type'		=> (int)$condition_type_list[$i]['id'],
 					'condition_type_name'	=> $condition_type_list[$i]['name'],
 					'condition_type_descr'	=> $condition_type_list[$i]['descr'],
 					'failure'				=> (int)$conditions[$i]['reference'] - (int)$conditions[$i]['degree'] < 0 ? 'X' : '',
@@ -312,6 +371,8 @@
 					'risk'					=> $risk,
 					'score'					=> $risk * (int)$condition_type_list[$i]['weight'] * (int)$conditions[$i]['degree']
 				);
+
+				array_unshift($values[0]['condition_type_list']['options'], array ('id'=>'','name'=> lang('consequence type')));
 			}
 //_debug_array($values);die();
 			return $values;
@@ -371,16 +432,80 @@
 			return	$this->so->update_priority_key($values);
 		}
 
+		public function read_survey_data($data)
+		{
+
+			$interlink 	= CreateObject('property.interlink');
+
+
+			$values = $this->so->read_survey_data($data);
+
+			foreach($values as &$entry)
+			{
+				$target = $interlink->get_relation('property', $this->acl_location, $entry['id'], 'target');
+				$related = array();
+				if($target)
+				{
+					foreach($target as $_target_section)
+					{
+						foreach ($_target_section['data'] as $_target_entry)
+						{
+							$related[] = "<a href=\"{$_target_entry['link']}\" title=\"{$_target_entry['title']}\">{$_target_section['descr']}::{$_target_entry['id']}::{$_target_entry['statustext']}</a>";
+						}
+					}
+					$entry['related'] = implode(' /</br>',$related);
+				}
+
+				$category 			= $this->cats->return_single($entry['cat_id']);
+				$entry['category']	= $category[0]['name'];
+			}
+
+			$this->total_records	= $this->so->total_records;
+			return $values;
+		}
+
 		function read($data)
 		{
+			$custom	= createObject('phpgwapi.custom_fields');
+			$attrib_data = $custom->find('property', $this->acl_location, 0, '','','',true, true);
+
+			$attrib_filter = array();
+			if($attrib_data)
+			{
+				foreach ( $attrib_data as $attrib )
+				{
+					if($attrib['datatype'] == 'LB' || $attrib['datatype'] == 'R')
+					{
+						if($_attrib_filter_value = phpgw::get_var($attrib['column_name'], 'int'))
+						{
+							$attrib_filter[] = "fm_request.{$attrib['column_name']} = '{$_attrib_filter_value}'";
+						}
+					}
+					else if($attrib['datatype'] == 'CH')
+					{
+						if($_attrib_filter_value = phpgw::get_var($attrib['column_name'], 'int'))
+						{
+							$attrib_filter[] = "fm_request.{$attrib['column_name']} {$GLOBALS['phpgw']->db->like} '%,{$_attrib_filter_value},%'";
+						}
+					}
+				}
+			}
+
 			$request = $this->so->read(array('start' => $this->start,'query' => $this->query,'sort' => $this->sort,'order' => $this->order,
 				'filter' => $this->filter,'district_id' => $this->district_id,'cat_id' => $this->cat_id,'status_id' => $this->status_id,
 				'project_id' => $data['project_id'],'allrows'=>$data['allrows'],'list_descr' => $data['list_descr'],
-				'dry_run'=>$data['dry_run'], 'p_num' => $this->p_num));
-			$this->total_records = $this->so->total_records;
+				'dry_run'=>$data['dry_run'], 'p_num' => $this->p_num,'start_date'=>$this->start_date,'end_date'=>$this->end_date,
+				'property_cat_id' => $this->property_cat_id, 'building_part' => $this->building_part,
+				'degree_id' => $this->degree_id, 'attrib_filter' => $attrib_filter, 'condition_survey_id' => $this->condition_survey_id,
+				'responsible_unit' => $this->responsible_unit, 'recommended_year' => $this->recommended_year));
 
-			$this->uicols	= $this->so->uicols;
-			$cols_extra		= $this->so->cols_extra;
+			$this->total_records			= $this->so->total_records;
+			$this->sum_investment			= $this->so->sum_investment;
+			$this->sum_operation			= $this->so->sum_operation;
+			$this->sum_potential_grants		= $this->so->sum_potential_grants;
+			$this->sum_consume				= $this->so->sum_consume;
+			$this->uicols					= $this->so->uicols;
+			$cols_extra						= $this->so->cols_extra;
 
 			$dateformat = $GLOBALS['phpgw_info']['user']['preferences']['common']['dateformat'];
 
@@ -389,6 +514,7 @@
 				$request[$i]['coordinator'] = $GLOBALS['phpgw']->accounts->id2name($request[$i]['coordinator']);
 				$request[$i]['start_date'] = $GLOBALS['phpgw']->common->show_date($request[$i]['start_date'],$dateformat);
 				$request[$i]['entry_date'] = $GLOBALS['phpgw']->common->show_date($request[$i]['entry_date'],$dateformat);
+				$request[$i]['planned_year'] = $request[$i]['planned_year'] ? date('Y',$request[$i]['planned_year']) : '';
 				$request[$i]['closed_date'] = $GLOBALS['phpgw']->common->show_date($request[$i]['closed_date'],$dateformat);
 				$request[$i]['in_progress_date'] = $GLOBALS['phpgw']->common->show_date($request[$i]['in_progress_date'],$dateformat);
 				$request[$i]['delivered_date'] = $GLOBALS['phpgw']->common->show_date($request[$i]['delivered_date'],$dateformat);
@@ -418,6 +544,7 @@
 				$this->uicols['formatter'][] 	= '';
 				$this->uicols['classname'][] 	= '';
 			}
+
 			return $request;
 		}
 
@@ -534,25 +661,25 @@
 
 				switch ($value['status'])
 				{
-				case 'R': $type = lang('Re-opened'); break;
-				case 'X': $type = lang('Closed');    break;
-				case 'O': $type = lang('Opened');    break;
-				case 'A': $type = lang('Re-assigned'); break;
-				case 'P': $type = lang('Priority changed'); break;
-				case 'CO': $type = lang('Initial Coordinator'); break;
-				case 'C': $type = lang('Coordinator changed'); break;
-				case 'TO': $type = lang('Initial Category'); break;
-				case 'T': $type = lang('Category changed'); break;
-				case 'SO': $type = lang('Initial Status'); break;
-				case 'S': $type = lang('Status changed'); break;
-				default: break;
+					case 'B': $type = lang('Budget changed'); break;
+					case 'R': $type = lang('Re-opened'); break;
+					case 'X': $type = lang('Closed');    break;
+					case 'O': $type = lang('Opened');    break;
+					case 'A': $type = lang('Re-assigned'); break;
+					case 'P': $type = lang('Priority changed'); break;
+					case 'CO': $type = lang('Initial Coordinator'); break;
+					case 'C': $type = lang('Coordinator changed'); break;
+					case 'TO': $type = lang('Initial Category'); break;
+					case 'T': $type = lang('Category changed'); break;
+					case 'SO': $type = lang('Initial Status'); break;
+					case 'S': $type = lang('Status changed'); break;
+					default: break;
 				}
 
 				if($value['new_value']=='O'){$value['new_value']=lang('Opened');}
-					if($value['new_value']=='X'){$value['new_value']=lang('Closed');}
+				if($value['new_value']=='X'){$value['new_value']=lang('Closed');}
 
-
-						$record_history[$i]['value_action']	= $type?$type:'';
+				$record_history[$i]['value_action']	= $type?$type:'';
 				unset($type);
 
 				if ($value['status'] == 'A')
@@ -566,7 +693,12 @@
 						$record_history[$i]['value_new_value']	= $GLOBALS['phpgw']->accounts->id2name($value['new_value']);
 					}
 				}
-				else if ($value['status'] == 'C' || $value['status'] == 'CO')
+				else if ($value['status'] == 'C')
+				{
+					$record_history[$i]['value_new_value']	= $GLOBALS['phpgw']->accounts->id2name($value['new_value']);
+					$record_history[$i]['value_old_value']	= $GLOBALS['phpgw']->accounts->id2name($value['old_value']);
+				}
+				else if ($value['status'] == 'CO')
 				{
 					$record_history[$i]['value_new_value']	= $GLOBALS['phpgw']->accounts->id2name($value['new_value']);
 				}
@@ -575,9 +707,15 @@
 					$category 								= $this->cats->return_single($value['new_value']);
 					$record_history[$i]['value_new_value']	= $category[0]['name'];
 				}
+				else if ($value['status'] == 'B' && $value['new_value'])
+				{
+					$record_history[$i]['value_new_value']	=number_format($value['new_value'], 0, ',', ' ');
+					$record_history[$i]['value_old_value']	=number_format($value['old_value'], 0, ',', ' ');
+				}
 				else if ($value['status'] != 'O' && $value['new_value'])
 				{
 					$record_history[$i]['value_new_value']	= $value['new_value'];
+					$record_history[$i]['value_old_value']	= $value['old_value'];
 				}
 				else
 				{
@@ -632,4 +770,14 @@
 		{
 			$this->so->delete($request_id);
 		}
+
+		public function get_user_list()
+		{
+			return $this->so->get_user_list();
+		}
+		public function get_recommended_year_list($selected = 0)
+		{
+			$recommended_year_list = $this->so->get_recommended_year_list();
+			return $this->bocommon->select_list($selected,$recommended_year_list);
+		}
 	}
