@@ -9,7 +9,7 @@
 	* @package phpgroupware
 	* @subpackage property
 	* @category core
- 	* @version $Id: class.boresponsible.inc.php 6718 2011-01-03 09:29:44Z sigurdne $
+ 	* @version $Id: class.boresponsible.inc.php 8963 2012-03-06 07:38:37Z sigurdne $
 	*/
 
 	/*
@@ -44,7 +44,7 @@
 		public $total_records = 0;
 		public $cat_id;
 		public $allrows;
-		public $acl_location = '.admin';
+		protected $acl_location = '.admin';
 
 		/**
 		 * Constructor
@@ -54,7 +54,10 @@
 
 		public function __construct($session = false)
 		{
+			$this->appname = phpgw::get_var('appname', 'string', 'REQUEST', 'property');
+
 			$this->so				= CreateObject('property.soresponsible');
+			$this->so->appname = $this->appname;
 			$this->so->acl_location = $this->acl_location;
 
 			if ($session)
@@ -94,15 +97,21 @@
 
 			switch ($this->location)
 			{
-			case '.project.workorder':
-				$location = '.project';
-				break;
-			default:
-				$location = $this->location;
+				case '.project.workorder':
+					$location = '.project';
+					break;
+				default:
+					$location = $this->location;
 			}
 
-			$this->cats					= CreateObject('phpgwapi.categories', -1,'property', $location);
-			$this->dateformat 			= $GLOBALS['phpgw_info']['user']['preferences']['common']['dateformat'];
+			$this->cats			= CreateObject('phpgwapi.categories', -1, $this->appname, $location);
+			$this->dateformat 	= $GLOBALS['phpgw_info']['user']['preferences']['common']['dateformat'];
+		}
+
+
+		public function get_acl_location()
+		{
+			return $this->acl_location;
 		}
 
 		/**
@@ -170,13 +179,13 @@
 			}
 
 			$values = $this->so->read_type(array('start' => $this->start, 'query' => $this->query, 'sort' => $this->sort,
-				'order' => $this->order, 'location' => $this->location, 'allrows'=>$this->allrows,
+				'order' => $this->order, 'appname' => $this->appname,'location' => $this->location, 'allrows'=>$this->allrows,
 				'filter' => $filter));
 			$this->total_records = $this->so->total_records;
 
-			if($value['cat_id'])
+			foreach($values as & $value)
 			{
-				foreach($values as & $value)
+				if($value['cat_id'])
 				{
 					$category = $this->cats->return_single($value['cat_id']);
 					$value['category']		= $category[0]['name'];
@@ -200,16 +209,16 @@
 			$selected	= isset($data['selected']) && $data['selected'] ? $data['selected'] : '';
 			$values = $this->so->read_type(array('start' => $this->start, 'query' => $this->query, 'sort' => $this->sort,
 				'order' => $this->order, 'location' => '', 'allrows'=>true,
-				'filter' => $filter));
+				'filter' => $filter, 'appname' => $data['appname']));
 			$responsibilities = array();
 			foreach($values as  $value)
 			{
 				$responsibilities[] = array
-					(
-						'id'		=> $value['id'],
-						'name'		=> $value['name'],
-						'selected'	=> $value['id'] == $selected ? 1 : 0
-					);
+				(
+					'id'		=> $value['id'],
+					'name'		=> $value['name'],
+					'selected'	=> $value['id'] == $selected ? 1 : 0
+				);
 			}
 
 			return $responsibilities;
@@ -279,6 +288,27 @@
 			return $receipt;
 		}
 
+		/**
+		 * Save responsibility role
+		 *
+		 * @param array $values values to be stored/edited and referencing ID if editing
+		 *
+		 * @return array $receip with result on the action(failed/success)
+		 */
+
+		public function save_role($values)
+		{
+			if (isset($values['id']) && $values['id'])
+			{
+				$receipt = $this->so->edit_role($values);
+			}
+			else
+			{
+				$receipt = $this->so->add_role($values);
+			}
+			return $receipt;
+		}
+
 		/**
 		 * Save responsibility contact
 		 *
@@ -420,6 +450,35 @@
 			return $values;
 		}
 
+		/**
+		 * Read single responsibility type
+		 *
+		 * @param integer $id ID of responsibility type
+		 *
+		 * @return array holding data of responsibility type
+		 */
+
+		public function read_single_role($id)
+		{
+			$values = $this->so->read_single_role($id);
+			return $values;
+		}
+
+		/**
+		 * Read single responsibility
+		 *
+		 * @param integer $id ID of responsibility type
+		 *
+		 * @return array holding data of responsibility type
+		 */
+
+		public function read_single($id)
+		{
+			$values = $this->so->read_single($id);
+			$values['entry_date'] = $GLOBALS['phpgw']->common->show_date($values['created_on'], $this->dateformat);
+			return $values;
+		}
+
 		/**
 		 * Read single contact for responsibility type at physical location
 		 *
