@@ -24,7 +24,7 @@
 	* @internal Development of this application was funded by http://www.bergen.kommune.no/bbb_/ekstern/
 	* @package property
 	* @subpackage agreement
- 	* @version $Id: class.bos_agreement.inc.php 7498 2011-08-12 08:52:29Z sigurdne $
+ 	* @version $Id: class.bos_agreement.inc.php 11361 2013-10-09 14:00:23Z sigurdne $
 	*/
 
 	/**
@@ -43,6 +43,7 @@
 		var $role;
 		var $member_id;
 		var $uicols = array();
+		var $location_code;
 
 		/**
 		 * @var object $custom reference to custom fields object
@@ -82,7 +83,8 @@
 			$allrows			= phpgw::get_var('allrows', 'bool');
 			$role				= phpgw::get_var('role');
 			$member_id			= phpgw::get_var('member_id', 'int');
-			$status_id	= phpgw::get_var('status_id', 'int');
+			$status_id			= phpgw::get_var('status_id', 'int');
+			$this->location_code= phpgw::get_var('location_code');
 
 			$this->p_num		= phpgw::get_var('p_num');
 
@@ -176,7 +178,7 @@
 		{
 			$s_agreements = $this->so->read(array('start' => $this->start,'query' => $this->query,'sort' => $this->sort,'order' => $this->order,
 				'filter' => $this->filter,'cat_id' => $this->cat_id,'allrows'=>$this->allrows,'member_id'=>$this->member_id,
-				'vendor_id'=>$this->vendor_id, 'p_num' => $this->p_num, 'status_id'=>$this->status_id));
+				'vendor_id'=>$this->vendor_id, 'p_num' => $this->p_num, 'status_id'=>$this->status_id, 'location_code' => $this->location_code));
 			$this->total_records = $this->so->total_records;
 
 			$this->uicols	= $this->so->uicols;
@@ -384,8 +386,7 @@
 
 		function import($import_data,$id)
 		{
-			$this->so->role = 'detail';
-			$custom_attributes = $this->so->read_attrib(array('allrows'=>true));
+			$custom_attributes = $this->custom->find('property', '.s_agreement.detail', 0, '', 'ASC', 'attrib_sort', true, true);
 
 			foreach($custom_attributes as $attrib)
 			{
@@ -407,6 +408,7 @@
 			unset($values['extra']['location_code']);
 			unset($values['extra']['address']);
 			unset($values['extra']['cost']);
+
 			return $this->so->add_item($values);
 		}
 
@@ -525,4 +527,3 @@
 		}
 
 	}
-
