@@ -24,7 +24,7 @@
 	* @internal Development of this application was funded by http://www.bergen.kommune.no/bbb_/ekstern/
 	* @package property
 	* @subpackage helpdesk
- 	* @version $Id: class.botts.inc.php 7227 2011-04-15 11:51:34Z sigurdne $
+ 	* @version $Id: class.botts.inc.php 11582 2014-01-02 08:48:52Z sigurdne $
 	*/
 
 	/**
@@ -52,6 +52,9 @@
 		public $total_records	= 0;
 		public $sum_budget		= 0;
 		public $sum_actual_cost	= 0;
+		public $sum_difference	= 0;
+		public $show_finnish_date = false;
+		public $simple = false;
 
 		var $public_functions = array
 		(
@@ -61,9 +64,16 @@
 			'addfiles'		=> true,
 		);
 
-		function property_botts($session=false)
+		function __construct($session=false)
 		{
+			if($GLOBALS['phpgw_info']['flags']['currentapp'] != 'property')
+			{
+				$GLOBALS['phpgw']->translation->add_app('property');
+			}
+
+			$this->account				= $GLOBALS['phpgw_info']['user']['account_id'];
 			$this->so 					= CreateObject('property.sotts');
+			$this->custom 				= & $this->so->custom;
 			$this->bocommon 			= CreateObject('property.bocommon');
 			$this->historylog			= & $this->so->historylog;
 			$this->config				= CreateObject('phpgwapi.config','property');
@@ -74,6 +84,29 @@
 
 			$this->config->read();
 
+
+			$user_groups =  $GLOBALS['phpgw']->accounts->membership($this->account);
+			$simple_group = isset($this->config->config_data['fmttssimple_group']) ? $this->config->config_data['fmttssimple_group'] : array();
+			foreach ( $user_groups as $group => $dummy)
+			{
+				if ( in_array($group, $simple_group))
+				{
+					$this->simple = true;
+					break;
+				}
+			}
+
+			reset($user_groups);
+			$group_finnish_date = isset($this->config->config_data['fmtts_group_finnish_date']) ? $this->config->config_data['fmtts_group_finnish_date'] : array();
+			foreach ( $user_groups as $group => $dummy)
+			{
+				if ( in_array($group, $group_finnish_date))
+				{
+					$this->show_finnish_date = true;
+					break;
+				}
+			}
+
 			if ($session)
 			{
 				$this->read_sessiondata();
@@ -100,10 +133,8 @@
 			$branch_id				= phpgw::get_var('branch_id', 'int');
 			$order_dim1				= phpgw::get_var('order_dim1', 'int');
 
+			$this->start			= $start 							? $start 			: 0;
 
-//			$this->start			= $start 							? $start 			: 0;
-
-			$this->start			= isset($_REQUEST['start']) 		? $start			: $this->start;
 			$this->query			= isset($_REQUEST['query']) 		? $query			: $this->query;
 			$this->sort				= isset($_REQUEST['sort']) 			? $sort				: $this->sort;
 			$this->order			= isset($_REQUEST['order']) 		? $order			: $this->order;
@@ -153,32 +184,187 @@
 			$this->vendor_id		= isset($data['vendor_id'])?$data['vendor_id']:'';
 		}
 
-		function column_list($selected = array(),$type_id='',$allrows='')
+
+		function column_list($selected = array())
 		{
 			if(!$selected)
 			{
 				$selected = isset($GLOBALS['phpgw_info']['user']['preferences']['property']['ticket_columns']) ? $GLOBALS['phpgw_info']['user']['preferences']['property']['ticket_columns'] : '';
 			}
-			$filter = array('list' => ''); // translates to "list IS NULL"
+			$_columns = $this->get_columns();
+
+			$columns = array();
+			foreach($_columns as $id => $column_info)
+			{
+				$columns[] = $column_info;
+			}
+
+			$column_list=$this->bocommon->select_multi_list($selected,$columns);
+			return $column_list;
+		}
+
+		public function get_columns()
+		{
 			$columns = array();
 
-			$columns[] = array
+
+			$columns['location_code'] = array
+				(
+					'id' => 'location_code',
+					'name'=> lang('location code')
+				);
+
+			$columns['modified_date'] = array
+				(
+					'id'		=> 'modified_date',
+					'name'		=> lang('modified date'),
+//					'sortable'	=> true
+				);
+
+			$columns['status'] = array
+				(
+					'id' => 'status',
+					'name'=> lang('status')
+				);
+			$columns['address'] = array
+				(
+					'id' => 'address',
+					'name'=> lang('address')
+				);
+			$columns['user'] = array
+				(
+					'id' => 'user',
+					'name'=> lang('user')
+				);
+			$columns['assignedto'] = array
+				(
+					'id' => 'assignedto',
+					'name'=> lang('assignedto')
+				);
+
+			if( $GLOBALS['phpgw']->acl->check('.ticket.order', PHPGW_ACL_ADD, 'property') )
+			{
+				$columns['order_id'] = array
+					(
+						'id' => 'order_id',
+						'name'=> lang('order id')
+					);
+				$columns['estimate'] = array
+					(
+						'id' => 'estimate',
+						'name'=> lang('estimate')
+					);
+				$columns['actual_cost'] = array
+					(
+						'id' => 'actual_cost',
+						'name'=> lang('actual cost')
+					);
+
+				$columns['difference'] = array
+					(
+						'id' => 'difference',
+						'name'=> lang('difference')
+					);
+			}
+
+			$columns['vendor'] = array
 				(
 					'id' => 'vendor',
 					'name'=> lang('vendor')
 				);
-			$columns[] = array
+			$columns['billable_hours'] = array
 				(
 					'id' => 'billable_hours',
 					'name'=> lang('billable hours')
 				);
-			$columns[] = array
+			$columns['district'] = array
 				(
 					'id' => 'district',
 					'name'=> lang('district')
 				);
-			$column_list=$this->bocommon->select_multi_list($selected,$columns);
-			return $column_list;
+
+			$this->get_origin_entity_type();
+
+			foreach($this->uicols_related as $related)
+			{
+				$columns[$related] = array
+				(
+						'id' => $related,
+						'name'=> ltrim(lang(str_replace('_', ' ', $related)),'!')
+				);
+			}
+
+			if( $this->show_finnish_date )
+			{
+				$columns['finnish_date'] = array
+					(
+						'id' => 'finnish_date',
+						'name'=> lang('finnish_date')
+					);
+				$columns['delay'] = array
+					(
+						'id' => 'delay',
+						'name'=> lang('delay')
+					);
+			}
+
+
+			$custom_cols = $this->custom->find('property', '.ticket', 0, '', 'ASC', 'attrib_sort', true, true);
+			foreach ($custom_cols as $custom_col)
+			{
+				$columns[$custom_col['column_name']] = array
+				(
+					'id' => $custom_col['column_name'],
+					'name'=> $custom_col['input_text'],
+					'datatype' => $custom_col['datatype'],
+				);
+			}
+
+			return $columns;
+		}
+
+		function get_group_list($selected = 0)
+		{
+			$query='';
+			$group_list	= $this->bocommon->get_group_list('select', $selected, $start=-1, $sort='ASC', $order='account_firstname', $query, $offset=-1);
+			$_candidates = array();
+			if(isset($this->config->config_data['fmtts_assign_group_candidates']) && is_array($this->config->config_data['fmtts_assign_group_candidates']))
+			{
+				foreach($this->config->config_data['fmtts_assign_group_candidates'] as $group_candidate)
+				{
+					if( $group_candidate )
+					{
+						$_candidates[] = $group_candidate;
+					}
+				}
+			}
+
+			if( $_candidates )
+			{
+				if($selected)
+				{
+					if( !in_array( $selected, $_candidates) )
+					{
+						$_candidates[] = $selected;
+					}
+				}
+
+				$values = array();
+				foreach ($group_list as $group)
+				{
+					if( in_array( $group['id'], $_candidates) )
+					{
+						$values[] = $group;
+					}
+				}
+
+				return $values;
+			}
+			else
+			{
+				return $group_list;
+
+			}
 		}
 
 		function filter($data=0)
@@ -272,29 +458,13 @@
 			return $status_text;
 		}
 
-
-		function get_priority_list($selected='')
+		function get_priority_list($selected = 0)
 		{
-
-			$prioritylevels = isset($this->config->config_data['prioritylevels']) && $this->config->config_data['prioritylevels'] ? $this->config->config_data['prioritylevels'] : 3;
-
 			if(!$selected)
 			{
 				$selected = isset($GLOBALS['phpgw_info']['user']['preferences']['property']['prioritydefault']) ? $GLOBALS['phpgw_info']['user']['preferences']['property']['prioritydefault'] : $prioritylevels;
 			}
-
-			$priority_comment[$prioritylevels]=' - '.lang('Lowest');
-			//			$priority_comment[2]=' - '.lang('Medium');
-			$priority_comment[1]=' - '.lang('Highest');
-
-			$priorities = array();
-			for ($i=1; $i<= $prioritylevels; $i++)
-			{
-				$priorities[$i]['id'] =$i;
-				$priorities[$i]['name'] =$i . (isset($priority_comment[$i])?$priority_comment[$i]:'');
-			}
-
-			return $this->bocommon->select_list($selected,$priorities);
+			return execMethod('property.bogeneric.get_list', array('type' => 'ticket_priority', 'selected' => $selected) );
 		}
 
 		function get_category_name($cat_id)
@@ -329,9 +499,10 @@
 				'ecodimb' => $this->ecodimb, 'b_account' => $this->b_account, 'building_part' => $this->building_part,
 				'branch_id' => $this->branch_id ,'order_dim1' => $this->order_dim1));
 
-			$this->total_records = $this->so->total_records;
-			$this->sum_budget = $this->so->sum_budget;
-			$this->sum_actual_cost = $this->so->sum_actual_cost;
+			$this->total_records		= $this->so->total_records;
+			$this->sum_budget			= $this->so->sum_budget;
+			$this->sum_actual_cost		= $this->so->sum_actual_cost;
+			$this->sum_difference		= $this->so->sum_difference;
 
 			if(!$external)
 			{
@@ -348,6 +519,17 @@
 				$this->uicols_related	= array('project');
 			}
 
+
+			$custom_status	= $this->so->get_custom_status();
+			$closed_status = array('X');
+			foreach($custom_status as $custom)
+			{
+				if($custom['closed'])
+				{
+					$closed_status[] =  "C{$custom['id']}";
+				}
+			}
+
 			foreach ($tickets as & $ticket)
 			{
 				if(!isset($category_name[$ticket['cat_id']]))
@@ -372,6 +554,19 @@
 					$ticket['user'] = $account[$ticket['user_id']];
 				}
 
+
+				$ticket['difference'] = 0;
+
+
+				if($ticket['estimate'] && !in_array( $ticket['status'], $closed_status) )
+				{
+					$ticket['difference'] =  $ticket['estimate'] - (float)$ticket['actual_cost'];
+					if($ticket['difference'] < 0)
+					{
+						$ticket['difference'] = 0;
+					}
+				}
+
 				if($ticket['assignedto'])
 				{
 					if(!isset($account[$ticket['assignedto']]))
@@ -398,7 +593,7 @@
 				}
 
 				$ticket['entry_date'] = $GLOBALS['phpgw']->common->show_date($ticket['entry_date'],$this->dateformat);
-
+				$ticket['modified_date'] = $GLOBALS['phpgw']->common->show_date($ticket['modified_date'],$this->dateformat);
 				if($ticket['finnish_date2'])
 				{
 					$ticket['delay'] = round(($ticket['finnish_date2']-$ticket['finnish_date'])/(24*3600));
@@ -406,11 +601,13 @@
 				}
 				$ticket['finnish_date'] = (isset($ticket['finnish_date']) && $ticket['finnish_date'] ? $GLOBALS['phpgw']->common->show_date($ticket['finnish_date'],$this->dateformat):'');
 
+/*
 				if ($ticket['status'] == 'X')
 				{
 					$history_values = $this->historylog->return_array(array(),array('X'),'history_timestamp','DESC',$ticket['id']);
 					$ticket['timestampclosed'] = $GLOBALS['phpgw']->common->show_date($history_values[0]['datetime'],$this->dateformat);
 				}
+*/
 				if ($ticket['new_ticket'])
 				{
 					$ticket['new_ticket'] = '*';
@@ -454,11 +651,13 @@
 			return $tickets;
 		}
 
-		function read_single($id)
+		function read_single($id, $values = array(), $view = false)
 		{
 			$this->so->update_view($id);
 
-			$ticket = $this->so->read_single($id);
+			$values['attributes'] = $this->custom->find('property', '.ticket', 0, '', 'ASC', 'attrib_sort', true, true);
+			$ticket = $this->so->read_single($id, $values);
+			$ticket = $this->custom->prepare($ticket, 'property', '.ticket', $view);
 
 			$ticket['user_lid'] = $GLOBALS['phpgw']->accounts->id2name($ticket['user_id']);
 			$ticket['group_lid'] = $GLOBALS['phpgw']->accounts->id2name($ticket['group_id']);
@@ -511,12 +710,12 @@
 				unset($ticket['location_data']['first_name']);
 			}
 
+			// Figure out when it was opened
 
-			$history_values = $this->historylog->return_array(array(),array('O'),'history_timestamp','DESC',$id);
-			$ticket['timestamp'] = $history_values[0]['datetime'];
-			$ticket['entry_date'] = $GLOBALS['phpgw']->common->show_date($history_values[0]['datetime'],$this->dateformat);
-			// Figure out when it was opened and last closed
+			$ticket['timestamp'] = $ticket['entry_date'];
+			$ticket['entry_date'] = $GLOBALS['phpgw']->common->show_date($ticket['entry_date'],$this->dateformat);
 
+			// Figure out when it was last closed
 			$history_values = $this->historylog->return_array(array(),array('O'),'history_timestamp','ASC',$id);
 			$ticket['last_opened'] = $GLOBALS['phpgw']->common->show_date($history_values[0]['datetime']);
 
@@ -644,13 +843,21 @@
 					if ((int)$value['new_value']>0)
 					{
 						$record_history[$i]['value_new_value']	= $GLOBALS['phpgw']->accounts->id2name($value['new_value']);
-						$record_history[$i]['value_old_value'] = $value['old_value'] ? $GLOBALS['phpgw']->accounts->id2name($value['old_value']) : '';
 					}
 					else
 					{
 						$record_history[$i]['value_new_value']	= lang('None');
+					}
+
+					if ((int)$value['old_value']>0)
+					{
+						$record_history[$i]['value_old_value'] = $value['old_value'] ? $GLOBALS['phpgw']->accounts->id2name($value['old_value']) : '';
+					}
+					else
+					{
 						$record_history[$i]['value_old_value']	= lang('None');
 					}
+
 				}
 				else if ($value['status'] == 'T')
 				{
@@ -677,7 +884,108 @@
 			return $record_history;
 		}
 
-		function add($ticket)
+		/**
+		 * Simplified method for adding tickets from external apps
+		 *	$data = array
+		 *	(
+		 *		'origin' 			=> $location_id,
+		 *		'origin_id'			=> $location_item_id,
+		 *		'location_code' 	=> $location_code,
+		 * 		'cat_id'			=> $cat_id,
+		 *		'priority'			=> $priority, //optional (1-3)
+		 *		'title'				=> $title,
+		 *		'details'			=> $details,
+		 *		'file_input_name'	=> 'file' // default, optional
+		 *	);
+		 * 
+		 */
+		function add_ticket($data)
+		{
+
+			$boloc	= CreateObject('property.bolocation');
+			$location_details = $boloc->read_single($data['location_code'], array('noattrib' => true));
+
+			$location = array();
+			$_location_arr = explode('-', $data['location_code']);
+			$i = 1;
+			foreach($_location_arr as $_loc)
+			{
+				$location["loc{$i}"] = $_loc;
+				$i++;
+			}
+
+			$assignedto = execMethod('property.boresponsible.get_responsible', array('location' => $location, 'cat_id' => $data['cat_id']));
+
+			if(!$assignedto)
+			{
+				$default_group = (int)$this->config->config_data['tts_default_group'];
+			}
+			else
+			{
+				$default_group = 0;
+			}
+
+			$priority_list = $this->get_priority_list();
+
+			$default_priority = isset($GLOBALS['phpgw_info']['user']['preferences']['property']['prioritydefault']) ? $GLOBALS['phpgw_info']['user']['preferences']['property']['prioritydefault'] : count($priority_list);
+
+			$ticket = array
+			(
+				'origin_id'			=> isset($data['origin_id']) ? $data['origin_id'] : null,
+				'origin_item_id'	=> isset($data['origin_item_id']) ? $data['origin_item_id'] : null,
+				'cat_id'   			=> $data['cat_id'],
+				'group_id'  		=> isset($data['group_id']) && $data['group_id'] ? $data['group_id']: $default_group,
+				'assignedto'		=> $assignedto,
+				'priority'			=> isset($data['priority']) && $data['priority'] ? $data['priority'] : $default_priority,
+				'status'			=> 'O', // O = Open
+				'subject'			=> $data['title'],
+				'details'			=> $data['details'],
+				'apply'				=> true,
+				'contact_id'		=> 0,
+				'location'			=> $location,
+				'location_code'		=> $data['location_code'],
+				'street_name'		=> $location_details['street_name'],
+				'street_number'		=> $location_details['street_number'],
+				'location_name'		=> $location_details['loc1_name'],
+			);
+
+			$result = $this->add($ticket);
+
+			// Files
+			$file_input_name = isset($data['file_input_name']) && $data['file_input_name'] ? $data['file_input_name'] : 'file';
+			
+			$file_name = @str_replace(' ','_',$_FILES[$file_input_name]['name']);
+			if($file_name && $result['id'])
+			{
+				$bofiles = CreateObject('property.bofiles');
+				$to_file = "{$bofiles->fakebase}/fmticket/{$result['id']}/{$file_name}";
+
+				if($bofiles->vfs->file_exists(array(
+					'string' => $to_file,
+					'relatives' => array(RELATIVE_NONE)
+				)))
+				{
+					$msglog['error'][] = array('msg'=>lang('This file already exists !'));
+				}
+				else
+				{
+					$bofiles->create_document_dir("fmticket/{$result['id']}");
+					$bofiles->vfs->override_acl = 1;
+
+					if(!$bofiles->vfs->cp(array (
+					'from'	=> $_FILES[$file_input_name]['tmp_name'],
+					'to'	=> $to_file,
+					'relatives'	=> array (RELATIVE_NONE|VFS_REAL, RELATIVE_ALL))))
+					{
+						$msglog['error'][] = array('msg' => lang('Failed to upload file!'));
+					}
+					$bofiles->vfs->override_acl = 0;
+				}
+			}
+			return (int)$result['id'];	
+		}
+
+		function add($ticket, $values_attribute = array())
 		{
 			if((!isset($ticket['location_code']) || ! $ticket['location_code']) && isset($ticket['location']) && is_array($ticket['location']))
 			{
@@ -693,16 +1001,21 @@
 
 			$ticket['finnish_date']	= $this->bocommon->date_to_timestamp($ticket['finnish_date']);
 
-			$receipt = $this->so->add($ticket);
+			if($values_attribute && is_array($values_attribute))
+			{
+				$values_attribute = $this->custom->convert_attribute_save($values_attribute);
+			}
+
+			$receipt = $this->so->add($ticket, $values_attribute);
 
 			$this->config->read();
 
 			if ( (isset($ticket['send_mail']) && $ticket['send_mail']) 
 				|| (isset($this->config->config_data['mailnotification'])
-				&& $this->config->config_data['mailnotification'])
+					&& $this->config->config_data['mailnotification'])
 			)
 			{
-				$receipt_mail = $this->mail_ticket($receipt['id'],false,$receipt,$ticket['location_code']);
+				$receipt_mail = $this->mail_ticket($receipt['id'],false,$receipt,$ticket['location_code'], false, isset($ticket['send_mail']) && $ticket['send_mail'] ? true : false);
 			}
 
 			$criteria = array
@@ -776,8 +1089,9 @@
 			return $address_element;
 		}
 
-		function mail_ticket($id, $fields_updated, $receipt = array(),$location_code='', $get_message = false)
+		function mail_ticket($id, $fields_updated, $receipt = array(),$location_code='', $get_message = false, $force_send = false)
 		{
+			$log_recipients = array();
 			$this->send			= CreateObject('phpgwapi.send');
 
 			$ticket	= $this->so->read_single($id);
@@ -814,7 +1128,7 @@
 			//-----------from--------
 			// build body
 			$body  = '';
-			$body .= '<a href ="http://' . $GLOBALS['phpgw_info']['server']['hostname'] . $GLOBALS['phpgw']->link('/index.php', array('menuaction' => 'property.uitts.view', 'id' => $id)).'">' . lang('Ticket').' #' .$id .'</a>'."\n";
+			$body .= '<a href ="' . $GLOBALS['phpgw']->link('/index.php', array('menuaction' => 'property.uitts.view', 'id' => $id),false,true).'">' . lang('Ticket').' #' .$id .'</a>'."\n";
 			$body .= lang('Date Opened').': '.$entry_date."\n";
 			$body .= lang('Category').': '. $this->get_category_name($ticket['cat_id']) ."\n";
 //			$body .= lang('Subject').': '. $ticket['subject'] ."\n";
@@ -845,18 +1159,15 @@
 			{
 				$body .= lang('Group').': '. $group_name ."\n";
 			}
-			$body .= lang('Opened By').': '. $ticket['user_name'] ."\n\n";
-			$body .= lang('First Note Added').":\n";
-			$body .= stripslashes(strip_tags($ticket['details']))."\n\n";
 
 			/**************************************************************\
 			 * Display additional notes                                     *
 			 \**************************************************************/
-			if($fields_updated)
+//			if($fields_updated)
 			{
 				$i=1;
 
-				$history_array = $this->historylog->return_array(array(),array('C'),'','',$id);
+				$history_array = $this->historylog->return_array(array(),array('C'),'history_id','DESC',$id);
 
 				foreach($history_array as $value)
 				{
@@ -865,7 +1176,7 @@
 					$body .=lang('Note').': '. nl2br(stripslashes($value['new_value']))."\n\n";
 					$i++;
 				}
-				$subject.= "-" .$i;
+				$subject .= "::{$i}";
 			}
 			/**************************************************************\
 			 * Display record history                                       *
@@ -877,6 +1188,10 @@
 			}
 
 
+			$body .= lang('Opened By').': '. $ticket['user_name'] ."\n\n";
+			$body .= lang('First Note Added').":\n";
+			$body .= stripslashes(strip_tags($ticket['details']))."\n\n";
+
 			if($get_message)
 			{
 				return array('subject' => $subject, 'body' => $body);
@@ -884,8 +1199,10 @@
 
 			$members = array();
 
-			if( isset($this->config->config_data['groupnotification']) && $this->config->config_data['groupnotification'] && $ticket['group_id'] )
+			if( (isset($this->config->config_data['groupnotification']) && $this->config->config_data['groupnotification'] && $ticket['group_id'] )
+					|| ($force_send && $ticket['group_id']))
 			{
+				$log_recipients[] = $group_name;
 				$members_gross = $GLOBALS['phpgw']->accounts->member($ticket['group_id'], true);
 				foreach($members_gross as $user)
 				{
@@ -902,17 +1219,23 @@
 			{
 				// add owner to recipients
 				$members[$ticket['user_id']] = $GLOBALS['phpgw']->accounts->id2name($ticket['user_id']);
+				$log_recipients[] = $GLOBALS['phpgw']->accounts->get($ticket['user_id'])->__toString();
 			}
 
-			$GLOBALS['phpgw']->preferences->set_account_id($ticket['assignedto'], true);
-			if( (isset($GLOBALS['phpgw']->preferences->data['property']['tts_notify_me'])
-					&& ($GLOBALS['phpgw']->preferences->data['property']['tts_notify_me'] == 1)
-				)
-				|| ($this->config->config_data['assignednotification'] && $ticket['assignedto'])
-			)
+			if($ticket['assignedto'])
 			{
-				// add assigned to recipients
-				$members[$ticket['assignedto']] = $GLOBALS['phpgw']->accounts->id2name($ticket['assignedto']);
+				$GLOBALS['phpgw']->preferences->set_account_id($ticket['assignedto'], true);
+				if( (isset($GLOBALS['phpgw']->preferences->data['property']['tts_notify_me'])
+						&& ($GLOBALS['phpgw']->preferences->data['property']['tts_notify_me'] == 1)
+					)
+					|| ($this->config->config_data['assignednotification'] && $ticket['assignedto'])
+					|| ($force_send && $ticket['assignedto'])
+				)
+				{
+					// add assigned to recipients
+					$members[$ticket['assignedto']] = $GLOBALS['phpgw']->accounts->id2name($ticket['assignedto']);
+					$log_recipients[] = $GLOBALS['phpgw']->accounts->get($ticket['assignedto'])->__toString();
+				}
 			}
 
 			$error = array();
@@ -945,6 +1268,49 @@
 				}
 			}
 
+
+			$notify_list = execMethod('property.notify.read', array
+				(
+					'location_id'		=> $GLOBALS['phpgw']->locations->get_id('property', $this->acl_location),
+					'location_item_id'	=> $id
+				)
+			);
+
+			if(isset($GLOBALS['phpgw_info']['user']['apps']['sms']))
+			{
+
+				$sms_text = "{$subject}. \r\n{$GLOBALS['phpgw_info']['user']['fullname']} \r\n{$GLOBALS['phpgw_info']['user']['preferences']['property']['email']}";
+				$sms	= CreateObject('sms.sms');
+
+				foreach($notify_list as $entry)
+				{
+					if($entry['is_active'] && $entry['notification_method'] == 'sms' && $entry['sms'])
+					{
+						$sms->websend2pv($this->account,$entry['sms'],$sms_text);
+						$toarray_sms[] = "{$entry['first_name']} {$entry['last_name']}({$entry['sms']})";
+						$receipt['message'][]=array('msg'=>lang('%1 is notified',"{$entry['first_name']} {$entry['last_name']}"));
+					}
+				}
+				unset($entry);
+				if($toarray_sms)
+				{
+					$this->historylog->add('MS',$id,"{$subject}::" . implode(',',$toarray_sms));						
+				}
+			}
+
+			reset($notify_list);
+			foreach($notify_list as $entry)
+			{
+				if($entry['is_active'] && $entry['notification_method'] == 'email' && $entry['email'])
+				{
+					$toarray[] = "{$entry['first_name']} {$entry['last_name']}<{$entry['email']}>";
+				}
+
+				$log_recipients[] = "{$entry['first_name']} {$entry['last_name']}";
+			}
+			unset($entry);
+
+			$rc = false;
 			if($toarray)
 			{
 				$to = implode(';',$toarray);
@@ -967,6 +1333,10 @@
 				}
 			}
 
+			if($rc && $log_recipients)
+			{
+				$this->historylog->add('M',$id,implode(';',array_unique($log_recipients)));				
+			}
 /*
 			if (!$rc && ($this->config->config_data['groupnotification'] || $this->config->config_data['ownernotification'] || $this->config->config_data['groupnotification']))
 			{
@@ -1006,15 +1376,56 @@
 
 		public function update_status($data, $id = 0)
 		{
-			$receipt 	= $this->so->update_status($data, $id);
+			$receipt = array();
+			if ($this->so->update_status($data, $id))
+			{
+				$receipt['message'][]= array('msg' => lang('Ticket %1 has been updated',$id));
+			}
 			$this->fields_updated = $this->so->fields_updated;
 			return $receipt;
 		}
 
-		public function update_ticket($data, $id,$receipt = array())
+		public function update_priority($data, $id = 0)
 		{
-			$receipt = $this->so->update_ticket($data, $id, $receipt);
-			$this->fields_updated = $this->so->fields_updated;		
+			$receipt 	= $this->so->update_priority($data, $id);
+			$this->fields_updated = $this->so->fields_updated;
+			return $receipt;
+		}
+
+		public function update_ticket($data, $id,$receipt = array(),$values_attribute = array())
+		{
+			if($values_attribute && is_array($values_attribute))
+			{
+				$values_attribute = $this->custom->convert_attribute_save($values_attribute);
+			}
+
+			$receipt = $this->so->update_ticket($data, $id, $receipt, $values_attribute);
+			$this->fields_updated = $this->so->fields_updated;
+
+			$criteria = array
+			(
+				'appname'	=> 'property',
+				'location'	=> $this->acl_location,
+				'allrows'	=> true
+			);
+
+			$custom_functions = $GLOBALS['phpgw']->custom_functions->find($criteria);
+
+			foreach ( $custom_functions as $entry )
+			{
+				// prevent path traversal
+				if ( preg_match('/\.\./', $entry['file_name']) )
+				{
+					continue;
+				}
+
+				$file = PHPGW_SERVER_ROOT . "/property/inc/custom/{$GLOBALS['phpgw_info']['user']['domain']}/{$entry['file_name']}";
+				if ( $entry['active'] && is_file($file) )
+				{
+					require $file;
+				}
+			}
+
 			return $receipt;
 		}
 
@@ -1185,4 +1596,11 @@
 				$fileuploader->upload("fmticket/{$id}");
 			}
 		}
+
+		public function get_attributes($values)
+		{
+			$values['attributes'] = $this->custom->find('property', '.ticket', 0, '', 'ASC', 'attrib_sort', true, true);
+			$values = $this->custom->prepare($values, 'property', '.ticket', false);
+			return $values;
+		}
 	}
