@@ -24,7 +24,7 @@
 	* @internal Development of this application was funded by http://www.bergen.kommune.no/bbb_/ekstern/
 	* @package property
 	* @subpackage project
- 	* @version $Id: class.boworkorder.inc.php 7077 2011-03-07 14:30:57Z sigurdne $
+ 	* @version $Id: class.boworkorder.inc.php 11573 2013-12-27 08:49:03Z sigurdne $
 	*/
 
 	/**
@@ -39,8 +39,10 @@
 		var $filter;
 		var $sort;
 		var $order;
+		var $filter_year;
 		var $cat_id;
 		var $order_sent_adress; // in case we want to resend the order as an reminder
+		var $allrows;
 
 		var $public_functions = array
 			(
@@ -48,7 +50,8 @@
 				'read_single'	=> true,
 				'save'			=> true,
 				'delete'		=> true,
-				'check_perms'	=> true
+				'check_perms'	=> true,
+				'get_category'	=> true
 			);
 
 		function property_boworkorder($session=false)
@@ -58,48 +61,51 @@
 			$this->cats			= CreateObject('phpgwapi.categories', -1,  'property', '.project');
 			$this->cats->supress_info	= true;
 			$this->interlink 	= & $this->so->interlink;
-			if ($session)
+			
+			$obligation	= phpgw::get_var('obligation', 'bool');
+			
+			if ($session && !$obligation)
 			{
 				$this->read_sessiondata();
 				$this->use_session = true;
 			}
 
+			$default_filter_year 	= isset($GLOBALS['phpgw_info']['user']['preferences']['property']['default_project_filter_year']) && $GLOBALS['phpgw_info']['user']['preferences']['property']['default_project_filter_year'] == 'current_year' ? date('Y') : 'all';
+
 			$start				= phpgw::get_var('start', 'int', 'REQUEST', 0);
 			$query				= phpgw::get_var('query');
 			$sort				= phpgw::get_var('sort');
 			$order				= phpgw::get_var('order');
 			$filter				= phpgw::get_var('filter', 'int');
+			$filter_year		= phpgw::get_var('filter_year', 'string', 'REQUEST', $default_filter_year);
 			$cat_id				= phpgw::get_var('cat_id', 'int');
 			$status_id			= phpgw::get_var('status_id');
 			$wo_hour_cat_id		= phpgw::get_var('wo_hour_cat_id', 'int');
 			$start_date			= phpgw::get_var('start_date');
 			$end_date			= phpgw::get_var('end_date');
 			$b_group			= phpgw::get_var('b_group');
+			$ecodimb			= phpgw::get_var('ecodimb');
 			$paid				= phpgw::get_var('paid', 'bool');
 			$b_account			= phpgw::get_var('b_account');
 			$district_id		= phpgw::get_var('district_id', 'int');
 			$criteria_id		= phpgw::get_var('criteria_id', 'int');
+			$this->allrows		= phpgw::get_var('allrows', 'bool');
+			$this->obligation	= $obligation;
 
 			$this->start		= $start ? $start : 0;
-			$this->criteria_id	= isset($criteria_id) && $criteria_id ? $criteria_id : '';
+			$this->filter_year	= $filter_year;
 
-			if(array_key_exists('b_account',$_POST) || array_key_exists('b_account',$_GET) )
-			{
-				$this->b_account = $b_account;
-			}
 			if(array_key_exists('district_id',$_POST) || array_key_exists('district_id',$_GET) )
 			{
 				$this->district_id = $district_id;
 			}
 
-			if(isset($paid))
-			{
-				$this->paid = $paid;
-			}
-			if(isset($b_group))
-			{
-				$this->b_group = $b_group;
-			}
+			$this->paid = $paid;
+
+			$this->b_group = $b_group;
+			$this->ecodimb = $ecodimb;
+			$this->b_account = $b_account;
+
 			if(array_key_exists('query',$_POST) || array_key_exists('query',$_GET) )
 			{
 				$this->query = $query;
@@ -120,6 +126,10 @@
 			{
 				$this->cat_id = $cat_id;
 			}
+			if(array_key_exists('criteria_id',$_POST) || array_key_exists('criteria_id',$_GET))
+			{
+				$this->criteria_id = $criteria_id;
+			}
 			if(array_key_exists('status_id',$_POST)  || array_key_exists('status_id',$_GET))
 			{
 				$this->status_id = $status_id;
@@ -150,11 +160,11 @@
 			$this->cat_id			= isset($data['cat_id']) ? $data['cat_id']: '';
 			$this->status_id		= isset($data['status_id']) ? $data['status_id']: '';
 			$this->wo_hour_cat_id	= isset($data['wo_hour_cat_id']) ? $data['wo_hour_cat_id']: '';
-			$this->start_date		= isset($data['start_date']) ? $data['start_date']: '';
-			$this->end_date			= isset($data['end_date']) ? $data['end_date']: '';
-			$this->b_group			= isset($data['b_group']) ? $data['b_group']: '';
-			$this->paid				= isset($data['paid']) ? $data['paid']: '';
-			$this->b_account		= isset($data['b_account']) ? $data['b_account']: '';
+	//		$this->start_date		= isset($data['start_date']) ? $data['start_date']: '';
+	//		$this->end_date			= isset($data['end_date']) ? $data['end_date']: '';
+	//		$this->b_group			= isset($data['b_group']) ? $data['b_group']: '';
+	//		$this->paid				= isset($data['paid']) ? $data['paid']: '';
+	//		$this->b_account		= isset($data['b_account']) ? $data['b_account']: '';
 			$this->district_id		= isset($data['district_id']) ? $data['district_id']: '';
 			$this->criteria_id		= isset($data['criteria_id'])?$data['criteria_id']:'';
 		}
@@ -167,6 +177,13 @@
 			}
 		}
 
+		public function get_category()
+		{
+			$cat_id	= phpgw::get_var('cat_id', 'int');
+			$category	= $this->cats->return_single($cat_id);
+			return $category[0];
+		}
+
 		function column_list($selected = array())
 		{
 			if(!$selected)
@@ -181,6 +198,12 @@
 		function get_column_list()
 		{
 			$columns = array();
+			$columns['continuous'] = array
+				(
+					'id'		=> 'continuous',
+					'name'		=> lang('continuous'),
+					'sortable'	=> true
+				);
 			$columns['ecodimb'] = array
 				(
 					'id'		=> 'ecodimb',
@@ -219,6 +242,13 @@
 					'sortable'	=> true
 				);
 
+			$columns['approved'] = array
+				(
+					'id'		=> 'approved',
+					'name'		=> lang('approved'),
+					'sortable'	=> true
+				);
+
 			return $columns;
 		}
 
@@ -417,7 +447,7 @@
 				);
 			$criteria[10] = array
 				(
-					'field'	=> 'fm_project.account_group',
+					'field'	=> 'fm_b_account.category',
 					'type'	=> 'int',
 					'matchtype' => 'exact',
 					'front' => '',
@@ -440,13 +470,18 @@
 			$start_date	= $this->bocommon->date_to_timestamp($data['start_date']);
 			$end_date	= $this->bocommon->date_to_timestamp($data['end_date']);
 
+			if(isset($this->allrows) && $this->allrows)
+			{
+				$data['allrows'] = true;
+			}
 
 			$workorder = $this->so->read(array('start' => $this->start,'query' => $this->query,'sort' => $this->sort,'order' => $this->order,
 				'filter' => $this->filter,'cat_id' => $this->cat_id,'status_id' => $this->status_id,
 				'wo_hour_cat_id' => $this->wo_hour_cat_id,
 				'start_date'=>$start_date,'end_date'=>$end_date,'allrows'=>$data['allrows'],
-				'b_group'=>$this->b_group,'paid'=>$this->paid,'b_account' => $this->b_account,
-				'district_id' => $this->district_id,'dry_run'=>$data['dry_run'], 'criteria' => $this->get_criteria($this->criteria_id)));
+				'b_group'=>$this->b_group,'ecodimb'=>$this->ecodimb, 'paid'=>$this->paid,'b_account' => $this->b_account,
+				'district_id' => $this->district_id,'dry_run'=>$data['dry_run'], 'criteria' => $this->get_criteria($this->criteria_id),
+				'obligation' => $this->obligation, 'filter_year' => $this->filter_year) );
 
 			$this->total_records = $this->so->total_records;
 
@@ -481,6 +516,11 @@
 
 		function read_single($workorder_id)
 		{
+			if(!$workorder_id)
+			{
+				return array();
+			}
+
 			$contacts	= CreateObject('property.sogeneric');
 			$contacts->get_location_info('vendor',false);
 			$workorder						= $this->so->read_single($workorder_id);
@@ -512,7 +552,6 @@
 			$config->read();
 			$tax = 1+($config->config_data['fm_tax'])/100;
 			$workorder['calculation']	= $workorder['calculation'] * $tax;
-			$workorder['actual_cost']	= $workorder['act_mtrl_cost'] + $workorder['act_vendor_cost'];
 
 			$vfs = CreateObject('phpgwapi.vfs');
 			$vfs->override_acl = 1;
@@ -584,6 +623,13 @@
 			$historylog	= CreateObject('property.historylog','workorder');
 			$history_array = $historylog->return_array(array('O'),array(),'','',$id);
 
+			$_status_list = $this->so->select_status_list();
+			$status_text = array();
+			foreach ($_status_list as $_status_entry)
+			{
+				$status_text[$_status_entry['id']] = $_status_entry['name'];
+			}
+
 			$i=0;
 			foreach ($history_array as $value) 
 			{
@@ -593,40 +639,42 @@
 
 				switch ($value['status'])
 				{
-				case 'R': $type = lang('Re-opened'); break;
-				case 'RM': $type = lang('remark'); break;
-				case 'X': $type = lang('Closed');    break;
-				case 'O': $type = lang('Opened');    break;
-				case 'A': $type = lang('Re-assigned'); break;
-				case 'P': $type = lang('Priority changed'); break;
-				case 'M':
-					$type = lang('Sent by email to');
-					$_order_sent_adress = explode(' ',$value['new_value']);
-					$this->order_sent_adress = $_order_sent_adress[0]; // in case we want to resend the order as an reminder
-					unset($_order_sent_adress);
-					break;
-				case 'MS':
-					$type = lang('Sent by sms');
-					break;
-				case 'B': $type = lang('Budget changed'); break;
-				case 'CO': $type = lang('Initial Coordinator'); break;
-				case 'C': $type = lang('Coordinator changed'); break;
-				case 'TO': $type = lang('Initial Category'); break;
-				case 'T': $type = lang('Category changed'); break;
-				case 'SO': $type = lang('Initial Status'); break;
-				case 'S': $type = lang('Status changed'); break;
-				case 'SC': $type = lang('Status confirmed'); break;
-				case 'AP': $type = lang('Ask for approval'); break;
-				case 'ON': $type = lang('Owner notified'); break;
-				case 'H': $type = lang('Billable hours changed'); break;
-				default: break;
+					case 'R': $type = lang('Re-opened'); break;
+					case 'RM': $type = lang('remark'); break;
+					case 'X': $type = lang('Closed');    break;
+					case 'O': $type = lang('Opened');    break;
+					case 'A': $type = lang('Re-assigned'); break;
+					case 'P': $type = lang('Priority changed'); break;
+					case 'M':
+						$type = lang('Sent by email to');
+						$_order_sent_adress = explode('::',$value['new_value']);
+						$this->order_sent_adress = $_order_sent_adress[0]; // in case we want to resend the order as an reminder
+						unset($_order_sent_adress);
+						break;
+					case 'MS':
+						$type = lang('Sent by sms');
+						break;
+					case 'B': $type = lang('Budget changed'); break;
+					case 'CO': $type = lang('Initial Coordinator'); break;
+					case 'C': $type = lang('Coordinator changed'); break;
+					case 'TO': $type = lang('Initial Category'); break;
+					case 'T': $type = lang('Category changed'); break;
+					case 'SO': $type = lang('Initial Status'); break;
+					case 'S': $type = lang('Status changed'); break;
+					case 'SC': $type = lang('Status confirmed'); break;
+					case 'AP': $type = lang('Ask for approval'); break;
+					case 'ON': $type = lang('Owner notified'); break;
+					case 'H': $type = lang('Billable hours changed'); break;
+					case 'NP': $type = lang('moved to another project'); break;
+					case 'OA': $type = lang('order approved'); break;
+					case 'OB': $type = lang('order approval revoked'); break;
+					default:
 				}
 
 				if($value['new_value']=='O'){$value['new_value']=lang('Opened');}
-					if($value['new_value']=='X'){$value['new_value']=lang('Closed');}
+				if($value['new_value']=='X'){$value['new_value']=lang('Closed');}
 
-
-						$record_history[$i]['value_action']	= $type?$type:'';
+				$record_history[$i]['value_action']	= $type ? $type:'';
 				unset($type);
 
 				if ($value['status'] == 'A')
@@ -670,6 +718,11 @@
 						$record_history[$i]['value_old_value']	= $category[0]['name'];
 					}
 				}
+				else if ($value['status'] == 'S' || $value['status'] == 'SO'  || $value['status'] == 'R' || $value['status'] == 'X')
+				{
+					$record_history[$i]['value_new_value']	= $status_text[$value['new_value']];
+					$record_history[$i]['value_old_value']	= $status_text[$value['old_value']];
+				}
 				else if ($value['status'] != 'O' && $value['new_value'])
 				{
 					$record_history[$i]['value_new_value']	= $value['new_value'];
@@ -709,17 +762,21 @@
 
 			if(isset($workorder['charge_tenant']) && $workorder['charge_tenant'] && $workorder['id'])
 			{
-				$project = execMethod('property.soproject.read_single',$workorder['project_id']);
+				if(!$_tenant_id = $workorder['extra']['tenant_id'])
+				{
+					$project = execMethod('property.soproject.read_single',$workorder['project_id']);
+					$_tenant_id = $project['tenant_id'];
+				}
 
 				$boclaim = CreateObject('property.botenant_claim');
 
 				$value_set = array
-					(
-						'workorder' 		=> $target,
-						'project_id'		=> $workorder['project_id'],
-					);
+				(
+					'workorder' 		=> $target,
+					'project_id'		=> $workorder['project_id'],
+				);
 
-				$claim = $boclaim->read(array('project_id' => $project['project_id']));
+				$claim = $boclaim->read(array('project_id' => $workorder['project_id']));
 				$target = array();
 				if($claim)
 				{
@@ -739,7 +796,7 @@
 				else
 				{
 					$value_set['amount']		= 0;
-					$value_set['tenant_id']		= $project['tenant_id'];
+					$value_set['tenant_id']		= $_tenant_id;
 					$value_set['b_account_id']	= $workorder['b_account_id'];
 					$value_set['cat_id']		= 99;
 					$value_set['status']		= 'open';
@@ -774,4 +831,28 @@
 			$this->so->delete($workorder_id);
 		}
 
+		public function get_user_list($selected = 0)
+		{
+			$ser_list = $this->so->get_user_list();
+			foreach($ser_list as &$user)
+			{
+				$user['selected'] = $user['id'] == $selected ? true : false;
+			}
+			return $ser_list;
+		}
+
+		public function get_budget($order_id)
+		{
+			return $this->so->get_budget($order_id);
+		}
+
+		/**
+		* Recalculate actual cost from payment history for all workorders
+		*
+		* @return void
+		*/
+		function recalculate()
+		{
+			$this->so->recalculate();
+		}
 	}
