@@ -9,7 +9,7 @@
 	* @package phpgroupware
 	* @subpackage property
 	* @category core
- 	* @version $Id: class.interlink.inc.php 6718 2011-01-03 09:29:44Z sigurdne $
+ 	* @version $Id: class.interlink.inc.php 11292 2013-09-13 07:21:29Z sigurdne $
 	*/
 
 	/*
@@ -77,10 +77,10 @@
 			switch( $role )
 			{
 				case 'target':
-					$sql = "SELECT location2_id as linkend_location, location2_item_id as linkend_id FROM phpgw_interlink WHERE location1_id = {$location_id} AND location1_item_id = {$id} ORDER by location2_id DESC";
+					$sql = "SELECT location2_id as linkend_location, location2_item_id as linkend_id, account_id,entry_date FROM phpgw_interlink WHERE location1_id = {$location_id} AND location1_item_id = {$id} ORDER by location2_id DESC";
 					break;
 				default:
-					$sql = "SELECT location1_id as linkend_location, location1_item_id as linkend_id FROM phpgw_interlink WHERE location2_id = {$location_id} AND location2_item_id = {$id} ORDER by location1_id DESC";
+					$sql = "SELECT location1_id as linkend_location, location1_item_id as linkend_id, account_id,entry_date FROM phpgw_interlink WHERE location2_id = {$location_id} AND location2_item_id = {$id} ORDER by location1_id DESC";
 			}
 
 			$this->_db->query($sql,__LINE__,__FILE__);
@@ -95,7 +95,12 @@
 					$i++;
 				}
 				$relation[$i]['linkend_location']	= $this->_db->f('linkend_location');
-				$relation[$i]['data'][] = array( 'id' => $this->_db->f('linkend_id'));
+				$relation[$i]['data'][] = array
+				(
+					'id'			=> $this->_db->f('linkend_id'),
+					'account_id'	=> $this->_db->f('account_id'),
+					'entry_date'	=> $this->_db->f('entry_date')
+				);
 
 				$last_type = $this->_db->f('linkend_location');
 			}
@@ -110,7 +115,9 @@
 				foreach ($entry['data'] as &$data)
 				{
 					$data['link'] = $this->get_relation_link($linkend_location, $data['id']);
-					$data['statustext'] = $this->get_relation_info($linkend_location, $data['id']);
+					$relation_info = $this->get_relation_info($linkend_location, $data['id']);
+					$data['statustext'] = $relation_info['statustext'];
+					$data['title'] = $relation_info['title'];
 				}
 			}
 			return $relation;
@@ -181,6 +188,58 @@
 			}
 			return $location_name;
 		}
+		/**
+		 * Get relation of the interlink
+		 *
+		 * @param integer $location_id the location
+		 * @param integer $id			the id of the referenced item
+		 *
+		 * @return string the linkt to the the related item
+		 */
+
+		public function get_location_link($location_id, $id, $action = 'view')
+		{
+			$system_location = $GLOBALS['phpgw']->locations->get_name($location_id);
+
+			$name = 'N∕A';
+			if( preg_match('/.location./i', $system_location['location']) )
+			{
+				$location_code = execMethod('property.solocation.get_location_code',$id);
+
+				$location = execMethod('property.solocation.read_single', $location_code);
+				$location_arr = explode('-', $location_code);
+				$i=1;
+				$name_arr = array();
+				foreach($location_arr as $_dummy)
+				{
+					$name_arr[] = $location["loc{$i}_name"];
+					$i++;
+				}
+
+				$name = implode('::', $name_arr);
+			}
+			else if( preg_match('/.entity./i', $system_location['location']) )
+			{
+				$name = execMethod('property.soentity.get_short_description', 
+							array('location_id' => $location_id, 'id' => $id));
+			}
+
+			$link = $this->get_relation_link($system_location['location'], $id, $action);
+			if ($link)
+			{
+				return array
+				(
+					'name'	=> $name,
+					'link'	=> $link
+				);
+			}
+			else
+			{
+				return array();
+			}
+		}
+
+
 		/**
 		 * Get relation of the interlink
 		 *
@@ -227,6 +286,10 @@
 			{
 				$link = array('menuaction' => "property.uirequest.{$function}", 'id' => $id);
 			}
+			else if($type == '.project.condition_survey')
+			{
+				$link = array('menuaction' => "property.uicondition_survey.{$function}", 'id' => $id);
+			}
 			else if($type == '.project')
 			{
 				$link = array('menuaction' => "property.uiproject.{$function}", 'id' => $id);
@@ -258,6 +321,24 @@
 						'id'			=> $id
 					);
 			}
+			else if($type == '.checklist')
+			{
+				$link = array('menuaction' => 'controller.uicheck_list.view_control_info', 'check_list_id' => $id);
+			}
+			else if($type == '.activity')
+			{
+				$link = array('menuaction' => 'logistic.uiactivity.view_resource_allocation', 'activity_id' => $id);
+			}
+			else if( substr($type, 1, 8) == 'location' )
+			{
+				$type		= explode('.',$type);
+				$link =	array
+					(
+						'menuaction'	=> "property.uilocation.{$function}",
+						'location_code'	=> $id,
+					);
+			}
+
 			return $GLOBALS['phpgw']->link('/index.php',$link);	
 		}
 
@@ -270,46 +351,66 @@
 		 * @return string info of the linked item
 		 */
 
-		public function get_relation_info($linkend_location, $id)
+		public function get_relation_info($linkend_location, $id=0)
 		{
-			$id = (int)$id;
+			$relation_info = array();
+			$id = isset($linkend_location['id']) ? (int)$linkend_location['id'] : (int)$id;
 			$type = $linkend_location['location'];
 			if($type == '.ticket')
 			{
-				$this->_db->query("SELECT status FROM fm_tts_tickets WHERE id = {$id}",__LINE__,__FILE__);
+				$this->_db->query("SELECT status, subject as title FROM fm_tts_tickets WHERE id = {$id}",__LINE__,__FILE__);
 				$this->_db->next_record();
 				$status_code = $this->_db->f('status');
+				$relation_info['title'] = $this->_db->f('title');
 
 				static $status_text;
 				if(!$status_text)
 				{
 					$status_text = execMethod('property.botts.get_status_text');
 				}
-				return $status_text[$status_code];
+				$relation_info['statustext'] = $status_text[$status_code];
+				return $relation_info;
 			}
 			else if($type == '.project.workorder')
 			{
-				$this->_db->query("SELECT fm_workorder_status.descr as status FROM fm_workorder {$this->_join} fm_workorder_status ON fm_workorder.status = fm_workorder_status.id WHERE fm_workorder.id = {$id}",__LINE__,__FILE__);
+				$this->_db->query("SELECT fm_workorder_status.descr as status, fm_workorder.title FROM fm_workorder {$this->_join} fm_workorder_status ON fm_workorder.status = fm_workorder_status.id WHERE fm_workorder.id = {$id}",__LINE__,__FILE__);
 				$this->_db->next_record();
-				return $this->_db->f('status');
+				$relation_info['statustext'] = $this->_db->f('status');
+				$relation_info['title'] = $this->_db->f('title');
+				return $relation_info;
 			}
 			else if($type == '.project.request')
 			{
-				$this->_db->query("SELECT fm_request_status.descr as status FROM fm_request {$this->_join} fm_request_status ON fm_request.status = fm_request_status.id WHERE fm_request.id = {$id}",__LINE__,__FILE__);				
+				$this->_db->query("SELECT fm_request.title, fm_request_status.descr as status FROM fm_request {$this->_join} fm_request_status ON fm_request.status = fm_request_status.id WHERE fm_request.id = {$id}",__LINE__,__FILE__);				
 				$this->_db->next_record();
-				return $this->_db->f('status');
+				$relation_info['statustext'] = $this->_db->f('status');
+				$relation_info['title'] = $this->_db->f('title');
+				return $relation_info;
+
+			}
+			else if($type == '.project.condition_survey')
+			{
+				$this->_db->query("SELECT fm_condition_survey.title, fm_condition_survey_status.descr as status FROM fm_condition_survey {$this->_join} fm_condition_survey_status ON fm_condition_survey.status_id = fm_condition_survey_status.id WHERE fm_condition_survey.id = {$id}",__LINE__,__FILE__);				
+				$this->_db->next_record();
+				$relation_info['statustext'] = $this->_db->f('status');
+				$relation_info['title'] = $this->_db->f('title');
+				return $relation_info;
+
 			}
 			else if($type == '.project')
 			{		
-				$this->_db->query("SELECT fm_project_status.descr as status FROM fm_project {$this->_join} fm_project_status ON fm_project.status = fm_project_status.id WHERE fm_project.id = {$id}",__LINE__,__FILE__);
+				$this->_db->query("SELECT fm_project.name as title, fm_project_status.descr as status FROM fm_project {$this->_join} fm_project_status ON fm_project.status = fm_project_status.id WHERE fm_project.id = {$id}",__LINE__,__FILE__);
 				$this->_db->next_record();
-				return $this->_db->f('status');
+				$relation_info['statustext'] = $this->_db->f('status');
+				$relation_info['title'] = $this->_db->f('title');
+				return $relation_info;
 			}
 			else if( substr($type, 1, 6) == 'entity' )
 			{
 				$type		= explode('.',$type);
 				$entity_id	= $type[2];
 				$cat_id		= $type[3];
+				$location_id	= $GLOBALS['phpgw']->locations->get_id('property', ".entity.{$entity_id}.{$cat_id}");
 				$metadata = $this->_db->metadata("fm_entity_{$entity_id}_{$cat_id}");
 				if(isset($metadata['status']))
 				{
@@ -317,7 +418,6 @@
 					$this->_db->query($sql,__LINE__,__FILE__);
 					$this->_db->next_record();
 					$status_id = (int)$this->_db->f('status');
-					$location_id	= $GLOBALS['phpgw']->locations->get_id('property', ".entity.{$entity_id}.{$cat_id}");
 
 					$sql = "SELECT phpgw_cust_choice.value as status FROM phpgw_cust_attribute"
 						. " {$this->_join} phpgw_cust_choice ON phpgw_cust_attribute.location_id = phpgw_cust_choice.location_id "
@@ -325,8 +425,17 @@
 						. " AND phpgw_cust_choice.id = {$status_id} AND phpgw_cust_attribute.location_id = {$location_id}";
 					$this->_db->query($sql,__LINE__,__FILE__);
 					$this->_db->next_record();
-					return $this->_db->f('status');
+					$relation_info['statustext'] = $this->_db->f('status');
 				}
+	
+				$relation_info['title'] = 'N∕A';
+
+				if($short_desc = execMethod('property.soentity.get_short_description',	array('location_id' => $location_id, 'id' => $id)))
+				{
+					$relation_info['title'] = $short_desc;
+				}
+
+				return $relation_info;
 			}
 			else if( substr($type, 1, 5) == 'catch' )
 			{
