@@ -7,7 +7,7 @@
 	 * @copyright Copyright (C) 2007,2008 Free Software Foundation, Inc. http://www.fsf.org/
 	 * @license http://www.gnu.org/licenses/gpl.html GNU General Public License
 	 * @package property
-	 * @version $Id: class.menu.inc.php 7401 2011-06-20 06:30:25Z sigurdne $
+	 * @version $Id: class.menu.inc.php 11608 2014-01-20 07:14:53Z sigurdne $
 	 */
 
 	/*
@@ -101,6 +101,11 @@
 					 */
 					}
 				}
+				$admin_children_entity['convert_to_eav'] = array
+				(
+						'text'	=> lang('convert to eav'),
+						'url'	=> $GLOBALS['phpgw']->link('/index.php', array('menuaction' => 'property.uiadmin_entity.convert_to_eav') )
+				);
 
 				$admin_children_tenant = array
 					(
@@ -144,6 +149,36 @@
 							'url'	=> $GLOBALS['phpgw']->link('/index.php', array('menuaction' => 'admin.ui_custom.list_attribute', 'appname' => 'property', 'location' => '.vendor', 'menu_selection' => 'admin::property::vendor::vendor_attribs') )
 						)
 					);
+
+				$admin_children_ticket = array
+					(
+						'ticket_cats'	=> array
+						(
+							'text'	=> lang('Ticket Categories'),
+							'url'	=> $GLOBALS['phpgw']->link('/index.php', array('menuaction' => 'admin.uicategories.index', 'appname' => 'property', 'location' => '.ticket', 'global_cats' => 'true', 'menu_selection' => 'admin::property::ticket::ticket_cats') )
+						),
+						'ticket_status'	=> array
+						(
+							'text'	=> lang('Ticket status'),
+							'url'	=> $GLOBALS['phpgw']->link('/index.php', array('menuaction' => 'property.uigeneric.index', 'type' => 'ticket_status') )
+						),
+						'ticket_priority'	=> array
+						(
+							'text'	=> lang('Ticket priority'),
+							'url'	=> $GLOBALS['phpgw']->link('/index.php', array('menuaction' => 'property.uigeneric.index', 'type' => 'ticket_priority') )
+						),
+						'ticket_config'	=> array
+						(
+							'text'	=> lang('ticket config'),
+							'url'	=> $GLOBALS['phpgw']->link('/index.php', array('menuaction' => 'admin.uiconfig2.index', 'location_id' => $GLOBALS['phpgw']->locations->get_id('property', '.ticket')) )
+						),
+						'ticket_attribs'	=> array
+						(
+							'text'	=> lang('ticket Attributes'),
+							'url'	=> $GLOBALS['phpgw']->link('/index.php', array('menuaction' => 'admin.ui_custom.list_attribute', 'appname' => 'property', 'location' => '.ticket', 'menu_selection' => 'admin::property::ticket::ticket_attribs') )
+						)
+					);
+
 				$admin_children_owner = array
 					(
 						'owner_cats'	=> array
@@ -158,6 +193,7 @@
 						)
 					);
 
+
 				$admin_children_accounting = array
 					(
 						'accounting_cats'	=> array
@@ -170,21 +206,66 @@
 							'text'	=> lang('budget account'),
 							'url'	=> $GLOBALS['phpgw']->link('/index.php', array('menuaction' => 'property.uigeneric.index', 'type' => 'budget_account') )
 						),
+						'department'	=> array
+						(
+							'text'	=> lang('department'),
+							'url'	=> $GLOBALS['phpgw']->link('/index.php', array('menuaction' => 'property.uigeneric.index', 'type' => 'department') )
+						),
 						'accounting_dimb'	=> array
 						(
 							'text'	=> lang('Accounting dim b'),
 							'url'	=> $GLOBALS['phpgw']->link('/index.php', array('menuaction' => 'property.uigeneric.index', 'type' => 'dimb') )
 						),
+/*
 						'dimb_roles'	=> array
 						(
 							'text'	=> lang('dimb roles'),
 							'url'	=> $GLOBALS['phpgw']->link('/index.php', array('menuaction' => 'admin.uicategories.index', 'appname' => 'property', 'location' => '.invoice.dimb', 'global_cats' => 'true', 'menu_selection' => 'admin::property::accounting::dimb_roles') )
 						),
+*/
+/*
+						'dimb_role'	=> array
+						(
+							'text'	=> lang('dimb roles'),
+							'url'	=> $GLOBALS['phpgw']->link('/index.php', array('menuaction' => 'property.uigeneric.index', 'type' => 'dimb_role') )
+						),
+						'dimb_role_user' => array
+						(
+							'text'	=> lang('dimb role user'),
+							'url'	=> $GLOBALS['phpgw']->link('/index.php', array('menuaction' => 'property.uigeneric.index', 'type' => 'dimb_role_user') )
+						),
+*/
+						'dimb_role_user2' => array
+						(
+							'text'	=> lang('dimb role user'),
+							'url'	=> $GLOBALS['phpgw']->link('/index.php', array('menuaction' => 'property.uidimb_role_user.index') )
+						),
+
 						'accounting_dimd'	=> array
 						(
 							'text'	=> lang('Accounting dim d'),
 							'url'	=> $GLOBALS['phpgw']->link('/index.php', array('menuaction' => 'property.uigeneric.index', 'type' => 'dimd') )
 						),
+						'periodization'	=> array
+						(
+							'text'	=> lang('periodization'),
+							'url'	=> $GLOBALS['phpgw']->link('/index.php', array('menuaction' => 'property.uigeneric.index', 'type' => 'periodization') )
+						),
+						'periodization_outline'	=> array
+						(
+							'text'	=> lang('periodization outline'),
+							'url'	=> $GLOBALS['phpgw']->link('/index.php', array('menuaction' => 'property.uigeneric.index', 'type' => 'periodization_outline') )
+						),
+						'period_transition'	=> array
+						(
+							'text'	=> lang('period transition'),
+							'url'	=> $GLOBALS['phpgw']->link('/index.php', array('menuaction' => 'property.uigeneric.index', 'type' => 'period_transition') )
+						),
+						'accounting_config'	=> array
+						(
+							'text'	=> lang('Configuration'),
+							'url'	=> $GLOBALS['phpgw']->link('/index.php', array('menuaction' => 'admin.uiconfig2.index', 'location_id' => $GLOBALS['phpgw']->locations->get_id('property', '.invoice')) )
+						),
 						'accounting_tax'	=> array
 						(
 							'text'	=> lang('Accounting tax'),
@@ -204,7 +285,16 @@
 						(
 							'text'	=> lang('Accounting voucher type'),
 							'url'	=> $GLOBALS['phpgw']->link('/index.php', array('menuaction' => 'property.uigeneric.index', 'type' => 'voucher_type') )
+						),
+						'check_missing_project_budget'	=> array
+						(
+							'text'	=> lang('check missing project budget'),
+							'url'	=> $GLOBALS['phpgw']->link('/index.php', array('menuaction' => 'property.uiproject.check_missing_project_budget') )
 						)
+
+
+
+
 					);
 
 				$admin_children_agreement = array
@@ -287,6 +377,11 @@
 						(
 							'url'	=> $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> 'property.uilocation.update_location') ),
 							'text'	=> lang('update location')
+						),
+						'location_contact'	=> array
+						(
+							'text'	=> lang('location contact'),
+							'url'	=> $GLOBALS['phpgw']->link('/index.php', array('menuaction' => 'property.uigeneric.index', 'type' => 'location_contact') )
 						)
 					);
 
@@ -295,7 +390,20 @@
 						'index'	=> array
 						(
 							'text'	=> lang('Configuration'),
-							'url'	=> $GLOBALS['phpgw']->link('/index.php', array('menuaction' => 'admin.uiconfig.index', 'appname' => 'property') )
+							'url'	=> $GLOBALS['phpgw']->link('/index.php', array('menuaction' => 'admin.uiconfig.index', 'appname' => 'property') ),
+							'children'	=> array
+							(
+								'custom config'	=> array
+								(
+									'text'	=> lang('custom config'),
+									'url'	=> $GLOBALS['phpgw']->link('/index.php', array('menuaction' => 'admin.uiconfig2.index', 'location_id' => $GLOBALS['phpgw']->locations->get_id('property', '.admin')) )
+								)
+							)
+						),
+						'import'	=> array
+						(
+							'text'	=> lang('Generic import'),
+							'url'	=> $GLOBALS['phpgw']->link('/index.php', array('menuaction' => 'property.uiimport.index') )
 						),
 						'entity'	=> array
 						(
@@ -331,15 +439,16 @@
 							'text'	=> lang('Workorder Detail Categories'),
 							'url'	=> $GLOBALS['phpgw']->link('/index.php', array('menuaction' => 'property.uigeneric.index', 'type' => 'wo_hours') )
 						),
-						'ticket_cats'	=> array
+						'workorder_recalculate'	=> array
 						(
-							'text'	=> lang('Ticket Categories'),
-							'url'	=> $GLOBALS['phpgw']->link('/index.php', array('menuaction' => 'admin.uicategories.index', 'appname' => 'property', 'location' => '.ticket', 'global_cats' => 'true', 'menu_selection' => 'admin::property::ticket_cats') )
+							'text'	=> lang('Workorder recalculate actual cost'),
+							'url'	=> $GLOBALS['phpgw']->link('/index.php', array('menuaction' => 'property.uiworkorder.recalculate') )
 						),
-						'ticket_status'	=> array
+						'ticket'	=> array
 						(
-							'text'	=> lang('Ticket status'),
-							'url'	=> $GLOBALS['phpgw']->link('/index.php', array('menuaction' => 'property.uigeneric.index', 'type' => 'ticket_status') )
+							'text'	=> lang('helpdesk'),
+							'url'	=> $GLOBALS['phpgw']->link('/index.php', array('menuaction' => 'admin.uicategories.index', 'appname' => 'property', 'location' => '.ticket', 'global_cats' => 'true', 'menu_selection' => 'admin::property::ticket::ticket_cats') ),
+							'children' => $admin_children_ticket
 						),
 						'tenant'	=> array
 						(
@@ -390,16 +499,36 @@
 							'text'	=> lang('User contact info'),
 							'url'	=> $GLOBALS['phpgw']->link('/index.php', array('menuaction' => 'property.uiadmin.contact_info') )
 						),
+						'request_cats'	=> array
+						(
+							'text'	=> lang('request categories'),
+							'url'	=> $GLOBALS['phpgw']->link('/index.php', array('menuaction' => 'admin.uicategories.index', 'appname' => 'property', 'location' => '.project.request', 'global_cats' => 'true', 'menu_selection' => 'admin::property::request_cats') )
+						),
 						'request_status'	=> array
 						(
 							'text'	=> lang('Request status'),
 							'url'	=> $GLOBALS['phpgw']->link('/index.php', array('menuaction' => 'property.uigeneric.index', 'type' => 'request_status') )
 						),
+						'request_responsible_unit'	=> array
+						(
+							'text'	=> lang('responsible unit'),
+							'url'	=> $GLOBALS['phpgw']->link('/index.php', array('menuaction' => 'property.uigeneric.index', 'type' => 'request_responsible_unit') )
+						),
 						'request_condition'	=> array
 						(
 							'text'	=> lang('Request condition_type'),
 							'url'	=> $GLOBALS['phpgw']->link('/index.php', array('menuaction' => 'property.uigeneric.index', 'type' => 'r_condition_type') )
 						),
+						'condition_survey_cats'	=> array
+						(
+							'text'	=> lang('condition survey Categories'),
+							'url'	=> $GLOBALS['phpgw']->link('/index.php', array('menuaction' => 'admin.uicategories.index', 'appname' => 'property', 'location' => '.project.condition_survey', 'global_cats' => 'true', 'menu_selection' => 'admin::property::condition_survey_cats') )
+						),
+						'condition_survey_status'	=> array
+						(
+							'text'	=> lang('condition survey status'),
+							'url'	=> $GLOBALS['phpgw']->link('/index.php', array('menuaction' => 'property.uigeneric.index', 'type' => 'condition_survey_status') )
+						),
 						'authorities_demands'	=> array
 						(
 							'text'	=> lang('authorities demands'),
@@ -412,7 +541,7 @@
 						),
 						'request_attribs'	=> array
 						(
-							'text'	=> lang('request Attributes'),
+							'text'	=> lang('request attributes'),
 							'url'	=> $GLOBALS['phpgw']->link('/index.php', array('menuaction' => 'admin.ui_custom.list_attribute', 'appname' => 'property', 'location' =>'.project.request', 'menu_selection' => 'admin::property::request_attribs') )
 						),
 						'order_dim1'	=> array
@@ -562,6 +691,8 @@
 				$config	= CreateObject('phpgwapi.config','property');
 				$config->read();
 				
+				$invoicehandler	= isset($config->config_data['invoicehandler']) && $config->config_data['invoicehandler'] == 2 ? 'uiinvoice2' : 'uiinvoice';
+
 				if(!isset($config->config_data['suppress_tenant']) || !$config->config_data['suppress_tenant'])
 				{
 					$children['tenant'] = array
@@ -656,16 +787,19 @@
 					);
 			}
 
-			$menus['navigation']['helpdesk']['children']['response_template'] = array
+			if(isset($GLOBALS['phpgw_info']['user']['apps']['sms']))
+			{
+				$menus['navigation']['helpdesk']['children']['response_template'] = array
 				(
 					'url'	=> $GLOBALS['phpgw']->link('/index.php', array('menuaction' => 'property.uigeneric.index', 'type' => 'response_template') ),
 					'text'	=> lang('response template'),
 					'image'		=> array('property', 'helpdesk')
 				);
+			}
 
 			if ( $acl->check('.project', PHPGW_ACL_READ, 'property') )
 			{
-
+/*
 				$cats	= CreateObject('phpgwapi.categories', -1,  'property', '.project');
 				$cats->supress_info	= true;
 
@@ -682,7 +816,7 @@
 					
 					);	
 				}
-
+*/
 				$menus['navigation']['project'] = array
 					(
 						'url'		=> $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> 'property.uiproject.index')),
@@ -695,7 +829,7 @@
 								'url'	=> $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> 'property.uiproject.index')),
 								'text'	=> lang('Project'),
 								'image'		=> array('property', 'project'),
-								'children'	=> $project_children
+						//		'children'	=> $project_children
 							),
 							'workorder'	=> array
 							(
@@ -703,6 +837,21 @@
 								'text'	=> lang('Workorder'),
 								'image'		=> array('property', 'project_workorder')
 							),
+							'condition_survey'	=> array
+							(
+								'url'	=> $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> 'property.uicondition_survey.index')),
+								'text'	=> lang('condition survey'),
+								'image'		=> array('property', 'condition_survey'),
+								'children'	=> array
+								(
+									'summation'	=> array
+									(
+										'url'	=> $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> 'property.uicondition_survey.summation')),
+										'text'	=> lang('summation'),
+										'image'		=> array('property', 'invoice')
+									)
+								)
+							),
 							'request'	=> array
 							(
 								'url'	=> $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> 'property.uirequest.index')),
@@ -714,6 +863,11 @@
 								'url'	=> $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> 'property.uitemplate.index')),
 								'text'	=> lang('template'),
 								'image'		=> array('property', 'project_template')
+							),
+							'project_bulk_update_status'	=> array
+							(
+								'text'	=> lang('bulk update status'),
+								'url'	=> $GLOBALS['phpgw']->link('/index.php', array('menuaction' => 'property.uiproject.bulk_update_status') )
 							)
 						)
 					);
@@ -751,6 +905,11 @@
 							'url'	=> $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> 'property.uiXport.export')),
 							'text'	=>	lang('Export invoice')
 						);
+					$children['rollback'] = array
+						(
+							'url'	=> $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> 'property.uiXport.rollback')),
+							'text'	=>	lang('Roll back')
+						);
 				}
 
 				if ( $acl->check('.invoice', PHPGW_ACL_ADD, 'property') )
@@ -764,17 +923,26 @@
 
 				$menus['navigation']['invoice'] = array
 					(
-						'url'	=> $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> 'property.uiinvoice.index')),
+						'url'	=> $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> "property.{$invoicehandler}.index")),
 						'text'	=> lang('Invoice'),
 						'image'	=> array('property', 'invoice'),
 						'children'	=> array_merge(array
 						(
+							'deposition'	=> array
+							(
+								'url'	=>	$GLOBALS['phpgw']->link('/index.php',array('menuaction'=> 'property.uiinvoice.reporting', 'type' => 'deposition')),
+								'text'	=> lang('deposition')
+							),
+							'reconciliation'	=> array
+							(
+								'url'	=>	$GLOBALS['phpgw']->link('/index.php',array('menuaction'=> 'property.uiinvoice.reporting', 'type' => 'reconciliation')),
+								'text'	=> lang('reconciliation')
+							),
 							'paid'		=> array
 							(
 								'url'	=>	$GLOBALS['phpgw']->link('/index.php',array('menuaction'=> 'property.uiinvoice.index', 'paid'=>true)),
 								'text'	=> lang('Paid')
 							),
-							// Should this be process? skwashd jan08
 							'consume'	=> array
 							(
 								'url'	=>	$GLOBALS['phpgw']->link('/index.php',array('menuaction'=> 'property.uiinvoice.consume')),
