@@ -24,7 +24,7 @@
 	* @internal Development of this application was funded by http://www.bergen.kommune.no/bbb_/ekstern/
 	* @package property
 	* @subpackage admin
- 	* @version $Id: class.soadmin_entity.inc.php 7215 2011-04-12 20:06:07Z sigurdne $
+ 	* @version $Id: class.soadmin_entity.inc.php 11443 2013-11-10 19:01:47Z sigurdne $
 	*/
 
 	/**
@@ -127,25 +127,22 @@
 
 		function read_category($data)
 		{
-			if(is_array($data))
-			{
-				$start		= isset($data['start'])&& $data['start'] ? $data['start'] : 0;
-				$query		= isset($data['query'])?$data['query']:'';
-				$sort		= isset($data['sort'])?$data['sort']:'DESC';
-				$order		= isset($data['order'])?$data['order']:'';
-				$allrows	= isset($data['allrows'])?$data['allrows']:'';
-				$entity_id	= isset($data['entity_id'])?$data['entity_id']:'';
-				$type		= isset($data['type']) && $data['type'] ? $data['type'] : $this->type;
-				$required	= isset($data['required'])?$data['required']:'';
-			}
+			$start		= isset($data['start'])&& $data['start'] ? $data['start'] : 0;
+			$query		= isset($data['query'])?$data['query']:'';
+			$sort		= isset($data['sort'])?$data['sort']:'DESC';
+			$order		= isset($data['order'])?$data['order']:'';
+			$allrows	= isset($data['allrows'])?$data['allrows']:'';
+			$entity_id	= isset($data['entity_id'])? (int)$data['entity_id']:0;
+			$type		= isset($data['type']) && $data['type'] ? $data['type'] : $this->type;
+			$required	= isset($data['required'])?$data['required']:'';
 
 			if ($order)
 			{
-				$ordermethod = " order by $order $sort";
+				$ordermethod = " ORDER BY {$order} {$sort}";
 			}
 			else
 			{
-				$ordermethod = ' order by id asc';
+				$ordermethod = ' ORDER BY id ASC';
 			}
 
 			$table = "fm_{$type}_category";
@@ -154,10 +151,10 @@
 			if($query)
 			{
 				$query = $this->db->db_addslashes($query);
-				$querymethod = " AND name $this->like '%$query%' or descr $this->like '%$query%'";
+				$querymethod = " AND name {$this->like} '%{$query}%' OR descr {$this->like} '%{$query}%'";
 			}
 
-			$sql = "SELECT * FROM $table WHERE entity_id=$entity_id $querymethod";
+			$sql = "SELECT * FROM {$table} WHERE entity_id={$entity_id} {$querymethod}";
 
 			$this->db->query($sql,__LINE__,__FILE__);
 			$this->total_records = $this->db->num_rows();
@@ -176,14 +173,17 @@
 			{
 				$id	= $this->db2->f('id');
 				$category = array
-					(
-						'id'		=> $id,
-						'name'		=> $this->db2->f('name'),
-						'prefix'	=> $this->db2->f('prefix'),
-						'descr'		=> $this->db2->f('descr'),
-						'level'		=> $this->db2->f('level'),
-						'parent_id'	=> $this->db2->f('parent_id')
-					);
+				(
+					'entity_id'		=> $entity_id,
+					'id'			=> $id,
+					'name'			=> $this->db2->f('name'),
+					'prefix'		=> $this->db2->f('prefix'),
+					'descr'			=> $this->db2->f('descr'),
+					'level'			=> $this->db2->f('level'),
+					'parent_id'		=> $this->db2->f('parent_id'),
+					'is_eav'		=> $this->db2->f('is_eav'),
+					'enable_bulk'	=> $this->db2->f('enable_bulk'),
+				);
 
 				if($required)
 				{
@@ -197,6 +197,12 @@
 					$values[] = $category;
 				}
 			}
+
+			foreach ($values as &$entry)
+			{
+				$entry['location_id'] = $GLOBALS['phpgw']->locations->get_id($this->type_app[$type], ".{$type}.{$entity_id}.{$entry['id']}");
+			}
+
 			return $values;
 		}
 
@@ -216,11 +222,12 @@
 			{
 				$id	= $db->f('id');
 				$this->category_tree[] = array
-					(
-						'id'		=> $id,
-						'name'		=> str_repeat('..',$level).$db->f('name'),
-						'parent_id'	=> $db->f('parent_id')
-					);
+				(
+					'id'			=> $id,
+					'name'			=> str_repeat('..',$level).$db->f('name'),
+					'parent_id'		=> $db->f('parent_id'),
+					'location_id'	=> $db->f('location_id')
+				);
 				$this->get_children2($entity_id, $id, $level+1);
 			}
 			return $this->category_tree;
@@ -239,20 +246,22 @@
 			{
 				$id	= $this->db->f('id');
 				$categories[$id] = array
-					(
-						'id'			=> $id,
-						'name'			=> $this->db->f('name',true),
-						'parent_id'		=> 0
-					);
+				(
+					'id'			=> $id,
+					'name'			=> $this->db->f('name',true),
+					'parent_id'		=> 0,
+					'location_id'	=> $this->db->f('location_id')
+				);
 			}
 
 			foreach($categories as $category)
 			{
-				$this->category_tree[] = array
-					(
-						'id'	=> $category['id'],
-						'name'	=> $category['name']
-					);
+				$this->category_tree[$category['id']] = array
+				(
+					'id'			=> $category['id'],
+					'name'			=> $category['name'],
+					'location_id'	=> $category['location_id']
+				);
 				$this->get_children2($entity_id, $category['id'], 1);
 			}
 			return $this->category_tree;
@@ -278,8 +287,6 @@
 			while ($this->db2->next_record())
 			{
 				$id	= $this->db2->f('id');
-		//		$location = ".entity.{$entity_id}.{$id}";
-		//		$location_id	= $GLOBALS['phpgw']->locations->get_id($this->type_app[$this->type], $location);
 
 				$children[$id] = array
 					(
@@ -290,7 +297,7 @@
 						'level'			=> (int)$this->db2->f('level'),
 						'parent_id'		=> (int)$this->db2->f('parent_id'),
 						'owner'			=> (int)$this->db2->f('owner'),
-						'location_id'	=> $location_id
+						'location_id'	=> (int)$this->db2->f('location_id')
 					);
 			}
 
@@ -317,12 +324,12 @@
 			$this->db2->query($sql,__LINE__,__FILE__);
 			$this->total_records = $this->db2->num_rows();
 
-			$category = array();
+			$categories = array();
 			while ($this->db2->next_record())
 			{
 				$id	= $this->db2->f('id');
 				$location = ".entity.{$entity_id}.{$id}";
-	//			$location_id	= $GLOBALS['phpgw']->locations->get_id($this->type_app[$this->type], $location);
+
 				if ( !$required || ($required && $GLOBALS['phpgw']->acl->check($location, PHPGW_ACL_READ, $this->type_app[$this->type])) )
 				{
 					$categories[$id] = array
@@ -333,7 +340,7 @@
 							'descr'			=> $this->db2->f('descr',true),
 							'level'			=> 0,
 							'parent_id'		=> 0,
-							'location_id'	=> $location_id
+							'location_id'	=> $this->db2->f('location_id')
 						);
 				}
 			}
@@ -427,27 +434,86 @@
 			if ($this->db->next_record())
 			{
 				$category = array
-					(
-						'id'						=> $this->db->f('id'),
-						'name'						=> $this->db->f('name',true),
-						'descr'						=> $this->db->f('descr',true),
-						'prefix'					=> $this->db->f('prefix',true),
-						'lookup_tenant'				=> $this->db->f('lookup_tenant'),
-						'tracking'					=> $this->db->f('tracking'),
-						'location_level'			=> $this->db->f('location_level'),
-						'location_link_level'		=> $this->db->f('location_link_level'),
-						'fileupload'				=> $this->db->f('fileupload'),
-						'loc_link'					=> $this->db->f('loc_link'),
-						'start_project'				=> $this->db->f('start_project'),
-						'start_ticket'				=> $this->db->f('start_ticket'),
-						'jasperupload'				=> $this->db->f('jasperupload'),
-						'parent_id'					=> $this->db->f('parent_id'),
-						'level'						=> $this->db->f('level')
+				(
+					'id'						=> $this->db->f('id'),
+					'name'						=> $this->db->f('name',true),
+					'descr'						=> $this->db->f('descr',true),
+					'prefix'					=> $this->db->f('prefix',true),
+					'lookup_tenant'				=> $this->db->f('lookup_tenant'),
+					'tracking'					=> $this->db->f('tracking'),
+					'location_level'			=> $this->db->f('location_level'),
+					'location_link_level'		=> $this->db->f('location_link_level'),
+					'fileupload'				=> $this->db->f('fileupload'),
+					'loc_link'					=> $this->db->f('loc_link'),
+					'start_project'				=> $this->db->f('start_project'),
+					'start_ticket'				=> $this->db->f('start_ticket'),
+					'is_eav'					=> $this->db->f('is_eav'),
+					'enable_bulk'				=> $this->db->f('enable_bulk'),
+					'jasperupload'				=> $this->db->f('jasperupload'),
+					'parent_id'					=> $this->db->f('parent_id'),
+					'level'						=> $this->db->f('level'),
+					'location_id'				=> $this->db->f('location_id')
 					);
 			}
+
+
 			return $category;
 		}
 
+		/**
+		* Get entity category based on location_id
+		* @param int $location_id the system location id
+		* @return array info about the entity category
+		*/
+		function get_single_category($location_id)
+		{
+			$loc_arr = $GLOBALS['phpgw']->locations->get_name($location_id);
+			
+			$type_arr = explode('.',  $loc_arr['location']);
+			
+			if(!count($type_arr) == 3)
+			{
+				return array();
+			}
+
+			$type = $type_arr[1];
+
+			$sql = "SELECT * FROM fm_{$type}_category WHERE location_id =" . (int)$location_id;
+
+			$this->db->query($sql,__LINE__,__FILE__);
+
+			$category = array();
+			if ($this->db->next_record())
+			{
+				$category = array
+				(
+					'id'						=> $this->db->f('id'),
+					'entity_id'					=> $this->db->f('entity_id'),
+					'name'						=> $this->db->f('name',true),
+					'descr'						=> $this->db->f('descr',true),
+					'prefix'					=> $this->db->f('prefix',true),
+					'lookup_tenant'				=> $this->db->f('lookup_tenant'),
+					'tracking'					=> $this->db->f('tracking'),
+					'location_level'			=> $this->db->f('location_level'),
+					'location_link_level'		=> $this->db->f('location_link_level'),
+					'fileupload'				=> $this->db->f('fileupload'),
+					'loc_link'					=> $this->db->f('loc_link'),
+					'start_project'				=> $this->db->f('start_project'),
+					'start_ticket'				=> $this->db->f('start_ticket'),
+					'is_eav'					=> $this->db->f('is_eav'),
+					'enable_bulk'				=> $this->db->f('enable_bulk'),
+					'jasperupload'				=> $this->db->f('jasperupload'),
+					'parent_id'					=> $this->db->f('parent_id'),
+					'level'						=> $this->db->f('level'),
+					'location_id'				=> $location_id
+					);
+
+			}
+
+			return $category;
+		}
+
+
 		function read_category_name($entity_id,$cat_id)
 		{
 			$sql = "SELECT * FROM fm_{$this->type}_category WHERE entity_id =" . (int)$entity_id . ' AND id = ' . (int)$cat_id;
@@ -463,8 +529,10 @@
 			$entity['descr'] = $this->db->db_addslashes($entity['descr']);
 
 			$entity['id'] = $this->bocommon->next_id("fm_{$this->type}");
+			$location_id = $GLOBALS['phpgw']->locations->add(".{$this->type}." . $entity['id'], $entity['name'], $this->type_app[$this->type], true);
 
 			$values= array(
+				$location_id,
 				$entity['id'],
 				$entity['name'],
 				$entity['descr'],
@@ -474,10 +542,9 @@
 
 			$values	= $this->db->validate_insert($values);
 
-			$this->db->query("INSERT INTO fm_{$this->type} (id,name, descr,location_form,documentation) "
+			$this->db->query("INSERT INTO fm_{$this->type} (location_id,id,name, descr,location_form,documentation) "
 				. "VALUES ($values)",__LINE__,__FILE__);
 
-			$GLOBALS['phpgw']->locations->add(".{$this->type}." . $entity['id'], $entity['name'], $this->type_app[$this->type], true);
 
 			$receipt['id']= $entity['id'];
 
@@ -525,6 +592,10 @@
 			$values['descr'] = $this->db->db_addslashes($values['descr']);
 
 			$values['id'] = $this->bocommon->next_id($table, array('entity_id'=>$values['entity_id']));
+			
+			$custom_tbl = !$values['is_eav'] ? "fm_{$this->type}_{$values['entity_id']}_{$values['id']}" : null;
+			
+			$location_id = $GLOBALS['phpgw']->locations->add(".{$this->type}.{$values['entity_id']}.{$values['id']}", $values['name'],  $this->type_app[$this->type], true, $custom_tbl, $c_function = true);
 
 			if($values['parent_id'])
 			{
@@ -540,6 +611,7 @@
 
 			$values_insert= array
 				(
+					$location_id,
 					$values['entity_id'],
 					$values['id'],
 					$values['name'],
@@ -553,6 +625,8 @@
 					$values['loc_link'],
 					$values['start_project'],
 					$values['start_ticket'],
+					$values['is_eav'],
+					$values['enable_bulk'],
 					$values['jasperupload'],
 					$values['parent_id'],
 					$level
@@ -560,13 +634,33 @@
 
 			$values_insert	= $this->db->validate_insert($values_insert);
 
-			$this->db->query("INSERT INTO {$table} (entity_id,id,name, descr,prefix,lookup_tenant,tracking,location_level,location_link_level,fileupload,loc_link,start_project,start_ticket,jasperupload,parent_id,level ) "
+			$this->db->query("INSERT INTO {$table} (location_id,entity_id,id,name, descr,prefix,lookup_tenant,tracking,location_level,location_link_level,fileupload,loc_link,start_project,start_ticket,is_eav,enable_bulk,jasperupload,parent_id,level ) "
 				. "VALUES ($values_insert)",__LINE__,__FILE__);
 
-			$location_id = $GLOBALS['phpgw']->locations->add(".{$this->type}.{$values['entity_id']}.{$values['id']}", $values['name'],  $this->type_app[$this->type], true, "fm_{$this->type}_{$values['entity_id']}_{$values['id']}");
 
 			$receipt['id']= $values['id'];
 
+			if($values['is_eav']) // if modelles as eav - we are good
+			{
+				$values_insert = array
+				(
+					'location_id'	=> $location_id,
+					'name'			=> ".{$this->type}.{$values['entity_id']}.{$values['id']}::{$values['name']}",
+					'description'	=> $values['descr'],
+					'is_ifc'		=> 0
+				);
+
+				$this->db->query('INSERT INTO fm_bim_type (' . implode(',',array_keys($values_insert)) . ') VALUES ('
+				 . $this->db->validate_insert(array_values($values_insert)) . ')',__LINE__,__FILE__);
+
+				$this->db->transaction_commit();			
+
+				$receipt['message'][] = array('msg'	=> lang('%1 has been saved as an eav-model',$values['name']));
+				return $receipt;
+			}
+			
+			
+			// if not eav - we need a table to hold the attributes
 			$this->init_process();
 
 			$fd = $this->get_default_column_def();
@@ -752,6 +846,8 @@
 						'loc_link'					=> $entity['loc_link'],
 						'start_project'				=> $entity['start_project'],
 						'start_ticket'				=> $entity['start_ticket'],
+						'is_eav'					=> $entity['is_eav'],
+						'enable_bulk'				=> $entity['enable_bulk'],
 						'jasperupload'				=> $entity['jasperupload'],
 						'parent_id'					=> $entity['parent_id'],
 						'level'						=> $level
@@ -860,8 +956,9 @@
 
 		function delete_entity($id)
 		{
+			$this->db->transaction_begin();
 			$id = (int) $id;
-			$category_list=$this->read_category(array('entity_id'=>$id));
+			$category_list=$this->read_category(array('allrows'=>true, 'entity_id'=>$id));
 			$locations = array();
 			$locations[] = $GLOBALS['phpgw']->locations->get_id( $this->type_app[$this->type], ".{$this->type}.{$id}");
 			$subs = $GLOBALS['phpgw']->locations->get_subs( $this->type_app[$this->type], ".{$this->type}.{$id}");
@@ -875,7 +972,7 @@
 			$this->db->query('DELETE FROM phpgw_cust_attribute WHERE location_id IN (' . implode(',', $locations) . ')',__LINE__,__FILE__);
 			$this->db->query('DELETE FROM phpgw_locations WHERE location_id IN (' . implode(',', $locations) . ')',__LINE__,__FILE__);
 			$this->db->query('DELETE FROM phpgw_acl WHERE location_id IN (' . implode(',', $locations) . ')',__LINE__,__FILE__);
-			if (isset($category_list) AND is_array($category_list))
+			if (isset($category_list) && is_array($category_list))
 			{
 				$this->init_process();
 
@@ -884,7 +981,7 @@
 					$this->oProc->DropTable("fm_{$this->type}_{$id}_{$entry['id']}");
 				}
 			}
-
+			$this->db->transaction_commit();
 		}
 
 		function delete_category($entity_id, $id)
@@ -924,10 +1021,22 @@
 				}
 			}
 
-			$this->oProc->DropTable("fm_{$this->type}_{$entity_id}_{$id}");
-
 			$location_id = $GLOBALS['phpgw']->locations->get_id( $this->type_app[$this->type], ".{$this->type}.{$entity_id}.{$id}");
 
+			$category = $this->read_single_category($entity_id, $id);
+			if($category['is_eav'])
+			{
+				$this->db->query("SELECT id as type FROM fm_bim_type WHERE location_id= {$location_id}",__LINE__,__FILE__);
+				$this->db->next_record();
+				$type = (int)$this->db->f('type');
+				$this->db->query("DELETE FROM fm_bim_item WHERE type = {$type}",__LINE__,__FILE__);
+				$this->db->query("DELETE FROM fm_bim_type WHERE location_id= {$location_id}",__LINE__,__FILE__);
+			}
+			else
+			{
+				$this->oProc->DropTable("fm_{$this->type}_{$entity_id}_{$id}");
+			}
+
 			$this->db->query("DELETE FROM fm_{$this->type}_category WHERE entity_id= {$entity_id} AND id= {$id}",__LINE__,__FILE__);
 			$this->db->query("DELETE FROM phpgw_cust_attribute WHERE location_id = {$location_id}",__LINE__,__FILE__);
 			$this->db->query("DELETE FROM phpgw_locations WHERE location_id  = {$location_id}",__LINE__,__FILE__);
@@ -1005,4 +1114,122 @@
 			$this->oProc->m_odb			= & $this->db;
 			$this->oProc->m_odb->Halt_On_Error	= 'yes';
 		}
+
+ 
+		/**
+		 * Reduserer fra 684 til 265 tabeller for Nordlandssykehuset
+		 *
+		 * @return bool true on success
+		 */
+		function convert_to_eav()
+		{
+//			die('vent litt med denne');
+
+			phpgw::import_class('phpgwapi.xmlhelper');			
+			$this->type = 'entity';
+			$entity_list 	= $this->read(array('allrows' => true));
+
+			$this->db->transaction_begin();
+
+			foreach($entity_list as $entry)
+			{
+				$cat_list = $this->read_category(array('allrows'=>true,'entity_id'=>$entry['id']));
+
+				foreach($cat_list as $category)
+				{
+					if(!$category['is_eav'])
+					{
+
+						$location_id = $GLOBALS['phpgw']->locations->get_id('property', ".{$this->type}.{$category['entity_id']}.{$category['id']}");
+						$values_insert = array
+						(
+							'location_id'	=> $location_id,
+							'name'			=> ".{$this->type}.{$category['entity_id']}.{$category['id']}::{$category['name']}",
+							'description'	=> $category['descr'],
+							'is_ifc'		=> 0
+						);
+
+						$this->db->query('INSERT INTO fm_bim_type (' . implode(',',array_keys($values_insert)) . ') VALUES ('
+				 		. $this->db->validate_insert(array_values($values_insert)) . ')',__LINE__,__FILE__);
+				 		
+						$sql = "UPDATE fm_{$this->type}_category SET is_eav = 1 WHERE entity_id =" . (int)$category['entity_id'] . ' AND id = ' . (int)$category['id'];
+						$this->db->query($sql,__LINE__,__FILE__);
+						
+						$sql = "UPDATE phpgw_locations SET c_attrib_table = NULL WHERE location_id = {$location_id}";
+						$this->db->query($sql,__LINE__,__FILE__);
+
+				 		$type = $this->db->get_last_insert_id('fm_bim_type', 'id');
+				 		
+				 		$sql = "SELECT * FROM fm_{$this->type}_{$category['entity_id']}_{$category['id']}";
+				 		$this->db->query($sql,__LINE__,__FILE__);
+						while ($this->db->next_record())
+						{
+							$data = $this->db->Record;
+
+							$xmldata = phpgwapi_xmlhelper::toXML($data, "_{$this->type}_{$category['entity_id']}_{$category['id']}");
+							$doc = new DOMDocument('1.0', 'utf-8');
+							$doc->loadXML($xmldata);
+							$domElement = $doc->getElementsByTagName("_{$this->type}_{$category['entity_id']}_{$category['id']}")->item(0);
+							$domAttribute = $doc->createAttribute('appname');
+							$domAttribute->value = 'property';
+
+							// Don't forget to append it to the element
+							$domElement->appendChild($domAttribute);
+	
+							// Append it to the document itself
+							$doc->appendChild($domElement);
+
+							$doc->preserveWhiteSpace = true;
+							$doc->formatOutput = true;
+							$xml = $doc->saveXML();
+
+							$p_location_id = '';
+							if($data['p_cat_id'])
+							{
+								$p_location_id = $GLOBALS['phpgw']->locations->get_id('property', ".{$this->type}.{$data['p_entity_id']}.{$data['p_cat_id']}");
+							}
+
+							$p_id ='';
+							if($data['p_num'])
+							{
+								$p_id		= (int) ltrim($data['p_num'], $category['prefix']);
+							}
+							if (function_exists('com_create_guid') === true)
+							{
+								$guid = trim(com_create_guid(), '{}');
+							}
+							else
+							{
+								$guid = sprintf('%04X%04X-%04X-%04X-%04X-%04X%04X%04X', mt_rand(0, 65535), mt_rand(0, 65535), mt_rand(0, 65535), mt_rand(16384, 20479), mt_rand(32768, 49151), mt_rand(0, 65535), mt_rand(0, 65535), mt_rand(0, 65535));
+							}
+
+							$values_insert = array
+							(
+				  				'id'					=> $data['id'],
+				  				'location_id'			=> $location_id,
+				  				'type'					=> $type,
+				  				'guid'					=> $guid,
+								'xml_representation'	=> $this->db->db_addslashes($xml),
+								'model'					=> 0,
+								'p_location_id'			=> $p_location_id,
+								'p_id'					=> isset($data['p_num']) && $data['p_num'] ? (int)$data['p_num'] : '',
+								'location_code'			=> $data['location_code'],
+								'loc1'					=> $data['loc1'],
+								'address'				=> $data['address'],
+								'entry_date'			=> $data['entry_date'],
+								'user_id'				=> $data['user_id']
+							);
+							
+							$this->db->query("INSERT INTO fm_bim_item (" . implode(',',array_keys($values_insert)) . ') VALUES ('
+			 					. $this->db->validate_insert(array_values($values_insert)) . ')',__LINE__,__FILE__);
+						}
+
+				 		$sql = "DROP TABLE fm_{$this->type}_{$category['entity_id']}_{$category['id']}";
+				 		_debug_array($sql);
+				 		$this->db->query($sql,__LINE__,__FILE__);
+					}
+				}
+			}
+			return $this->db->transaction_commit();
+		}
 	}
