@@ -24,7 +24,7 @@
 	* @internal Development of this application was funded by http://www.bergen.kommune.no/bbb_/ekstern/
 	* @package property
 	* @subpackage admin
- 	* @version $Id: class.soadmin_location.inc.php 7440 2011-06-28 09:07:45Z sigurdne $
+ 	* @version $Id: class.soadmin_location.inc.php 10479 2012-11-06 10:47:26Z sigurdne $
 	*/
 
 	/**
@@ -476,7 +476,16 @@
 
 		function get_tables_to_alter()
 		{
-			$tables = array('fm_project','fm_tts_tickets','fm_request','fm_document','fm_investment');
+			$tables = array
+			(
+				'fm_project',
+				'fm_tts_tickets',
+				'fm_request',
+				'fm_document',
+				'fm_investment',
+				'fm_condition_survey'
+			);
+
 			$entity			= CreateObject('property.soadmin_entity');
 			$entity_list 	= $entity->read(array('allrows' => true));
 			foreach($entity_list as $entry)
