@@ -24,7 +24,7 @@
 	* @internal Development of this application was funded by http://www.bergen.kommune.no/bbb_/ekstern/
 	* @package property
 	* @subpackage budget
- 	* @version $Id: class.sobudget.inc.php 7112 2011-03-11 12:46:45Z sigurdne $
+ 	* @version $Id: class.sobudget.inc.php 11547 2013-12-19 18:50:32Z sigurdne $
 	*/
 
 	/**
@@ -34,6 +34,11 @@
 
 	class property_sobudget
 	{
+		var	$sum_budget_cost		= 0;
+		var	$sum_obligation_cost	= 0;
+		var	$sum_actual_cost		= 0;
+		var $sum_hits				= 0;
+
 		function __construct()
 		{
 			$this->cats					= CreateObject('phpgwapi.categories', -1,  'property', '.project');
@@ -42,6 +47,7 @@
 			$this->account		= $GLOBALS['phpgw_info']['user']['account_id'];
 			$this->db           = & $GLOBALS['phpgw']->db;
 			$this->join			= & $this->db->join;
+			$this->left_join	= & $this->db->left_join;
 			$this->like			= & $this->db->like;
 		}
 
@@ -142,14 +148,30 @@
 			if($query)
 			{
 				$query = $this->db->db_addslashes($query);
-				$querymethod = " $where ( descr $this->like '%$query%') OR fm_budget.b_account_id='$query'";
+				$querymethod = " $where ( descr {$this->like} '%$query%' OR fm_budget.b_account_id='$query')";
 			}
 
 
-			$sql = "SELECT fm_budget.*, fm_budget.category as cat_id, ecodimb, descr,fm_b_account.category as grouping FROM fm_budget $this->join fm_b_account ON fm_budget.b_account_id = fm_b_account.id $filtermethod $querymethod";
+			$sql = "SELECT fm_budget.*, fm_budget.category as cat_id, ecodimb, descr,fm_b_account.category as grouping"
+			. " FROM fm_budget {$this->join} fm_b_account ON fm_budget.b_account_id = fm_b_account.id"
+			. " $filtermethod $querymethod";
 
-			$this->db->query($sql,__LINE__,__FILE__);
-			$this->total_records = $this->db->num_rows();
+			if($GLOBALS['phpgw_info']['server']['db_type']=='postgres')
+			{
+				$sql_count = 'SELECT count(id) as cnt, sum(budget_cost) AS sum_budget_cost FROM (SELECT DISTINCT fm_budget.id, budget_cost '. substr($sql,strripos($sql,'FROM')) .') AS t';
+				$this->db->query($sql_count,__LINE__,__FILE__);
+				$this->db->next_record();
+				$this->total_records 		= $this->db->f('cnt');
+				$this->sum_budget_cost		= $this->db->f('sum_budget_cost');
+			}
+			else
+			{
+				$sql_count = 'SELECT count(fm_budget.id) as cnt, sum(budget_cost) AS sum_budget_cost ' . substr($sql,strripos($sql,'FROM'));
+				$this->db->query($sql_count,__LINE__,__FILE__);
+				$this->db->next_record();
+				$this->total_records 		= $this->db->f('cnt');
+				$this->sum_budget_cost		= $this->db->f('sum_budget_cost');
+			}
 
 			if(!$allrows)
 			{
@@ -176,7 +198,7 @@
 						'entry_date'		=> $this->db->f('entry_date'),
 						'ecodimb'			=> $this->db->f('ecodimb'),
 						'cat_id'			=> $this->db->f('cat_id'),
-						//			'user'				=> $GLOBALS['phpgw']->accounts->id2name($this->db->f('user_id'))
+			//			'user'				=> $GLOBALS['phpgw']->accounts->id2name($this->db->f('user_id'))
 					);
 			}
 			return $budget;
@@ -264,13 +286,12 @@
 						'budget_id'		=> $this->db->f('id'),
 						'year'			=> $this->db->f('year'),
 						'grouping'		=> $this->db->f('b_group'),
-						'district_id'		=> $this->db->f('district_id'),
+						'district_id'	=> $this->db->f('district_id'),
 						'revision'		=> $this->db->f('revision'),
-						'budget_cost'		=> $this->db->f('budget_cost'),
-						'entry_date'		=> $this->db->f('entry_date'),
-						'ecodimb'			=> $this->db->f('ecodimb'),
-						'cat_id'			=> $this->db->f('category'),
-						//		'user'			=> $GLOBALS['phpgw']->accounts->id2name($this->db->f('user_id'))
+						'budget_cost'	=> $this->db->f('budget_cost'),
+						'entry_date'	=> $this->db->f('entry_date'),
+						'ecodimb'		=> $this->db->f('ecodimb'),
+						'cat_id'		=> $this->db->f('category'),
 					);
 			}
 			return $budget;
@@ -446,7 +467,7 @@
 					$budget['revision'],
 					$budget['district_id'],
 					$budget['b_account_id'],
-					$budget['budget_cost'],
+					(int)$budget['budget_cost'],
 					$budget['ecodimb'],
 					$budget['cat_id']
 				);
@@ -476,7 +497,7 @@
 				(
 					'remark'		=> $budget['remark'],
 					'entry_date'	=> time(),
-					'budget_cost'	=> $budget['budget_cost'],
+					'budget_cost'	=> (int)$budget['budget_cost'],
 					'year'			=> $budget['year'],
 					'revision'		=> $budget['revision'],
 					'district_id'	=> $budget['district_id'],
@@ -497,59 +518,100 @@
 
 		function read_obligations($data)
 		{
-			//_debug_array($data);			
+			//_debug_array($data);
 			$start			= isset($data['start']) && $data['start'] ? $data['start'] : 0;
 			$filter			= isset($data['filter']) ? $data['filter'] : 'none';
 			$query			= isset($data['query']) ? $data['query'] : '';
 			$sort			= isset($data['sort']) ? $data['sort'] : 'DESC';
 			$order			= isset($data['order']) ? $data['order'] : '';
 			$allrows		= isset($data['allrows']) ? $data['allrows'] : '';
-			$district_id	= isset($data['district_id']) ? $data['district_id'] : '';
+			$filter_district_id	= isset($data['district_id']) && $data['district_id'] ? (int)$data['district_id'] : 0;
 			$year			= isset($data['year']) ? (int)$data['year'] : '';
 			$grouping		= isset($data['grouping']) ? $data['grouping'] : '';
 			$revision		= isset($data['revision']) ? $data['revision'] : 1;
-			$year			= isset($data['year']) ? $data['year'] : '';
+			$year			= isset($data['year']) &&  $data['year'] ? (int)$data['year'] : 0;
 			$cat_id			= isset($data['cat_id']) ? $data['cat_id'] : '';
 			$details		= isset($data['details']) ? $data['details'] : '';
 			$dimb_id		= isset($data['dimb_id'])  && $data['dimb_id'] ? (int)$data['dimb_id'] : 0;
+			$department		= isset($data['department'])  && $data['department'] ? (int)$data['department'] : 0;
+			$direction		= isset($data['direction'])  && $data['direction'] ? $data['direction'] : 'expences';
 
 			if(!$year)
 			{
 				return array();
 			}
-			//_debug_array($allrows);
-			$ordermethod = '';
+
+			$filtermethod_direction = '';
+
+			if($direction == 'income')
+			{
+				$filtermethod_direction = "fm_b_account.id {$this->like} '3%'";
+			}
+			else
+			{
+				$filtermethod_direction = "fm_b_account.id NOT {$this->like} '3%'";
+			}
+
 			/* 0 => cancelled, 1 => obligation , 2 => paid */
-			$filtermethod = "WHERE fm_workorder.paid = 1 and fm_workorder.vendor_id > 0";
+
+			$filtermethod = '';
 
 			$start_date = mktime(1, 1, 1, 1, 1, $year);
 			$end_date = mktime  (23, 59, 59, 12, 31, $year);
-//			$filtermethod .= " AND fm_workorder.start_date >= $start_date AND fm_workorder.start_date <= $end_date";
-			$filtermethod .= " AND fm_workorder_status.closed IS NULL AND fm_workorder.start_date <= $end_date";
+
+			$start_periode = date('Ym',mktime(2,0,0,1,1,$year));
+			$end_periode = date('Ym',mktime(2,0,0,12,31,$year));
+
+
+			$filtermethod = '';
+			$filtermethod_order = " WHERE (fm_workorder_budget.year = $year OR fm_workorder_status.closed IS NULL)";
 
 			$where = 'AND';
 
+			$cat_ids = array();
 			if ($cat_id > 0)
 			{
-				$filtermethod .= " $where fm_project.category = " . (int)$cat_id;
+				$cat_ids = $this->get_sub_cats($cat_id);
+			}
+
+			if($cat_ids)
+			{
+				$filtermethod .= " {$where} fm_workorder.category IN (". implode(',', $cat_ids) . ')';
 				$where = 'AND';
 			}
 
-			if ($district_id > 0)
+			if ($filter_district_id > 0)
 			{
-				$filtermethod .= " $where district_id=" . (int)$district_id;
+				$filtermethod .= " {$where} district_id=" . (int)$filter_district_id;
 				$where = 'AND';
 			}
 
 			if ($dimb_id > 0)
 			{
-				$filtermethod .= " $where fm_workorder.ecodimb={$dimb_id}";
+				$filtermethod .= " {$where} fm_project.ecodimb={$dimb_id}";
+				$where = 'AND';
+			}
+
+			$_department_dimb = array();
+			if ($department > 0)
+			{
+				$_department_dimb[] = -1;//block in case no one found
+				$this->db->query("SELECT id FROM fm_ecodimb WHERE department = $department ",__LINE__,__FILE__);
+				while ($this->db->next_record())
+				{
+					$_department_dimb[] = $this->db->f('id');
+				}
+			}
+
+			if($_department_dimb)
+			{
+				$filtermethod .= " $where fm_project.ecodimb IN (" . implode(',', $_department_dimb) . ')';
 				$where = 'AND';
 			}
 
 			if ($grouping > 0)
 			{
-				$filtermethod .= " $where fm_b_account.category='$grouping' ";
+				$filtermethod .= " $where fm_b_account.category='{$grouping}' ";
 				$where = 'AND';
 			}
 
@@ -559,6 +621,19 @@
 				$query = $this->db->db_addslashes($query);
 			}
  */
+			$config						= CreateObject('phpgwapi.config','property');
+			$config->read();
+
+			if(isset($config->config_data['location_at_workorder']) && $config->config_data['location_at_workorder'])
+			{
+				$_join_district =	"{$this->join} fm_locations ON fm_workorder.location_code = fm_locations.location_code"
+									. " {$this->join} fm_location1 ON fm_location1.loc1 = fm_locations.loc1";
+			}
+			else
+			{
+				$_join_district = "{$this->join} fm_location1 ON fm_project.loc1 = fm_location1.loc1";
+			}
+
 			if( $details )
 			{
 				$b_account_field = 'id';
@@ -568,30 +643,111 @@
 				$b_account_field = 'category';
 			}
 
-			$sql = "SELECT sum(combined_cost) as combined_cost, count(fm_workorder.id) as hits, fm_b_account.{$b_account_field} as {$b_account_field}, district_id, fm_workorder.ecodimb"
+			$this->db->query('SELECT id, percent FROM fm_ecomva',__LINE__,__FILE__);
+			$_taxcode = array(0 => 0);
+			while ($this->db->next_record())
+			{
+				$_taxcode[$this->db->f('id')] = $this->db->f('percent');
+			}
+
+			$sql = "SELECT DISTINCT fm_workorder.id AS id, fm_location1.mva,project_id,"
+				. " fm_b_account.{$b_account_field} AS b_account, district_id, fm_project.ecodimb"
 				. " FROM fm_workorder"
-				. " $this->join fm_workorder_status ON fm_workorder.status = fm_workorder_status.id"
-				. " $this->join fm_b_account ON fm_workorder.account_id = fm_b_account.id"
-				. " $this->join fm_project ON  fm_workorder.project_id = fm_project.id"
-				. " $this->join fm_location1 ON fm_project.loc1 = fm_location1.loc1"
-				. " $this->join fm_part_of_town ON fm_location1.part_of_town_id = fm_part_of_town.part_of_town_id"
-				. " $filtermethod $querymethod GROUP BY fm_b_account.{$b_account_field},district_id,fm_workorder.ecodimb";
+				. " {$this->join} fm_workorder_status ON fm_workorder.status = fm_workorder_status.id"
+				. " {$this->join} fm_workorder_budget ON (fm_workorder.id = fm_workorder_budget.order_id)"
+				. " {$this->join} fm_b_account ON fm_workorder.account_id = fm_b_account.id"
+				. " {$this->join} fm_project ON  fm_workorder.project_id = fm_project.id"
+				. " {$_join_district}"
+				. " {$this->join} fm_part_of_town ON fm_location1.part_of_town_id = fm_part_of_town.part_of_town_id"
+				. " {$filtermethod_order}{$filtermethod} {$querymethod} {$where} {$filtermethod_direction}"
+				. " ORDER BY fm_workorder.id ASC";
 
-			//_debug_array($sql);die();
-			$this->db->query($sql . $ordermethod,__LINE__,__FILE__);
+//			_debug_array($sql);
+			//die();
+			$this->db->query($sql,__LINE__,__FILE__);
+			$_temp_paid_info = array();
+$projects = array();
 
-			$obligations = array();
 
 			while ($this->db->next_record())
 			{
-				$obligations[$this->db->f($b_account_field)][$this->db->f('district_id')][(int)$this->db->f('ecodimb')] = round($this->db->f('combined_cost'));
-				$hits[$this->db->f($b_account_field)][$this->db->f('district_id')][(int)$this->db->f('ecodimb')] = $this->db->f('hits');
-				$accout_info[$this->db->f($b_account_field)] = true;
-				$district[$this->db->f('district_id')] = true;
-				$ecodimb[(int)$this->db->f('ecodimb')] = true;
-			}
 
-			//_debug_array($obligations);die();
+				$_id = $this->db->f('id');
+				$district_id = $filter_district_id ? (int)$this->db->f('district_id') : 0;
+
+
+$projects[$this->db->f('project_id')] = 0;
+$projects2[$_id] = $this->db->f('project_id');
+
+				$_temp_paid_info[$_id] = array
+				(
+					'actual_cost'			=> 0,
+					'mva'					=> (int)$this->db->f('mva'),
+					'district_id'			=> $district_id,
+					'ecodimb'				=> (int)$this->db->f('ecodimb'),
+					'b_account'				=> $this->db->f('b_account'),
+				);
+			}
+ksort($projects);
+//_debug_array(count($projects2));
+//_debug_array($projects2);
+
+			$soworkorder = CreateObject('property.soworkorder');
+
+			$sum_actual_cost = 0;
+			$actual_cost = array();
+			$sum_obligation_cost = 0;
+			$obligations = array();
+			$sum_hits = 0;
+
+			$sum_hits = count($_temp_paid_info);
+
+			foreach ($_temp_paid_info as $order_id => &$order_info)
+			{
+				$order_budget = $soworkorder->get_budget($order_id);
+//_debug_array($order_budget);
+				$_count = false;
+				foreach($order_budget as $budget)
+				{
+					if($budget['year'] == $year)
+					{
+/*
+$projects3[$projects2[$order_id]]['actual_cost']+= $budget['actual_cost'];
+$projects3[$projects2[$order_id]]['combined_cost']+= $budget['sum_orders'];
+$projects3[$projects2[$order_id]]['budget']+= $budget['budget'];
+$projects3[$projects2[$order_id]]['obligation']+= $budget['sum_oblications'];
+*/
+					//	$order_info['actual_cost']		= $budget['actual_cost'];
+					//	$order_info['combined_cost']	= $budget['sum_orders'];
+					//	$order_info['budget']			= $budget['budget'];
+					//	$order_info['obligation']		= $budget['sum_oblications'];
+
+						$sum_obligation_cost += $budget['sum_oblications'];
+						$obligations[$order_info['b_account']][$order_info['district_id']][$order_info['ecodimb']] += $budget['sum_oblications'];
+
+						$_taxfactor		= 1 + ($_taxcode[(int)$order_info['mva']]/100);
+						$_actual_cost	= round($budget['actual_cost']/$_taxfactor);
+
+//_debug_array($_test);
+
+						$sum_actual_cost += $_actual_cost;
+						$actual_cost[$order_info['b_account']][$order_info['district_id']][$order_info['ecodimb']] += $_actual_cost;
+					}
+
+					if(!$_count)
+					{
+						$hits[$order_info['b_account']][$order_info['district_id']][$order_info['ecodimb']] += 1;
+						$accout_info[$order_info['b_account']] = true;
+						$district[$order_info['district_id']] = true;
+						$ecodimb[$order_info['ecodimb']] = true;
+						$_count = true;
+					}
+				}
+			}
+//_debug_array($projects3);
+
+
+//			_debug_array($obligations);
 
 			//----------- ad hoc order
 			$filtermethod = "WHERE fm_tts_tickets.vendor_id > 0 AND budget > 0";
@@ -603,15 +759,15 @@
 
 			$where = 'AND';
 
-			if ($cat_id > 0)
+			if($cat_ids)
 			{
-				$filtermethod .= " $where fm_tts_tickets.cat_id = " . (int)$cat_id;
+				$filtermethod .= " $where fm_tts_tickets.cat_id IN (". implode(',', $cat_ids) . ')';
 				$where = 'AND';
 			}
 
-			if ($district_id > 0)
+			if ($filter_district_id > 0)
 			{
-				$filtermethod .= " $where district_id=" . (int)$district_id;
+				$filtermethod .= " $where district_id=" . (int)$filter_district_id;
 				$where = 'AND';
 			}
 
@@ -621,6 +777,12 @@
 				$where = 'AND';
 			}
 
+			if($_department_dimb)
+			{
+				$filtermethod .= " $where fm_tts_tickets.ecodimb IN (" . implode(',', $_department_dimb) . ')';
+				$where = 'AND';
+			}
+
 			if ($grouping > 0)
 			{
 				$filtermethod .= " $where fm_b_account.category='$grouping' ";
@@ -632,38 +794,48 @@
 				. " FROM fm_tts_tickets"
 				. " $this->join fm_b_account ON fm_tts_tickets.b_account_id = fm_b_account.id "
 				. " $this->join fm_location1 ON fm_tts_tickets.loc1 = fm_location1.loc1 "
-				. " $this->join fm_part_of_town ON fm_location1.part_of_town_id = fm_part_of_town.part_of_town_id $filtermethod $filtermethod2 $querymethod GROUP BY fm_b_account.{$b_account_field},district_id,fm_tts_tickets.ecodimb";
+				. " $this->join fm_part_of_town ON fm_location1.part_of_town_id = fm_part_of_town.part_of_town_id $filtermethod $filtermethod2 $querymethod  {$where} {$filtermethod_direction} GROUP BY fm_b_account.{$b_account_field},district_id,fm_tts_tickets.ecodimb";
 
 			//_debug_array($sql);die();
 			$this->db->query($sql . $ordermethod,__LINE__,__FILE__);
 
 			while ($this->db->next_record())
 			{
-				$obligations[$this->db->f($b_account_field)][$this->db->f('district_id')][(int)$this->db->f('ecodimb')] += round($this->db->f('budget'));
-				$hits[$this->db->f($b_account_field)][$this->db->f('district_id')][(int)$this->db->f('ecodimb')] += $this->db->f('hits');
+				$_budget = round($this->db->f('budget'));
+				$sum_obligation_cost += $_budget;
+				$_hits = $this->db->f('hits');
+				$sum_hits += $_hits;
+
+				$district_id = $filter_district_id ? (int)$this->db->f('district_id') : 0;
+				$obligations[$this->db->f($b_account_field)][$district_id][(int)$this->db->f('ecodimb')] += $_budget;
+				$hits[$this->db->f($b_account_field)][$district_id][(int)$this->db->f('ecodimb')] += $_hits;
 				$accout_info[$this->db->f($b_account_field)] = true;
-				$district[$this->db->f('district_id')] = true;
+				$district[$district_id] = true;
 				$ecodimb[(int)$this->db->f('ecodimb')] = true;
 			}
-			//_debug_array($obligations);die();
 
+			//_debug_array($obligations);die();
 
 			$sql = "SELECT sum(budget) as budget, count(fm_tts_tickets.id) as hits, fm_b_account.{$b_account_field} as {$b_account_field}, district_id, fm_tts_tickets.ecodimb"
 				. " FROM fm_tts_tickets"
 				. " $this->join fm_b_account ON fm_tts_tickets.b_account_id = fm_b_account.id "
 				. " $this->join fm_location1 ON fm_tts_tickets.loc1 = fm_location1.loc1 "
-				. " $this->join fm_part_of_town ON fm_location1.part_of_town_id = fm_part_of_town.part_of_town_id $filtermethod $querymethod GROUP BY fm_b_account.{$b_account_field},district_id,fm_tts_tickets.ecodimb";
+				. " $this->join fm_part_of_town ON fm_location1.part_of_town_id = fm_part_of_town.part_of_town_id $filtermethod $querymethod  {$where} {$filtermethod_direction} GROUP BY fm_b_account.{$b_account_field},district_id,fm_tts_tickets.ecodimb";
 
 
 			$sql = str_replace('budget', 'actual_cost', $sql);
 			$this->db->query($sql . $ordermethod,__LINE__,__FILE__);
 
-			$actual_cost = array();
 			while ($this->db->next_record())
 			{
-				$actual_cost[$this->db->f($b_account_field)][$this->db->f('district_id')][(int)$this->db->f('ecodimb')] = round($this->db->f('actual_cost'));
+				$_actual_cost = round($this->db->f('actual_cost'));
+				$sum_actual_cost += round($this->db->f('actual_cost'));
+
+				$district_id = $filter_district_id ? (int)$this->db->f('district_id') : 0;
+
+				$actual_cost[$this->db->f($b_account_field)][$district_id][(int)$this->db->f('ecodimb')] += $_actual_cost;
 				$accout_info[$this->db->f($b_account_field)] = true;
-				$district[$this->db->f('district_id')] = true;
+				$district[$district_id] = true;
 				$ecodimb[(int)$this->db->f('ecodimb')] = true;
 			}
 			//_debug_array($actual_cost);die();
@@ -677,8 +849,8 @@
 			$filtermethod = '';
 			$where = 'AND';
 			if ($grouping > 0)
-			{	
-				$filtermethod = " $where fm_b_account.category='$grouping' ";
+			{
+				$filtermethod .= " $where fm_b_account.category='$grouping' ";
 /*
 				if (!$details)
 				{
@@ -692,9 +864,15 @@
  */
 			}
 
-			if ($district_id > 0)
+			if($cat_ids)
 			{
-				$filtermethod .= " $where district_id='$district_id' ";
+				$filtermethod .= " $where fm_budget.category IN (". implode(',', $cat_ids) . ')';
+				$where = 'AND';
+			}
+
+			if ($filter_district_id > 0)
+			{
+				$filtermethod .= " $where district_id='$filter_district_id' ";
 				$where = 'AND';
 			}
 
@@ -704,77 +882,186 @@
 				$where = 'AND';
 			}
 
+			if($_department_dimb)
+			{
+				$filtermethod .= " $where ecodimb IN (" . implode(',', $_department_dimb) . ')';
+				$where = 'AND';
+			}
+
+
 			if( $details )
 			{
 				$sql = "SELECT budget_cost,b_account_id as b_account_field,district_id,ecodimb FROM fm_budget"
-					. " {$this->join} fm_b_account ON fm_budget.b_account_id =fm_b_account.id WHERE year={$year} AND revision = '$revision' $filtermethod GROUP BY budget_cost,b_account_id,district_id,ecodimb";
+					. " {$this->join} fm_b_account ON fm_budget.b_account_id =fm_b_account.id WHERE year={$year} AND revision = '$revision' $filtermethod {$where} {$filtermethod_direction}"
+					. " GROUP BY budget_cost,b_account_id,district_id,ecodimb";
 			}
 			else
 			{
 				$sql = "SELECT sum(budget_cost) as budget_cost ,fm_b_account.category as b_account_field,district_id,ecodimb FROM fm_budget"
-					. " $this->join fm_b_account ON fm_budget.b_account_id =fm_b_account.id WHERE year={$year} AND revision = '$revision' $filtermethod GROUP BY fm_b_account.category,district_id,ecodimb";
+					. " $this->join fm_b_account ON fm_budget.b_account_id =fm_b_account.id WHERE year={$year} AND revision = '$revision' $filtermethod  {$where} {$filtermethod_direction}"
+					. " GROUP BY fm_b_account.category,district_id,ecodimb";
 			}
 			//_debug_array($sql);
 			$this->db->query($sql,__LINE__,__FILE__);
 
+			$sum_budget_cost = 0;
 			$budget_cost = array();
 			while ($this->db->next_record())
 			{
-				$budget_cost[$this->db->f('b_account_field')][$this->db->f('district_id')][(int)$this->db->f('ecodimb')] = round($this->db->f('budget_cost'));
+				$_budget_cost = round($this->db->f('budget_cost'));
+				$district_id = $filter_district_id ? (int)$this->db->f('district_id') : 0;
+				$sum_budget_cost += $_budget_cost;
+				$budget_cost[$this->db->f('b_account_field')][$district_id][(int)$this->db->f('ecodimb')] += $_budget_cost;
 				$accout_info[$this->db->f('b_account_field')] = true;
-				$district[$this->db->f('district_id')] = true;
+				$district[$district_id] = true;
 				$ecodimb[(int)$this->db->f('ecodimb')] = true;
 			}
 
 			//_debug_array($budget_cost);die();
 
-			$filtermethod = '';
+// start service agreements
+
+			$filtermethod = " fm_s_agreement_budget.year = $year";
 			$where = 'AND';
 
-			if ($cat_id > 0)
+			if($cat_ids)
 			{
-				$filtermethod .= " $where fm_project.category = " . (int)$cat_id;
+				$filtermethod .= " $where fm_s_agreement.category IN (". implode(',', $cat_ids) . ')';
 				$where = 'AND';
 			}
 
 			if ($grouping > 0)
 			{
-				$filtermethod = " $where fm_b_account.category='$grouping' ";
-				$where = 'AND';
-			}
-
-			if ($district_id > 0)
-			{
-				$filtermethod .= " $where district_id='$district_id' ";
+				$filtermethod .= " $where fm_b_account.category='$grouping' ";
 				$where = 'AND';
 			}
 
 			if ($dimb_id > 0)
 			{
-				$filtermethod .= " $where dimb={$dimb_id}";
+				$filtermethod .= " $where fm_s_agreement_budget.ecodimb={$dimb_id}";
 				$where = 'AND';
 			}
 
-			$start_periode = date('Ym',mktime(2,0,0,1,1,$year));
-			$end_periode = date('Ym',mktime(2,0,0,12,31,$year));
+			if($_department_dimb)
+			{
+				$filtermethod .= " $where fm_s_agreement_budget.ecodimb IN (" . implode(',', $_department_dimb) . ')';
+				$where = 'AND';
+			}
 
-			$sql = "SELECT fm_b_account.{$b_account_field} as $b_account_field, district_id, sum(godkjentbelop) as actual_cost,dimb FROM fm_ecobilagoverf"
-				. " $this->join fm_b_account ON fm_ecobilagoverf.spbudact_code =fm_b_account.id"
-				. " $this->join fm_location1 ON fm_ecobilagoverf.loc1 = fm_location1.loc1"
-				. " $this->join fm_part_of_town ON fm_location1.part_of_town_id = fm_part_of_town.part_of_town_id"
-				. " WHERE periode >= $start_periode AND periode <= $end_periode {$filtermethod}"
-				. " GROUP BY fm_b_account.{$b_account_field}, district_id,dimb";
+			$sql = "SELECT sum(budget) as budget, count(fm_s_agreement.id) as hits, fm_b_account.{$b_account_field} as {$b_account_field}, fm_s_agreement_budget.ecodimb"
+				. " FROM fm_s_agreement"
+				. " {$this->join} fm_s_agreement_budget ON fm_s_agreement.id = fm_s_agreement_budget.agreement_id"
+				. " $this->join fm_b_account ON fm_s_agreement_budget.budget_account = fm_b_account.id "
+				. " WHERE $filtermethod $querymethod {$where} {$filtermethod_direction} GROUP BY fm_b_account.{$b_account_field},fm_s_agreement_budget.ecodimb";
 
-			//_debug_array($sql);
+			//_debug_array($sql);die();
+			$this->db->query($sql . $ordermethod,__LINE__,__FILE__);
+
+			$_dummy_district = $filter_district_id ? $filter_district_id : 0;
+			while ($this->db->next_record())
+			{
+				$_budget = round($this->db->f('budget'));
+				$sum_obligation_cost += $_budget;
+				$_hits = $this->db->f('hits');
+				$sum_hits += $_hits;
+
+				$obligations[$this->db->f($b_account_field)][$_dummy_district][(int)$this->db->f('ecodimb')] += $_budget;
+				$hits[$this->db->f($b_account_field)][$_dummy_district][(int)$this->db->f('ecodimb')] += $_hits;
+				$accout_info[$this->db->f($b_account_field)] = true;
+				$district[$_dummy_district] = true;
+				$ecodimb[(int)$this->db->f('ecodimb')] = true;
+			}
+
+
+//-------start check paid service agreement-----------
+
+			$sql = "SELECT fm_b_account.{$b_account_field} as {$b_account_field}, sum(fm_ecobilagoverf.godkjentbelop) as actual_cost,fm_s_agreement_budget.ecodimb"
+				. " FROM fm_ecobilagoverf"
+				. " {$this->join} fm_b_account ON fm_ecobilagoverf.spbudact_code =fm_b_account.id"
+				. " {$this->join} fm_s_agreement ON fm_ecobilagoverf.pmwrkord_code = fm_s_agreement.id"
+				. " {$this->join} fm_s_agreement_budget ON fm_s_agreement.id = fm_s_agreement_budget.agreement_id"
+				. " WHERE periode >= $start_periode AND periode <= $end_periode AND {$filtermethod} {$where} {$filtermethod_direction}"
+				. " GROUP BY fm_b_account.{$b_account_field}, ecodimb";
+//_debug_array($sql);
 			$this->db->query($sql,__LINE__,__FILE__);
 
 			while ($this->db->next_record())
 			{
-				$actual_cost[$this->db->f($b_account_field)][$this->db->f('district_id')][(int)$this->db->f('dimb')] += round($this->db->f('actual_cost'));
-				$accout_info[$this->db->f($b_account_field)] = true;
-				$district[$this->db->f('district_id')] = true;
+				$_actual_cost = round($this->db->f('actual_cost'));
+				$_account_value = $this->db->f($b_account_field);
+				$_dimb = (int)$this->db->f('ecodimb');
+
+				$sum_actual_cost += $_actual_cost;
+				$actual_cost[$_account_value][$_dummy_district][$_dimb] += $_actual_cost;
+				$obligations[$_account_value][$_dummy_district][$_dimb] -= $_actual_cost;
+				$accout_info[$_account_value] = true;
+				$district[$_dummy_district] = true;
 				$ecodimb[(int)$this->db->f('dimb')] = true;
 			}
+
+//-------end check paid-----------
+
+//-------start check active invoices service agreement-----------
+
+			$filtermethod = '';
+			$where = 'WHERE';
+
+			if($cat_ids)
+			{
+				$filtermethod .= " $where fm_s_agreement.category IN (". implode(',', $cat_ids) . ')';
+				$where = 'AND';
+			}
+
+			if ($grouping > 0)
+			{
+				$filtermethod .= " $where fm_b_account.category='$grouping' ";
+				$where = 'AND';
+			}
+
+			if ($dimb_id > 0)
+			{
+				$filtermethod .= " $where fm_s_agreement_budget.ecodimb={$dimb_id}";
+				$where = 'AND';
+			}
+
+			if($_department_dimb)
+			{
+				$filtermethod .= " $where fm_s_agreement_budget.ecodimb IN (" . implode(',', $_department_dimb) . ')';
+				$where = 'AND';
+			}
+
+			$sql = "SELECT fm_b_account.{$b_account_field} as {$b_account_field}, sum(fm_ecobilag.godkjentbelop) as actual_cost,fm_s_agreement_budget.ecodimb"
+				. " FROM fm_ecobilag"
+				. " {$this->join} fm_b_account ON fm_ecobilag.spbudact_code =fm_b_account.id"
+				. " {$this->join} fm_s_agreement ON fm_ecobilag.pmwrkord_code = fm_s_agreement.id"
+				. " {$this->join} fm_s_agreement_budget ON fm_s_agreement.id = fm_s_agreement_budget.agreement_id"
+				. " {$filtermethod} {$where} {$filtermethod_direction}"
+				. " GROUP BY fm_b_account.{$b_account_field}, ecodimb";
+//_debug_array($sql);
+			$this->db->query($sql,__LINE__,__FILE__);
+
+			while ($this->db->next_record())
+			{
+				$_actual_cost = round($this->db->f('actual_cost'));
+				$_account_value = $this->db->f($b_account_field);
+				$_dimb = (int)$this->db->f('ecodimb');
+
+				$sum_actual_cost += $_actual_cost;
+				$actual_cost[$_account_value][$_dummy_district][$_dimb] += $_actual_cost;
+				$obligations[$_account_value][$_dummy_district][$_dimb] -= $_actual_cost;
+				$accout_info[$_account_value] = true;
+				$district[$_dummy_district] = true;
+				$ecodimb[(int)$this->db->f('dimb')] = true;
+			}
+
+
+//-------end check active invoices-----------
+// end service agreements
+			$this->sum_budget_cost		= $sum_budget_cost;
+			$this->sum_obligation_cost	= $sum_obligation_cost;
+			$this->sum_actual_cost		= $sum_actual_cost;
+			$this->sum_hits 			= $sum_hits;
+
 			//_debug_array($actual_cost);die();
 			$result = array();
 
@@ -817,7 +1104,7 @@
 							{
 								$result[] = array(
 									'grouping'		=> $details ? '' : $b_account, 
-									'b_account'		=> $b_account,
+									'b_account'		=> $details ? $b_account : '',
 									'district_id'	=> $district_id,
 									'ecodimb'		=> $dimb,
 									'actual_cost'	=> isset($actual_cost[$b_account][$district_id][$dimb]) && $actual_cost[$b_account][$district_id][$dimb] ? round($actual_cost[$b_account][$district_id][$dimb]) : 0,
@@ -836,14 +1123,14 @@
 			//cramirez
 			if($this->total_records == 0)
 			{
-				return $result;				
+				return $result;
 			}
 
 			if(!$allrows)
 			{
 				$num_rows = isset($GLOBALS['phpgw_info']['user']['preferences']['common']['maxmatchs'])?intval($GLOBALS['phpgw_info']['user']['preferences']['common']['maxmatchs']):15;
 
-				//_debug_array(array($start,$this->total_records,$this->total_records,$num_rows));				
+				//_debug_array(array($start,$this->total_records,$this->total_records,$num_rows));
 				$page = ceil( ( $start / $this->total_records ) * ($this->total_records/ $num_rows) );
 
 				$out = array_chunk($result, $num_rows);
