@@ -24,7 +24,7 @@
 	* @internal Development of this application was funded by http://www.bergen.kommune.no/bbb_/ekstern/
 	* @package property
 	* @subpackage core
- 	* @version $Id: class.socommon.inc.php 6948 2011-02-07 08:06:45Z sigurdne $
+ 	* @version $Id: class.socommon.inc.php 9522 2012-06-06 12:59:29Z sigurdne $
 	*/
 
 	/**
@@ -167,7 +167,7 @@
 
 		function reset_fm_cache_userlist()
 		{
-			$this->db->query("DELETE FROM fm_cache WHERE name $this->like 'acl_userlist_%'",__LINE__,__FILE__, true);
+			$this->db->query("DELETE FROM fm_cache WHERE name {$this->like} 'acl_userlist_%'",__LINE__,__FILE__, true);
 			return $this->db->affected_rows();
 		}
 
@@ -306,8 +306,14 @@
 			return $entity;
 		}
 
+
 		function increment_id($name)
 		{
+			if(!$name)
+			{
+				throw new Exception("property_socommon::increment_id() - Missing name");
+			}
+
 			if($name == 'order') // FIXME: temporary hack
 			{
 				$name = 'workorder';
@@ -316,14 +322,24 @@
 			{
 				$name = 'workorder';
 			}
-			$this->db->query("SELECT value FROM fm_idgenerator WHERE name='{$name}'");
+
+			$this->db->query("SELECT name FROM fm_idgenerator WHERE name='{$name}'");
+			$this->db->next_record();
+			if(!$this->db->f('name'))
+			{
+				throw new Exception("property_socommon::increment_id() - not a valid name: '{$name}'");			
+			}
+
+			$now = time();
+			$this->db->query("SELECT value, start_date FROM fm_idgenerator WHERE name='{$name}' AND start_date < {$now} ORDER BY start_date DESC");
 			$this->db->next_record();
 			$next_id = $this->db->f('value') +1;
-
-			$this->db->query("UPDATE fm_idgenerator SET value = $next_id WHERE name = '{$name}'");
+			$start_date = (int)$this->db->f('start_date');
+			$this->db->query("UPDATE fm_idgenerator SET value = $next_id WHERE name = '{$name}' AND start_date = {$start_date}");
 			return $next_id;
 		}
 
+
 		function new_db($db ='' )
 		{
 			if(is_object($db))
@@ -397,4 +413,5 @@
 			}
 			return $access_location;
 		}
+
 	}
