@@ -24,7 +24,7 @@
 	* @internal Development of this application was funded by http://www.bergen.kommune.no/bbb_/ekstern/
 	* @package property
 	* @subpackage document
- 	* @version $Id: class.sodocument.inc.php 7098 2011-03-09 08:14:06Z sigurdne $
+ 	* @version $Id: class.sodocument.inc.php 11600 2014-01-16 14:44:14Z sigurdne $
 	*/
 
 	/**
@@ -149,10 +149,10 @@
 					'paranthesis'	=> $paranthesis,
 					'query'			=> $query,
 					'force_location'=> true,
-					'no_address'	=> true,
-					'uicol_address'=> true
+					'no_address'	=> false,
 				));
 
+
 				$this->bocommon->fm_cache('sql_document_' . $entity_id,$sql);
 
 				$this->uicols		= $this->bocommon->uicols;
@@ -174,7 +174,7 @@
 				$this->cols_extra	= $this->bocommon->fm_cache('cols_extra_document_' . $entity_id);
 			}
 
-			$groupmethod= " GROUP BY fm_document.location_code";
+			$groupmethod= " GROUP BY fm_document.location_code, fm_location1.loc1_name";
 
 			if ($entity_id)
 			{
@@ -182,6 +182,9 @@
 				$groupmethod.= " ,fm_document.p_entity_id,fm_entity_category.name,fm_document.p_num,fm_document.p_cat_id";
 			}
 
+			//FIXME
+			$groupmethod = '';
+
 			if ($order)
 			{
 				$ordermethod = " order by fm_document.$order $sort";
@@ -399,6 +402,11 @@
 
 		function add($document)
 		{
+			if(isset($document['link']) && $document['link'])
+			{
+				$document['link'] = str_replace('\\' , '/', $document['link']);	
+			}
+
 			while (is_array($document['location']) && list($input_name,$value) = each($document['location']))
 			{
 				if($value)
@@ -441,7 +449,7 @@
 
 			$values= array(
 				$this->db->db_addslashes($document['document_name']),
-				$document['link'],
+				$this->db->db_addslashes($document['link']),
 				$document['title'],
 				'public',
 				$document['doc_type'],
@@ -486,6 +494,12 @@
 
 		function edit($document)
 		{
+
+			if(isset($document['link']) && $document['link'])
+			{
+				$document['link'] = str_replace('\\' , '/', $document['link']);	
+			}
+
 			$receipt = array();
 			$value_set=array();
 			if (isset($document['location']) && is_array($document['location']))
@@ -523,7 +537,7 @@
 			$old_doc_type		= $this->db->f('category');
 			$old_coordinator	= $this->db->f('coordinator');
 			$old_document_name	= $this->db->f('document_name');
-			$old_link			= $this->db->f('link');
+			$old_link			= $this->db->f('link',true);
 			$old_location_code	= $this->db->f('location_code');
 			$old_p_entity_id	= $this->db->f('p_entity_id');
 			$old_p_cat_id		= $this->db->f('p_cat_id');
@@ -560,9 +574,9 @@
 				$document['document_name'] = $document['document_name_orig'];
 			}
 
-			if($old_link !=$document['link'] )
+			if($old_link != $document['link'] )
 			{
-				$this->historylog->add('L',$document['document_id'],$document['link'],$old_link);
+				$this->historylog->add('L',$document['document_id'],$this->db->db_addslashes($document['link']),$old_link);
 				$alter_link=true;
 			}
 
@@ -598,7 +612,7 @@
 			}
 
 			$value_set['document_name']	= $this->db->db_addslashes($document['document_name']);
-			$value_set['link']			= $document['link'];
+			$value_set['link']			= $this->db->db_addslashes($document['link']);
 			$value_set['title']			= $this->db->db_addslashes($document['title']);
 			$value_set['branch_id']		= $document['branch_id'];
 			$value_set['status']		= $document['status'];
