@@ -24,7 +24,7 @@
 	* @internal Development of this application was funded by http://www.bergen.kommune.no/bbb_/ekstern/
 	* @package property
 	* @subpackage admin
- 	* @version $Id: class.sogeneric.inc.php 7484 2011-08-08 12:44:31Z sigurdne $
+ 	* @version $Id: class.sogeneric.inc.php 11593 2014-01-09 13:59:35Z sigurdne $
 	*/
 
 	/**
@@ -39,8 +39,9 @@
 		var $location_info = array();
 		var $tree = array();
 		protected $table;
+		var $appname = 'property';
 
-		function __construct()
+		function __construct($type = '', $type_id = 0)
 		{
 			$this->account	= $GLOBALS['phpgw_info']['user']['account_id'];
 			$this->custom 	= createObject('property.custom_fields');
@@ -48,15 +49,22 @@
 			$this->_db2		= clone($this->_db);
 			$this->_like	= & $this->_db->like;
 			$this->_join	= & $this->_db->join;
+
+			if($type)
+			{
+				$this->get_location_info($type,$type_id);
+			}
+			
 		}
 
 		function read($data, $filter = array())
 		{
-			$start		= isset($data['start']) && $data['start'] ? $data['start']:0;
-			$query		= isset($data['query'])?$data['query']:'';
-			$sort		= isset($data['sort']) && $data['sort'] ? $data['sort']:'DESC';
-			$order		= isset($data['order'])?$data['order']:'';
-			$allrows	= isset($data['allrows'])?$data['allrows']:'';
+			$start				= isset($data['start']) && $data['start'] ? $data['start'] : 0;
+			$query				= isset($data['query']) ? $data['query']:'';
+			$sort				= isset($data['sort']) && $data['sort'] ? $data['sort'] : 'DESC';
+			$order				= isset($data['order']) ? $data['order'] : '';
+			$allrows			= isset($data['allrows']) ? $data['allrows'] : '';
+			$custom_criteria	= isset($data['custom_criteria']) && $data['custom_criteria'] ? $data['custom_criteria'] : array();
 
 			$values = array();
 			if (!isset($this->location_info['table']) || !$table = $this->location_info['table'])
@@ -64,6 +72,24 @@
 				return $values;
 			}
 
+			
+			$_join_method = array();
+			$_filter_array = array();
+			if($custom_criteria)
+			{
+				foreach ($custom_criteria as $_custom_criteria)
+				{
+					if(isset($this->location_info['custom_criteria'][$_custom_criteria]['join']) && is_array($this->location_info['custom_criteria'][$_custom_criteria]['join']))
+					{
+						$_join_method = array_merge($_join_method, $this->location_info['custom_criteria'][$_custom_criteria]['join']);
+					}
+					if(isset($this->location_info['custom_criteria'][$_custom_criteria]['filter']) && is_array($this->location_info['custom_criteria'][$_custom_criteria]['filter']))
+					{
+						$_filter_array = array_merge($_filter_array, $this->location_info['custom_criteria'][$_custom_criteria]['filter']);
+					}
+				}
+			}
+
 /*
 			$valid_order = false;
 
@@ -92,7 +118,7 @@
 				}			
 			}
  */
-			$_filter_array = array();
+
 			$get_single = array();
 			foreach ( $this->location_info['fields'] as $field )
 			{
@@ -178,6 +204,33 @@
 				$where = 'AND';
 			}
 
+			if(isset($this->location_info['filter']) && $this->location_info['filter'] && is_array($this->location_info['filter']))
+			{
+				$_filtermethod = array();
+				foreach($this->location_info['filter'] as $_argument => $_argument_value)
+				{
+					if(preg_match('/^##/', $_argument_value))
+					{
+						$_argument_value_name = trim($_argument_value,'#');
+						$_argument_value = $values[$_argument_value_name];
+					}
+					if(preg_match('/^\$this->/', $_argument_value))
+					{
+						$_argument_value_name = ltrim($_argument_value,'$this->');
+						$_argument_value = $this->$_argument_value_name;
+					}								
+					
+					$_filtermethod[] = "{$_argument} = '{$_argument_value}'";
+				}
+
+
+				if($_filtermethod)
+				{
+					$filtermethod = "{$where} " . implode(' AND ', $_filtermethod);
+					$where = 'AND';
+				}
+			}
+
 			if($_filter_array)
 			{
 				$filtermethod .= " $where " . implode(' AND ', $_filter_array);
@@ -263,7 +316,9 @@
 				$querymethod .= $_query_end;
 			}
 
-			$sql = "SELECT * FROM $table {$filtermethod} {$querymethod}";
+			$join_method = $_join_method ?  implode (' ', $_join_method) : '';
+
+			$sql = "SELECT DISTINCT {$table}.* FROM {$table} {$join_method} {$filtermethod} {$querymethod}";
 
 			$this->_db->query('SELECT count(*) as cnt ' . substr($sql,strripos($sql,'from')),__LINE__,__FILE__);
 			$this->_db->next_record();
@@ -288,7 +343,7 @@
 				{
 					$dataset[$j][$field] = array
 						(
-							'value'		=> $this->_db->f($field),
+							'value'		=> $this->_db->f($field,true),
 							'datatype'	=> $uicols['datatype'][$key],
 							'attrib_id'	=> $uicols['attib_id'][$key]
 						);
@@ -432,8 +487,31 @@
 								'name' => 'descr',
 								'descr' => lang('descr'),
 								'type' => 'varchar'
+							),
+							array
+							(
+								'name'			=> 'department',
+								'descr'			=> lang('department'),
+								'type'			=> 'select',
+								'nullable'		=> false,
+								'filter'		=> true,
+								'sortable'	=> true,
+								'values_def'	=> array
+								(
+									'valueset'		=> false,
+									'method'		=> 'property.bogeneric.get_list',
+									'method_input'	=> array('type' => 'department',	'selected' => '##department##')
+								)
 							)
 						),
+						'custom_criteria' => array
+						(
+							'dimb_role_user' => array
+							(
+								'join'		=> array("{$this->_db->join} fm_ecodimb_role_user ON fm_ecodimb.id = fm_ecodimb_role_user.ecodimb"),
+								'filter'	=> array('fm_ecodimb_role_user.user_id = ' . (int) $this->account)
+							)	
+						),
 						'edit_msg'	=> lang('edit'),
 						'add_msg'	=> lang('add'),
 						'name'		=> lang('dimb'),
@@ -464,6 +542,35 @@
 						'menu_selection' => 'admin::property::accounting::accounting_dimd'
 					);
 				break;
+			case 'periodization':
+				$info = array
+					(
+						'table' => 'fm_eco_periodization',
+						'id'				=> array('name' => 'id', 'type' => 'int'),
+						'fields'			=> array
+						(
+							array
+							(
+								'name' => 'descr',
+								'descr' => lang('descr'),
+								'type' => 'varchar'
+							),
+							array
+							(
+								'name' => 'active',
+								'descr' => lang('active'),
+								'type' => 'checkbox',
+								'default' => 'checked'
+							)
+						),
+						'edit_msg'	=> lang('edit'),
+						'add_msg'	=> lang('add'),
+						'name'		=> lang('periodization'),
+						'acl_app' 			=> 'property',
+						'acl_location' => '.admin',
+						'menu_selection' => 'admin::property::accounting::periodization'
+					);
+				break;
 			case 'tax':
 				$info = array
 					(
@@ -471,6 +578,12 @@
 						'id'				=> array('name' => 'id', 'type' => 'int'),
 						'fields'			=> array
 						(
+							array
+							(
+								'name' => 'percent',
+								'descr' => lang('percent'),
+								'type' => 'int'
+							),
 							array
 							(
 								'name' => 'descr',
@@ -684,7 +797,7 @@
 								'name'			=> 'member_of',
 								'descr'			=> lang('member'),
 								'type'			=> 'multiple_select',
-								'nullable'		=> false,
+								'nullable'		=> true,
 								'filter'		=> true,
 								'sortable'		=> false,
 								'hidden'		=> true,
@@ -1009,6 +1122,131 @@
 						'menu_selection' => 'admin::property::accounting::accounting_cats'
 					);
 				break;
+
+			case 'dimb_role':
+				$info = array
+					(
+						'table' 			=> 'fm_ecodimb_role',
+						'id'				=> array('name' => 'id', 'type' => 'int'),
+						'fields'			=> array
+						(
+							array
+							(
+								'name' => 'name',
+								'descr' => lang('name'),
+								'type' => 'varchar'
+							)
+						),
+						'edit_msg'			=> lang('edit role'),
+						'add_msg'			=> lang('add role'),
+						'name'				=> lang('dimb role'),
+						'acl_app' 			=> 'property',
+						'acl_location' 		=> '.admin',
+						'menu_selection' 	=> 'admin::property::accounting::dimb_role'
+					);
+				break;
+			case 'condition_survey_status':
+				$info = array
+					(
+						'table' 			=> 'fm_condition_survey_status',
+						'id'				=> array('name' => 'id', 'type' => 'int'),
+						'fields'			=> array
+						(
+							array
+							(
+								'name' => 'descr',
+								'descr' => lang('descr'),
+								'type' => 'varchar'
+							),
+							array
+							(
+								'name' => 'sorting',
+								'descr' => lang('sorting'),
+								'type' => 'integer',
+								'sortable'=> true
+							),
+							array
+							(
+								'name' => 'in_progress',
+								'descr' => lang('In progress'),
+								'type' => 'checkbox'
+							),
+							array
+							(
+								'name' => 'delivered',
+								'descr' => lang('delivered'),
+								'type' => 'checkbox'
+							),
+							array
+							(
+								'name' => 'closed',
+								'descr' => lang('closed'),
+								'type' => 'checkbox'
+							)
+						),
+						'edit_msg'			=> lang('edit status'),
+						'add_msg'			=> lang('add status'),
+						'name'				=> lang('request status'),
+						'acl_app' 			=> 'property',
+						'acl_location' 		=> '.admin',
+						'menu_selection'	=> 'admin::property::condition_survey_status'
+					);
+				break;
+
+			case 'request_responsible_unit':
+				$_lang_responsible_unit = lang('responsible unit');
+				$info = array
+					(
+						'table' 			=> 'fm_request_responsible_unit',
+						'id'				=> array('name' => 'id', 'type' => 'int'),
+						'fields'			=> array
+						(
+							array
+							(
+								'name' => 'name',
+								'descr' => lang('name'),
+								'type' => 'varchar'
+							),
+							array
+							(
+								'name' => 'descr',
+								'descr' => lang('descr'),
+								'type' => 'varchar'
+							)
+						),
+						'edit_msg'			=> lang('edit') . ' ' . $_lang_responsible_unit,
+						'add_msg'			=> lang('add') . ' ' . $_lang_responsible_unit,
+						'name'				=> $_lang_responsible_unit,
+						'acl_app' 			=> 'property',
+						'acl_location' 		=> '.admin',
+						'menu_selection'	=> 'admin::property::request_responsible_unit'
+					);
+				break;
+
+			case 'ticket_priority':
+				$_lang_priority = lang('priority');
+				$info = array
+					(
+						'table' 			=> 'fm_tts_priority',
+						'id'				=> array('name' => 'id', 'type' => 'int'),
+						'fields'			=> array
+						(
+							array
+							(
+								'name' => 'name',
+								'descr' => lang('name'),
+								'type' => 'varchar'
+							),
+						),
+						'edit_msg'			=> lang('edit') . ' ' . $_lang_priority,
+						'add_msg'			=> lang('add') . ' ' . $_lang_priority,
+						'name'				=> $_lang_priority,
+						'acl_app' 			=> 'property',
+						'acl_location' 		=> '.admin',
+						'menu_selection'	=> 'admin::property::ticket::ticket_priority'
+					);
+				break;
+
 				//-------- ID type varchar
 			case 'project_status':
 				$info = array
@@ -1160,6 +1398,12 @@
 					);
 				break;
 			case 'building_part':
+
+				$config				= CreateObject('phpgwapi.config','property');
+				$config->read();
+			
+				$filter_buildingpart = isset($config->config_data['filter_buildingpart']) ? $config->config_data['filter_buildingpart'] : array();
+			
 				$info = array
 					(
 						'table' 			=> 'fm_building_part',
@@ -1171,7 +1415,56 @@
 								'name' => 'descr',
 								'descr' => lang('descr'),
 								'type' => 'varchar'
-							)
+							),
+							array
+							(
+								'name' => 'filter_1',
+								'descr' => isset($filter_buildingpart[1]) &&  $filter_buildingpart[1] ? $filter_buildingpart[1] : 'Filter 1',
+								'type' => 'checkbox',
+								'filter'	=> true,
+								'sortable'	=> true,
+								'values_def'	=> array
+								(
+									'valueset'		=> array(array('id' => 1, 'name' => lang('active'))),
+								)
+
+							),
+							array
+							(
+								'name' => 'filter_2',
+								'descr' => isset($filter_buildingpart[2]) &&  $filter_buildingpart[2] ? $filter_buildingpart[2] : 'Filter 2',
+								'type' => 'checkbox',
+								'filter'	=> true,
+								'sortable'	=> true,
+								'values_def'	=> array
+								(
+									'valueset'		=> array(array('id' => 1, 'name' => lang('active'))),
+								)
+							),
+							array
+							(
+								'name' => 'filter_3',
+								'descr' => isset($filter_buildingpart[3]) &&  $filter_buildingpart[3] ? $filter_buildingpart[3] : 'Filter 3',
+								'type' => 'checkbox',
+								'filter'	=> true,
+								'sortable'	=> true,
+								'values_def'	=> array
+								(
+									'valueset'		=> array(array('id' => 1, 'name' => lang('active'))),
+								)
+							),
+							array
+							(
+								'name' => 'filter_4',
+								'descr' => isset($filter_buildingpart[4]) &&  $filter_buildingpart[4] ? $filter_buildingpart[4] : 'Filter 4',
+								'type' => 'checkbox',
+								'filter'	=> true,
+								'sortable'	=> true,
+								'values_def'	=> array
+								(
+									'valueset'		=> array(array('id' => 1, 'name' => lang('active'))),
+								)
+							),
 						),
 						'edit_msg'			=> lang('edit'),
 						'add_msg'			=> lang('add'),
@@ -1207,9 +1500,15 @@
 				$info = array
 					(
 						'table' 			=> 'fm_standard_unit',
-						'id'				=> array('name' => 'id', 'type' => 'varchar'),
+						'id'				=> array('name' => 'id', 'type' => 'int'),
 						'fields'			=> array
 						(
+							array
+							(
+								'name' => 'name',
+								'descr' => lang('name'),
+								'type' => 'varchar'
+							),
 							array
 							(
 								'name' => 'descr',
@@ -1332,7 +1631,133 @@
 					);
 				break;
 
+			case 'department':
+
+				$info = array
+					(
+						'table' 			=> 'fm_department',
+						'id'				=> array('name' => 'id', 'type' => 'int'),
+						'fields'			=> array
+						(
+							array
+							(
+								'name' => 'name',
+								'descr' => lang('name'),
+								'type' => 'varchar',
+								'nullable'	=> false,
+								'size'		=> 60,
+								'sortable'	=> true
+							),
+							array
+							(
+								'name'			=> 'parent_id',
+								'descr'			=> lang('parent'),
+								'type'			=> 'select',
+								'sortable'		=> true,
+								'nullable'		=> true,
+								'filter'		=> false,
+								'role'			=> 'parent',
+								'values_def'	=> array
+								(
+									'valueset'		=> false,
+									'method'		=> 'property.bogeneric.get_list',
+									'method_input'	=> array('type' => 'department', 'role' => 'parent', 'selected' => '##parent_id##')
+								)
+							)
+						),
+						'edit_msg'			=> lang('edit'),
+						'add_msg'			=> lang('add'),
+						'name'				=> lang('department'),
+						'acl_app' 			=> 'property',
+						'acl_location' 		=> '.admin',
+						'menu_selection' 	=> 'admin::property::accounting::department',
+						'default'			=> array
+							(
+								'created_by' 	=> array('add'		=> '$this->account'),
+								'created_on'	=> array('add'		=> 'time()'),
+								'modified_by' 	=> array('edit'	=> '$this->account'),
+								'modified_on'	=> array('edit'	=> 'time()'),
+							),
+						'check_grant'		=> false	
+					);
+				break;
+
 				//-------- ID type auto
+
+			case 'dimb_role_user':
+
+				$info = array
+					(
+						'table' 			=> 'fm_ecodimb_role_user',
+						'id'				=> array('name' => 'id', 'type' => 'auto'),
+						'fields'			=> array
+						(
+							array
+							(
+								'name'			=> 'ecodimb',
+								'descr'			=> lang('dim b'),
+								'type'			=> 'select',
+								'nullable'		=> false,
+								'filter'		=> true,
+								'sortable'	=> true,
+								'values_def'	=> array
+								(
+									'valueset'		=> false,
+									'method'		=> 'property.bogeneric.get_list',
+									'method_input'	=> array('type' => 'dimb',	'selected' => '##ecodimb##')//b_account_category
+								)
+							),
+							array
+							(
+								'name'			=> 'role_id',
+								'descr'			=> lang('role type'),
+								'type'			=> 'select',
+								'filter'		=> true,
+								'sortable'	=> true,
+								'values_def'	=> array
+								(
+									'valueset'		=> false,
+									'method'		=> 'property.bogeneric.get_list',
+									'method_input'	=> array('type' => 'dimb_role',	'selected' => '##role_id##')
+								)
+							),
+							array
+							(
+								'name'			=> 'user_id',
+								'descr'			=> lang('user'),
+								'type'			=> 'select',
+								'filter'		=> true,
+								'get_single'	=> 'get_user',
+								'values_def'	=> array
+								(
+									'valueset'		=> false,
+									'method'		=> 'property.bocommon.get_user_list_right2',
+									'method_input'	=> array('selected' => '##user_id##', 'right' => 1, 'acl_location' => '.invoice')
+								)
+							),
+							array
+							(
+								'name' => 'default_user',
+								'descr' => lang('default'),
+								'type' => 'checkbox',
+								'default' => 'checked'
+							),
+						),
+						'edit_msg'			=> lang('edit'),
+						'add_msg'			=> lang('add'),
+						'name'				=> lang('dimb role'),
+						'acl_app' 			=> 'property',
+						'acl_location' 		=> '.admin',
+						'menu_selection' 	=> 'admin::property::accounting::dimb_role_user',
+						'default'			=> array
+							(
+								'created_by' 	=> array('add'	=> '$this->account'),
+								'created_on'	=> array('add'	=> 'time()'),
+							),
+						'check_grant'		=> false	
+					);
+				break;
+
 			case 'order_dim1':
 				$info = array
 					(
@@ -1457,7 +1882,6 @@
 				break;
 
 			case 'event_action':
-
 				$info = array
 					(
 						'table' 			=> 'fm_event_action',
@@ -1565,10 +1989,10 @@
 						),
 						'edit_msg'			=> lang('edit'),
 						'add_msg'			=> lang('add'),
-						'name'				=> lang('event action'),
+						'name'				=> lang('ticket status'),
 						'acl_app' 			=> 'property',
 						'acl_location' 		=> '.admin',
-						'menu_selection'	=> 'admin::property::ticket_status'
+						'menu_selection'	=> 'admin::property::ticket::ticket_status'
 					);
 				break;
 
@@ -1832,14 +2256,15 @@
 							),
 							array
 							(
-								'name'			=> 'location',
-								'descr'			=> lang('location'),
+								'name'			=> 'location_level',
+								'descr'			=> lang('location level'),
 								'type'			=> 'select',
 								'values_def'	=> array
 								(
 									'valueset'		=> false,
 									'method'		=> 'preferences.boadmin_acl.get_locations',
 									'method_input'	=> array('acl_app' => 'property',	'selected' => '##location##')
+//									'method_input'	=> array('acl_app' => '$this->appname',	'selected' => '##location##', 'have_categories' => true)
 								)
 							),
 							array
@@ -1851,10 +2276,11 @@
 								(
 									'valueset'		=> false,
 									'method'		=> 'property.boresponsible.get_responsibilities',
-									'method_input'	=> array('acl_app' => 'property',	'selected' => '##responsibility_id##')
+									'method_input'	=> array('appname' => '$this->appname',	'selected' => '##responsibility_id##')
 								)
 							)
 						),
+						'edit_action'		=> 'property.uiresponsible.edit_role',
 						'edit_msg'			=> lang('edit'),
 						'add_msg'			=> lang('add'),
 						'name'				=> lang('responsibility role'),
@@ -1863,11 +2289,13 @@
 						'menu_selection'	=> 'admin::property::responsibility_role',
 						'default'			=> array
 						(
+							'appname'		=> array('add'	=> '$this->appname'),
 							'user_id' 		=> array('add'	=> '$this->account'),
 							'entry_date'	=> array('add'	=> 'time()'),
 							'modified_date'	=> array('edit'	=> 'time()'),
 						),
-						'check_grant'		=> false
+						'check_grant'		=> false,
+						'filter'			=> array('appname' => '$this->appname')
 					);
 
 				break;
@@ -1955,6 +2383,242 @@
 					);
 
 				break;
+			case 'location_contact':
+				$info = array
+					(
+						'table' 			=> 'fm_location_contact',
+						'id'				=> array('name' => 'id', 'type' => 'auto'),
+						'fields'			=> array
+						(
+							array
+							(
+								'name' => 'contact_id',
+								'descr' => lang('contact'),
+								'type' => 'int',//contact
+								'nullable'	=> false,
+							),
+							array
+							(
+								'name' => 'location_code',
+								'descr' => lang('location_code'),
+								'type' => 'varchar',//location
+								'nullable'	=> false,
+							)
+						),
+						'edit_msg'			=> lang('edit'),
+						'add_msg'			=> lang('add'),
+						'name'				=> lang('location contact'),
+						'acl_app' 			=> 'property',
+						'acl_location' 		=> '.admin',
+						'menu_selection'	=> 'admin::property::location::location_contact',
+						'default'			=> array
+						(
+							'user_id' 		=> array('add'	=> '$this->account'),
+							'entry_date'	=> array('add'	=> 'time()'),
+							'modified_date'	=> array('edit'	=> 'time()'),
+						)
+					);
+
+				break;
+
+			case 'periodization_outline':
+				$valueset_month = array();
+
+				for ($i=1;$i<13;$i++)
+				{
+					$valueset_month[] = array
+					(
+						'id'	=> $i,
+						'name'	=> $i
+					);
+				}
+
+				$info = array
+					(
+						'table' 			=> 'fm_eco_periodization_outline',
+						'id'				=> array('name' => 'id', 'type' => 'auto'),
+						'fields'			=> array
+						(
+							array
+							(
+								'name'			=> 'periodization_id',
+								'descr'			=> lang('periodization'),
+								'type'			=> 'select',
+								'nullable'		=> false,
+								'filter'		=> true,
+								'sortable'	=> true,
+								'values_def'	=> array
+								(
+									'valueset'		=> false,
+									'method'		=> 'property.bogeneric.get_list',
+									'method_input'	=> array('type' => 'periodization',	'selected' => '##periodization_id##')
+								)
+							),
+							array
+							(
+								'name'			=> 'month',
+								'descr'			=> lang('month'),
+								'type'			=> 'select',
+								'nullable'		=> false,
+								'filter'		=> true,
+								'sortable'	=> true,
+								'values_def'	=> array
+								(
+									'valueset'		=> $valueset_month,
+								)
+							),
+							array
+							(
+								'name'		=> 'value',
+								'descr'		=> lang('value'),
+								'type'		=> 'numeric',
+								'nullable'	=> true,
+								'size'		=> 4,
+								'sortable'	=> true
+							),
+							array
+							(
+								'name'		=> 'dividend',
+								'descr'		=> lang('fraction::dividend'),
+								'type'		=> 'integer',
+								'nullable'	=> true,
+								'size'		=> 4,
+								'sortable'	=> true
+							),
+							array
+							(
+								'name'		=> 'divisor',
+								'descr'		=> lang('fraction::divisor'),
+								'type'		=> 'integer',
+								'nullable'	=> true,
+								'size'		=> 4,
+								'sortable'	=> true
+							),
+
+							array
+							(
+								'name' => 'remark',
+								'descr' => lang('remark'),
+								'type' => 'varchar',
+								'nullable'	=> false,
+								'size'		=> 60,
+								'sortable'	=> true
+							)
+						),
+						'edit_msg'			=> lang('edit'),
+						'add_msg'			=> lang('add'),
+						'name'				=> lang('periodization'),
+						'acl_app' 			=> 'property',
+						'acl_location' => '.admin',
+						'menu_selection' => 'admin::property::accounting::periodization_outline'
+					);
+
+				break;
+
+			case 'period_transition':
+				$valueset_month = array();
+				$valueset_day = array();
+				$valueset_hour = array();
+
+				$lang_default = lang('default');
+				for ($i=1;$i<14;$i++)
+				{
+					$valueset_month[] = array
+					(
+						'id'	=> $i,
+						'name'	=> $i == 13 ?  "{$i} ({$lang_default})" : $i
+					);
+				}
+
+				for ($i=1;$i<32;$i++)
+				{
+					$valueset_day[] = array
+					(
+						'id'	=> $i,
+						'name'	=> $i
+					);
+				}
+
+				for ($i=1;$i<25;$i++)
+				{
+					$valueset_hour[] = array
+					(
+						'id'	=> $i,
+						'name'	=> $i
+					);
+				}
+
+				$info = array
+					(
+						'table' 			=> 'fm_eco_period_transition',
+						'id'				=> array('name' => 'id', 'type' => 'auto'),
+						'fields'			=> array
+						(
+							array
+							(
+								'name'			=> 'month',
+								'descr'			=> lang('month'),
+								'type'			=> 'select',
+								'nullable'		=> false,
+								'filter'		=> true,
+								'sortable'		=> true,
+								'values_def'	=> array
+								(
+									'valueset'		=> $valueset_month,
+								)
+							),
+							array
+							(
+								'name'		=> 'day',
+								'descr'		=> lang('day'),
+								'type'		=> 'select',
+								'nullable'	=> false,
+								'size'		=> 4,
+								'sortable'	=> true,
+								'values_def'	=> array
+								(
+									'valueset'		=> $valueset_day,
+								)
+							),
+							array
+							(
+								'name'		=> 'hour',
+								'descr'		=> lang('hour'),
+								'type'		=> 'select',
+								'nullable'	=> true,
+								'size'		=> 4,
+								'sortable'	=> true,
+								'values_def'	=> array
+								(
+									'valueset'		=> $valueset_hour,
+								)
+							),
+							array
+							(
+								'name'		=> 'remark',
+								'descr'		=> lang('remark'),
+								'type'		=> 'varchar',
+								'nullable'	=> true,
+								'size'		=> 60,
+								'sortable'	=> true
+							)
+						),
+						'edit_msg'			=> lang('edit'),
+						'add_msg'			=> lang('add'),
+						'name'				=> lang('period transition'),
+						'acl_app' 			=> 'property',
+						'acl_location' => '.admin',
+						'menu_selection' => 'admin::property::accounting::period_transition',
+						'default'			=> array
+						(
+							'user_id' 		=> array('add'	=> '$this->account'),
+							'entry_date'	=> array('add'	=> 'time()'),
+							'modified_date'	=> array('edit'	=> 'time()'),
+						)
+					);
+
+				break;
+
 // START BOOKING TABLES
 			case 'bb_office':
 				$info = array
@@ -1968,6 +2632,12 @@
 								'name' => 'name',
 								'descr' => lang('name'),
 								'type' => 'varchar'
+							),
+							array
+							(
+								'name' => 'description',
+								'descr' => lang('description'),
+								'type' => 'text'
 							)
 						),
 						'edit_msg'			=> lang('edit'),
@@ -2025,6 +2695,58 @@
 				break;
 
 // END BOOKING TABLES
+// START CONTROLLER TABLES
+			case 'controller_check_item_status':
+				$info = array
+					(
+						'table' 			=> 'controller_check_item_status',
+						'id'				=> array('name' => 'id', 'type' => 'auto'),
+						'fields'			=> array
+						(
+							array
+							(
+								'name' => 'name',
+								'descr' => lang('name'),
+								'type' => 'varchar'
+							),
+							array
+							(
+								'name' => 'sorting',
+								'descr' => lang('sorting'),
+								'type' => 'integer',
+								'sortable'=> true
+							),
+							array
+							(
+								'name' => 'open',
+								'descr' => lang('open'),
+								'type' => 'checkbox'
+							),
+							array
+							(
+								'name' => 'pending',
+								'descr' => lang('pending'),
+								'type' => 'checkbox'
+							),
+							array
+							(
+								'name' => 'closed',
+								'descr' => lang('closed'),
+								'type' => 'checkbox'
+							)
+						),
+						'edit_msg'			=> lang('edit'),
+						'add_msg'			=> lang('add'),
+						'name'				=> lang('status'),
+						'acl_app' 			=> 'controller',
+						'acl_location' 		=> 'admin',
+						'menu_selection'	=> 'admin::controller::check_item_status'
+					);
+				break;
+
+// END CONTROLLER TABLES
+
+
 			default:
 				$message =lang('ERROR: illegal type %1', $type);
 				phpgwapi_cache::message_set($message, 'error');
@@ -2069,7 +2791,7 @@
 				{
 					foreach ( $values['attributes'] as &$attr )
 					{
-						$attr['value'] 	= $this->_db->f($attr['column_name']);
+						$attr['value'] 	= $this->_db->f($attr['column_name'], true);
 					}
 				}
 			}
@@ -2100,7 +2822,14 @@
 				$_filter = array();
 				foreach ($data['filter'] as $_field => $_value)
 				{
-					$_filter[] = "{$_field} = '{$_value}'";
+					if($data['filter_method'] == 'like')
+					{
+						$_filter[] = "{$_field} {$this->_db->like} '%{$_value}%'";
+					}
+					else
+					{
+						$_filter[] = "{$_field} = '{$_value}'";
+					}
 				}
 				if($_filter)
 				{
@@ -2189,6 +2918,15 @@
 			{
 				unset($data['apply']);
 			}
+			
+			// in case of backslash characters - as in path-references
+			foreach($data as $_key => &$_value)
+			{
+				$_value = str_replace('\\' , '/', $_value);	
+			}
+			unset($_key);
+			unset($_value);
+
 
 			foreach ( $this->location_info['fields'] as $field )
 			{
@@ -2296,6 +3034,7 @@
 
 		function edit($data,$values_attribute)
 		{
+
 			$receipt = array();
 
 			if (!isset($this->location_info['table']) || !$table = $this->location_info['table'])
@@ -2304,6 +3043,14 @@
 				return $receipt;
 			}
 
+			// in case of backslash characters - as in path-references
+			foreach($data as $_key => &$_value)
+			{
+				$_value = str_replace('\\' , '/', $_value);	
+			}
+			unset($_key);
+			unset($_value);
+
 			$value_set = array();
 
 			if(isset($data['extra']))
@@ -2548,6 +3295,7 @@
 
 		public function get_children2($data, $parent, $level, $reset = false)
 		{
+			$parent = (int)$parent;
 			$mapping = array();
 			if(isset($data['mapping']) && $data['mapping'])
 			{
@@ -2568,6 +3316,7 @@
 				return $this->tree;
 			}
 			$sql = "SELECT * FROM {$table} WHERE parent_id = {$parent}";
+
 			$db->query($sql,__LINE__,__FILE__);
 
 			while ($db->next_record())
@@ -2577,9 +3326,9 @@
 				(
 					'id'		=> $id,
 					'name'		=> str_repeat('..',$level) . $db->f($mapping['name'],true),
-					'parent_id'	=> $db->f('parent_id')
+					'parent_id'	=> $parent
 				);
-				$this->get_children2($id, $level+1);
+				$this->get_children2($data, $id, $level+1);
 			}
 			return $this->tree;
 		} 
