@@ -24,7 +24,7 @@
 	* @internal Development of this application was funded by http://www.bergen.kommune.no/bbb_/ekstern/
 	* @package property
 	* @subpackage location
- 	* @version $Id: class.solocation.inc.php 7434 2011-06-27 13:36:06Z sigurdne $
+ 	* @version $Id: class.solocation.inc.php 11524 2013-12-10 20:24:15Z sigurdne $
 	*/
 
 	/**
@@ -61,8 +61,10 @@
 			$this->like			= & $this->db->like;
 		}
 
-		function read_entity_to_link($location_code)
+		function read_entity_to_link($location_code, $exact = false)
 		{
+			$condition = $exact ? "= '{$location_code}'" : "{$this->like} '{$location_code}%'";
+			
 			$entity = array();
 
 			$type_app = execMethod('property.soentity.get_type_app');
@@ -86,13 +88,26 @@
 							'entity_id'	=> $this->db->f('entity_id'),
 							'cat_id'	=> $this->db->f('id'),
 							'name'		=> $this->db->f('name'),
-							'descr'		=> $this->db->f('descr')
+							'descr'		=> $this->db->f('descr'),
+							'is_eav'	=> $this->db->f('is_eav')
 						);
 				}
 
 				foreach($category as $entry)
 				{
-					$sql = "SELECT count(*) as hits FROM fm_{$type}_{$entry['entity_id']}_{$entry['cat_id']} WHERE location_code $this->like '$location_code%'";
+					if($entry['is_eav'])
+					{
+						$location_id = $GLOBALS['phpgw']->locations->get_id($app, ".{$type}.{$entry['entity_id']}.{$entry['cat_id']}");	
+						$this->db->query("SELECT id as bim_type FROM fm_bim_type WHERE location_id = {$location_id}",__LINE__,__FILE__);
+						$this->db->next_record();
+						$bim_type = (int)$this->db->f('bim_type');
+						$sql = "SELECT count(*) as hits FROM fm_bim_item WHERE location_code {$condition} AND type = {$bim_type}";					
+					}
+					else
+					{
+						$sql = "SELECT count(*) as hits FROM fm_{$type}_{$entry['entity_id']}_{$entry['cat_id']} WHERE location_code {$condition}";
+					}
+
 					$this->db->query($sql,__LINE__,__FILE__);
 					$this->db->next_record();
 					if($this->db->f('hits'))
@@ -115,7 +130,7 @@
 				}
 			}
 
-			$sql = "SELECT count(*) as hits FROM fm_tts_tickets WHERE location_code $this->like '$location_code%'";
+			$sql = "SELECT count(*) as hits FROM fm_tts_tickets WHERE location_code {$condition}";
 			$this->db->query($sql,__LINE__,__FILE__);
 			$this->db->next_record();
 			if($this->db->f('hits'))
@@ -129,7 +144,7 @@
 					);
 			}
 
-			$sql = "SELECT count(*) as hits FROM fm_request WHERE location_code $this->like '$location_code%'";
+			$sql = "SELECT count(*) as hits FROM fm_request WHERE location_code {$condition}";
 			$this->db->query($sql,__LINE__,__FILE__);
 			$this->db->next_record();
 			if($this->db->f('hits'))
@@ -143,7 +158,7 @@
 					);
 			}
 
-			$sql = "SELECT count(*) as hits FROM fm_project WHERE location_code $this->like '$location_code%'";
+			$sql = "SELECT count(*) as hits FROM fm_project WHERE location_code {$condition}";
 			$this->db->query($sql,__LINE__,__FILE__);
 			$this->db->next_record();
 			if($this->db->f('hits'))
@@ -157,7 +172,7 @@
 					);
 			}
 
-			$sql = "SELECT count(*) as hits FROM fm_gab_location WHERE location_code $this->like '$location_code%'";
+			$sql = "SELECT count(*) as hits FROM fm_gab_location WHERE location_code {$condition}";
 			$this->db->query($sql,__LINE__,__FILE__);
 			$this->db->next_record();
 			if($this->db->f('hits'))
@@ -172,16 +187,19 @@
 			}
 
 
-			$sql = "SELECT count(*) as hits FROM fm_s_agreement {$this->join} fm_s_agreement_detail ON fm_s_agreement.id = fm_s_agreement_detail.agreement_id WHERE location_code {$this->like} '$location_code%'";
+			$sql = "SELECT DISTINCT fm_s_agreement.id FROM fm_s_agreement"
+			. " {$this->join} fm_s_agreement_detail ON fm_s_agreement.id = fm_s_agreement_detail.agreement_id"
+			. " WHERE location_code {$condition}"
+			. " GROUP BY fm_s_agreement.id";
 			$this->db->query($sql,__LINE__,__FILE__);
-			$this->db->next_record();
-			if($this->db->f('hits'))
+			$hits = $this->db->num_rows();
+
+			if( $hits )
 			{
-				$hits = $this->db->f('hits');
 				$entity['related'][] = array
 					(
 						'entity_link'	=> $GLOBALS['phpgw']->link('/index.php',array('menuaction' => 'property.uis_agreement.index',
-																'query'=> $location_code)),
+																'location_code'=> $location_code)),
 						'name'			=> lang('service agreement') . " [{$hits}]",
 						'descr'			=> lang('service agreement')
 					);
@@ -264,7 +282,7 @@
 			$start					= isset($data['start']) && $data['start'] ? $data['start'] : 0;
 			$filter					= isset($data['filter']) && $data['filter'] ? $data['filter'] : 0;
 			$query					= isset($data['query']) ? $data['query'] : '';
-			$sort					= isset($data['sort']) && $data['sort'] ? $data['sort'] : 'DESC';
+			$sort					= isset($data['sort']) && $data['sort'] ? $data['sort'] : 'ASC';
 			$order					= isset($data['order']) ? $data['order'] : '';
 			$cat_id					= isset($data['cat_id']) && $data['cat_id'] ? $data['cat_id']:'';
 			$type_id				= isset($data['type_id']) ? $data['type_id'] : '';
@@ -278,6 +296,9 @@
 			$location_code			= isset($data['location_code']) ? $data['location_code'] : '';
 			$filter_role_on_contact = $data['filter_role_on_contact'] ? (int)$data['filter_role_on_contact'] : 0;
 			$role_id				= $data['role_id'] ? (int)$data['role_id'] : 0;
+			$results				= $data['results'] ? (int)$data['results'] : 0;
+			$control_registered		= isset($data['control_registered']) ? $data['control_registered'] : '';
+			$control_id				= isset($data['control_id']) && $data['control_id'] ? $data['control_id'] : 0;
 
 			if (!$type_id)
 			{
@@ -291,13 +312,13 @@
 
 			switch ($order)
 			{
-			case 'undefined':
-				$order = '';
-				break;
-			case 'loc1':
-				$order = 'fm_location1.loc1';
-				break;
-			default:
+				case 'undefined':
+					$order = '';
+					break;
+				case 'loc1':
+					$order = 'fm_location1.loc1';
+					break;
+				default:
 			}
 
 
@@ -537,6 +558,18 @@
 					$paranthesis .='(';
 					$joinmethod .= " {$this->join} fm_responsibility_role ON ( fm_responsibility.id = fm_responsibility_role.responsibility_id))";
 					$paranthesis .='(';
+
+					$cols.= ',fm_responsibility_role.id as role_id';
+					$cols_return[] 	= 'role_id';
+					$uicols['input_type'][]		= 'hidden';
+					$uicols['name'][]			= 'role_id';
+					$uicols['descr'][]			= 'dummy';
+					$uicols['statustext'][]		= 'dummy';
+					$uicols['exchange'][]		= false;
+					$uicols['align'][] 			= '';
+					$uicols['datatype'][]		= '';
+					$uicols['formatter'][]		= '';
+
 				}
 
 				$from = " FROM {$paranthesis} fm_location{$type_id} ";
@@ -544,19 +577,29 @@
 				$sql = "SELECT $cols $from $joinmethod";
 
 				$this->socommon->fm_cache('sql_'. $type_id . '_lt' . $lookup_tenant . '_l' . $lookup . '_f' . !!$filter_role_on_contact ,$sql);
-				$this->socommon->fm_cache('uicols_'. $type_id  . '_' . $lookup_tenant . '_' . $lookup,$uicols);
-				$this->socommon->fm_cache('cols_return_'. $type_id  . '_' . $lookup_tenant . '_' . $lookup,$cols_return);
+				$this->socommon->fm_cache('uicols_'. $type_id  . '_' . $lookup_tenant . '_' . $lookup . '_f' . !!$filter_role_on_contact,$uicols);
+				$this->socommon->fm_cache('cols_return_'. $type_id  . '_' . $lookup_tenant . '_' . $lookup . '_f' . !!$filter_role_on_contact,$cols_return);
 
 			}
 			else
 			{
-				$uicols = $this->socommon->fm_cache('uicols_'. $type_id  . '_' . $lookup_tenant . '_' . $lookup);
-				$cols_return = $this->socommon->fm_cache('cols_return_'. $type_id  . '_' . $lookup_tenant . '_' . $lookup);
+				$uicols = $this->socommon->fm_cache('uicols_'. $type_id  . '_' . $lookup_tenant . '_' . $lookup . '_f' . !!$filter_role_on_contact);
+				$cols_return = $this->socommon->fm_cache('cols_return_'. $type_id  . '_' . $lookup_tenant . '_' . $lookup . '_f' . !!$filter_role_on_contact);
 
 				$sub_query_tenant	= $this->socommon->fm_cache('sub_query_tenant_'. $type_id  . '_' . $lookup_tenant . '_' . $lookup);
 				$sub_query_street	= $this->socommon->fm_cache('sub_query_street_'. $type_id  . '_' . $lookup_tenant . '_' . $lookup);
 			}
 
+			$filtermethod = '';
+			$where= 'WHERE';
+			if($control_registered)
+			{
+				$sql .= "{$this->join} controller_control_location_list ON (fm_location{$type_id}.location_code = controller_control_location_list.location_code )";
+				$filtermethod .= " $where  controller_control_location_list.control_id = $control_id";
+				$where = 'AND';
+			}
+
+
 			//---------------------start custom user cols
 
 			$user_columns = isset($GLOBALS['phpgw_info']['user']['preferences']['property']['location_columns_'.$type_id . !!$lookup]) ? $GLOBALS['phpgw_info']['user']['preferences']['property']['location_columns_'.$type_id . !!$lookup] : '';
@@ -638,26 +681,24 @@
 			$this->uicols = $uicols;
 
 
-			if ($order)
+			if ($order && !$order =='fm_location1.loc1')
 			{
-				$ordermethod = " order by $order $sort";
+				$ordermethod = " ORDER BY {$order} {$sort}";
 			}
 			else
 			{
-				$ordermethod = ' order by fm_location' . ($type_id) .'.loc1 ASC';
+				$ordermethod = " ORDER BY fm_location{$type_id}.loc1 {$sort}";
 
 				if ($type_id > 1)
 				{
-					for ($i=1;$i<($type_id+1);$i++)
+					for ($i=2;$i<($type_id+1);$i++)
 					{
 						$ordermethod .= ",fm_location{$type_id}.loc{$i} ASC";
 					}
 				}
 			}
 
-			$where= 'WHERE';
 
-			$filtermethod = '';
 			$GLOBALS['phpgw']->config->read();
 			if(isset($GLOBALS['phpgw']->config->config_data['acl_at_location']) && $GLOBALS['phpgw']->config->config_data['acl_at_location'])
 			{
@@ -729,7 +770,14 @@
 				$time = time() +1;
 				$filtermethod .= " {$where} active_from < {$time} AND (active_to > {$time} OR active_to = 0)"
 					." AND expired_on IS NULL AND fm_responsibility_role.id ={$role_id} AND contact_id = {$filter_role_on_contact}";
-				$where= 'AND';			
+				$where= 'AND';
+			}
+			else if ($filter_role_on_contact)
+			{
+				$time = time() +1;
+				$filtermethod .= " {$where} active_from < {$time} AND (active_to > {$time} OR active_to = 0)"
+					." AND expired_on IS NULL AND contact_id = {$filter_role_on_contact}";
+				$where= 'AND';	
 			}
 
 			$_querymethod = array();
@@ -861,9 +909,31 @@
 			$sql .= "$filtermethod $querymethod";
 
 			$values = array();
-			$this->db->query('SELECT count(*) AS cnt ' . substr($sql,strripos($sql,' from')),__LINE__,__FILE__);
-			$this->db->next_record();
-			$this->total_records = $this->db->f('cnt');
+//			$this->db->query('SELECT count(*) AS cnt ' . substr($sql,strripos($sql,' from')),__LINE__,__FILE__);
+//			$this->db->next_record();
+//			$this->total_records = $this->db->f('cnt');
+
+			$cache_info = phpgwapi_cache::session_get('property',"location{$type_id}_listing_metadata");
+
+			if (!isset($cache_info['sql_hash']) || $cache_info['sql_hash'] != md5($sql))
+			{
+				$cache_info = array();
+			}
+			
+			if(!$cache_info)
+			{
+				$this->db->query('SELECT count(*) AS cnt ' . substr($sql,strripos($sql,' from')),__LINE__,__FILE__);
+				$this->db->next_record();
+
+				$cache_info = array
+				(
+					'total_records'		=> $this->db->f('cnt'),
+					'sql_hash'			=> md5($sql)
+				);
+				phpgwapi_cache::session_set('property',"location{$type_id}_listing_metadata",$cache_info);
+			}
+
+			$this->total_records	= $cache_info['total_records'];
 
 			//cramirez.r@ccfirst.com 23/07/08 avoid retrieve data in first time, only render definition for headers (var myColumnDefs)
 			if($dry_run)
@@ -873,10 +943,13 @@
 
 			if(!$allrows)
 			{
-				$this->db->limit_query($sql . $ordermethod,$start,__LINE__,__FILE__);
+				$this->db->limit_query($sql . $ordermethod,$start,__LINE__,__FILE__,$results);
 			}
 			else
 			{
+
+				$_fetch_single = false;
+/*
 				if($this->total_records > 200)
 				{
 					$_fetch_single = true;
@@ -885,6 +958,7 @@
 				{
 					$_fetch_single = false;
 				}
+*/
 				$this->db->query($sql . $ordermethod,__LINE__,__FILE__, false, $_fetch_single );
 				unset($_fetch_single);
 			}
@@ -909,6 +983,8 @@
 				$j++;				
 			}
 
+			$this->db->set_fetch_single(false);
+
 			$values = $this->custom->translate_value($dataset, $location_id, $location_count);
 			return $values;
 		}
@@ -1104,6 +1180,9 @@
 
 		function read_single($location_code='',$values = array())
 		{
+			//cache result
+			static $location = array();
+
 			$location_array = explode('-',$location_code);
 			$type_id= count($location_array);
 
@@ -1112,6 +1191,11 @@
 				return;
 			}
 
+			if(isset($location[$location_code]))
+			{
+				return $location[$location_code];
+			}
+
 			$cols = "fm_location{$type_id}.category as cat_id";
 			$cols .= ",fm_location{$type_id}_category.descr as category_name";
 			$cols_return[] 	= 'cat_id';
@@ -1161,23 +1245,26 @@
 //			_debug_array($sql);
 			$cols_return	= $this->cols_return;
 
-			$this->db->next_record();
-
-			foreach ($cols_return as $col)
+			if($this->db->next_record())
 			{
-				$values[$col] = $this->db->f($col,true);
-			}
-
-			if ( isset($values['attributes']) && is_array($values['attributes']) )
-			{
-				foreach ( $values['attributes'] as &$attr )
+				foreach ($cols_return as $col)
 				{
-					$attr['value'] 	= $this->db->f($attr['column_name']);
+					$values[$col] = $this->db->f($col,true);
+				}
+
+				if ( isset($values['attributes']) && is_array($values['attributes']) )
+				{
+					foreach ( $values['attributes'] as &$attr )
+					{
+						$attr['value'] 	= $this->db->f($attr['column_name']);
+					}
 				}
 			}
 
 			//_debug_array($cols_return);
 			//_debug_array($values);
+
+			$location[$location_code] = $values;
 			return $values;
 		}
 
@@ -1223,7 +1310,7 @@
 			//echo $sql;
 			$this->db->query($sql,__LINE__,__FILE__);
 
-			$sql	= "INSERT INTO fm_locations (level, location_code) VALUES ({$type_id}, '{$location['location_code']}')";
+			$sql	= "INSERT INTO fm_locations (level, location_code, loc1) VALUES ({$type_id}, '{$location['location_code']}', '{$location['loc1']}')";
 			$this->db->query($sql,__LINE__,__FILE__);
 
 			$this->db->transaction_commit();
@@ -1255,7 +1342,7 @@
 					{
 						$input_name='category';
 					}
-					$value_set[$input_name]	= $value;
+					$value_set[$input_name]	= $this->db->db_addslashes($value);
 				}
 			}
 
@@ -1273,7 +1360,7 @@
 
 			$value_set['entry_date'] = time();
 
-			$value_set	= $this->bocommon->validate_db_update($value_set);
+			$value_set	= $this->db->validate_update($value_set);
 
 			$sql = "SELECT * from fm_location$type_id where location_code ='" . $location['location_code'] . "'";
 			$this->db->query($sql,__LINE__,__FILE__);
@@ -1307,10 +1394,10 @@
 			}
 
 			$cols[] = 'exp_date';
-			$vals[] = date($this->bocommon->datetimeformat,time());
+			$vals[] = date($this->db->datetime_format(),time());
 
 			$cols	=implode(",", $cols);
-			$vals = $this->bocommon->validate_db_insert($vals);
+			$vals = $this->db->validate_insert($vals);
 
 			$this->db->transaction_begin();
 			$sql = "INSERT INTO fm_location" . $type_id ."_history ($cols) VALUES ($vals)";
@@ -1464,13 +1551,14 @@
 			$locations = array();
 			for ($i=1;$i<($levels+1);$i++)
 			{
-				$this->db->query("SELECT fm_location{$i}.location_code from fm_location{$i} $this->left_join fm_locations ON fm_location{$i}.location_code = fm_locations.location_code WHERE fm_locations.location_code IS NULL");
+				$this->db->query("SELECT fm_location{$i}.location_code, fm_location{$i}.loc1 FROM fm_location{$i} {$this->left_join} fm_locations ON fm_location{$i}.location_code = fm_locations.location_code WHERE fm_locations.location_code IS NULL");
 				while($this->db->next_record())
 				{
 					$locations[] = array
 						(
 							'level' 		=> $i,
-							'location_code' => $this->db->f('location_code')
+							'location_code' => $this->db->f('location_code'),
+							'loc1' 			=> $this->db->f('loc1')
 						);
 				}
 			}
@@ -1478,7 +1566,7 @@
 			$receipt = array();
 			foreach ($locations as $location)
 			{
-				$this->db->query("INSERT INTO fm_locations (level, location_code) VALUES ({$location['level']}, '{$location['location_code']}')");
+				$this->db->query("INSERT INTO fm_locations (level, location_code, loc1) VALUES ({$location['level']}, '{$location['location_code']}', '{$location['loc1']}')");
 
 				$receipt['message'][]=array('msg'=>lang('location %1 added at level %2', $location['location_code'], $location['level']));
 			}
@@ -1537,7 +1625,7 @@
 				$type_id=4;
 			}
 
-			$entity_table = 'fm_location' . $type_id ;
+			$entity_table = "fm_location{$type_id}";
 			$cols_return = array();
 			$paranthesis = '';
 
@@ -1590,10 +1678,35 @@
 			$uicols['descr'][]	= lang('number');
 			$uicols['input_type'][]	= 'text';
 
-			$joinmethod= "$this->join $entity_table"."_category on $entity_table.category=$entity_table"."_category.id";
+			$this->uicols		= $uicols;
 
-			$sql = $this->bocommon->generate_sql(array('entity_table'=>$entity_table,'cols_return'=>$cols_return,'cols'=>$cols,
-				'uicols'=>$uicols,'joinmethod'=>$joinmethod,'paranthesis'=>$paranthesis,'no_address'=>true,'location_level'=>$type_id));
+			$joinmethod = "{$this->join} fm_part_of_town ON (fm_location1.part_of_town_id = fm_part_of_town.part_of_town_id))";
+			$paranthesis .='(';
+			$joinmethod .= " {$this->join} fm_owner ON (fm_location1.owner_id = fm_owner.id))";
+			$paranthesis .='(';
+
+			$_level = 2;
+			for ($i=1; $i<$type_id; $i++)
+			{
+				$joinmethod .= " {$this->join} fm_location{$_level}";
+				$paranthesis .='(';
+				$on = 'ON';
+				for ($k=($_level-1); $k>0; $k--)
+				{
+					$joinmethod .= " $on (fm_location{$_level}.loc{$k} = fm_location" . ($_level-1) . ".loc{$k})";
+					$on = 'AND';
+					if($k==1)
+					{
+						$joinmethod .= ")";
+					}
+				}
+				$_level ++;
+			}
+
+			$joinmethod.= " {$this->join} {$entity_table}_category ON ($entity_table.category = {$entity_table}_category.id))";
+			$paranthesis .='(';
+
+			$sql = "SELECT $cols FROM $paranthesis fm_location1 $joinmethod";
 
 			$this->db->query($sql . $filtermethod . $groupmethod . " ORDER BY $entity_table.category",__LINE__,__FILE__);
 
@@ -1601,16 +1714,14 @@
 			while ($this->db->next_record())
 			{
 				$summary[]=array
-					(
-						'number'		=> $this->db->f('number'),
-						'type'			=> '[' . $this->db->f('category') . '] ' .$this->db->f('type'),
-						'part_of_town'	=> $this->db->f('part_of_town'),
-						'district_id'	=> $this->db->f('district_id')
-					);
+				(
+					'number'		=> $this->db->f('number'),
+					'type'			=> '[' . $this->db->f('category') . '] ' .$this->db->f('type'),
+					'part_of_town'	=> $this->db->f('part_of_town'),
+					'district_id'	=> $this->db->f('district_id')
+				);
 			}
 
-
-			$this->uicols		= $uicols;
 			return $summary;
 		}
 
@@ -1744,4 +1855,98 @@
 			$this->db->next_record();
 			return $this->db->f('id');
 		}
+
+
+		public function get_location_code($id)
+		{
+			$sql = "SELECT location_code FROM fm_locations WHERE id = '{$id}'";
+			$this->db->query($sql,__LINE__,__FILE__);
+			$this->db->next_record();
+			return $this->db->f('location_code');
+		}
+
+		function get_children($criteria = '')
+		{
+			$join_method = '';
+			$filtermethod = '';
+			if(is_array($criteria))
+			{
+				$location_code 		= $criteria['location_code'];
+				$child_level		= $criteria['child_level'];
+				$id_field			= 'location_code';
+				$field_name			= $criteria['field_name'];
+				$part_of_town_id	= $criteria['part_of_town_id'];
+				
+				if($part_of_town_id)
+				{
+					$join_method = "{$this->join} fm_part_of_town ON fm_part_of_town.part_of_town_id = fm_location1.part_of_town_id";
+					$filtermethod = 'AND fm_part_of_town.part_of_town_id =' . (int) $part_of_town_id;
+				}
+			}
+			else
+			{
+				$location_code = $criteria;
+				if(!$location_code)
+				{
+					$level = 0;
+				}
+				else
+				{
+					$level = count(explode('-', $location_code));
+				}
+
+				$child_level = $level + 1;
+				$id_field = "loc{$child_level}";
+				$field_name = "loc{$child_level}_name";
+			}
+
+			$location_types	= $this->soadmin_location->select_location_type();
+
+			$values = array();
+			
+			if( $child_level > count($location_types))
+			{
+				return $values;
+			}
+			
+			$this->db->query("SELECT $id_field AS id, {$field_name} AS name FROM fm_location{$child_level} {$join_method} WHERE location_code {$this->like} '{$location_code}%' {$filtermethod} ORDER BY {$field_name} ASC",__LINE__,__FILE__);
+			while ($this->db->next_record())
+			{
+				$id = $this->db->f('id');
+				$values[] = array
+				(
+					'id'	=>  $id,
+					'name'	=>  $this->db->f('name')
+				);
+			}
+			return $values;
+		}
+
+		/**
+		 * Get location by name
+		 *
+		 * @param array   $data array with level and name to search for
+		 *
+		 * @return array array of hits
+		 */
+		public function get_locations_by_name($data)
+		{
+			$level = isset($data['level']) && $data['level'] ? $data['level'] : 1;
+
+			$location_name = isset($data['location_name']) && $data['location_name'] ? $data['location_name'] : '';
+			$values = array();
+			if($location_name)
+			{
+				$this->db->query("SELECT loc{$level}_name as name, location_code FROM fm_location{$level} WHERE loc{$level}_name {$this->like} '{$location_name}%'",__LINE__,__FILE__);
+				while ($this->db->next_record())
+				{
+					$values[] = array
+					(
+						'name'			=> $this->db->f('name',true),
+						'location_code'	=> $this->db->f('location_code'),
+					);
+				}
+			}
+			return $values;
+		}
 	}
