@@ -24,7 +24,7 @@
 	* @internal Development of this application was funded by http://www.bergen.kommune.no/bbb_/ekstern/
 	* @package property
 	* @subpackage agreement
- 	* @version $Id: class.sos_agreement.inc.php 7498 2011-08-12 08:52:29Z sigurdne $
+ 	* @version $Id: class.sos_agreement.inc.php 11361 2013-10-09 14:00:23Z sigurdne $
 	*/
 
 	phpgw::import_class('phpgwapi.datetime');
@@ -83,6 +83,7 @@
 				$detail			= isset($data['detail'])?$data['detail']:'';
 				$p_num			= isset($data['p_num']) ? $data['p_num'] : '';
 				$status_id		= isset($data['status_id']) && $data['status_id'] ? (int)$data['status_id']:0;
+				$location_code	= isset($data['location_code'])?$data['location_code']:'';
 			}
 
 			$choice_table = 'phpgw_cust_choice';
@@ -150,13 +151,14 @@
 			}
 			else
 			{
+				$query = '';
 				$allrows=true;
 				$entity_table = 'fm_s_agreement_detail';
 				$location_id = $GLOBALS['phpgw']->locations->get_id('property', '.s_agreement.detail'); 
 				$attribute_filter = " location_id = {$location_id}";
 
 				$paranthesis .='(';
-				$joinmethod .= " $this->join  fm_s_agreement_pricing ON ( $entity_table.agreement_id =fm_s_agreement_pricing.agreement_id AND $entity_table.id =fm_s_agreement_pricing.item_id))";
+				$joinmethod .= " {$this->join}  fm_s_agreement_pricing ON ( $entity_table.agreement_id =fm_s_agreement_pricing.agreement_id AND {$entity_table}.id =fm_s_agreement_pricing.item_id))";
 
 				$cols = "$entity_table.*, fm_s_agreement_pricing.cost,fm_s_agreement_pricing.id as index_count,fm_s_agreement_pricing.index_date,fm_s_agreement_pricing.item_id,fm_s_agreement_pricing.this_index";
 
@@ -284,17 +286,29 @@
 
 			if ($order)
 			{
-				switch ($order)
+				if(!$detail)
 				{
-					case 'id':
-					case 'status':
-						$ordermethod = " ORDER BY {$entity_table}.{$order} {$sort}";
-						break;
-					case 'category':
-						$ordermethod = " ORDER BY {$category_table}.descr {$sort}";					
-						break;
-					default:
-						$ordermethod = " ORDER BY {$order} {$sort}";
+					switch ($order)
+					{
+						case 'id':
+						case 'status':
+							$ordermethod = " ORDER BY {$entity_table}.{$order} {$sort}";
+							break;
+						case 'category':
+							$ordermethod = " ORDER BY {$category_table}.descr {$sort}";					
+							break;
+						default:
+							$ordermethod = " ORDER BY {$order} {$sort}";
+					}
+				}
+				else
+				{
+					switch ($order)
+					{
+						case 'id':
+							$ordermethod = " ORDER BY {$entity_table}.{$order} {$sort}";
+							break;
+					}
 				}
 			}
 			else
@@ -334,13 +348,19 @@
 				$where= 'AND';
 			}
 
-			if ($cat_id)
+			if ($location_code)
+			{
+				$filtermethod .= " $where location_code {$this->like} '{$location_code}%'";
+				$where= 'AND';
+			}
+
+			if ($cat_id && !$detail)
 			{
 				$filtermethod .= " $where $entity_table.category='$cat_id' ";
 				$where= 'AND';
 			}
 
-			if ($vendor_id)
+			if ($vendor_id && !$detail)
 			{
 				$filtermethod .= " $where $entity_table.vendor_id='$vendor_id' ";
 				$where= 'AND';
@@ -348,7 +368,7 @@
 
 			if ($member_id > 0  && !$detail)
 			{
-				$filtermethod .= " $where $entity_table.member_of $this->like '%,$member_id,%' ";
+				$filtermethod .= " $where fm_vendor.member_of {$this->like} '%,$member_id,%' ";
 				$where= 'AND';
 			}
 
@@ -359,6 +379,11 @@
 			}
 
 
+			$_querymethod = array();
+			$__querymethod = array();
+			$_joinmethod_datatype = array();
+			$_joinmethod_datatype_custom = array();
+
 			$querymethod = '';
 			if($query)
 			{
@@ -377,26 +402,112 @@
 
 					while ($this->db->next_record())
 					{
-						if($this->db->f('datatype')=='V' || $this->db->f('datatype')=='email' || $this->db->f('datatype')=='CH')
+						switch ($this->db->f('datatype'))
 						{
-							$query_arr[]= "$entity_table." . $this->db->f('column_name') . " $this->like '%$query%'";
-						}
-						else
-						{
-							$query_arr[]= "$entity_table." . $this->db->f('column_name') . " = '$query'";
-						}
-					}
+							case 'V':
+							case 'email':
+							case 'T':
+								if(!$criteria_id)
+								{
+									$_querymethod[]= "$entity_table." . $this->db->f('column_name') . " {$this->like} '%{$query}%'";
+									$__querymethod = array(); // remove block
+								}
+								break;
+							case 'CH':
+								if(!$criteria_id)
+								{
+									// from filter
+									$_querymethod[]= "$entity_table." . $this->db->f('column_name') . " {$this->like} '%,{$query},%'";
+									$__querymethod = array(); // remove block
 
-					$query_arr[]= "location_code {$this->like} '$query%'";
+									// from text-search
+									$_filter_choise = "WHERE (phpgw_cust_choice.location_id =" . (int)$this->db->f('location_id')
+										." AND phpgw_cust_choice.attrib_id =" . (int)$this->db->f('id')
+										." AND phpgw_cust_choice.value {$this->like} '%{$query}%')";
 
-					if (isset($query_arr[0]))
-					{
-						$querymethod = " $where (" . implode (' OR ',$query_arr) . ')';
-						$where = 'AND';
+									$this->db2->query("SELECT phpgw_cust_choice.id FROM phpgw_cust_choice {$_filter_choise}",__LINE__,__FILE__);
+									while ($this->db2->next_record())
+									{
+										$_querymethod[]= "$entity_table." . $this->db->f('column_name') . " {$this->like} '%,". $this->db2->f('id') . ",%'";
+									}
+								}
+								break;
+							case 'R':
+							case 'LB':
+								if(!$criteria_id)
+								{
+									$_filter_choise = "WHERE (phpgw_cust_choice.location_id =" . (int)$this->db->f('location_id')
+										." AND phpgw_cust_choice.attrib_id =" . (int)$this->db->f('id')
+										." AND phpgw_cust_choice.value {$this->like} '%{$query}%')";
+
+									$this->db2->query("SELECT phpgw_cust_choice.id FROM phpgw_cust_choice {$_filter_choise}",__LINE__,__FILE__);
+									$__filter_choise = array();
+									while ($this->db2->next_record())
+									{
+										$__filter_choise[] = $this->db2->f('id');
+									}
+
+									if($__filter_choise)
+									{
+										$_querymethod[]= "$entity_table." . $this->db->f('column_name') . ' IN (' . implode(',', $__filter_choise) . ')';
+									}
+	
+									$__querymethod = array(); // remove block
+								}
+								break;
+							case 'I':
+								if(ctype_digit($query) && !$criteria_id)
+								{
+									$_querymethod[]= "$entity_table." . $this->db->f('column_name') . " = " . (int)$query;
+									$__querymethod = array(); // remove block
+								}
+								break;
+							case 'VENDOR':
+								if($criteria_id == 'vendor')
+								{
+									$_joinmethod_datatype[] = "{$this->join} fm_vendor ON ({$entity_table}." . $this->db->f('column_name') . " = fm_vendor.id AND fm_vendor.org_name {$this->like} '%{$query}%') ";
+									$__querymethod = array(); // remove block
+								}
+								break;
+							case 'AB':
+								if($criteria_id == 'ab')
+								{
+									$_joinmethod_datatype[] = "{$this->join} phpgw_contact_person ON ({$entity_table}." . $this->db->f('column_name') . " = pphpgw_contact_person.person_id AND (phpgw_contact_person.first_name {$this->like} '%{$query}%' OR phpgw_contact_person.last_name {$this->like} '%{$query}%'))";
+									$__querymethod = array(); // remove block
+								}
+								break;
+							case 'ABO':
+								if($criteria_id == 'abo')
+								{
+									$_joinmethod_datatype[] = "{$this->join} phpgw_contact_org ON ({$entity_table}." . $this->db->f('column_name') . " = phpgw_contact_org.org_id AND phpgw_contact_org.name {$this->like} '%{$query}%')";
+									$__querymethod = array(); // remove block
+								}
+								break;
+							default:
+								if(!$criteria_id)
+								{
+									$_querymethod[]= "$entity_table." . $this->db->f('column_name') . " = '{$query}'";
+									$__querymethod = array(); // remove block
+								}
+						}
 					}
 				}
 			}
 
+
+			$_joinmethod_datatype = array_merge($_joinmethod_datatype, $_joinmethod_datatype_custom);
+			foreach($_joinmethod_datatype as $_joinmethod)
+			{
+				$sql .= $_joinmethod;
+			}
+
+			$_querymethod = array_merge($__querymethod, $_querymethod);
+			if ($_querymethod)
+			{
+				$querymethod = " $where (" . implode (' OR ',$_querymethod) . ')';
+				unset($_querymethod);
+			}
+
 			$sql .= " $filtermethod $querymethod";
 //			echo $sql;
 
@@ -454,8 +565,7 @@
 						}
 						else if($return_extra['datatype']=='CH' && $value)
 						{
-//							$ch= unserialize($value);
-							$ch = explode(',', trim($data['value'], ','));
+							$ch = explode(',', trim($value, ','));
 							if (isset($ch) AND is_array($ch))
 							{
 								for ($k=0;$k<count($ch);$k++)
@@ -602,7 +712,7 @@
 				$values['id']				= $this->db->f('id');
 				$values['entry_date']		= $this->db->f('entry_date');
 				$values['cat_id']			= $this->db->f('category');
-				$values['member_of']		= explode(',',$this->db->f('member_of'));
+				$values['member_of']		= explode(',',trim($this->db->f('member_of'),','));
 				$values['cat_id']			= $this->db->f('category');
 				$values['start_date']		= $this->db->f('start_date');
 				$values['end_date']			= $this->db->f('end_date');
@@ -676,7 +786,8 @@
 
 			if($values['member_of'])
 			{
-				$values['member_of']=',' . implode(',',$values['member_of']) . ',';
+				$member_of =  ',' . implode(',',$values['member_of']) . ',';
+				$values['member_of']= $member_of;
 			}
 
 			$this->db->transaction_begin();
@@ -747,6 +858,12 @@
 
 			$this->db->query("INSERT INTO fm_orders (id,type) VALUES ($id,'s_agreement')");
 
+			if( $member_of && $values['vendor_id'])
+			{
+				$vendor_id = (int)$values['vendor_id'];
+				$this->db->query("UPDATE fm_vendor SET member_of = '{$member_of}' WHERE id= {$vendor_id}");				
+			}
+
 			$receipt['s_agreement_id']= $id;//$this->db->get_last_insert_id($table,'id');
 
 			$receipt['message'][] = array('msg'=>lang('s_agreement %1 has been saved',$receipt['s_agreement_id']));
@@ -908,8 +1025,8 @@
 
 		function edit($values,$values_attribute = array())
 		{
-			//_debug_array($values);
-			//_debug_array($values_attribute);
+//			_debug_array($values);
+//			_debug_array($values_attribute);
 
 			$table = 'fm_s_agreement';
 
@@ -918,7 +1035,8 @@
 
 			if($values['member_of'])
 			{
-				$values['member_of']=',' . implode(',',$values['member_of']) . ',';
+				$member_of =  ',' . implode(',',$values['member_of']) . ',';
+				$values['member_of']= $member_of;
 			}
 
 			if(isset($values['extra']) && is_array($values['extra']))
@@ -949,6 +1067,8 @@
 
 			$value_set['name']	= $values['name'];
 			$value_set['descr']	= $values['descr'];
+			$value_set['vendor_id']	= $values['vendor_id'];
+
 			if($value_set)
 			{
 				$value_set	= ',' . $this->db->validate_update($value_set);
@@ -974,6 +1094,12 @@
 
 			$this->db->query("UPDATE fm_s_agreement_pricing set index_date=" . intval($values['start_date']) . " WHERE id=1 AND agreement_id= '{$values['s_agreement_id']}'");
 
+			if( $member_of && $values['vendor_id'])
+			{
+				$vendor_id = (int)$values['vendor_id'];
+				$this->db->query("UPDATE fm_vendor SET member_of = '{$member_of}' WHERE id= {$vendor_id}");				
+			}
+
 			$this->db->transaction_commit();
 			$receipt['s_agreement_id']= $values['s_agreement_id'];
 			$receipt['message'][] = array('msg'=>lang('s_agreement %1 has been edited',$values['s_agreement_id']));
