@@ -24,7 +24,7 @@
 	* @internal Development of this application was funded by http://www.bergen.kommune.no/bbb_/ekstern/
 	* @package property
 	* @subpackage helpdesk
- 	* @version $Id: class.sotts.inc.php 7197 2011-04-07 12:17:22Z sigurdne $
+ 	* @version $Id: class.sotts.inc.php 11527 2013-12-12 13:31:29Z sigurdne $
 	*/
 
 	phpgw::import_class('phpgwapi.datetime');
@@ -36,11 +36,14 @@
 
 	class property_sotts
 	{
-		var $uicols_related = array();
-		var $acl_location = '.ticket';
-		public $total_records	= 0;
-		public $sum_budget		= 0;
-		public $sum_actual_cost	= 0;
+		var $fields_updated			= false;
+		var $uicols_related			= array();
+		var $acl_location 			= '.ticket';
+		public $total_records		= 0;
+		public $sum_budget			= 0;
+		public $sum_actual_cost		= 0;
+		public $sum_difference		= 0;
+		protected $global_lock = false;
 
 		public $soap_functions = array
 			(
@@ -65,6 +68,7 @@
 		{
 			$this->account		= (int)$GLOBALS['phpgw_info']['user']['account_id'];
 			$this->historylog	= CreateObject('property.historylog','tts');
+			$this->custom 		= createObject('property.custom_fields');
 			$this->db 			= & $GLOBALS['phpgw']->db;
 			$this->like 		= & $this->db->like;
 			$this->join 		= & $this->db->join;
@@ -140,14 +144,6 @@
 			$branch_id		= isset($data['branch_id']) && $data['branch_id'] ? (int)$data['branch_id']:0;
 			$order_dim1		= isset($data['order_dim1']) && $data['order_dim1'] ? (int)$data['order_dim1']:0;
 
-			$this->grants 	= $GLOBALS['phpgw']->session->appsession('grants_ticket','property');
-
-			if(!$this->grants)
-			{
-				$this->grants	= $GLOBALS['phpgw']->acl->get_grants('property','.ticket');
-				$GLOBALS['phpgw']->session->appsession('grants_ticket','property',$this->grants);
-			}
-
 			$result_order_field = '';
 			if ($order)
 			{
@@ -181,50 +177,62 @@
 
 			$GLOBALS['phpgw']->config->read();
 
-			$public_user_list = array();
-			if(isset($GLOBALS['phpgw']->config->config_data['acl_at_tts_category']) && $GLOBALS['phpgw']->config->config_data['acl_at_tts_category'])
+			if(!isset($GLOBALS['phpgw']->config->config_data['bypass_acl_at_tickets']) || !$GLOBALS['phpgw']->config->config_data['bypass_acl_at_tickets'])
 			{
-				$categories = $GLOBALS['phpgw']->locations->get_subs('property', '.ticket.category');
+				$this->grants 	= $GLOBALS['phpgw']->session->appsession('grants_ticket','property');
 
-				$category_grants = array();
-				foreach ($categories as $location)
+				if(!$this->grants)
 				{
-					$category_grants	= array_merge($category_grants, $GLOBALS['phpgw']->acl->get_grants('property',$location));
+					$GLOBALS['phpgw']->acl->set_account_id($this->account);
+					$this->grants	= $GLOBALS['phpgw']->acl->get_grants('property','.ticket');
+					$GLOBALS['phpgw']->session->appsession('grants_ticket','property',$this->grants);
 				}
 
-				foreach($category_grants as $user => $right)
+				$public_user_list = array();
+				if(isset($GLOBALS['phpgw']->config->config_data['acl_at_tts_category']) && $GLOBALS['phpgw']->config->config_data['acl_at_tts_category'])
 				{
-					$public_user_list[] = $user;
-				}
-			}
+					$categories = $GLOBALS['phpgw']->locations->get_subs('property', '.ticket.category');
 
-			if(isset($GLOBALS['phpgw']->config->config_data['acl_at_location']) && $GLOBALS['phpgw']->config->config_data['acl_at_location'])
-			{
-				$access_location = execMethod('property.socommon.get_location_list', PHPGW_ACL_READ);
-				if($access_location)
+					$category_grants = array();
+					foreach ($categories as $location)
+					{
+						$category_grants	= array_merge($category_grants, $GLOBALS['phpgw']->acl->get_grants('property',$location));
+					}
+
+					foreach($category_grants as $user => $right)
+					{
+						$public_user_list[] = $user;
+					}
+				}
+
+				if(isset($GLOBALS['phpgw']->config->config_data['acl_at_location']) && $GLOBALS['phpgw']->config->config_data['acl_at_location'])
 				{
-					$filtermethod .= " $where fm_tts_tickets.loc1 in ('" . implode("','", $access_location) . "')";
+					$access_location = execMethod('property.socommon.get_location_list', PHPGW_ACL_READ);
+					if($access_location)
+					{
+						$filtermethod .= " $where fm_tts_tickets.loc1 in ('" . implode("','", $access_location) . "')";
+						$where= 'AND';
+					}
+				}
+
+				if (is_array($this->grants))
+				{
+					$grants = & $this->grants;
+					foreach($grants as $user => $right)
+					{
+						$public_user_list[] = $user;
+					}
+				}
+
+				if($public_user_list)
+				{
+					$public_user_list = array_unique($public_user_list);
+					reset($public_user_list);
+					$filtermethod .= " $where ( fm_tts_tickets.user_id IN(" . implode(',',$public_user_list) . "))";
 					$where= 'AND';
 				}
 			}
 
-			if (is_array($this->grants))
-			{
-				$grants = & $this->grants;
-				foreach($grants as $user => $right)
-				{
-					$public_user_list[] = $user;
-				}
-			}
-			
-			if($public_user_list)
-			{
-				$public_user_list = array_unique($public_user_list);
-				reset($public_user_list);
-				$filtermethod .= " $where ( fm_tts_tickets.user_id IN(" . implode(',',$public_user_list) . "))";
-				$where= 'AND';			
-			}
-
 			if($tenant_id = $GLOBALS['phpgw']->session->appsession('tenant_id','property'))
 			{
 				$filtermethod .= $where . ' fm_tts_tickets.tenant_id=' . $tenant_id;
@@ -285,7 +293,7 @@
 				{
 					if($value)
 					{
-						$filtermethod .= "{$or} fm_tts_tickets.status = '{$value}'";					
+						$filtermethod .= "{$or} fm_tts_tickets.status = '{$value}'";
 						$or = ' OR';
 					}
 				}
@@ -351,7 +359,10 @@
 				$filtermethod .= " {$where} (assignedto={$user_id}";
 				$where = 'AND';
 
-				$membership = $GLOBALS['phpgw']->accounts->membership($user_id);
+				if(!$membership = $GLOBALS['phpgw']->accounts->membership($user_id))
+				{
+					$membership = array(-1 => 0);
+				}
 				$filtermethod .= ' OR (assignedto IS NULL AND group_id IN (' . implode(',',array_keys($membership)) . ')))'; 
 			}
 
@@ -434,36 +445,85 @@
 
 			$return_fields = "fm_tts_tickets.id,fm_tts_tickets.assignedto,fm_tts_tickets.status,fm_tts_tickets.user_id,"
 			. "fm_tts_tickets.subject,fm_tts_tickets.address,fm_tts_tickets.location_code,fm_tts_tickets.priority,fm_tts_tickets.cat_id,fm_tts_tickets.group_id,"
-			. "fm_tts_tickets.entry_date,fm_tts_tickets.finnish_date,fm_tts_tickets.finnish_date2,fm_tts_tickets.order_id,fm_tts_tickets.vendor_id,fm_tts_tickets.actual_cost,"
+			. "fm_tts_tickets.entry_date,fm_tts_tickets.modified_date,fm_tts_tickets.finnish_date,fm_tts_tickets.finnish_date2,fm_tts_tickets.order_id,fm_tts_tickets.vendor_id,fm_tts_tickets.actual_cost,"
 			. "fm_tts_tickets.budget,fm_tts_tickets.billable_hours,fm_district.descr as district,fm_tts_views.id as view,fm_location1.loc1_name {$result_order_field}";
+
+			$custom_cols = $this->custom->find('property', '.ticket', 0, '', 'ASC', 'attrib_sort', true, true);
 			
-			//fm_tts_tickets.* ,fm_location1.loc1_name, fm_tts_views.id as view {$result_order_field},fm_district.descr as district
+			foreach ($custom_cols as $custom_col)
+			{
+				$return_fields .= ",fm_tts_tickets.{$custom_col['column_name']}";
+			}
+
 			$sql = "SELECT DISTINCT {$return_fields}  FROM fm_tts_tickets"
-				. " {$this->join} fm_location1 ON fm_tts_tickets.loc1=fm_location1.loc1"
-				. " {$this->join} fm_part_of_town ON fm_location1.part_of_town_id=fm_part_of_town.part_of_town_id"
-				. " {$this->join} fm_district ON fm_district.id = fm_part_of_town.district_id"
+				. " {$this->left_join} fm_location1 ON fm_tts_tickets.loc1=fm_location1.loc1"
+				. " {$this->left_join} fm_part_of_town ON fm_location1.part_of_town_id=fm_part_of_town.part_of_town_id"
+				. " {$this->left_join} fm_district ON fm_district.id = fm_part_of_town.district_id"
 				. " {$order_join}"
 				. " LEFT OUTER JOIN fm_tts_views ON (fm_tts_tickets.id = fm_tts_views.id AND fm_tts_views.account_id='{$this->account}')"
 				. " {$filtermethod} {$querymethod}";
 
 
 			$sql_cnt = "SELECT DISTINCT fm_tts_tickets.budget ,fm_tts_tickets.actual_cost, fm_tts_tickets.id FROM fm_tts_tickets"
-				. " $this->join fm_location1 ON fm_tts_tickets.loc1=fm_location1.loc1"
-				. " $this->join fm_part_of_town ON fm_location1.part_of_town_id=fm_part_of_town.part_of_town_id"
-				. " $this->join fm_district ON fm_district.id = fm_part_of_town.district_id"
+				. " {$this->left_join} fm_location1 ON fm_tts_tickets.loc1=fm_location1.loc1"
+				. " {$this->left_join} fm_part_of_town ON fm_location1.part_of_town_id=fm_part_of_town.part_of_town_id"
+				. " {$this->left_join} fm_district ON fm_district.id = fm_part_of_town.district_id"
 				. " $order_join"
 				. " LEFT OUTER JOIN fm_tts_views ON (fm_tts_tickets.id = fm_tts_views.id AND fm_tts_views.account_id='{$this->account}')"
 				. " $filtermethod $querymethod";
 
 //_debug_array($sql);
 
-			$sql2 = "SELECT count(*) as cnt, sum(budget) as sum_budget, sum(actual_cost) as sum_actual_cost FROM ({$sql_cnt}) as t";
-			$this->db->query($sql2,__LINE__,__FILE__);
-			$this->db->next_record();
-			$this->total_records	= $this->db->f('cnt');
-			$this->sum_budget		= $this->db->f('sum_budget');
-			$this->sum_actual_cost	= $this->db->f('sum_actual_cost');
-			unset($sql2);
+			$cache_info = phpgwapi_cache::session_get('property','tts_listing_metadata');
+
+			if (!isset($cache_info['sql_hash']) || $cache_info['sql_hash'] != md5($sql_cnt))
+			{
+				$cache_info = array();
+			}
+
+			if(!$cache_info)
+			{
+				$sql2 = "SELECT count(*) as cnt, sum(budget) as sum_budget, sum(actual_cost) as sum_actual_cost FROM ({$sql_cnt}) as t";
+				$this->db->query($sql2,__LINE__,__FILE__);
+				$this->db->next_record();
+				unset($sql2);
+
+				$cache_info = array
+				(
+					'total_records'		=> $this->db->f('cnt'),
+					'sum_budget'		=> $this->db->f('sum_budget'),
+					'sum_actual_cost'	=> $this->db->f('sum_actual_cost'),
+					'sql_hash'			=> md5($sql_cnt)
+				);
+
+
+				$custom_status	= $this->get_custom_status();
+				$closed_status = array('X');
+				foreach($custom_status as $custom)
+				{
+					if($custom['closed'])
+					{
+						$closed_status[] =  "C{$custom['id']}";
+					}
+				}
+
+				$filter_closed = "{$where} fm_tts_tickets.status NOT IN ('" . implode("','", $closed_status) . "')";
+				$sql2 = "SELECT (sum(budget) - sum(actual_cost)) as sum_difference FROM ({$sql_cnt} {$filter_closed}) as t";
+				$this->db->query($sql2,__LINE__,__FILE__);
+				$this->db->next_record();
+				unset($sql2);
+
+				$cache_info['sum_difference']	= (int)$this->db->f('sum_difference');
+
+				phpgwapi_cache::session_set('property','tts_listing_metadata',$cache_info);
+			}
+
+			$this->total_records	= $cache_info['total_records'];
+			$this->sum_budget		= $cache_info['sum_budget'];
+			$this->sum_actual_cost	= $cache_info['sum_actual_cost'];
+			$this->sum_difference	= $cache_info['sum_difference'];
+
+			$location_id = $GLOBALS['phpgw']->locations->get_id('property', '.ticket');
 
 			$tickets = array();
 			if(!$dry_run)
@@ -474,6 +534,8 @@
 				}
 				else
 				{
+					$_fetch_single = false;
+/*
 					if($this->total_records > 200)
 					{
 						$_fetch_single = true;
@@ -482,10 +544,12 @@
 					{
 						$_fetch_single = false;
 					}
+*/
 					$this->db->query($sql . $ordermethod,__LINE__,__FILE__, false, $_fetch_single );
 					unset($_fetch_single);
 				}
 
+				$i = 0;
 				while ($this->db->next_record())
 				{
 					$tickets[]= array
@@ -503,6 +567,7 @@
 							'cat_id'			=> $this->db->f('cat_id'),
 							'group_id'			=> $this->db->f('group_id'),
 							'entry_date'		=> $this->db->f('entry_date'),
+							'modified_date'		=> $this->db->f('modified_date'),
 							'finnish_date'		=> $this->db->f('finnish_date'),
 							'finnish_date2'		=> $this->db->f('finnish_date2'),
 							'order_id'			=> $this->db->f('order_id'),
@@ -512,9 +577,21 @@
 							'new_ticket'		=> $this->db->f('view') ? false : true,
 							'billable_hours'	=> $this->db->f('billable_hours'),
 					);
+
+					foreach ($custom_cols as $custom_col)
+					{
+						if($custom_value = $this->db->f($custom_col['column_name'],true))
+						{
+							$custom_value = $this->custom->get_translated_value(array('value' =>$custom_value, 'attrib_id' => $custom_col['attrib_id'], 'datatype' => $custom_col['datatype'] ), $location_id);
+						}
+						$tickets[$i][$custom_col['column_name']] = $custom_value;
+					}
+					$i ++;
 				}
 			}
 
+			$this->db->set_fetch_single(false);
+
 			return $tickets;
 		}
 
@@ -540,12 +617,17 @@
 
 			$entity[$i]['type']='.project';
 			$uicols[]	= 'project';
+			$i++;
+
+			$entity[$i]['type']='.project.workorder';
+			$uicols[]	= 'workorder';
+
 
 			$this->uicols_related	= $uicols;
 			return $entity;
 		}
 
-		function read_single($id)
+		function read_single($id, $values = array())
 		{
 			$id = (int) $id;
 			$sql = "SELECT * FROM fm_tts_tickets WHERE id = {$id}";
@@ -554,6 +636,7 @@
 
 			if ($this->db->next_record())
 			{
+				$ticket['id']				= $id;
 				$ticket['assignedto']		= $this->db->f('assignedto');
 				$ticket['user_id']			= $this->db->f('user_id');
 				$ticket['group_id']			= $this->db->f('group_id');
@@ -561,7 +644,7 @@
 				$ticket['cat_id']			= $this->db->f('cat_id');
 				$ticket['subject']			= $this->db->f('subject', true);
 				$ticket['priority']			= $this->db->f('priority');
-				$ticket['details']			= htmlspecialchars ($this->db->f('details', true));
+				$ticket['details']			= $this->db->f('details', true);
 				$ticket['location_code']	= $this->db->f('location_code');
 				$ticket['contact_phone']	= $this->db->f('contact_phone');
 				$ticket['contact_email']	= $this->db->f('contact_email',true);
@@ -586,6 +669,9 @@
 				$ticket['publish_note']		= $this->db->f('publish_note');
 				$ticket['billable_hours']	= $this->db->f('billable_hours');
 				$ticket['branch_id']		= $this->db->f('branch_id');
+				$ticket['entry_date']		= $this->db->f('entry_date');
+				$ticket['modified_date']	= $this->db->f('modified_date');
+
 				$user_id=(int)$this->db->f('user_id');
 
 				$ticket['user_name']	= $GLOBALS['phpgw']->accounts->get($user_id)->__toString();
@@ -593,6 +679,15 @@
 				{
 					$ticket['assignedto_name']	= $GLOBALS['phpgw']->accounts->get($ticket['assignedto'])->__toString();
 				}
+
+				if ( isset($values['attributes']) && is_array($values['attributes']) )
+				{
+					$ticket['attributes'] = $values['attributes'];
+					foreach ( $ticket['attributes'] as &$attr )
+					{
+						$attr['value'] 	= $this->db->f($attr['column_name']);
+					}
+				}
 			}
 
 			return $ticket;
@@ -613,8 +708,10 @@
 			}
 		}
 
-		function add($ticket)
+		function add(&$ticket , $values_attribute = array())
 		{
+			$table = 'fm_tts_tickets';
+
 			if(isset($ticket['location']) && is_array($ticket['location']))
 			{
 				foreach ($ticket['location'] as $input_name => $value)
@@ -626,6 +723,18 @@
 				}
 			}
 
+			$data_attribute = $this->custom->prepare_for_db($table, $values_attribute);
+			if(isset($data_attribute['value_set']))
+			{
+				foreach($data_attribute['value_set'] as $input_name => $value)
+				{
+					if(isset($value) && $value)
+					{
+						$value_set[$input_name] = $value;
+					}
+				}
+			}
+
 			if(isset($ticket['extra']) && is_array($ticket['extra']))
 			{
 				foreach ($ticket['extra'] as $input_name => $value)
@@ -667,7 +776,7 @@
 
 			if(isset($entity_category) && $entity_category)
 			{
-				$_address[] = "{$entity_category['name']}::{$ticket['extra']['p_num']}";				
+				$_address[] = "{$entity_category['name']}::{$ticket['extra']['p_num']}";
 			}
 
 			$address	= $this->db->db_addslashes(implode('::', $_address));
@@ -685,6 +794,7 @@
 			$value_set['location_code']	= $ticket['location_code'];
 			$value_set['address']		= $address;
 			$value_set['entry_date']	= time();
+			$value_set['modified_date']	= time();
 			$value_set['finnish_date']	= $ticket['finnish_date'];
 			$value_set['contact_id']	= $ticket['contact_id'];
 			$value_set['publish_note']	= 1;
@@ -694,7 +804,6 @@
 			$values	= $this->db->validate_insert(array_values($value_set));
 			$this->db->transaction_begin();
 
-			$table = 'fm_tts_tickets';
 			$this->db->query("INSERT INTO {$table} ({$cols}) VALUES ({$values})",__LINE__,__FILE__);
 
 			$id = $this->db->get_last_insert_id($table,'id');
@@ -707,20 +816,47 @@
 			{
 				if($ticket['origin'][0]['data'][0]['id'])
 				{
-					$interlink_data = array
-						(
-							'location1_id'		=> $GLOBALS['phpgw']->locations->get_id('property', $ticket['origin'][0]['location']),
-							'location1_item_id' => $ticket['origin'][0]['data'][0]['id'],
-							'location2_id'		=> $GLOBALS['phpgw']->locations->get_id('property', '.ticket'),			
-							'location2_item_id' => $id,
-							'account_id'		=> $this->account
-						);
-
-					$interlink 	= CreateObject('property.interlink');
-					$interlink->add($interlink_data,$this->db);
+					$ticket['origin_id'] = $GLOBALS['phpgw']->locations->get_id('property', $ticket['origin'][0]['location']);
+					$ticket['origin_item_id'] = $ticket['origin'][0]['data'][0]['id'];
 				}
 			}
 
+			if(isset($ticket['origin_id']) && $ticket['origin_id'] && isset($ticket['origin_item_id']) && $ticket['origin_item_id'])
+			{
+				$interlink_data = array
+				(
+					'location1_id'		=> $ticket['origin_id'],
+					'location1_item_id' => $ticket['origin_item_id'],
+					'location2_id'		=> $GLOBALS['phpgw']->locations->get_id('property', '.ticket'),
+					'location2_item_id' => $id,
+					'account_id'		=> $this->account
+				);
+			}
+			else if(isset($ticket['extra']) && is_array($ticket['extra']) && isset($ticket['extra']['p_num']) && $ticket['extra']['p_num'])
+			{
+				$ticket['origin_id'] = $GLOBALS['phpgw']->locations->get_id('property', ".entity.{$ticket['extra']['p_entity_id']}.{$ticket['extra']['p_cat_id']}");
+ 
+ 				$this->db->query('SELECT prefix FROM fm_entity_category WHERE entity_id = '. (int)$ticket['extra']['p_entity_id'] . ' AND id = ' . (int)$ticket['extra']['p_cat_id']);
+				$this->db->next_record();
+				$prefix = $this->db->f('prefix');
+				$ticket['origin_item_id']		= (int) ltrim($ticket['extra']['p_num'], $prefix);
+			
+				$interlink_data = array
+				(
+					'location1_id'		=> $ticket['origin_id'],
+					'location1_item_id' => $ticket['origin_item_id'],
+					'location2_id'		=> $GLOBALS['phpgw']->locations->get_id('property', '.ticket'),
+					'location2_item_id' => $id,
+					'account_id'		=> $this->account
+				);
+			}
+
+			if($interlink_data)
+			{
+				$interlink 	= CreateObject('property.interlink');
+				$interlink->add($interlink_data,$this->db);
+			}
+
 			if($this->db->transaction_commit())
 			{
 				$this->historylog->add('O',$id, time(),'');
@@ -732,6 +868,7 @@
 
 			$receipt['message'][]=array('msg'=>lang('Ticket %1 has been saved',$id));
 			$receipt['id']	= $id;
+			$ticket['id'] = $id; //returned by reference
 			return $receipt;
 		}
 
@@ -750,24 +887,33 @@
 			while ($this->db->next_record())
 			{
 				$status[] = array
-					(
-						'id'	=> $this->db->f('id'),
-						'name'	=> $this->db->f('name', true),
-						'color'	=> $this->db->f('color')
-					);
+				(
+					'id'		=> $this->db->f('id'),
+					'name'		=> $this->db->f('name', true),
+					'color'		=> $this->db->f('color'),
+					'closed'	=> $this->db->f('closed')
+				);
 			}
 			return $status;
 		}
+
 		function update_status($ticket,$id = 0)
 		{
 			$id = (int) $id;
-			$receipt = array();
 			// DB Content is fresher than http posted value.
 			$this->db->query("select * from fm_tts_tickets where id='$id'",__LINE__,__FILE__);
 			$this->db->next_record();
 			$old_status  		= $this->db->f('status');
 
-			$this->db->transaction_begin();
+			if ( $this->db->get_transaction() )
+			{
+				$this->global_lock = true;
+			}
+			else
+			{
+				$this->db->transaction_begin();
+			}
+
 
 			/*
 			 ** phpgw_fm_tts_append.append_type - Defs
@@ -793,8 +939,9 @@
 				$check_old_custom = (int) trim($old_status,'C');
 				$this->db->query("SELECT * from fm_tts_status WHERE id = {$check_old_custom}",__LINE__,__FILE__);
 				$this->db->next_record();
+				$old_closed = $this->db->f('closed');
 				$this->fields_updated = true;
-				if($old_status=='X' || $this->db->f('closed'))
+				if($old_status=='X' || $old_closed)
 				{
 					$new_status = $ticket['status'];
 					$this->historylog->add('R',$id,$ticket['status'],$old_status);
@@ -807,44 +954,103 @@
 					$this->db->query("UPDATE fm_tts_tickets SET status='{$ticket['status']}' WHERE id={$id}",__LINE__,__FILE__);
 				}
 				$this->check_pending_action($ticket, $id);
+
+				//Close cases
+				$check_new_custom = (int) trim($ticket['status'],'C');
+				$this->db->query("SELECT closed from fm_tts_status WHERE id = {$check_new_custom}",__LINE__,__FILE__);
+				$this->db->next_record();
+
+				if(($this->db->f('closed') || $ticket['status'] == 'X') && ($old_status!='X' && !$old_closed))
+				{
+					$location_id = $GLOBALS['phpgw']->locations->get_id('property', '.ticket');
+					// at controller
+					if(isset($GLOBALS['phpgw_info']['user']['apps']['controller']))
+					{
+						$controller = CreateObject('controller.uicase'); 
+						$controller->updateStatusForCases($location_id, $id, 1);
+					}
+					// at request
+					execMethod('property.sorequest.update_status_from_related', array(
+						'location_id'	=> $location_id,
+						'id' 			=> $id,
+						'status'		=> 'closed')
+					);
+				}
+
+			}
+
+			if ($this->fields_updated)
+			{
+				$this->db->query('UPDATE fm_tts_tickets SET modified_date= ' . time() . " WHERE id={$id}",__LINE__,__FILE__);
+			}
+
+			if ( !$this->global_lock )
+			{
+				$this->db->transaction_commit();
+			}
+
+			return $this->fields_updated;
+
+		}
+
+		function update_priority($ticket,$id = 0)
+		{
+			$id = (int) $id;
+			$receipt = array();
+			$this->db->query("SELECT priority FROM fm_tts_tickets WHERE id={$id}",__LINE__,__FILE__);
+			$this->db->next_record();
+			$oldpriority  = $this->db->f('priority');
+
+			$this->db->transaction_begin();
+
+			if ($oldpriority != $ticket['priority'])
+			{
+				$this->fields_updated = true;
+				$this->db->query("UPDATE fm_tts_tickets set priority='" . $ticket['priority']
+					. "' WHERE id={$id}",__LINE__,__FILE__);
+				$this->historylog->add('P',$id,$ticket['priority'],$oldpriority);
+			}
+
+			if ($this->fields_updated)
+			{
+				$this->db->query('UPDATE fm_tts_tickets SET modified_date= ' . time() . " WHERE id={$id}",__LINE__,__FILE__);
+				$receipt['message'][]= array('msg' => lang('Ticket %1 has been updated',$id));
 			}
 
 			$this->db->transaction_commit();
 
-			if ($this->fields_updated)
-			{
-				$receipt['message'][]= array('msg' => lang('Ticket %1 has been updated',$id));
-			}
-
 			return $receipt;
-
 		}
 
-		function update_ticket($ticket,$id = 0, $receipt = array())
+
+		function update_ticket(&$ticket,$id = 0, $receipt = array(), $values_attribute = array())
 		{
+			$this->fields_updated = array();
 			$id = (int) $id;
+			$ticket['id'] = $id;
 			// DB Content is fresher than http posted value.
 			$this->db->query("select * from fm_tts_tickets where id='$id'",__LINE__,__FILE__);
 			$this->db->next_record();
 
-			$location_code 	= $this->db->f('location_code');
-			$oldlocation_code 	= $this->db->f('location_code');
-			$oldfinnish_date 	= $this->db->f('finnish_date');
-			$oldfinnish_date2 	= $this->db->f('finnish_date2');
-			$oldassigned 		= $this->db->f('assignedto');
-			$oldgroup_id 		= $this->db->f('group_id');
-			$oldpriority 		= $this->db->f('priority');
-			$oldcat_id 			= $this->db->f('cat_id');
-			$old_status  		= $this->db->f('status');
-			$old_budget  		= $this->db->f('budget');
-			$old_billable_hours	= $this->db->f('billable_hours');
-			//	$old_billable_rate	= $this->db->f('billable_rate');
-			$old_subject		= $this->db->f('subject');
-			$old_contact_id		= $this->db->f('contact_id');
-			$old_actual_cost	= $this->db->f('actual_cost');
-			$old_order_cat_id	= $this->db->f('order_cat_id');
-			$old_building_part	= $this->db->f('building_part',true);
-			$old_order_dim1		= (int)$this->db->f('order_dim1');
+			$location_code 			= $this->db->f('location_code');
+			$oldlocation_code 		= $this->db->f('location_code');
+			$oldfinnish_date 		= $this->db->f('finnish_date');
+			$oldfinnish_date2 		= $this->db->f('finnish_date2');
+			$oldassigned 			= $this->db->f('assignedto');
+			$oldgroup_id 			= $this->db->f('group_id');
+			$oldpriority 			= $this->db->f('priority');
+			$oldcat_id 				= $this->db->f('cat_id');
+			$old_status  			= $this->db->f('status');
+			$ticket['old_status']	= $old_status; // used for custom functions
+			$old_budget  			= $this->db->f('budget');
+			$old_billable_hours		= (float)$this->db->f('billable_hours');
+		//	$old_billable_rate	= $this->db->f('billable_rate');
+			$old_subject			= $this->db->f('subject');
+			$old_contact_id			= $this->db->f('contact_id');
+			$old_actual_cost		= $this->db->f('actual_cost');
+			$old_order_cat_id		= $this->db->f('order_cat_id');
+			$old_building_part		= $this->db->f('building_part',true);
+			$old_order_dim1			= (int)$this->db->f('order_dim1');
 
 
 			if($oldcat_id ==0){$oldcat_id ='';}
@@ -922,7 +1128,7 @@
 			{
 				if ($oldfinnish_date != $finnish_date)
 				{
-					$this->fields_updated = true;
+					$this->fields_updated[] = 'finnish_date';
 					$this->historylog->add('F',$id,$finnish_date,$oldfinnish_date);
 				}
 			}
@@ -932,8 +1138,9 @@
 				$check_old_custom = (int) trim($old_status,'C');
 				$this->db->query("SELECT * from fm_tts_status WHERE id = {$check_old_custom}",__LINE__,__FILE__);
 				$this->db->next_record();
-				$this->fields_updated = true;
-				if($old_status=='X' || $this->db->f('closed'))
+				$old_closed = $this->db->f('closed');
+				$this->fields_updated[] = 'status';
+				if($old_status=='X' || $old_closed)
 				{
 					$new_status = $ticket['status'];
 					$this->historylog->add('R',$id,$ticket['status'],$old_status);
@@ -946,11 +1153,33 @@
 					$this->db->query("UPDATE fm_tts_tickets SET status='{$ticket['status']}' WHERE id={$id}",__LINE__,__FILE__);
 				}
 				$this->check_pending_action($ticket, $id);
+
+				//Close cases at related
+				$check_new_custom = (int) trim($ticket['status'],'C');
+				$this->db->query("SELECT closed from fm_tts_status WHERE id = {$check_new_custom}",__LINE__,__FILE__);
+				$this->db->next_record();
+
+				if(($this->db->f('closed') || $ticket['status'] == 'X') && ($old_status!='X' && !$old_closed))
+				{
+					$location_id = $GLOBALS['phpgw']->locations->get_id('property', '.ticket');
+					// at controller
+					if(isset($GLOBALS['phpgw_info']['user']['apps']['controller']))
+					{
+						$controller = CreateObject('controller.uicase'); 
+						$controller->updateStatusForCases($location_id, $id, 1);
+					}
+					// at request
+					execMethod('property.sorequest.update_status_from_related', array(
+						'location_id'	=> $location_id,
+						'id' 			=> $id,
+						'status'		=> 'closed')
+					);
+				}
 			}
 
 			if (($oldassigned != $ticket['assignedto']) && $ticket['assignedto'] != 'ignore')
 			{
-				$this->fields_updated = true;
+				$this->fields_updated[] = 'assignedto';
 
 				$value_set=array('assignedto'	=> $ticket['assignedto']);
 				$value_set	= $this->db->validate_update($value_set);
@@ -961,7 +1190,7 @@
 
 			if (($oldgroup_id != $ticket['group_id']) && $ticket['group_id'] != 'ignore')
 			{
-				$this->fields_updated = true;
+				$this->fields_updated[] = 'group_id';
 
 				$value_set=array('group_id'	=> $ticket['group_id']);
 				$value_set	= $this->db->validate_update($value_set);
@@ -972,7 +1201,7 @@
 
 			if ($oldpriority != $ticket['priority'])
 			{
-				$this->fields_updated = true;
+				$this->fields_updated[] = 'priority';
 				$this->db->query("update fm_tts_tickets set priority='" . $ticket['priority']
 					. "' where id='$id'",__LINE__,__FILE__);
 				$this->historylog->add('P',$id,$ticket['priority'],$oldpriority);
@@ -981,13 +1210,13 @@
 			if ($old_contact_id != $ticket['contact_id'])
 			{
 				$contact_id  = (int) $ticket['contact_id'];
-				$this->fields_updated = true;
+				$this->fields_updated[] = 'contact_id';
 				$this->db->query("update fm_tts_tickets set contact_id={$contact_id} WHERE id=$id",__LINE__,__FILE__);
 			}
 
 			if (($oldcat_id != $ticket['cat_id']) && $ticket['cat_id'] != 'ignore')
 			{
-				$this->fields_updated = true;
+				$this->fields_updated[] = 'cat_id';
 				$this->db->query("update fm_tts_tickets set cat_id='" . $ticket['cat_id']
 					. "' where id='$id'",__LINE__,__FILE__);
 				$this->historylog->add('T',$id,$ticket['cat_id'],$oldcat_id);
@@ -995,7 +1224,7 @@
 
 			if ($old_budget != $ticket['budget'])
 			{
-				$this->fields_updated = true;
+				$this->fields_updated[] = 'budget';
 				$this->db->query("UPDATE fm_tts_tickets set budget='" . (int)$ticket['budget']
 					. "' where id='$id'",__LINE__,__FILE__);
 				$this->historylog->add('B',$id,$ticket['budget'],$old_budget);
@@ -1003,7 +1232,7 @@
 	/*
 			if ($old_billable_rate != $ticket['billable_rate'])
 			{
-				$this->fields_updated = true;
+				$this->fields_updated[] = 'billable_rate';
 				$this->db->query("update fm_tts_tickets set billable_rate='" . $ticket['billable_rate']
 					. "' where id='$id'",__LINE__,__FILE__);
 				$this->historylog->add('B',$id,$ticket['billable_rate'],$old_billable_rate);
@@ -1019,10 +1248,11 @@
 
 			if($ticket['billable_hours'])
 			{
-				$ticket['billable_hours'] = str_replace(',','.', $ticket['billable_hours']);
-			}
-			if ((float)$old_billable_hours != (float)$ticket['billable_hours'])
-			{
+				$ticket['billable_hours'] = (float)str_replace(',','.', $ticket['billable_hours']);
+				$ticket['billable_hours'] += (float)$old_billable_hours;
+//			}
+//			if ((float)$old_billable_hours != $ticket['billable_hours'])
+//			{
 				$this->db->query("UPDATE fm_tts_tickets SET billable_hours='{$ticket['billable_hours']}'"
 					. " WHERE id='{$id}'",__LINE__,__FILE__);
 				$this->historylog->add('H',$id,$ticket['billable_hours'],$old_billable_hours);
@@ -1042,7 +1272,7 @@
 				$this->db->query("UPDATE fm_tts_tickets SET order_cat_id='" . (int)$ticket['order_cat_id']
 					. "' WHERE id='$id'",__LINE__,__FILE__);
 				$receipt['message'][]= array('msg' => lang('order category has been updated'));
-				$this->fields_updated = true;
+				$this->fields_updated[] = 'order_cat_id';
 			}
 
 			if ((int)$old_order_dim1 != (int)$ticket['order_dim1'])
@@ -1050,7 +1280,7 @@
 				$this->db->query("UPDATE fm_tts_tickets SET order_dim1='" . (int)$ticket['order_dim1']
 					. "' WHERE id='$id'",__LINE__,__FILE__);
 				$receipt['message'][]= array('msg' => lang('order_dim1 has been updated'));
-				$this->fields_updated = true;
+				$this->fields_updated[] = 'order_dim1';
 			}
 
 			if ($old_building_part != $ticket['building_part'])
@@ -1058,12 +1288,12 @@
 				$this->db->query("UPDATE fm_tts_tickets SET building_part='" . $ticket['building_part']
 					. "' WHERE id='$id'",__LINE__,__FILE__);
 				$receipt['message'][]= array('msg' => lang('building part has been updated'));
-				$this->fields_updated = true;
+				$this->fields_updated[] = 'building_part';
 			}
 
 			if (($old_note != $ticket['note']) && $ticket['note'])
 			{
-				$this->fields_updated = true;
+				$this->fields_updated[] = 'note';
 				$this->historylog->add('C',$id,$ticket['note'],$old_note);
 				$_history_id = $this->db->get_last_insert_id('fm_tts_history','history_id');
 				$this->db->query("UPDATE fm_tts_history SET publish = 1 WHERE history_id = $_history_id",__LINE__,__FILE__);
@@ -1117,7 +1347,7 @@
 
 					if(isset($entity_category) && $entity_category)
 					{
-						$_address[] = "{$entity_category['name']}::{$ticket['extra']['p_num']}";				
+						$_address[] = "{$entity_category['name']}::{$ticket['extra']['p_num']}";
 					}
 
 					$address	= $this->db->db_addslashes(implode('::', $_address));
@@ -1180,45 +1410,44 @@
 				}
 			}
 
-			$value_set					= array();
-			$value_set['vendor_id']		= $ticket['vendor_id'];
-			$value_set['b_account_id']	= $ticket['b_account_id'];
-			$value_set['order_descr']	= $this->db->db_addslashes($ticket['order_descr']);
-			$value_set['ecodimb']		= $ticket['ecodimb'];
-			$value_set['budget']		= $ticket['budget'];
-			$value_set['branch_id']		= $ticket['branch_id'];
-			$value_set					= $this->db->validate_update($value_set);
+			$value_set	= array();
+
+			$data_attribute = $this->custom->prepare_for_db('fm_tts_tickets', $values_attribute);
+
+			if(isset($data_attribute['value_set']))
+			{
+				foreach($data_attribute['value_set'] as $input_name => $value)
+				{
+					$value_set[$input_name] = $value;
+				}
+			}
+
+			$value_set['modified_date']	= time();
+
+
+			// check order-rights
+			
+			$order_add 	= $GLOBALS['phpgw']->acl->check('.ticket.order', PHPGW_ACL_ADD, 'property');
+			$order_edit = $GLOBALS['phpgw']->acl->check('.ticket.order', PHPGW_ACL_EDIT, 'property');
+
+			if($order_add || $order_edit)
+			{
+				$value_set['vendor_id']		= $ticket['vendor_id'];
+				$value_set['b_account_id']	= $ticket['b_account_id'];
+				$value_set['order_descr']	= $this->db->db_addslashes($ticket['order_descr']);
+				$value_set['ecodimb']		= $ticket['ecodimb'];
+				$value_set['budget']		= $ticket['budget'];
+				$value_set['branch_id']		= $ticket['branch_id'];
+			}
+
+			$value_set	= $this->db->validate_update($value_set);
 			$this->db->query("UPDATE fm_tts_tickets SET $value_set WHERE id={$id}",__LINE__,__FILE__);
 
 			$this->db->transaction_commit();
 
-			if (isset($this->fields_updated))
+			if (isset($this->fields_updated) && $this->fields_updated)
 			{
 				$receipt['message'][]= array('msg' => lang('Ticket has been updated'));
-
-				$criteria = array
-					(
-						'appname'	=> 'property',
-						'location'	=> $this->acl_location,
-						'allrows'	=> true
-					);
-
-				$custom_functions = $GLOBALS['phpgw']->custom_functions->find($criteria);
-
-				foreach ( $custom_functions as $entry )
-				{
-					// prevent path traversal
-					if ( preg_match('/\.\./', $entry['file_name']) )
-					{
-						continue;
-					}
-
-					$file = PHPGW_SERVER_ROOT . "/property/inc/custom/{$GLOBALS['phpgw_info']['user']['domain']}/{$entry['file_name']}";
-					if ( $entry['active'] && is_file($file) )
-					{
-						require_once $file;
-					}
-				}
 			}
 			return $receipt;
 		}
@@ -1282,7 +1511,7 @@
 				throw new Exception("phpgwapi_locations::get_id ('property', '.ticket') returned 0");
 			}
 
-			$this->db->transaction_begin();	
+			$this->db->transaction_begin();
 
 			$this->db->query("DELETE FROM fm_action_pending WHERE location_id = {$location_id} AND item_id = {$id}",__LINE__,__FILE__);
 			$this->db->query("DELETE FROM phpgw_interlink WHERE location1_id = {$location_id} AND location1_item_id = {$id}",__LINE__,__FILE__);
@@ -1305,7 +1534,7 @@
 		{
 			$values = array();
 			$sql = "SELECT DISTINCT fm_vendor.id, fm_vendor.org_name FROM fm_tts_tickets {$this->join} fm_vendor ON fm_tts_tickets.vendor_id = fm_vendor.id ORDER BY org_name ASC";
-			
+
 			$this->db->query($sql, __LINE__,__FILE__);
 
 			while ($this->db->next_record())
@@ -1316,14 +1545,14 @@
 					'name'	=> $this->db->f('org_name', true)
 				);
 			}
-	
+
 			return $values;
 		}
 		public function get_ecodimb()
 		{
 			$values = array();
 			$sql = "SELECT DISTINCT fm_ecodimb.id, fm_ecodimb.descr as name FROM fm_tts_tickets {$this->join} fm_ecodimb ON fm_tts_tickets.ecodimb = fm_ecodimb.id ORDER BY name ASC";
-			
+
 			$this->db->query($sql, __LINE__,__FILE__);
 
 			while ($this->db->next_record())
@@ -1334,14 +1563,14 @@
 					'name'	=> $this->db->f('name', true)
 				);
 			}
-	
+
 			return $values;
 		}
 		public function get_b_account()
 		{
 			$values = array();
 			$sql = "SELECT DISTINCT fm_b_account.id, fm_b_account.descr as name FROM fm_tts_tickets {$this->join} fm_b_account ON fm_tts_tickets.b_account_id = fm_b_account.id ORDER BY id ASC";
-			
+
 			$this->db->query($sql, __LINE__,__FILE__);
 
 			while ($this->db->next_record())
@@ -1352,14 +1581,14 @@
 					'name'	=> $this->db->f('name', true)
 				);
 			}
-	
+
 			return $values;
 		}
 		public function get_building_part()
 		{
 			$values = array();
 			$sql = "SELECT DISTINCT fm_building_part.id, fm_building_part.descr as name FROM fm_tts_tickets {$this->join} fm_building_part ON fm_tts_tickets.building_part = fm_building_part.id ORDER BY id ASC";
-			
+
 			$this->db->query($sql, __LINE__,__FILE__);
 
 			while ($this->db->next_record())
@@ -1371,14 +1600,14 @@
 					'name'	=> $id . ' ' . $this->db->f('name', true)
 				);
 			}
-	
+
 			return $values;
 		}
 		public function get_branch()
 		{
 			$values = array();
 			$sql = "SELECT DISTINCT fm_branch.id, fm_branch.descr as name FROM fm_tts_tickets {$this->join} fm_branch ON fm_tts_tickets.branch_id = fm_branch.id ORDER BY name ASC";
-			
+
 			$this->db->query($sql, __LINE__,__FILE__);
 
 			while ($this->db->next_record())
@@ -1389,14 +1618,14 @@
 					'name'	=> $this->db->f('name', true)
 				);
 			}
-	
+
 			return $values;
 		}
 		public function get_order_dim1()
 		{
 			$values = array();
 			$sql = "SELECT DISTINCT fm_order_dim1.id, fm_order_dim1.descr as name FROM fm_tts_tickets {$this->join} fm_order_dim1 ON fm_tts_tickets.order_dim1 = fm_order_dim1.id ORDER BY name ASC";
-			
+
 			$this->db->query($sql, __LINE__,__FILE__);
 
 			while ($this->db->next_record())
@@ -1407,7 +1636,7 @@
 					'name'	=> $this->db->f('name', true)
 				);
 			}
-	
+
 			return $values;
 		}
 	}
