@@ -24,7 +24,7 @@
 	* @internal Development of this application was funded by http://www.bergen.kommune.no/bbb_/ekstern/
 	* @package property
 	* @subpackage admin
- 	* @version $Id: class.uiXport.inc.php 6937 2011-02-06 18:32:32Z sigurdne $
+ 	* @version $Id: class.uiXport.inc.php 9208 2012-04-23 12:10:17Z sigurdne $
 	*/
 
 	phpgw::import_class('phpgwapi.datetime');
@@ -266,18 +266,14 @@
 
 			$msgbox_data = $this->bocommon->msgbox_data($receipt);
 
-			$jscal = CreateObject('phpgwapi.jscalendar');
-			$jscal->add_listener('invoice_date');
-			$jscal->add_listener('payment_date');
+			$GLOBALS['phpgw']->jqcal->add_listener('invoice_date');
+			$GLOBALS['phpgw']->jqcal->add_listener('payment_date');
 
 			$data = array
 				(
 					'menu'								=> $this->bocommon->get_menu(),
 					'msgbox_data'						=> $GLOBALS['phpgw']->common->msgbox($msgbox_data),
 
-					'img_cal'							=> $GLOBALS['phpgw']->common->image('phpgwapi','cal'),
-					'lang_datetitle'					=> lang('Select date'),
-
 					'form_action'						=> $GLOBALS['phpgw']->link('/index.php',$link_data),
 					'cancel_action'						=> $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> 'property.uiinvoice.index', 'sub'=> $sub)),
 					'lang_cancel'						=> lang('Cancel'),
@@ -591,6 +587,8 @@
 				$GLOBALS['phpgw']->redirect_link('/index.php',array('menuaction'=> 'property.uilocation.stop', 'perm'=>16, 'acl_location'=> $this->acl_location));
 			}
 
+			$GLOBALS['phpgw_info']['flags']['menu_selection'] = 'property::invoice::rollback';
+
 			$GLOBALS['phpgw']->xslttpl->add_file(array('invoice',
 				'search_field'));
 
@@ -605,14 +603,14 @@
 					$receipt['error'][] = array('msg'=> lang('No conversion type could be located.') .' - ' . lang('Please choose a conversion type from the list'));
 				}
 
-				if(!$values['file'])
+				if(!$values['file'] && !$values['voucher_id'])
 				{
-					$receipt['error'][] = array('msg'=>lang('Please choose a file'));
+					$receipt['error'][] = array('msg'=>lang('Please choose a file or a voucher'));
 				}
 
 				if(!$receipt['error'])
 				{
-					$receipt = $this->bo->rollback($values['conv_type'],$values['file'],$date);
+					$receipt = $this->bo->rollback($values['conv_type'],$values['file'],$date,$values['voucher_id']);
 				}
 			}
 			else
@@ -623,8 +621,7 @@
 			$link_data = array('menuaction'	=> 'property.uiXport.rollback');
 
 			//_debug_array($receipt);
-			$jscal = CreateObject('phpgwapi.jscalendar');
-			$jscal->add_listener('date');
+			$GLOBALS['phpgw']->jqcal->add_listener('date');
 
 			$msgbox_data = $this->bocommon->msgbox_data($receipt);
 
@@ -632,10 +629,6 @@
 				(
 					'msgbox_data'				=> $GLOBALS['phpgw']->common->msgbox($msgbox_data),
 
-					'img_cal'					=> $GLOBALS['phpgw']->common->image('phpgwapi','cal'),
-					'lang_datetitle'			=> lang('Select date'),
-					'calendar_setup'			=> "Calendar.setup({inputField  : 'date',ifFormat  : '" . $jsDateFormat . "',button : 'date-trigger'});",
-
 					'lang_select_conv'			=> lang('Select conversion'),
 					'conv_list'					=> $this->bo->select_export_conv($values['conv_type']),
 					'select_conv'				=> 'values[conv_type]',
