@@ -24,7 +24,7 @@
 	* @internal Development of this application was funded by http://www.bergen.kommune.no/bbb_/ekstern/
 	* @package property
 	* @subpackage admin
- 	* @version $Id: class.uiadmin_entity.inc.php 7491 2011-08-11 11:33:09Z sigurdne $
+ 	* @version $Id: class.uiadmin_entity.inc.php 11152 2013-06-06 09:28:37Z sigurdne $
 	*/
 	phpgw::import_class('phpgwapi.yui');
 
@@ -57,7 +57,8 @@
 				'edit_attrib' 			=> true,
 				'list_custom_function'	=> true,
 				'edit_custom_function'	=> true,
-				'get_template_attributes'=> true
+				'get_template_attributes'=> true,
+				'convert_to_eav'		=> true
 			);
 
 		function property_uiadmin_entity()
@@ -95,7 +96,6 @@
 					'query'		=> $this->query,
 					'sort'		=> $this->sort,
 					'order'		=> $this->order,
-					'allrows'	=> $this->allrows,
 					'entity_id'	=> $this->entity_id,
 					'cat_id'	=> $this->cat_id
 				);
@@ -533,7 +533,6 @@
 			{
 				$entry['location_id'] = $GLOBALS['phpgw']->locations->get_id($this->type_app[$this->type], ".{$this->type}.{$entity_id}.{$entry['id']}");
 			}			
-
 			$uicols['name'][0]	= 'location_id';
 			$uicols['descr'][0]	= 'location_id';
 			$uicols['name'][1]	= 'id';
@@ -546,6 +545,10 @@
 			$uicols['descr'][4]	= lang('Prefix');
 			$uicols['name'][5]	= 'entity_id';
 			$uicols['descr'][5]	= lang('id');
+			$uicols['name'][6]	= 'is_eav';
+			$uicols['descr'][6]	= lang('is_eav');
+			$uicols['name'][6]	= 'enable_bulk';
+			$uicols['descr'][6]	= lang('enable bulk');
 			$j = 0;
 			$count_uicols_name = count($uicols['name']);
 
@@ -1176,6 +1179,8 @@
 					'value_start_project'				=> $values['start_project'],
 					'start_ticket'						=> true,
 					'value_start_ticket'				=> $values['start_ticket'],
+					'value_is_eav'						=> $values['is_eav'],
+					'value_enable_bulk'					=> $values['enable_bulk'],
 					'jasperupload'						=> true,
 					'category_list'						=> $category_list,
 					'parent_list'						=> $parent_list
@@ -1239,7 +1244,14 @@
 		{
 			if(!$this->acl_delete)
 			{
-				$GLOBALS['phpgw']->redirect_link('/index.php',array('menuaction'=> 'property.uilocation.stop', 'perm'=> 8, 'acl_location'=> $this->acl_location));
+				if( phpgw::get_var('phpgw_return_as') == 'json' )
+				{
+					return "Go away!";
+				}
+				else
+				{
+					$GLOBALS['phpgw']->redirect_link('/index.php',array('menuaction'=> 'property.uilocation.stop', 'perm'=> 8, 'acl_location'=> $this->acl_location));
+				}
 			}
 
 			$entity_id		= phpgw::get_var('entity_id', 'int');
@@ -1441,19 +1453,21 @@
 				//				$dry_run = true;
 			}
 
-			$attrib_list = $this->bo->read_attrib_group($entity_id,$cat_id);
+			$attrib_list = $this->bo->read_attrib_group($entity_id,$cat_id, phpgw::get_var( 'allrows', 'bool' ));
 			$uicols['name'][0]	= 'id';
 			$uicols['descr'][0]	= lang('id');
-			$uicols['name'][1]	= 'name';
-			$uicols['descr'][1]	= lang('Name');
-			$uicols['name'][2]	= 'descr';
-			$uicols['descr'][2]	= lang('Descr');
-			$uicols['name'][3]	= 'group_sort';
-			$uicols['descr'][3]	= lang('sorting');
-			$uicols['name'][4]	= 'up';
-			$uicols['descr'][4]	= lang('up');
-			$uicols['name'][5]	= 'down';
-			$uicols['descr'][5]	= lang('down');
+			$uicols['name'][1]	= 'parent_id';
+			$uicols['descr'][1]	= lang('parent');
+			$uicols['name'][2]	= 'name';
+			$uicols['descr'][2]	= lang('Name');
+			$uicols['name'][3]	= 'descr';
+			$uicols['descr'][3]	= lang('Descr');
+			$uicols['name'][4]	= 'group_sort_text';
+			$uicols['descr'][4]	= lang('sorting');
+			$uicols['name'][5]	= 'up';
+			$uicols['descr'][5]	= lang('up');
+			$uicols['name'][6]	= 'down';
+			$uicols['descr'][6]	= lang('down');
 			$j = 0;
 			$count_uicols_name = count($uicols['name']);
 
@@ -1844,6 +1858,8 @@
 			$uicols['descr'][7]	= lang('Search');
 			$uicols['name'][8]	= 'id';
 			$uicols['descr'][8]	= lang('id');
+			$uicols['name'][9]	= 'short_description';
+			$uicols['descr'][9]	= lang('short description');
 			$j = 0;
 			$count_uicols_name = count($uicols['name']);
 
@@ -2187,6 +2203,34 @@
 				$action='add';
 			}
 
+
+			$location_id = $GLOBALS['phpgw']->locations->get_id($this->type_app[$this->type], ".{$this->type}.{$entity_id}.{$cat_id}");
+
+			$parent_list = $GLOBALS['phpgw']->custom_fields->find_group( $this->type_app[$this->type],".{$this->type}.{$entity_id}.{$cat_id}", 0, '',	'', '', true );
+			
+			$parent_list = $this->bocommon->select_list($values['parent_id'],$parent_list);
+//_debug_array($parent_list);die();
+
+			if($id)
+			{
+				$exclude = array($id);
+				$children =  $GLOBALS['phpgw']->custom_fields->get_attribute_group_children($location_id, $id,0, 0, true);
+
+				foreach($children as $child)
+				{
+					$exclude[] = $child['id']; 
+				}
+
+				$k = count($parent_list);
+				for ($i=0; $i<$k; $i++)
+				{
+					if (in_array($parent_list[$i]['id'],$exclude))
+					{
+						unset($parent_list[$i]);
+					}
+				}
+			}
+
 			$link_data = array
 				(
 					'menuaction'	=> 'property.uiadmin_entity.edit_attrib_group',
@@ -2232,7 +2276,8 @@
 					'value_remark'						=> $values['remark'],
 
 					'lang_done_attribtext'				=> lang('Back to the list'),
-					'lang_save_attribtext'				=> lang('Save the attribute')
+					'lang_save_attribtext'				=> lang('Save the attribute'),
+					'parent_list'						=> $parent_list
 				);
 			//_debug_array($values);
 
@@ -2352,17 +2397,33 @@
 			}
 
 			$link_data = array
-				(
-					'menuaction'	=> 'property.uiadmin_entity.edit_attrib',
-					'entity_id'		=> $entity_id,
-					'cat_id'		=> $cat_id,
-					'id'			=> $id,
-					'type'			=> $this->type
-				);
+			(
+				'menuaction'	=> 'property.uiadmin_entity.edit_attrib',
+				'entity_id'		=> $entity_id,
+				'cat_id'		=> $cat_id,
+				'id'			=> $id,
+				'type'			=> $this->type
+			);
 
-			if($values['column_info']['type']=='R' || $values['column_info']['type']=='CH' || $values['column_info']['type']=='LB')
+			$multiple_choice = false;
+			$custom_get_list = false;
+			$custom_get_single = false;
+			switch($values['column_info']['type'])
 			{
-				$multiple_choice= true;
+				case 'R':
+				case 'CH':
+				case 'LB':
+					$multiple_choice = true;
+					break;
+				case 'custom1':
+					$custom_get_list = true;
+					break;
+				case 'custom2':
+				case 'custom3':
+					$custom_get_list = true;
+					$custom_get_single = true;
+					break;
+				default:
 			}
 
 			$entity = $this->bo->read_single($entity_id,false);
@@ -2371,68 +2432,38 @@
 			$msgbox_data = (isset($receipt)?$this->bocommon->msgbox_data($receipt):'');
 
 			$data = array
-				(
-					'lang_entity'						=> lang('entity'),
-					'entity_name'						=> $entity['name'],
-					'lang_category'						=> lang('category'),
-					'category_name'						=> $category['name'],
-
-					'lang_choice'						=> lang('Choice'),
-					'lang_new_value'					=> lang('New value'),
-					'lang_new_value_statustext'			=> lang('New value for multiple choice'),
-					'multiple_choice'					=> (isset($multiple_choice)?$multiple_choice:''),
-					'value_choice'						=> (isset($values['choice'])?$values['choice']:''),
-					'lang_delete_value'					=> lang('Delete value'),
-					'lang_value'						=> lang('value'),
-					'lang_delete_choice_statustext'		=> lang('Delete this value from the list of multiple choice'),
-
-					'msgbox_data'						=> $GLOBALS['phpgw']->common->msgbox($msgbox_data),
-					'form_action'						=> $GLOBALS['phpgw']->link('/index.php',$link_data),
-					'done_action'						=> $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> 'property.uiadmin_entity.list_attribute', 'entity_id'=> $entity_id, 'cat_id'=> $cat_id, 'type' => $this->type)),
-					'lang_id'							=> lang('Attribute ID'),
-					'lang_entity_type'					=> lang('Entity type'),
-					'lang_no_entity_type'				=> lang('No entity type'),
-					'lang_save'							=> lang('save'),
-					'lang_done'							=> lang('done'),
-					'value_id'							=> $id,
-
-					'lang_column_name'					=> lang('Column name'),
-					'value_column_name'					=> $values['column_name'],
-					'lang_column_name_statustext'		=> lang('enter the name for the column'),
-
-					'lang_input_text'					=> lang('input text'),
-					'value_input_text'					=> $values['input_text'],
-					'lang_input_name_statustext'		=> lang('enter the input text for records'),
-
-					'lang_id_attribtext'				=> lang('Enter the attribute ID'),
-					'lang_entity_statustext'			=> lang('Select a entity type'),
-
-					'lang_statustext'					=> lang('Statustext'),
-					'lang_statustext_attribtext'		=> lang('Enter a statustext for the inputfield in forms'),
-					'value_statustext'					=> $values['statustext'],
-
-					'lang_done_attribtext'				=> lang('Back to the list'),
-					'lang_save_attribtext'				=> lang('Save the attribute'),
-
-					'datatype_list'						=> $this->bocommon->select_datatype($values['column_info']['type']),
-
-					'attrib_group_list'					=> $this->bo->get_attrib_group_list($entity_id,$cat_id, $values['group_id']),
-
-					'value_precision'					=> $values['column_info']['precision'],
-
-					'value_scale'						=> $values['column_info']['scale'],
-
-					'value_default'						=> $values['column_info']['default'],
-
-					'nullable_list'						=> $this->bocommon->select_nullable($values['column_info']['nullable']),
-					'value_lookup_form'					=> $values['lookup_form'],
-					'value_list'						=> $values['list'],
-					'value_search'						=> $values['search'],
-					'value_history'						=> $values['history'],
-					'value_disabled'					=> $values['disabled'],
-					'value_helpmsg'						=> $values['helpmsg'],
-				);
-			//_debug_array($values);
+			(
+				'entity_name'						=> $entity['name'],
+				'category_name'						=> $category['name'],
+				'multiple_choice'					=> $multiple_choice,
+				'value_choice'						=> (isset($values['choice'])?$values['choice']:''),
+				'custom_get_list'					=> $custom_get_list,
+				'custom_get_single'					=> $custom_get_single,
+				'msgbox_data'						=> $GLOBALS['phpgw']->common->msgbox($msgbox_data),
+				'form_action'						=> $GLOBALS['phpgw']->link('/index.php',$link_data),
+				'done_action'						=> $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> 'property.uiadmin_entity.list_attribute', 'entity_id'=> $entity_id, 'cat_id'=> $cat_id, 'type' => $this->type)),
+				'value_id'							=> $id,
+				'value_column_name'					=> $values['column_name'],
+				'value_input_text'					=> $values['input_text'],
+				'value_statustext'					=> $values['statustext'],
+				'datatype_list'						=> $this->bocommon->select_datatype($values['column_info']['type']),
+				'attrib_group_list'					=> $this->bo->get_attrib_group_list($entity_id,$cat_id, $values['group_id']),
+				'value_precision'					=> $values['column_info']['precision'],
+				'value_scale'						=> $values['column_info']['scale'],
+				'value_default'						=> $values['column_info']['default'],
+				'nullable_list'						=> $this->bocommon->select_nullable($values['column_info']['nullable']),
+				'value_lookup_form'					=> $values['lookup_form'],
+				'value_list'						=> $values['list'],
+				'value_search'						=> $values['search'],
+				'value_history'						=> $values['history'],
+				'value_disabled'					=> $values['disabled'],
+				'value_helpmsg'						=> $values['helpmsg'],
+				'value_get_list_function'			=> $values['get_list_function'],
+				'value_get_list_function_input'		=> print_r($values['get_list_function_input'],true),
+				'value_get_single_function'			=> $values['get_single_function'],
+				'value_get_single_function_input'	=> print_r($values['get_single_function_input'],true),
+				'value_short_description'			=> $values['short_description']
+			);
 
 			$appname = lang('entity');
 
@@ -2556,16 +2587,18 @@
 			$uicols['descr'][1]	= lang('id');
 			$uicols['name'][2]	= 'descr';
 			$uicols['descr'][2]	= lang('Descr');
-			$uicols['name'][3]	= 'active';
-			$uicols['descr'][3]	= lang('Active');
-			$uicols['name'][4]	= 'sorting';
-			$uicols['descr'][4]	= lang('sorting');
-			$uicols['name'][5]	= 'up';
-			$uicols['descr'][5]	= lang('up');
-			$uicols['name'][6]	= 'down';
-			$uicols['descr'][6]	= lang('down');
-			$uicols['name'][7]	= 'file_name';
-			$uicols['descr'][7]	= lang('Name');
+			$uicols['name'][3]	= 'client_side';
+			$uicols['descr'][3]	= lang('client-side');
+			$uicols['name'][4]	= 'active';
+			$uicols['descr'][4]	= lang('Active');
+			$uicols['name'][5]	= 'sorting';
+			$uicols['descr'][5]	= lang('sorting');
+			$uicols['name'][6]	= 'up';
+			$uicols['descr'][6]	= lang('up');
+			$uicols['name'][7]	= 'down';
+			$uicols['descr'][7]	= lang('down');
+			$uicols['name'][8]	= 'file_name';
+			$uicols['descr'][8]	= lang('Name');
 			$j = 0;
 			$count_uicols_name = count($uicols['name']);
 
@@ -2891,7 +2924,6 @@
 					'type'		=> $this->type
 				);
 
-
 			//_debug_array($values);
 
 			$entity = $this->bo->read_single($entity_id,false);
@@ -2929,6 +2961,7 @@
 					'custom_function_list'				=> $this->bo->select_custom_function($values['custom_function_file']),
 
 					'value_active'						=> $values['active'],
+					'value_client_side'					=> $values['client_side'],
 					'lang_active'						=> lang('Active'),
 					'lang_active_statustext'			=> lang('check to activate custom function'),
 				);
@@ -2938,4 +2971,50 @@
 			$GLOBALS['phpgw_info']['flags']['app_header'] = lang($this->type_app[$this->type]) . ' - ' . $appname . ': ' . $function_msg;
 			$GLOBALS['phpgw']->xslttpl->set_var('phpgw',array('edit_custom_function' => $data));
 		}
+		
+		function convert_to_eav()
+		{
+			$GLOBALS['phpgw_info']['flags']['menu_selection'] = "admin::{$this->type_app[$this->type]}::entity::convert_to_eav";
+			$function = 'list_attribute';
+			if ( $custom_function_id )
+			{
+				$function = 'list_custom_function';
+			}
+
+			$redirect_args = array
+			(
+				'menuaction'	=> 'admin.uimainscreen.mainscreen'
+			);
+
+			if ( phpgw::get_var('delete', 'bool', 'POST') )
+			{
+				$this->bo->convert_to_eav();
+				$GLOBALS['phpgw']->redirect_link('/index.php', $redirect_args);
+			}
+
+			if ( phpgw::get_var('cancel', 'bool', 'POST') )
+			{
+				$GLOBALS['phpgw']->redirect_link('/index.php', $redirect_args);
+			}
+
+			$GLOBALS['phpgw']->xslttpl->add_file(array('delete'));
+
+			$link_data = array
+			(
+				'menuaction'			=> 'property.uiadmin_entity.convert_to_eav',
+			);
+
+			$data = array
+			(
+				'delete_url'				=> $GLOBALS['phpgw']->link('/index.php', $link_data),
+				'lang_confirm_msg'			=> lang('do you really want to convert to eav'),
+				'lang_delete'				=> lang('yes'),
+				'lang_cancel'				=> lang('no')
+			);
+
+			$function_msg	= lang('convert to eav');
+
+			$GLOBALS['phpgw_info']['flags']['app_header'] = lang('property'). '::' . $function_msg;
+			$GLOBALS['phpgw']->xslttpl->set_var('phpgw',array('delete' => $data));
+		}
 	}
