@@ -24,7 +24,7 @@
 	* @internal Development of this application was funded by http://www.bergen.kommune.no/bbb_/ekstern/
 	* @package property
 	* @subpackage agreement
- 	* @version $Id: class.uiagreement.inc.php 7495 2011-08-11 12:01:59Z sigurdne $
+ 	* @version $Id: class.uiagreement.inc.php 11054 2013-04-11 11:32:15Z sigurdne $
 	*/
 
 	/**
@@ -967,10 +967,9 @@
 				$agreement = $this->bocommon->preserve_attribute_values($agreement,$values_attribute);
 			}
 
-			$jscal = CreateObject('phpgwapi.jscalendar');
-			$jscal->add_listener('values_start_date');
-			$jscal->add_listener('values_end_date');
-			$jscal->add_listener('values_termination_date');
+			$GLOBALS['phpgw']->jqcal->add_listener('values_start_date');
+			$GLOBALS['phpgw']->jqcal->add_listener('values_end_date');
+			$GLOBALS['phpgw']->jqcal->add_listener('values_termination_date');
 
 			if ($id)
 			{
@@ -1065,12 +1064,9 @@
 
 				if (isset($content) && is_array($content))
 				{
-					$jscal->add_listener('values_date');
+					$GLOBALS['phpgw']->jqcal->add_listener('values_date');
 					$table_update[] = array
 						(
-							'img_cal'						=> $GLOBALS['phpgw']->common->image('phpgwapi','cal'),
-							'lang_datetitle'				=> lang('Select date'),
-
 							'lang_new_index'				=> lang('New index'),
 							'lang_new_index_statustext'		=> lang('Enter a new index'),
 							'lang_date_statustext'			=> lang('Select the date for the update'),
@@ -1342,7 +1338,7 @@
 					'values'		=>	json_encode(array(	array(key => id,			label=>$table_header[0]['header'],	sortable=>true,resizeable=>true),
 					array(key => num,			label=>$table_header[1]['header'],	sortable=>true,resizeable=>true),
 					array(key => descr,			label=>$table_header[2]['header'],	sortable=>true,resizeable=>true),
-					array(key => unit,			label=>$table_header[3]['header'],	sortable=>true,resizeable=>true, formatter=>FormatterCenter),
+					array(key => unit_name,			label=>$table_header[3]['header'],	sortable=>true,resizeable=>true, formatter=>FormatterCenter),
 					array(key => m_cost,		label=>$table_header[4]['header'],	sortable=>true,resizeable=>true, formatter=>FormatterRight),
 					array(key => w_cost,		label=>$table_header[5]['header'],	sortable=>true,resizeable=>true, formatter=>FormatterRight),
 					array(key => total_cost,	label=>$table_header[6]['header'],	sortable=>true,resizeable=>true, formatter=>FormatterRight),
@@ -1400,7 +1396,6 @@
 					'myColumnDefs'							=> $myColumnDefs,
 					'myButtons'								=> $myButtons,
 
-					'img_cal'								=> $GLOBALS['phpgw']->common->image('phpgwapi','cal'),
 					'allow_allrows'							=> true,
 					'allrows'								=> $this->allrows,
 					'start_record'							=> $this->start,
@@ -1521,7 +1516,13 @@
 
 		function download()
 		{
+			if(!$this->acl_read)
+			{
+				$GLOBALS['phpgw']->redirect_link('/index.php',array('menuaction'=> 'property.uilocation.stop', 'perm'=>1, 'acl_location'=> $this->acl_location));
+			}
+
 			$id	= phpgw::get_var('id', 'int');
+			$this->bo->allrows	= true;
 			if($id)
 			{
 				$list = $this->bo->read_details($id);
@@ -1612,8 +1613,7 @@
 				);
 
 
-			$jscal = CreateObject('phpgwapi.jscalendar');
-			$jscal->add_listener('values_date');
+			$GLOBALS['phpgw']->jqcal->add_listener('values_date');
 
 			$msgbox_data = $this->bocommon->msgbox_data($receipt);
 
@@ -1644,8 +1644,6 @@
 
 			$table_update[] = array
 				(
-					'img_cal'					=> $GLOBALS['phpgw']->common->image('phpgwapi','cal'),
-					'lang_datetitle'			=> lang('Select date'),
 					'lang_new_index'			=> lang('New index'),
 					'lang_new_index_statustext'	=> lang('Enter a new index'),
 					'lang_date_statustext'		=> lang('Select the date for the update'),
@@ -1774,7 +1772,6 @@
 					'attributes_values'				=> $values['attributes'],
 					'lookup_functions'				=> $values['lookup_functions'],
 					'dateformat'					=> $dateformat,
-					'img_cal'						=> $GLOBALS['phpgw']->common->image('phpgwapi','cal'),
 
 					'lang_agreement'				=> lang('Agreement'),
 					'agreement_name'				=> $agreement['name'],
@@ -2128,6 +2125,7 @@
 
 			//---datatable1 settings---------------------------------------------------
 			//Prepare array for $datavalues[1]
+
 			for($y=0;$y<count($content);$y++)
 			{
 				for($z=0;$z<=count($content[$y]['row']);$z++)
@@ -2152,16 +2150,16 @@
 			$myColumnDefs[1] = array
 				(
 					'name'			=> "1",
-					'values'		=>	json_encode(array(	array(key => activity_id,	label=>$table_header[0]['header'],	sortable=>true,resizeable=>true),
-					array(key => num,			label=>$table_header[1]['header'],	sortable=>true,resizeable=>true),
-					array(key => descr,			label=>$table_header[2]['header'],	sortable=>true,resizeable=>true),
-					array(key => unit,			label=>$table_header[3]['header'],	sortable=>true,resizeable=>true, formatter=>FormatterCenter),
-					array(key => m_cost,		label=>$table_header[4]['header'],	sortable=>true,resizeable=>true, formatter=>FormatterRight),
-					array(key => w_cost,		label=>$table_header[5]['header'],	sortable=>true,resizeable=>true, formatter=>FormatterRight),
-					array(key => total_cost,	label=>$table_header[6]['header'],	sortable=>true,resizeable=>true, formatter=>FormatterRight),
-					array(key => this_index,	label=>$table_header[7]['header'],	sortable=>true,resizeable=>true),
-					array(key => index_count,	label=>$table_header[8]['header'],	sortable=>true,resizeable=>true, formatter=>FormatterCenter),
-					array(key => index_date,	label=>$table_header[9]['header'],	sortable=>true,resizeable=>true)
+					'values'		=>	json_encode(array(	array('key' => 'activity_id',	'label'=>$table_header[0]['header'],	'sortable'=>true,'resizeable'=>true),
+					array('key' => 'num',			'label'=>$table_header[1]['header'],	'sortable'=>true,'resizeable'=>true),
+					array('key' => 'descr',			'label'=>$table_header[2]['header'],	'sortable'=>true,'resizeable'=>true),
+					array('key' => 'unit_name',		'label'=>$table_header[3]['header'],	'sortable'=>true,'resizeable'=>true, 'formatter'=>'FormatterCenter'),
+					array('key' => 'm_cost',		'label'=>$table_header[4]['header'],	'sortable'=>true,'resizeable'=>true, 'formatter'=>'FormatterRight'),
+					array('key' => 'w_cost',		'label'=>$table_header[5]['header'],	'sortable'=>true,'resizeable'=>true, 'formatter'=>'FormatterRight'),
+					array('key' => 'total_cost',	'label'=>$table_header[6]['header'],	'sortable'=>true,'resizeable'=>true, 'formatter'=>'FormatterRight'),
+					array('key' => 'this_index',	'label'=>$table_header[7]['header'],	'sortable'=>true,'resizeable'=>true),
+					array('key' => 'index_count',	'label'=>$table_header[8]['header'],	'sortable'=>true,'resizeable'=>true, 'formatter'=>'FormatterCenter'),
+					array('key' => 'index_date',	'label'=>$table_header[9]['header'],	'sortable'=>true,'resizeable'=>true)
 				)));
 
 			//---datatable2 settings---------------------------------------------------
@@ -2196,6 +2194,13 @@
 					'values'	=>	json_encode(array(array(key => file_name,label=>lang('Filename'),sortable=>false,resizeable=>true)))
 				);
 
+
+			$link_download = array
+				(
+					'menuaction'	=> 'property.uiagreement.download',
+					'id'		=>$agreement_id
+				);
+
 			$data = array
 				(
 					'property_js'				=> json_encode($GLOBALS['phpgw_info']['server']['webserver_url']."/property/js/yahoo/property2.js"),
@@ -2264,7 +2269,13 @@
 					'lang_status'				=> lang('Status'),
 					'status_list'				=> $this->bo->select_status_list('select',$agreement['status']),
 					'textareacols'				=> isset($GLOBALS['phpgw_info']['user']['preferences']['property']['textareacols']) && $GLOBALS['phpgw_info']['user']['preferences']['property']['textareacols'] ? $GLOBALS['phpgw_info']['user']['preferences']['property']['textareacols'] : 40,
-					'textarearows'				=> isset($GLOBALS['phpgw_info']['user']['preferences']['property']['textarearows']) && $GLOBALS['phpgw_info']['user']['preferences']['property']['textarearows'] ? $GLOBALS['phpgw_info']['user']['preferences']['property']['textarearows'] : 6
+					'textarearows'				=> isset($GLOBALS['phpgw_info']['user']['preferences']['property']['textarearows']) && $GLOBALS['phpgw_info']['user']['preferences']['property']['textarearows'] ? $GLOBALS['phpgw_info']['user']['preferences']['property']['textarearows'] : 6,
+
+					'lang_download'				=> 'download',
+					'link_download'				=> $GLOBALS['phpgw']->link('/index.php',$link_download),
+					'lang_download_help'		=> lang('Download table to your browser'),
+
+
 				);
 
 			//---datatable settings--------------------
