@@ -24,7 +24,7 @@
 	* @internal Development of this application was funded by http://www.bergen.kommune.no/bbb_/ekstern/
 	* @package property
 	* @subpackage budget
- 	* @version $Id: class.uibudget.inc.php 7036 2011-02-23 09:27:06Z sigurdne $
+ 	* @version $Id: class.uibudget.inc.php 11547 2013-12-19 18:50:32Z sigurdne $
 	*/
 
 	/**
@@ -46,13 +46,13 @@
 			(
 				'index'			=> true,
 				'basis'			=> true,
-				'obligations'		=> true,
+				'obligations'	=> true,
 				'view'			=> true,
 				'edit'			=> true,
-				'edit_basis'		=> true,
-				'download'			=> true,
+				'edit_basis'	=> true,
+				'download'		=> true,
 				'delete'		=> true,
-				'delete_basis'		=> true
+				'delete_basis'	=> true
 			);
 		function property_uibudget()
 		{
@@ -78,6 +78,7 @@
 			$this->grouping		= $this->bo->grouping;
 			$this->revision		= $this->bo->revision;
 			$this->details		= $this->bo->details;
+			$this->direction	= $this->bo->direction;
 
 			$this->acl 			= & $GLOBALS['phpgw']->acl;
 
@@ -94,7 +95,8 @@
 					'filter'		=> $this->filter,
 					'cat_id'		=> $this->cat_id,
 					'dimb_id'		=> $this->dimb_id,
-					'allrows'		=> $this->allrows
+					'allrows'		=> $this->allrows,
+					'direction'		=> $this->direction
 				);
 			$this->bo->save_sessiondata($data);
 		}
@@ -115,7 +117,7 @@
 
 			$revision_list	= $this->bo->get_revision_filter_list($this->revision); // reset year
 			$this->year		= $this->bo->year;
-			$this->revision = $this->bo->revision; 
+			$this->revision = $this->bo->revision;
 			$GLOBALS['phpgw_info']['flags']['menu_selection'] .= '::budget';
 
 			$datatable = array();
@@ -157,7 +159,7 @@
 				array_unshift ($values_combo_box[0],$default_value);
 
 				$values_combo_box[1]  = $this->bo->get_revision_filter_list($this->revision);
-				$default_value = array ('id'=>'','name'=>lang('no revision')); 
+				$default_value = array ('id'=>'','name'=>lang('no revision'));
 				if (count($values_combo_box[1]))
 				{
 					array_unshift ($values_combo_box[1],$default_value);
@@ -186,14 +188,28 @@
 					$values_combo_box[3][] = $default_value;
 				}
 
-				$values_combo_box[4] = $this->cats->formatted_xslt_list(array('format'=>'filter','selected' => $this->cat_id,'globals' => True));
-				$default_value = array ('cat_id'=>'','name'=> lang('no category'));
-				array_unshift ($values_combo_box[4]['cat_list'],$default_value);
+				$cat_filter =  $this->cats->formatted_xslt_list(array('select_name' => 'cat_id','selected' => $this->cat_id,'globals' => True,'link_data' => $link_data));
+				foreach($cat_filter['cat_list'] as $_cat)
+				{
+					$values_combo_box[4][] = array
+					(
+						'id' => $_cat['cat_id'],
+						'name' => $_cat['name'],
+						'selected' => $_cat['selected'] ? 1 : 0
+					);
+				}
+
+				array_unshift ($values_combo_box[4],array ('id'=>'', 'name'=>lang('no category')));
 
 				$values_combo_box[5]  = $this->bocommon->select_category_list(array('type'=>'dimb'));
+				foreach($values_combo_box[5] as & $_dimb)
+				{
+					$_dimb['name'] = "{$_dimb['id']}-{$_dimb['name']}";
+				}
 				$default_value = array ('id'=>'','name'=>lang('no dimb'));
 				array_unshift ($values_combo_box[5],$default_value);
 
+
 				$datatable['actions']['form'] = array
 					(
 						array
@@ -245,21 +261,26 @@
 									'tab_index' => 4
 								),
 								array
-								( //boton 	GROUPING
-									'id' 		=> 'btn_cat_id',
-									'name' 		=> 'cat_id',
-									'value'		=> lang('category'),
-									'type' 		=> 'button',
-									'style' 	=> 'filter',
+								( //boton 	USER
+									//	'id' => 'btn_user_id',
+									'id' => 'sel_cat_id',
+									'name' => 'cat_id',
+									'value'	=> lang('Category'),
+									'type' => 'select',
+									'style' => 'filter',
+									'values' => $values_combo_box[4],
+									'onchange'=> 'onChangeSelect("cat_id");',
 									'tab_index' => 5
 								),
 								array
-								( //boton 	GROUPING
-									'id' 		=> 'btn_dimb_id',
-									'name' 		=> 'dimb_id',
-									'value'		=> lang('dimb'),
-									'type' 		=> 'button',
-									'style' 	=> 'filter',
+								(
+									'id' => 'sel_dimb_id',
+									'name' => 'dimb_id',
+									'value'	=> lang('dimb'),
+									'type' => 'select',
+									'style' => 'filter',
+									'values' => $values_combo_box[5],
+									'onchange'=> 'onChangeSelect("dimb_id");',
 									'tab_index' => 6
 								),
 								array
@@ -318,6 +339,7 @@
 									'id' => 'values_combo_box_3',
 									'value'	=> $this->bocommon->select2String($values_combo_box[3])
 								),
+/*
 								array
 								( //div values  combo_box_4
 									'id' => 'values_combo_box_4',
@@ -328,6 +350,7 @@
 									'id' => 'values_combo_box_5',
 									'value'	=> $this->bocommon->select2String($values_combo_box[5])
 								)
+*/
 							)
 						)
 					)
@@ -358,7 +381,7 @@
 					'visible'=>true,	'name'=>'category',	'label'=>lang('category'),	'className'=>'rightClasss', 'sortable'=>false,	'sort_field'=>'','formatter'=>''),
 				array(
 					'visible'=>true,	'name'=>'budget_cost',	'label'=>lang('budget_cost'),	'className'=>'rightClasss', 'sortable'=>true,	'sort_field'=>'budget_cost','formatter'=>'myFormatDate'),
-			);			
+			);
 
 			$content = array();
 			$j = 0;
@@ -459,7 +482,8 @@
 					'startIndex' 		=> $datatable['pagination']['records_start'],
 					'sort'				=> $datatable['sorting']['order'],
 					'dir'				=> $datatable['sorting']['sort'],
-					'records'			=> array()
+					'records'			=> array(),
+					'sum_budget'		=> $this->bo->sum_budget_cost
 				);
 
 			// values for datatable
@@ -477,7 +501,7 @@
 			}
 			//Depended select: REVISION
 			$opt_cb_depend  = $this->bo->get_revision_filter_list($this->revision);
-			$default_value = array ('id'=>'','name'=>lang('no revision')); 
+			$default_value = array ('id'=>'','name'=>lang('no revision'));
 			if (count($opt_cb_depend))
 			{
 				array_unshift ($opt_cb_depend,$default_value);
@@ -503,7 +527,7 @@
 			}
 			$json['hidden']['dependent'][] = array ('id' 	=> $this->grouping,
 				'value' => $this->bocommon->select2String($opt_cb_depend)
-			);										
+			);
 
 			// right in datatable
 			if(isset($datatable['rowactions']['action']) && is_array($datatable['rowactions']['action']))
@@ -562,7 +586,7 @@
 
 			$revision_list	= $this->bo->get_revision_filter_list($this->revision,$basis=true); // reset year
 			$this->year		= $this->bo->year;
-			$this->revision = $this->bo->revision; 
+			$this->revision = $this->bo->revision;
 			$GLOBALS['phpgw_info']['flags']['menu_selection'] .= '::basis';
 
 			$datatable = array();
@@ -604,7 +628,7 @@
 				array_unshift ($values_combo_box[0],$default_value);
 
 				$values_combo_box[1]  = $this->bo->get_revision_filter_list($this->revision,$basis=true);
-				$default_value = array ('id'=>'','name'=>lang('no revision')); 
+				$default_value = array ('id'=>'','name'=>lang('no revision'));
 				if (count($values_combo_box[1]))
 				{
 					array_unshift ($values_combo_box[1],$default_value);
@@ -785,7 +809,7 @@
 					'visible'=>true,	'name'=>'category',	'label'=>lang('category'),	'className'=>'rightClasss', 'sortable'=>false,	'sort_field'=>'','formatter'=>''),
 				array(
 					'visible'=>true,	'name'=>'budget_cost',	'label'=>lang('budget_cost'),	'className'=>'rightClasss', 'sortable'=>true,	'sort_field'=>'budget_cost','formatter'=>myFormatDate),
-			);			
+			);
 
 			$content = array();
 			$j = 0;
@@ -904,7 +928,7 @@
 			}
 			//Depended select: REVISION
 			$opt_cb_depend  = $this->bo->get_revision_filter_list($this->revision,$basis=true);
-			$default_value = array ('id'=>'','name'=>lang('no revision')); 
+			$default_value = array ('id'=>'','name'=>lang('no revision'));
 			if (count($opt_cb_depend))
 			{
 				array_unshift ($opt_cb_depend,$default_value);
@@ -930,7 +954,7 @@
 			}
 			$json['hidden']['dependent'][] = array ('id' 	=> $this->grouping,
 				'value' => $this->bocommon->select2String($opt_cb_depend)
-			);										
+			);
 
 			// right in datatable
 			if(isset($datatable['rowactions']['action']) && is_array($datatable['rowactions']['action']))
@@ -992,21 +1016,23 @@
 
 			$datatable = array();
 			$values_combo_box = array();
-
+			$dry_run = false;
+			$this->save_sessiondata();
 			if( phpgw::get_var('phpgw_return_as') != 'json' )
 			{
 				$datatable['config']['base_url']	= $GLOBALS['phpgw']->link('/index.php', array
 					(
-						'menuaction'	=>'property.uibudget.obligations',
-						'cat_id'		=>$this->cat_id,
-						'filter'		=>$this->filter,
-						'query'			=>$this->query,
-						'district_id'	=>$this->district_id,
-						'grouping'		=>$this->grouping,
-						'year'			=>$this->year,
+						'menuaction'	=> 'property.uibudget.obligations',
+						'cat_id'		=> $this->cat_id,
+						'filter'		=> $this->filter,
+						'query'			=> $this->query,
+						'district_id'	=> $this->district_id,
+						'grouping'		=> $this->grouping,
+						'year'			=> $this->year,
 						'details'		=> $this->details,
 						'allrows'		=> $this->allrows,
-						'dimb_id'		=>$this->dimb_id
+						'dimb_id'		=> $this->dimb_id,
+						'direction'		=> $this->direction
 					));
 				$datatable['config']['allow_allrows'] = true;
 
@@ -1019,6 +1045,7 @@
 					."year:'{$this->year}',"
 					."details:'{$this->details}',"
 					."dimb_id:'{$this->dimb_id}',"
+					."direction:'{$this->direction}',"
 					."allrows:'{$this->allrows}',"
 					."download:'obligations'";
 
@@ -1031,21 +1058,51 @@
 				array_unshift ($values_combo_box[1],$default_value);
 
 				$cat_filter =  $this->cats->formatted_xslt_list(array('select_name' => 'cat_id','selected' => $this->cat_id,'globals' => True,'link_data' => $link_data));
-				$values_combo_box[2] =  $cat_filter[cat_list];
-				$default_value = array ('cat_id'=>'','name'=>lang('no category'));
-				array_unshift ($values_combo_box[2],$default_value);
+				foreach($cat_filter['cat_list'] as $_cat)
+				{
+					$values_combo_box[2][] = array
+					(
+						'id' => $_cat['cat_id'],
+						'name' => $_cat['name'],
+						'selected' => $_cat['selected'] ? 1 : 0
+					);
+				}
+
+				array_unshift ($values_combo_box[2],array ('id'=>'', 'name'=>lang('no category')));
+
+//_debug_array($values_combo_box[2]);
 
 				$values_combo_box[3] =  $this->bo->get_b_group_list($this->grouping);
 				$default_value = array ('id'=>'','name'=>lang('no grouping'));
 				array_unshift ($values_combo_box[3],$default_value);
 
-				$values_combo_box[4]  = $this->bocommon->select_category_list(array('type'=>'dimb'));
-				foreach($values_combo_box[4] as & $_dimb)
+				$values_combo_box[4]  = $this->bocommon->select_category_list(array('type'=>'department'));
+				array_unshift ($values_combo_box[4], array ('id'=>'','name'=>lang('department')));
+
+				$values_combo_box[5]  = $this->bocommon->select_category_list(array('type'=>'dimb'));
+				foreach($values_combo_box[5] as & $_dimb)
 				{
 					$_dimb['name'] = "{$_dimb['id']}-{$_dimb['name']}";
 				}
 				$default_value = array ('id'=>'','name'=>lang('no dimb'));
-				array_unshift ($values_combo_box[4],$default_value);
+				array_unshift ($values_combo_box[5],$default_value);
+
+
+				$values_combo_box[6]  = array
+				(
+					array
+					(
+						'id' => 'expences',
+						'name'	=> lang('expences'),
+						'selected'	=> $this->direction == 'expences' ? 1 : 0
+					),
+					array
+					(
+						'id' => 'income',
+						'name'	=> lang('income'),
+						'selected'	=> $this->direction == 'income' ? 1 : 0
+					)
+				);
 
 				$datatable['actions']['form'] = array
 					(
@@ -1079,7 +1136,7 @@
 									'style' 	=> 'filter',
 									'tab_index' => 2
 								),
-								array
+/*								array
 								( //boton 	CATEGORY
 									'id' 		=> 'btn_cat_id',
 									'name' 		=> 'cat_id',
@@ -1087,7 +1144,7 @@
 									'type' 		=> 'button',
 									'style' 	=> 'filter',
 									'tab_index' => 3
-								),			                                        
+								),*/
 								array
 								( //boton 	GROUPING
 									'id' 		=> 'btn_grouping',
@@ -1098,20 +1155,74 @@
 									'tab_index' => 4
 								),
 								array
-								( //boton 	GROUPING
-									'id' 		=> 'btn_dimb_id',
-									'name' 		=> 'dimb_id',
-									'value'		=> lang('dimb'),
-									'type' 		=> 'button',
-									'style' 	=> 'filter',
+								( //boton 	USER
+									//	'id' => 'btn_user_id',
+									'id' => 'sel_cat_id',
+									'name' => 'cat_id',
+									'value'	=> lang('Category'),
+									'type' => 'select',
+									'style' => 'filter',
+									'values' => $values_combo_box[2],
+									'onchange'=> 'onChangeSelect("cat_id");',
+									'tab_index' => 3
+								),
+/*
+								array
+								( //boton 	USER
+									//	'id' => 'btn_user_id',
+									'id' => 'sel_grouping',
+									'name' => 'grouping',
+									'value'	=> lang('grouping'),
+									'type' => 'select',
+									'style' => 'filter',
+									'values' => $values_combo_box[3],
+									'onchange'=> 'onChangeSelect("grouping");',
+									'tab_index' => 4
+								),
+*/
+								array
+								( //boton 	USER
+									//	'id' => 'btn_user_id',
+									'id' => 'sel_department',
+									'name' => 'department',
+									'value'	=> lang('department'),
+									'type' => 'select',
+									'style' => 'filter',
+									'values' => $values_combo_box[4],
+									'onchange'=> 'onChangeSelect("department");',
 									'tab_index' => 5
 								),
+								array
+								( //boton 	USER
+									//	'id' => 'btn_user_id',
+									'id' => 'sel_dimb_id',
+									'name' => 'dimb_id',
+									'value'	=> lang('dimb'),
+									'type' => 'select',
+									'style' => 'filter',
+									'values' => $values_combo_box[5],
+									'onchange'=> 'onChangeSelect("dimb_id");',
+									'tab_index' => 6
+								),
+								array
+								( //boton 	USER
+									//	'id' => 'btn_user_id',
+									'id' => 'sel_direction',
+									'name' => 'direction',
+									'value'	=> lang('direction'),
+									'type' => 'select',
+									'style' => 'filter',
+									'values' => $values_combo_box[6],
+									'onchange'=> 'onChangeSelect("direction");',
+									'tab_index' => 7
+								),
+
 								array
 								(
 									'type'	=> 'button',
 									'id'	=> 'btn_export',
 									'value'	=> lang('download'),
-									'tab_index' => 8
+									'tab_index' => 10
 								),
 								array
 								( //boton     SEARCH
@@ -1119,7 +1230,7 @@
 									'name' 		=> 'search',
 									'value'    	=> lang('search'),
 									'type' 		=> 'button',
-									'tab_index' => 7
+									'tab_index' => 9
 								),
 								array
 								( // TEXT IMPUT
@@ -1129,7 +1240,7 @@
 									'type' 		=> 'text',
 									'size'    	=> 28,
 									'onkeypress'=> 'return pulsar(event)',
-									'tab_index' => 6
+									'tab_index' => 8
 								)
 							),
 							'hidden_value' => array
@@ -1145,25 +1256,21 @@
 									'value'	=> $this->bocommon->select2String($values_combo_box[1])
 								),
 								array
-								( //div values  combo_box_2
-									'id' => 'values_combo_box_2',
-									'value'	=> $this->bocommon->select2String($values_combo_box[2],'cat_id','name')
-								),
-								array
 								( //div values  combo_box_3
-									'id' => 'values_combo_box_3',
+									'id' => 'values_combo_box_2',
 									'value'	=> $this->bocommon->select2String($values_combo_box[3])
-								),
+								),/*
 								array
 								( //div values  combo_box_4
 									'id' => 'values_combo_box_4',
 									'value'	=> $this->bocommon->select2String($values_combo_box[4])
-								)
+								)*/
 
 							)
 						)
 					)
 				);
+				$dry_run = true;
 			}
 
 			$uicols = array (
@@ -1172,8 +1279,8 @@
 					'col_name'=>'grouping',		'visible'=>false,	'label'=>'',				'className'=>'',				'sortable'=>false,	'sort_field'=>'',			'formatter'=>''),
 				array(
 					'col_name'=>'b_account',		'visible'=>true,	'label'=>lang('grouping'),	'className'=>'centerClasss',	'sortable'=>true,	'sort_field'=>'b_account',	'formatter'=>'myformatLinkPGW'),
-				array(
-					'col_name'=>'district_id',	'visible'=>true,	'label'=>lang('district_id'),'className'=>'centerClasss',	'sortable'=>false,	'sort_field'=>'',			'formatter'=>''),
+//				array(
+//					'col_name'=>'district_id',	'visible'=>true,	'label'=>lang('district_id'),'className'=>'centerClasss',	'sortable'=>false,	'sort_field'=>'',			'formatter'=>''),
 				array(
 					'col_name'=>'ecodimb',		'visible'=>true,	'label'=>lang('dimb'),	'className'=>'centerClasss',	'sortable'=>false,	'sort_field'=>'',			'formatter'=>''),
 				array(
@@ -1200,19 +1307,29 @@
 					'col_name'=>'diff_ex',		'visible'=>false,	'label'=>'',				'className'=>'rightClasss', 	'sortable'=>false,	'sort_field'=>'',			'formatter'=>''),
 				array(
 					'col_name'=>'diff',			'visible'=>true,	'label'=>lang('difference'),'className'=>'rightClasss', 	'sortable'=>false,	'sort_field'=>'',			'formatter'=>'')
-				);	
+				);
 
-			$location_list = array();
 
-			$location_list = $this->bo->read_obligations(); 
+			//FIXME
+			if($dry_run)
+			{
+				$location_list = array();
+
+			}
+		//	else
+			{
+				$location_list = $this->bo->read_obligations();
+			}
+
 			//_debug_array($location_list);
+
 			$entry = $content = array();
 			$j = 0;
 			//cramirez: add this code because  "mktime" functions fire an error
 			if($this->year == "")
 			{
 				$today = getdate();
-				$this->year = $today[year];
+				$this->year = $today['year'];
 			}
 
 			if (isset($location_list) && is_array($location_list))
@@ -1220,16 +1337,15 @@
 				$details = $this->details ? false : true;
 
 				$start_date = $GLOBALS['phpgw']->common->show_date(mktime(0,0,0,1,1,$this->year),$GLOBALS['phpgw_info']['user']['preferences']['common']['dateformat']);
-				$end_date	= $GLOBALS['phpgw']->common->show_date(mktime(0,0,0,12,31,$this->year),$GLOBALS['phpgw_info']['user']['preferences']['common']['dateformat']); 
+				$end_date	= $GLOBALS['phpgw']->common->show_date(mktime(0,0,0,12,31,$this->year),$GLOBALS['phpgw_info']['user']['preferences']['common']['dateformat']);
 
-				$sum_obligation = $sum_hits = $sum_budget_cost = $sum_actual_cost = 0;	
+				$sum_obligation = $sum_hits = $sum_budget_cost = $sum_actual_cost = 0;
 				foreach($location_list as $entry)
 				{
-					//_debug_array($entry);
 					$content[] = array
 						(
 							'grouping'			=> $entry['grouping'],
-							'b_account'			=> $entry['b_account'],	
+							'b_account'			=> $entry['b_account'],
 							'district_id'		=> $entry['district_id'],
 							'ecodimb'			=> $entry['ecodimb'],
 							'hits_ex'			=> $entry['hits'],
@@ -1238,21 +1354,15 @@
 							'budget_cost'		=> number_format($entry['budget_cost'], 0, ',', ' '),
 							'obligation_ex'		=> $entry['obligation'],
 							'obligation'		=> number_format($entry['obligation'], 0, ',', ' '),
-							'link_obligation'	=> $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> 'property.uiworkorder.index', 'filter'=>'all', 'paid'=>1, 'district_id'=> $entry['district_id'], 'b_group'=> $entry['grouping'], 'b_account' =>$b_account, 'start_date'=> $start_date, 'end_date'=> $end_date)),
+							'link_obligation'	=> $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> 'property.uiworkorder.index', 'filter'=>'all', 'paid'=>1, 'district_id'=> $entry['district_id'], 'b_group'=> $entry['grouping'], 'b_account' =>$entry['b_account'], 'start_date'=> $start_date, 'end_date'=> $end_date, 'ecodimb' => $entry['ecodimb'], 'status_id' => 'all', 'obligation' => true)),
 							'actual_cost_ex'	=> $entry['actual_cost'],
 							'actual_cost'		=> number_format($entry['actual_cost'], 0, ',', ' '),
-							'link_actual_cost'	=> $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> 'property.uiinvoice.consume', 'district_id'=> $entry['district_id'], 'b_account_class'=> $entry['grouping'], 'b_account' =>$b_account,  'start_date'=> $start_date, 'end_date'=> $end_date, 'submit_search'=>true)),
+							'link_actual_cost'	=> $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> 'property.uiinvoice.consume', 'district_id'=> $entry['district_id'], 'b_account_class'=> $entry['grouping'], 'b_account' =>$entry['b_account'],  'start_date'=> $start_date, 'end_date'=> $end_date, 'ecodimb' => $entry['ecodimb'], 'submit_search'=>true)),
 							'diff_ex'			=> $entry['budget_cost'] - $entry['actual_cost'] - $entry['obligation'],
 							'diff'				=> number_format($entry['budget_cost'] - $entry['actual_cost'] - $entry['obligation'], 0, ',', ' ')
-						);	
-
-					//					$sum_obligation += $entry['obligation'];
-					//					$sum_hits += $entry['hits'];
-					//					$sum_budget_cost += $entry['budget_cost'];
-					//					$sum_actual_cost += $entry['actual_cost'];					
+						);
 				}
 
-				//				$sum_diff = $sum_budget_cost - $sum_actual_cost - $sum_obligation;
 			}
 
 			$j=0;
@@ -1321,7 +1431,12 @@
 					'startIndex' 		=> $datatable['pagination']['records_start'],
 					'sort'				=> $datatable['sorting']['order'],
 					'dir'				=> $datatable['sorting']['sort'],
-					'records'			=> array()
+					'records'			=> array(),
+					'sum_budget'		=> $this->bo->sum_budget_cost,
+					'sum_obligation'	=> $this->bo->sum_obligation_cost,
+					'sum_actual'		=> $this->bo->sum_actual_cost,
+					'sum_diff'			=> $this->bo->sum_budget_cost - $this->bo->sum_actual_cost - $this->bo->sum_obligation_cost,
+					'sum_hits'			=> $this->bo->sum_hits
 				);
 
 			// values for datatable
@@ -1414,12 +1529,12 @@
 
 				if(!$values['district_id'] && !$budget_id > 0)
 				{
-					//			$receipt['error'][]=array('msg'=>lang('Please select a district !'));
+		//			$receipt['error'][]=array('msg'=>lang('Please select a district !'));
 				}
 
 				if(!$values['budget_cost'])
 				{
-					$receipt['error'][]=array('msg'=>lang('Please enter a budget cost !'));
+//					$receipt['error'][]=array('msg'=>lang('Please enter a budget cost !'));
 				}
 
 				if(!isset($receipt['error']) || !$receipt['error'])
@@ -1488,7 +1603,7 @@
 
 					'lang_year'						=> lang('year'),
 					'lang_year_statustext'			=> lang('Budget year'),
-					'year'							=> $this->bocommon->select_list($values['year'],$this->bo->get_year_list()),
+					'year'							=> $this->bocommon->select_list($values['year']?$values['year']:date('Y'),$this->bo->get_year_list()),
 
 					'lang_district'					=> lang('District'),
 					'lang_no_district'				=> lang('no district'),
@@ -1883,7 +1998,7 @@
 						lang('grouping'),
 						lang('district_id'),
 						lang('dimb'),
-						lang('category'), 
+						lang('category'),
 						lang('budget')
 					);
 					break;
@@ -1898,7 +2013,7 @@
 						'grouping',
 						'district_id',
 						'ecodimb',
-						'category', 
+						'category',
 						'budget_cost'
 						);
 					$descr = array
@@ -1910,20 +2025,20 @@
 						lang('grouping'),
 						lang('district_id'),
 						lang('dimb'),
-						lang('category'), 
+						lang('category'),
 						lang('budget')
 					);
 					break;
 				case 'obligations':
 					$gross_list= $this->bo->read_obligations();
-					$sum_obligation = $sum_hits = $sum_budget_cost = $sum_actual_cost = 0;	
+					$sum_obligation = $sum_hits = $sum_budget_cost = $sum_actual_cost = 0;
 					$list = array();
 					foreach($gross_list as $entry)
 					{
 						$list[] = array
 						(
 							'grouping'			=> $entry['grouping'],
-							'b_account'			=> $entry['b_account'],	
+							'b_account'			=> $entry['b_account'],
 							'district_id'		=> $entry['district_id'],
 							'ecodimb'			=> $entry['ecodimb'],
 							'hits'				=> $entry['hits'],
@@ -1931,7 +2046,7 @@
 							'obligation'		=> $entry['obligation'],
 							'actual_cost'		=> $entry['actual_cost'],
 							'diff'				=> ($entry['budget_cost'] - $entry['actual_cost'] - $entry['obligation']),
-						);	
+						);
 					}
 					$names = array
 					(
