@@ -57,17 +57,6 @@
 		return $text;
 	}
 
-	/**
-	 * Generates a javascript translator object/hash for the specified fields.
-	 */
-	function js_lang()
-	{
-		$keys = func_get_args();
-		$strings = array();
-		foreach($keys as $key) { $strings[$key] = is_string($key) ? lang($key) : call_user_func_array('lang', $key); }
-		return json_encode($strings);
-	}
-	
 	/**
 	 * Creates an array of translated strings.
 	 */
