@@ -24,7 +24,7 @@
 	* @internal Development of this application was funded by http://www.bergen.kommune.no/bbb_/ekstern/
 	* @package property
 	* @subpackage document
- 	* @version $Id: class.uidocument.inc.php 6937 2011-02-06 18:32:32Z sigurdne $
+ 	* @version $Id: class.uidocument.inc.php 9208 2012-04-23 12:10:17Z sigurdne $
 	*/
 	phpgw::import_class('phpgwapi.yui');
 
@@ -763,6 +763,11 @@
 				{
 					if($document_entry['link'])
 					{
+						if(!preg_match('/^HTTP/i', $document_entry['link']))
+						{
+							$document_entry['link'] = 'file:///' . str_replace(':','|',$document_entry['link']);
+						}
+
 						$link_view_file=$document_entry['link'];
 						$document_entry['document_name']='link';
 						unset($link_to_files);
@@ -788,8 +793,8 @@
 						if(isset($uicols['datatype']) && isset($uicols['datatype'][$k]) && $uicols['datatype'][$k]=='link' && $document_entry[$uicols['name'][$k]])
 						{
 							$datatable['rows']['row'][$j]['column'][$k]['format'] 		= 'link';
-							$datatable['rows']['row'][$j]['column'][$k]['value']		= $document_entry[$uicols['name'][$k]];
 							$datatable['rows']['row'][$j]['column'][$k]['link']			= $link_view_file;
+							$datatable['rows']['row'][$j]['column'][$k]['value']		= $document_entry[$uicols['name'][$k]];
 							$datatable['rows']['row'][$j]['column'][$k]['target']		= '_blank';
 						}
 					}
@@ -1315,8 +1320,7 @@
 
 			$msgbox_data = $this->bocommon->msgbox_data($receipt);
 
-			$jscal = CreateObject('phpgwapi.jscalendar');
-			$jscal->add_listener('values_document_date');
+			$GLOBALS['phpgw']->jqcal->add_listener('values_document_date');
 
 			//data test    	$record_history = array(array(value_date=>"1111",value_user=>"22222",value_action=>"33333",value_new_value=>"44444444"));
 
@@ -1355,9 +1359,6 @@
 					'lang_history'					=> lang('History'),
 					'lang_no_history'				=> lang('No history'),
 
-					'img_cal'						=> $GLOBALS['phpgw']->common->image('phpgwapi','cal'),
-					'lang_datetitle'				=> lang('Select date'),
-
 					'lang_document_date_statustext'	=> lang('Select date the document was created'),
 					'lang_document_date'			=> lang('document date'),
 					'value_document_date'			=> $values['document_date'],
