@@ -24,7 +24,7 @@
 	* @internal Development of this application was funded by http://www.bergen.kommune.no/bbb_/ekstern/
 	* @package property
 	* @subpackage admin
- 	* @version $Id: class.uievent.inc.php 7189 2011-04-06 10:14:45Z sigurdne $
+ 	* @version $Id: class.uievent.inc.php 9208 2012-04-23 12:10:17Z sigurdne $
 	*/
 	phpgw::import_class('phpgwapi.yui');
 	phpgw::import_class('property.uicommon');
@@ -81,6 +81,7 @@
 			$this->allrows				= $this->bo->allrows;
 			$this->location_id			= $this->bo->location_id;
 			$this->user_id				= $this->bo->user_id;
+			$this->status_id			= $this->bo->status_id;
 		}
 
 		function save_sessiondata()
@@ -94,6 +95,7 @@
 					'allrows'		=> $this->allrows,
 					'location_id'	=> $this->location_id,
 					'user_id'		=> $this->user_id,
+					'status_id'		=> $this->status_id
 				);
 			$this->bo->save_sessiondata($data);
 		}
@@ -140,7 +142,8 @@
 
 				$datatable['config']['base_java_url'] = "menuaction:'property.uievent.index',"
 					."location_id:'{$this->location_id}',"
-					."user_id:'{$this->user_id}'";
+					."user_id:'{$this->user_id}',"
+					."status_id:'{$this->status_id}'";					
 
 				$values_combo_box = array();
 
@@ -154,6 +157,12 @@
 				$default_value = array('id'=>'','name'=>lang('no user'));
 				array_unshift ($values_combo_box[1],$default_value);
 
+				$values_combo_box[2]  = array();
+				array_unshift ($values_combo_box[2],array ('id'=>'exception','name'=> lang('exception')));
+				array_unshift ($values_combo_box[2],array ('id'=>'closed','name'=> lang('closed')));
+				array_unshift ($values_combo_box[2],array ('id'=>'all','name'=> lang('all')));
+				array_unshift ($values_combo_box[2],array ('id'=>'open','name'=> lang('open')));
+
 				$datatable['config']['allow_allrows'] = true;
 
 				$datatable['actions']['form'] = array
@@ -191,6 +200,15 @@
 									'tab_index' => 2
 								),
 								array
+								( //boton 	STATUS
+									'id' => 'btn_status_id',
+									'name' => 'status_id',
+									'value'	=> lang('Status'),
+									'type' => 'button',
+									'style' => 'filter',
+									'tab_index' => 3
+								),
+								array
 								( // boton SAVE
 									'id'	=> 'btn_save',
 									//'name' => 'save',
@@ -224,7 +242,7 @@
 										'menuaction' => 'property.uiproject.date_search')
 									)."','','width=350,height=250')",
 									'value' => lang('Date search'),
-									'tab_index' => 5
+									'tab_index' => 6
 								),
 								array
 								( //button     SEARCH
@@ -232,7 +250,7 @@
 									'name' => 'search',
 									'value'    => lang('search'),
 									'type' => 'button',
-									'tab_index' => 4
+									'tab_index' => 5
 								),
 								array
 								( // TEXT INPUT
@@ -242,7 +260,7 @@
 									'type' => 'text',
 									'onkeypress' => 'return pulsar(event)',
 									'size'    => 28,
-									'tab_index' => 3
+									'tab_index' => 4
 								),
 								array
 								( //place holder for selected events
@@ -262,6 +280,11 @@
 								( //div values  combo_box_1
 									'id' => 'values_combo_box_1',
 									'value'	=> $this->bocommon->select2String($values_combo_box[1])
+								),
+								array
+								( //div values  combo_box_2
+									'id' => 'values_combo_box_2',
+									'value'	=> $this->bocommon->select2String($values_combo_box[2])
 								)
 							)
 						)
@@ -751,9 +774,8 @@
 				$tabs['plan']		= array('label' => lang('plan'), 'link' => '#plan');
 			}
 
-			$jscal = CreateObject('phpgwapi.jscalendar');
-			$jscal->add_listener('values_start_date');
-			$jscal->add_listener('values_end_date');
+			$GLOBALS['phpgw']->jqcal->add_listener('values_start_date');
+			$GLOBALS['phpgw']->jqcal->add_listener('values_end_date');
 
 			$msgbox_data = $this->bocommon->msgbox_data($receipt);
 
@@ -766,13 +788,10 @@
 				(
 					'contact_data'					=> $contact_data,
 					'link_schedule'					=> $GLOBALS['phpgw']->link('/index.php',$link_schedule_data),
-					'img_cal'						=> $GLOBALS['phpgw']->common->image('phpgwapi','cal'),
-					'lang_datetitle'			=> lang('Select date'),
 
 					'lang_start_date_statustext'	=> lang('Select the date for the event'),
 					'lang_start_date'				=> lang('date'),
 					'value_start_date'				=> $values['start_date'],
-					//			'start_date'					=> $start_date,
 
 					'value_enabled'					=> isset($values['enabled']) ? $values['enabled'] : '',
 					'lang_enabled'					=> lang('enabled'),
