@@ -24,7 +24,7 @@
 	* @internal Development of this application was funded by http://www.bergen.kommune.no/bbb_/ekstern/
 	* @package property
 	* @subpackage agreement
- 	* @version $Id: class.uipricebook.inc.php 6718 2011-01-03 09:29:44Z sigurdne $
+ 	* @version $Id: class.uipricebook.inc.php 10797 2013-02-12 12:18:01Z sigurdne $
 	*/
 
 	/**
@@ -235,13 +235,10 @@
 
 			if($this->acl_manage)
 			{
-				$jscal = CreateObject('phpgwapi.jscalendar');
-				$jscal->add_listener('values_date');
+				$GLOBALS['phpgw']->jqcal->add_listener('values_date');
 
 				$table_update[] = array
 					(
-						'img_cal'						=> $GLOBALS['phpgw']->common->image('phpgwapi','cal'),
-						'lang_datetitle'				=> lang('Select date'),
 						'lang_new_index'				=> lang('New index'),
 						'lang_new_index_statustext'		=> lang('Enter a new index'),
 						'lang_date_statustext'			=> lang('Select the date for the update'),
@@ -896,13 +893,10 @@
 					'lang_delete'		=> lang('Delete')
 				);
 
-			$jscal = CreateObject('phpgwapi.jscalendar');
-			$jscal->add_listener('values_date');
+			$GLOBALS['phpgw']->jqcal->add_listener('values_date');
 
 			$table_update[] = array
 				(
-					'img_cal'						=> $GLOBALS['phpgw']->common->image('phpgwapi','cal'),
-					'lang_datetitle'				=> lang('Select date'),
 					'lang_new_index'				=> lang('New index'),
 					'lang_new_index_statustext'		=> lang('Enter a new index'),
 					'lang_date_statustext'			=> lang('Select the date for the update'),
@@ -912,8 +906,6 @@
 
 			$table_first_entry[] = array
 				(
-					'img_cal'					=> $GLOBALS['phpgw']->common->image('phpgwapi','cal'),
-					'lang_datetitle'			=> lang('Select date'),
 					'lang_m_cost'				=> lang('Material cost'),
 					'lang_m_cost_statustext'	=> lang('Enter a value for the material cost'),
 					'lang_w_cost'				=> lang('Labour cost'),
@@ -1154,7 +1146,7 @@
 
 			$uicols = array (
 				'input_type'	=>	array(hidden,text,text,text,text,text,text,text),
-				'name'			=>	array(activity_id,num,descr,unit,ns3420,base_descr,branch,dim_d),
+				'name'			=>	array(activity_id,num,descr,unit_name,ns3420,base_descr,branch,dim_d),
 				'formatter'		=>	array('','','','','','','',''),
 				'descr'			=>	array('',lang('Activity Num'),lang('Description'),lang('Unit'),lang('NS3420'),lang('Base'),lang('Branch'),lang('Dim d'))
 			);
