@@ -9,7 +9,7 @@
 	* @package phpgroupware
 	* @subpackage property
 	* @category core
- 	* @version $Id: class.uiresponsible.inc.php 6972 2011-02-11 09:03:26Z sigurdne $
+ 	* @version $Id: class.uiresponsible.inc.php 9208 2012-04-23 12:10:17Z sigurdne $
 	*/
 
 	/*
@@ -75,6 +75,11 @@
 		 */
 		protected $acl_location;
 
+		/**
+		 * @var string $appname the application name
+		 */
+		protected $appname;
+
 		/**
 		 * @var bool $acl_read does the current user have read access to the current location
 		 */
@@ -102,7 +107,8 @@
 			(
 				'index' 		=> true,
 				'contact' 		=> true,
-				'edit_type' 	=> true,
+				'edit' 			=> true,
+				'edit_role'		=> true,
 				'edit_contact' 	=> true,
 				'no_access'		=> true,
 				'delete_type'	=> true
@@ -115,17 +121,18 @@
 		public function __construct()
 		{
 			$GLOBALS['phpgw_info']['flags']['xslt_app'] = true;
-			$GLOBALS['phpgw_info']['flags']['menu_selection'] = 'admin::property::responsible_matrix';
+
 			$this->bo					= CreateObject('property.boresponsible', true);
 			$this->nextmatchs			= CreateObject('phpgwapi.nextmatchs');
 			$this->acl 					= & $GLOBALS['phpgw']->acl;
-			$this->acl_location 		= $this->bo->acl_location;
+			$this->acl_location 		= $this->bo->get_acl_location();
 			$this->acl_read 			= $this->acl->check($this->acl_location, PHPGW_ACL_READ, 'property');
 			$this->acl_add 				= $this->acl->check($this->acl_location, PHPGW_ACL_ADD, 'property');
 			$this->acl_edit 			= $this->acl->check($this->acl_location, PHPGW_ACL_EDIT, 'property');
 			$this->acl_delete 			= $this->acl->check($this->acl_location, PHPGW_ACL_DELETE, 'property');
 			$this->bolocation			= CreateObject('preferences.boadmin_acl');
-			$this->bolocation->acl_app 	= 'property';
+			$this->appname				= $this->bo->appname;
+			$this->bolocation->acl_app 	= $this->appname;
 			$this->location				= $this->bo->location;
 			$this->cats					= & $this->bo->cats;
 			$this->query				= $this->bo->query;
@@ -133,6 +140,8 @@
 			$this->sort					= $this->bo->sort;
 			$this->order				= $this->bo->order;
 			$this->cat_id				= $this->bo->cat_id;
+
+			$GLOBALS['phpgw_info']['flags']['menu_selection'] = "admin::{$this->appname}::responsible_matrix";
 		}
 
 		/**
@@ -189,7 +198,8 @@
 						'menuaction'=> 'property.uiresponsible.index',
 						'query'		=> $this->query,
 						'location'	=> $this->location,
-						'lookup'	=> $lookup
+						'lookup'	=> $lookup,
+						'appname'	=> $this->appname
 
 					));
 
@@ -198,16 +208,24 @@
 				$datatable['config']['base_java_url'] = "menuaction:'property.uiresponsible.index',"	    											
 					."query:'{$this->query}',"
 					."location:'{$this->location}',"
-					."lookup:'{$lookup}'";          
+					."lookup:'{$lookup}',"          
+					."appname:'{$this->appname}'";          
 
-				$values_combo_box[0]  = $this->bolocation->select_location('filter', $this->location);
-				$default_value = array ('id'=>'','descr'=>lang('No location'));
-				array_unshift ($values_combo_box[0],$default_value);
-				foreach($values_combo_box[0] as &$_location)
+				$values_combo_box = array();
+
+				$locations = $GLOBALS['phpgw']->locations->get_locations(false, $this->appname, false, false, true);
+				foreach ( $locations as $loc_id => $loc_descr )
 				{
-					$_location['name'] = $_location['descr'];
+					$values_combo_box[0][] = array
+					(
+						'id'	=> $loc_id,
+						'name'	=> "{$loc_id} [{$loc_descr}]",
+					);
 				}
 
+				$default_value = array ('id'=>'','name'=>lang('No location'));
+				array_unshift ($values_combo_box[0],$default_value);
+
 				$datatable['actions']['form'] = array
 					(
 						array
@@ -218,7 +236,8 @@
 								'menuaction' 	=> 'property.uiresponsible.index',
 								'query'		=> $this->query,
 								'location'	=> $this->location,
-								'lookup'	=> $lookup
+								'lookup'	=> $lookup,
+								'appname'	=> $this->appname
 							)
 						),
 						'fields'	=> array
@@ -267,7 +286,7 @@
 								array
 								( //div values  combo_box_0
 									'id' => 'values_combo_box_0',
-									'value'	=> $bocommon->select2String($values_combo_box[0], 'id','descr') //i.e.  id,value/id,vale/
+									'value'	=> $bocommon->select2String($values_combo_box[0], 'id','name') //i.e.  id,value/id,vale/
 								)
 							)
 						)
@@ -279,10 +298,10 @@
 			$responsible_info = $this->bo->read_type();
 
 			$uicols = array (
-				'input_type'	=>	array('hidden','text','text','text','text','hidden','text','text','hidden','hidden'),
-				'name'			=>	array('id','name','descr','category','created_by','created_on','app_name','active','loc','location'),
+				'input_type'	=>	array('text','text','text','hidden','hidden','hidden','text','hidden','hidden','hidden'),
+				'name'			=>	array('id','name','descr','category','created_by','created_on','appname','active','loc','location'),
 				'formatter'		=>	array('','','','','','','','','',''),
-				'descr'			=>	array('',lang('name'),lang('descr'),lang('category'),lang('supervisor'),'',lang('location'),lang('active'),'','')
+				'descr'			=>	array(lang('id'),lang('name'),lang('descr'),lang('category'),lang('user'),'',lang('application'),lang('active'),'','')
 			);
 
 			$j=0;
@@ -330,6 +349,11 @@
 						$datatable['headers']['header'][$i]['sortable']		= true;
 						$datatable['headers']['header'][$i]['sort_field'] 	= 'name';
 					}		
+					else if($uicols['name'][$i]=='id')
+					{
+						$datatable['headers']['header'][$i]['sortable']		= true;
+						$datatable['headers']['header'][$i]['sort_field'] 	= 'id';
+					}		
 				}
 				else
 				{
@@ -399,8 +423,9 @@
 							'text' 			=> lang('edit'),
 							'action'		=> $GLOBALS['phpgw']->link('/index.php',array
 							(
-								'menuaction'	=> 'property.uiresponsible.edit_type',
-								//											'location'		=> $this->location
+								'menuaction'	=> 'property.uiresponsible.edit',
+								'appname'	=> $this->appname
+//								'location'		=> $this->location
 							)),
 							'parameters'	=> $parameters3
 						);
@@ -415,7 +440,8 @@
 							'confirm_msg'	=> lang('do you really want to delete this entry'),
 							'action'		=> $GLOBALS['phpgw']->link('/index.php',array
 							(
-								'menuaction'	=> 'property.uiresponsible.delete_type'
+								'menuaction'	=> 'property.uiresponsible.delete_type',
+								'appname'	=> $this->appname
 							)),
 							'parameters'	=> $parameters
 						);
@@ -427,7 +453,8 @@
 						'text' 			=> lang('contacts'),
 						'action'		=> $GLOBALS['phpgw']->link('/index.php',array
 						(
-							'menuaction'	=> 'property.uiresponsible.contact'
+							'menuaction'	=> 'property.uiresponsible.contact',
+							'appname'	=> $this->appname
 						)),
 						'parameters'	=> $parameters2
 					);
@@ -440,7 +467,8 @@
 							'text' 			=> lang('add'),
 							'action'		=> $GLOBALS['phpgw']->link('/index.php',array
 							(
-								'menuaction'	=> 'property.uiresponsible.edit_type',
+								'menuaction'	=> 'property.uiresponsible.edit',
+								'appname'		=> $this->appname,
 								'location'		=> $this->location
 							))
 						);
@@ -582,126 +610,171 @@
 			$this->_save_sessiondata();
 		}
 
-		/**
-		 * Add or Edit available responsible types
-		 *
-		 * @return void
-		 */
 
-		public function edit_type()
+		function edit()
 		{
-			if(!$this->acl_add)
+			if(!$this->acl_add && !$this->acl_edit)
 			{
-				$this->no_access();
-				return;
+				$GLOBALS['phpgw']->redirect_link('/index.php',array('menuaction'=> 'property.uilocation.stop', 'perm'=>2, 'acl_location'=> $this->acl_location));
 			}
 
-			if(!$GLOBALS['phpgw']->locations->get_id('property', $this->location))
+			$id			= phpgw::get_var('id', 'int');
+			$location	= phpgw::get_var('location', 'string');
+			$values		= phpgw::get_var('values');
+
+			if ((isset($values['save']) && $values['save']) || (isset($values['apply']) && $values['apply']))
 			{
-				$receipt['error'][]=array('msg'=>lang('not a valid location!'));
-			}
-
-			$id		= phpgw::get_var('id', 'int');
-			$values	= phpgw::get_var('values', 'string', 'POST');
-
-			$GLOBALS['phpgw']->xslttpl->add_file(array('responsible'));
-
-			if (isset($values) && is_array($values))
-			{
-				if(!$this->acl_edit)
+				if($GLOBALS['phpgw']->session->is_repost())
 				{
-					$this->no_access();
-					return;
+	//				$receipt['error'][]=array('msg'=>lang('Hmm... looks like a repost!'));
 				}
 
-				if ((isset($values['save']) && $values['save']) || (isset($values['apply']) && $values['apply']))
+				if(!isset($values['location']) || !$values['location'])
 				{
-					$values['location'] = $this->location;
-					if(!$values['cat_id'] || $values['cat_id'] == 'none')
-					{
-						//			$receipt['error'][]=array('msg'=>lang('Please select a category!'));
-					}
-					if(!$values['name'])
-					{
-						$receipt['error'][]=array('msg'=>lang('Please enter a name !'));
-					}
+//					$receipt['error'][]=array('msg'=>lang('Please select a location!'));
+				}
 
-					if($id)
-					{
-						$values['id']=$id;
-					}
+				if(!isset($values['name']) || !$values['name'])
+				{
+					$receipt['error'][]=array('msg'=>lang('Please enter a name!'));
+				}
 
-					if(!isset($receipt['error']) || !$receipt['error'])
-					{
-						$receipt = $this->bo->save_type($values);
-						$id = $receipt['id'];
-
-						if (isset($values['save']) && $values['save'])
-						{
-							$GLOBALS['phpgw']->session->appsession('session_data', 'responsible_receipt', $receipt);
-							$GLOBALS['phpgw']->redirect_link('/index.php', array
-								(
-									'menuaction'=> 'property.uiresponsible.index',
-									'location' => $this->location
-								));
-						}
-					}
+				if($id)
+				{
+					$values['id']=$id;
 				}
 				else
 				{
-					$GLOBALS['phpgw']->redirect_link('/index.php', array
-						(
-							'menuaction'=> 'property.uiresponsible.index',
-							'location' => $this->location
-						));
+					$id = $values['id'];
+				}
+
+				if(!$receipt['error'])
+				{
+					$receipt = $this->bo->save_type($values);
+					$id = $receipt['id'];
+
+					if (isset($values['save']) && $values['save'])
+					{
+						$GLOBALS['phpgw']->session->appsession('session_data','responsible_receipt',$receipt);
+						$GLOBALS['phpgw']->redirect_link('/index.php',array('menuaction'=> 'property.uiresponsible.index', 'appname' => $this->appname));
+					}
 				}
 			}
 
+			if (isset($values['cancel']) && $values['cancel'])
+			{
+				$GLOBALS['phpgw']->redirect_link('/index.php',array('menuaction'=> 'property.uiresponsible.index', 'appname' => $this->appname));
+			}
 
 			if ($id)
 			{
-				$function_msg = lang('edit responsible type');
-				$values = $this->bo->read_single_type($id);
+				$values = $this->bo->read_single($id);
+				$function_msg = lang('edit responsible');
+/*
+				$this->acl->set_account_id($this->account);
+				$grants	= $this->acl->get_grants('property','.responsible');
+				if(!$this->bocommon->check_perms($grants[$values['user_id']], PHPGW_ACL_READ))
+				{
+					$values = array();
+					$receipt['error'][]=array('msg'=>lang('You are not granted sufficient rights for this entry'));
+				}
+
+*/
 			}
 			else
 			{
-				$function_msg = lang('add responsible type');
+				$function_msg = lang('add responsible');
 			}
 
 			$link_data = array
 				(
-					'menuaction'	=> 'property.uiresponsible.edit_type',
-					'id'			=> $id,
-					'location'		=> $this->location
+					'menuaction'	=> 'property.uiresponsible.edit',
+					'id'		=> $id,
+					'app'		=> $this->appname
 				);
 
-			$msgbox_data = (isset($receipt)?$GLOBALS['phpgw']->common->msgbox_data($receipt):'');
+			$locations = $GLOBALS['phpgw']->locations->get_locations(false, $this->appname, false, false, true);
+
+			$selected_location = $location ? $location : $values['location'];
+			if(isset($values['location_id']) && $values['location_id'] && !$selected_location)
+			{
+				$locations_info = $GLOBALS['phpgw']->locations->get_name($values['location_id']);
+				$selected_location = $locations_info['location'];
+			}
+
+			$location_list = array();
+			foreach ( $locations as $_location => $descr )
+			{
+				$location_list[] = array
+					(
+						'id'		=> $_location,
+						'name'		=> "{$_location} [{$descr}]",
+						'selected'	=> $_location == $selected_location
+					);
+			}
+
+			$module_def = array
+			(
+				array('key' => 'appname',	'label'=>lang('appname'),'sortable'=>true,'resizeable'=>true),
+				array('key' => 'location',	'label'=>lang('location'),'sortable'=>true,'resizeable'=>true),
+				array('key' => 'category',	'label'=>lang('category'),'sortable'=>true,'resizeable'=>true),
+				array('key' => 'active',	'label'=>lang('active'),'sortable'=>true,'resizeable'=>true),
+				array('key' => 'delete_module','label'=>lang('delete'),'sortable'=>false,'resizeable'=>true,'formatter'=>'FormatterCenter')
+			);
+
+			$responsibility_module = isset($values['module']) && $values['module'] ? $values['module'] : array();
+
+			foreach($responsibility_module as &$module)
+			{
+				$_location_info = $GLOBALS['phpgw']->locations->get_name($module['location_id']);
+				$module['appname'] = $_location_info['appname'];
+				$module['location'] = $_location_info['location'];
+				$category = $this->cats->return_single($module['cat_id']);
+				$module['category'] = $category[0]['name'];
+
+				if ($this->acl->check('admin', PHPGW_ACL_EDIT, $module['appname']))
+				{
+					$_checked = $module['active'] ? 'checked = "checked"' : '';
+					$module['active'] = "<input type='checkbox' name='values[set_active][]' {$_checked} value='{$module['location_id']}_{$module['cat_id']}' title='".lang('Check to set active')."'>";
+					$module['delete_module'] = "<input type='checkbox' name='values[delete_module][]' value='{$module['location_id']}_{$module['cat_id']}' title='".lang('Check to delete')."'>";
+				}
+			}
+
+			//---datatable settings--------------------------
+			$datavalues[0] = array
+				(
+					'name'					=> "0",
+					'values' 				=> json_encode($responsibility_module),
+					'total_records'			=> count($responsibility_module),
+					'is_paginator'			=> 0,
+					'footer'				=> 0
+				);					
+			$myColumnDefs[0] = array
+				(
+					'name'		=> "0",
+					'values'	=>	json_encode($module_def)
+				);		
+			//-----------------------------------------------
+
+			$msgbox_data = $GLOBALS['phpgw']->common->msgbox_data($receipt);
 
 			$data = array
 				(
-					'value_entry_date'				=> isset($values['entry_date']) ? $values['entry_date'] : '',
-					'value_name'					=> isset($values['name']) ? $values['name'] : '',
-					'value_descr'					=> isset($values['descr']) ? $values['descr'] : '',
-					'value_active'					=> isset($values['active']) ? $values['active'] : '',
-
-					'lang_entry_date'				=> lang('Entry date'),
-					'lang_name'						=> lang('name'),
-					'lang_descr'					=> lang('descr'),
-
 					'msgbox_data'					=> $GLOBALS['phpgw']->common->msgbox($msgbox_data),
-					'form_action'					=> $GLOBALS['phpgw']->link('/index.php', $link_data),
-					'lang_id'						=> lang('ID'),
-					'lang_save'						=> lang('save'),
-					'lang_cancel'					=> lang('cancel'),
+					'form_action'					=> $GLOBALS['phpgw']->link('/index.php',$link_data),
+					'value_appname'					=> $this->appname,
+					'value_location'				=> $location,
 					'value_id'						=> $id,
-					'lang_active'					=> lang('active'),
-					'lang_active_on_statustext'		=> lang('set this item inactive'),
-					'lang_active_off_statustext'	=> lang('set this item active'),
-					'lang_cancel_status_text'		=> lang('Back to the list'),
-					'lang_save_status_text'			=> lang('Save the responsible type'),
-					'lang_apply'					=> lang('apply'),
-					'lang_apply_status_text'		=> lang('Apply the values'),
-
+					'value_name'					=> $values['name'],
+					'value_descr'					=> $values['descr'],
+					'value_access'					=> $values['access'],
+					'apps_list'						=> array('options' => execMethod('property.bojasper.get_apps', $this->appname)), 
+					'location_list'					=> array('options' => $location_list),
+					'td_count'						=> '""',
+					'base_java_url'					=> "{menuaction:'property.uiresponsible.edit'}",
+					'property_js'					=> json_encode($GLOBALS['phpgw_info']['server']['webserver_url']."/property/js/yahoo/property2.js"),
+					'datatable'						=> $datavalues,
+					'myColumnDefs'					=> $myColumnDefs,
 					'lang_category'					=> lang('category'),
 					'lang_no_cat'					=> lang('no category'),
 					'cat_select'					=> $this->cats->formatted_xslt_list(array
@@ -711,10 +784,162 @@
 					)),
 				);
 
-			$GLOBALS['phpgw_info']['flags']['app_header'] = lang('responsible matrix') . "::{$this->location}::{$function_msg}";
-			$GLOBALS['phpgw']->xslttpl->set_var('phpgw', array('edit_type' => $data));
+			//---datatable settings--------------------
+			phpgwapi_yui::load_widget('dragdrop');
+			phpgwapi_yui::load_widget('datatable');
+			phpgwapi_yui::load_widget('loader');
+
+			$GLOBALS['phpgw']->css->validate_file('property');
+			$GLOBALS['phpgw']->css->add_external_file('phpgwapi/js/yahoo/datatable/assets/skins/sam/datatable.css');
+			$GLOBALS['phpgw']->js->validate_file( 'yahoo', 'responsible.edit', 'property' );
+			//-----------------------datatable settings---
+
+			$appname						= 'Responsible';
+
+			$GLOBALS['phpgw_info']['flags']['app_header'] = lang('property') . "::{$appname}::$function_msg::".lang($this->appname);
+			$GLOBALS['phpgw']->xslttpl->add_file(array('responsible'));
+			$GLOBALS['phpgw']->xslttpl->set_var('phpgw',array('edit' => $data));
 		}
 
+
+		function edit_role()
+		{
+			if(!$this->acl_add && !$this->acl_edit)
+			{
+				$GLOBALS['phpgw']->redirect_link('/index.php',array('menuaction'=> 'property.uilocation.stop', 'perm'=>2, 'acl_location'=> $this->acl_location));
+			}
+
+			$id			= phpgw::get_var('id', 'int');
+			$location	= phpgw::get_var('location', 'string');
+			$values		= phpgw::get_var('values');
+
+			if ((isset($values['save']) && $values['save']) || (isset($values['apply']) && $values['apply']))
+			{
+				if($GLOBALS['phpgw']->session->is_repost())
+				{
+	//				$receipt['error'][]=array('msg'=>lang('Hmm... looks like a repost!'));
+				}
+
+				if(!isset($values['location']) || !$values['location'])
+				{
+	//				$receipt['error'][]=array('msg'=>lang('Please select a location!'));
+				}
+
+				if(!isset($values['name']) || !$values['name'])
+				{
+					$receipt['error'][]=array('msg'=>lang('Please enter a name!'));
+				}
+
+				if($id)
+				{
+					$values['id']=$id;
+				}
+				else
+				{
+					$id = $values['id'];
+				}
+
+				if(!$receipt['error'])
+				{
+					$receipt = $this->bo->save_role($values);
+					$id = $receipt['id'];
+
+					if (isset($values['save']) && $values['save'])
+					{
+						$GLOBALS['phpgw']->session->appsession('session_data','responsible_receipt',$receipt);
+						$GLOBALS['phpgw']->redirect_link('/index.php',array('menuaction'=> 'property.uigeneric.index', 'type' => 'responsibility_role', 'appname' => $this->appname));
+					}
+				}
+			}
+
+			if (isset($values['cancel']) && $values['cancel'])
+			{
+				$GLOBALS['phpgw']->redirect_link('/index.php',array('menuaction'=> 'property.uigeneric.index', 'type' => 'responsibility_role', 'appname' => $this->appname));
+			}
+
+			if ($id)
+			{
+				$values = $this->bo->read_single_role($id);
+				$function_msg = lang('edit role');
+/*
+				$this->acl->set_account_id($this->account);
+				$grants	= $this->acl->get_grants('property','.responsible');
+				if(!$this->bocommon->check_perms($grants[$values['user_id']], PHPGW_ACL_READ))
+				{
+					$values = array();
+					$receipt['error'][]=array('msg'=>lang('You are not granted sufficient rights for this entry'));
+				}
+
+*/
+			}
+			else
+			{
+				$function_msg = lang('add role');
+			}
+
+
+			$link_data = array
+			(
+				'menuaction'	=> 'property.uiresponsible.edit_role',
+				'id'		=> $id,
+				'app'		=> $this->appname
+			);
+
+			$location_types = execMethod('property.soadmin_location.get_location_type');
+
+			$levels = isset($values['location_level']) && $values['location_level'] ? $values['location_level'] : array();
+			$level_list = array();
+			foreach ( $location_types as $location_type )
+			{
+				$level_list[] = array
+					(
+						'id'		=> $location_type['id'],
+						'name'		=>  $location_type['name'],
+						'selected'	=> in_array($location_type['id'], $levels)
+					);
+			}
+			//-----------------------------------------------
+
+			$msgbox_data = $GLOBALS['phpgw']->common->msgbox_data($receipt);
+
+			$data = array
+				(
+					'msgbox_data'					=> $GLOBALS['phpgw']->common->msgbox($msgbox_data),
+					'form_action'					=> $GLOBALS['phpgw']->link('/index.php',$link_data),
+					'value_appname'					=> $this->appname,
+					'value_location'				=> $location,
+					'value_id'						=> $id,
+					'value_name'					=> $values['name'],
+					'value_remark'					=> $values['remark'],
+					'value_access'					=> $values['access'],
+					'responsibility_list'			=> array('options' => execMethod('property.boresponsible.get_responsibilities', array('appname' => $this->appname,	'selected' => $values['responsibility_id']))),
+					'level_list'					=> array('checkbox' => $level_list),
+					'td_count'						=> '""',
+					'base_java_url'					=> "{menuaction:'property.uiresponsible.edit'}",
+					'property_js'					=> json_encode($GLOBALS['phpgw_info']['server']['webserver_url']."/property/js/yahoo/property2.js"),
+					'datatable'						=> $datavalues,
+					'myColumnDefs'					=> $myColumnDefs,
+				);
+
+			//---datatable settings--------------------
+			phpgwapi_yui::load_widget('dragdrop');
+			phpgwapi_yui::load_widget('datatable');
+			phpgwapi_yui::load_widget('loader');
+
+			$GLOBALS['phpgw']->css->validate_file('property');
+			$GLOBALS['phpgw']->css->add_external_file('phpgwapi/js/yahoo/datatable/assets/skins/sam/datatable.css');
+			$GLOBALS['phpgw']->js->validate_file( 'yahoo', 'responsible.edit', 'property' );
+			//-----------------------datatable settings---
+
+			$appname						= 'Responsible';
+
+			$GLOBALS['phpgw_info']['flags']['app_header'] = lang('property') . "::{$appname}::$function_msg::".lang($this->appname);
+			$GLOBALS['phpgw']->xslttpl->add_file(array('responsible'));
+			$GLOBALS['phpgw']->xslttpl->set_var('phpgw',array('edit_role' => $data));
+		}
+
+
+
 		/**
 		 * List of contacts given responsibilities within locations
 		 *
@@ -747,7 +972,8 @@
 						(
 							'menuaction'	=> 'property.uiresponsible.edit_contact',
 							'id'			=> $entry['id'],
-							'location'		=> str_replace('property', '', $entry['app_name']),
+							'appname'		=> $this->appname,
+							'location'		=> str_replace($this->appname, '', $entry['app_name']),
 							'type_id'		=> $type_id
 						));
 					$lang_edit_text			= lang('edit type');
@@ -800,6 +1026,7 @@
 						(
 							'menuaction'	=> 'property.uiresponsible.contact',
 							'allrows'		=> $this->allrows,
+							'appname'		=> $this->appname,
 							'location'		=> $this->location,
 							'type_id'		=> $type_id
 						)
@@ -813,6 +1040,7 @@
 						(
 							'menuaction'	=> 'property.uiresponsible.contact',
 							'allrows'		=> $this->allrows,
+							'appname'		=> $this->appname,
 							'location'		=> $this->location,
 							'type_id'		=> $type_id
 						)
@@ -826,6 +1054,7 @@
 						(
 							'menuaction'	=> 'property.uiresponsible.contact',
 							'allrows'		=> $this->allrows,
+							'appname'		=> $this->appname,
 							'location'		=> $this->location,
 							'type_id'		=> $type_id
 						)
@@ -839,6 +1068,7 @@
 						(
 							'menuaction'	=> 'property.uiresponsible.contact',
 							'allrows'		=> $this->allrows,
+							'appname'		=> $this->appname,
 							'location'		=> $this->location,
 							'type_id'		=> $type_id
 						)
@@ -871,6 +1101,7 @@
 					'sort'			=> $this->sort,
 					'order'			=> $this->order,
 					'query'			=> $this->query,
+					'appname'		=> $this->appname,
 					'location'		=> $this->location,
 					'type_id'		=> $type_id
 
@@ -879,6 +1110,7 @@
 			$link_add_action = array
 				(
 					'menuaction'	=> 'property.uiresponsible.edit_contact',
+					'appname'		=> $this->appname,
 					'location'		=> $this->location,
 					'type_id'		=> $type_id
 				);
@@ -891,8 +1123,11 @@
 					'lang_cancel'				=> lang('cancel'),
 					'lang_cancel_statustext'	=> lang('back to list type'),
 					'cancel_action'				=> $GLOBALS['phpgw']->link('/index.php', array
-					('menuaction'	=> 'property.uiresponsible.index'
-				))
+						(
+							'menuaction'	=> 'property.uiresponsible.index',
+							'appname'		=> $this->appname
+						)
+					)
 			);
 
 			$receipt = $GLOBALS['phpgw']->session->appsession('session_data', 'responsible_contact_receipt');
@@ -1044,6 +1279,7 @@
 							$GLOBALS['phpgw']->redirect_link('/index.php', array
 								(
 									'menuaction'=> 'property.uiresponsible.contact',
+									'appname'		=> $this->appname,
 									'location'	=> $this->location,
 									'type_id'	=> $type_id
 								));
@@ -1053,6 +1289,7 @@
 							$GLOBALS['phpgw']->redirect_link('/index.php', array
 								(
 									'menuaction'=> 'property.uiresponsible.edit_contact',
+									'appname'		=> $this->appname,
 									'location'	=> $this->location,
 									'type_id'	=> $type_id,
 									'id'		=> $id
@@ -1080,6 +1317,7 @@
 					$GLOBALS['phpgw']->redirect_link('/index.php', array
 						(
 							'menuaction'=> 'property.uiresponsible.contact',
+							'appname'		=> $this->appname,
 							'location' => $this->location,
 							'type_id' => $type_id
 						));
@@ -1119,6 +1357,7 @@
 				(
 					'menuaction'	=> 'property.uiresponsible.edit_contact',
 					'id'			=> $id,
+					'appname'		=> $this->appname,
 					'location'		=> $this->location,
 					'type_id'		=> $type_id
 				);
@@ -1153,9 +1392,8 @@
 
 			$GLOBALS['phpgw_info']['flags']['java_script'] .= $lookup_function;
 
-			$jscal = CreateObject('phpgwapi.jscalendar');
-			$jscal->add_listener('values_active_from');
-			$jscal->add_listener('values_active_to');
+			$GLOBALS['phpgw']->jqcal->add_listener('values_active_from');
+			$GLOBALS['phpgw']->jqcal->add_listener('values_active_to');
 
 			$type = $this->bo->read_single_type($type_id);
 
@@ -1197,11 +1435,8 @@
 					'lang_active_to'				=> lang('active to'),
 					'value_active_from'				=> isset($values['active_from']) ? $values['active_from'] : '',
 					'value_active_to'				=> isset($values['active_to']) ? $values['active_to'] : '',
-					'img_cal'						=> $GLOBALS['phpgw']->common->image('phpgwapi', 'cal'),
-					'lang_datetitle'				=> lang('Select date'),
 					'lang_active_from_statustext'	=> lang('Select the start date for this responsibility'),
 					'lang_active_to_statustext'		=> lang('Select the closing date for this responsibility'),
-
 				);
 
 			$GLOBALS['phpgw_info']['flags']['app_header'] = lang('responsible matrix') . "::{$function_msg}";
