@@ -24,7 +24,7 @@
 	* @internal Development of this application was funded by http://www.bergen.kommune.no/bbb_/ekstern/
 	* @package property
 	* @subpackage agreement
- 	* @version $Id: class.uis_agreement.inc.php 7498 2011-08-12 08:52:29Z sigurdne $
+ 	* @version $Id: class.uis_agreement.inc.php 11361 2013-10-09 14:00:23Z sigurdne $
 	*/
 
 	/**
@@ -32,6 +32,7 @@
 	 * @package property
 	 */
 
+	phpgw::import_class('phpgwapi.jquery');
 	phpgw::import_class('phpgwapi.yui');
 
 	class property_uis_agreement
@@ -46,16 +47,17 @@
 
 		var $public_functions = array
 			(
-				'index'  		=> true,
-				'view'			=> true,
-				'edit'   		=> true,
-				'delete'		=> true,
-				'columns'		=> true,
-				'edit_item'		=> true,
-				'view_item'		=> true,
-				'view_file'		=> true,
-				'download'		=> true,
-				'import'		=> true
+				'index'  				=> true,
+				'view'					=> true,
+				'edit'   				=> true,
+				'delete'				=> true,
+				'columns'				=> true,
+				'edit_item'				=> true,
+				'view_item'				=> true,
+				'view_file'				=> true,
+				'download'				=> true,
+				'import'				=> true,
+				'get_vendor_member_info'=> true
 			);
 
 		function property_uis_agreement()
@@ -91,6 +93,7 @@
 			$this->member_id			= $this->bo->member_id;
 			$this->p_num				= $this->bo->p_num;
 			$this->status_id			= $this->bo->status_id;
+			$this->location_code		= $this->bo->location_code;
 		}
 
 		function save_sessiondata()
@@ -187,28 +190,31 @@
 				$datatable['config']['base_url'] = $GLOBALS['phpgw']->link('/index.php', array
 					(
 						'menuaction'	=> 'property.uis_agreement.index',
-						'sort'		=>$this->sort,
-						'order'		=>$this->order,
-						'cat_id'	=>$this->cat_id,
-						'filter'	=>$this->filter,
-						'query'		=>$this->query,
-						'role'		=> $this->role,
-						'member_id'	=> $this->member_id,
-						'p_num'		=> $this->p_num,
-						'status_id'		=> $this->status_id
+						'sort'			=>$this->sort,
+						'order'			=>$this->order,
+						'cat_id'		=>$this->cat_id,
+						'filter'		=>$this->filter,
+						'query'			=>$this->query,
+						'role'			=> $this->role,
+						'member_id'		=> $this->member_id,
+						'p_num'			=> $this->p_num,
+						'status_id'		=> $this->status_id,
+						'location_code'	=> $this->location_code
 					));
 
-				$datatable['config']['base_java_url'] = "menuaction:'property.uis_agreement.index'";
-/*
+				$datatable['config']['base_java_url'] = "menuaction:'property.uis_agreement.index',"
 					."sort:'{$this->sort}',"
 					."order:'{$this->order}',"
 					."cat_id: '{$this->cat_id}',"
+					."vendor_id: '{$this->vendor_id}',"
+					."status_id: '{$this->status_id}',"
 					."filter:'{$this->filter}',"
 					."query:'{$this->query}',"
 					."p_num: '{$this->p_num}',"
 					."role:'{$this->role}',"
+					."location_code:'{$this->location_code}',"
 					."member_id:'{$this->member_id}'";
-*/
+
 				$datatable['config']['allow_allrows'] = true;
 
 				$link_data = array
@@ -249,14 +255,15 @@
 							array
 							(
 								'menuaction' 		=> 'property.uis_agreement.index',
-								'sort'		=>$this->sort,
-								'order'		=>$this->order,
-								'cat_id'	=>$this->cat_id,
-								'filter'	=>$this->filter,
-								'query'		=>$this->query,
-								'role'		=> $this->role,
-								'member_id'	=> $this->member_id,
-								'status_id'	=> $this->status_id
+								'sort'				=> $this->sort,
+								'order'				=> $this->order,
+								'cat_id'			=> $this->cat_id,
+								'filter'			=> $this->filter,
+								'query'				=> $this->query,
+								'role'				=> $this->role,
+								'member_id'			=> $this->member_id,
+								'status_id'			=> $this->status_id,
+								'location_code'		=> $this->location_code
 							)
 						),
 						'fields'	=> array
@@ -735,7 +742,7 @@
 			$import = CreateObject('property.import');
 
 			$importfile = $import->importfile();
-			$id		= phpgw::get_var('id', 'int');
+			$id		= phpgw::get_var('id');
 			if(isset($importfile) && is_file($importfile) && !phpgw::get_var('cancel'))
 			{
 				$list = $this->bo->read_details(0);
@@ -775,6 +782,7 @@
 				$GLOBALS['phpgw']->redirect_link('/index.php',array('menuaction'=> 'property.uis_agreement.view', 'id'=> $id));
 			}
 
+			phpgwapi_jquery::load_widget('core');
 			$values			= phpgw::get_var('values');
 			$delete_item	= phpgw::get_var('delete_item');
 			$item_id		= phpgw::get_var('item_id');
@@ -966,10 +974,10 @@
 				$values = $this->bocommon->preserve_attribute_values($values,$values_attribute);
 			}
 
-			$jscal = CreateObject('phpgwapi.jscalendar');
-			$jscal->add_listener('values_start_date');
-			$jscal->add_listener('values_end_date');
-			$jscal->add_listener('values_termination_date');
+
+			$GLOBALS['phpgw']->jqcal->add_listener('values_start_date');
+			$GLOBALS['phpgw']->jqcal->add_listener('values_end_date');
+			$GLOBALS['phpgw']->jqcal->add_listener('values_termination_date');
 
 			$this->member_id = $values['member_of'] ? $values['member_of'] : $this->member_id;
 
@@ -991,12 +999,10 @@
 
 				if (isset($content) && is_array($content))
 				{
-					$jscal->add_listener('values_date');
+					$GLOBALS['phpgw']->jqcal->add_listener('values_date');
 
 					$table_update[] = array
 						(
-							'img_cal'					=> $GLOBALS['phpgw']->common->image('phpgwapi','cal'),
-							'lang_datetitle'			=> lang('Select date'),
 							'lang_new_index'			=> lang('New index'),
 							'lang_new_index_statustext'	=> lang('Enter a new index'),
 							'lang_date_statustext'		=> lang('Select the date for the update'),
@@ -1044,7 +1050,14 @@
 
 			$msgbox_data = $this->bocommon->msgbox_data($receipt);
 
-			$member_of_data	= $this->cats->formatted_xslt_list(array('selected' => $this->member_id,'globals' => true,link_data => array()));
+			if($values['vendor_id'])
+			{
+				$member_of_list = $this->get_vendor_member_info($values['vendor_id']);
+			}
+			else
+			{
+				$member_of_list	= array();
+			}
 
 			$table_add[] = array
 				(
@@ -1453,9 +1466,10 @@ die();
 			if($id)
 			{
 				$content_budget = $this->bo->get_budget($id);
+				$lang_delete = lang('Check to delete year');
 				foreach($content_budget as & $b_entry)
 				{
-					$b_entry['delete_year'] = '<input type="checkbox" name="values[delete_b_year][]" value="'.$b_entry['year'].'" title="'.lang('Check to delete year').'">';				
+					$b_entry['delete_year'] = "<input type='checkbox' name='values[delete_b_year][]' value='{$b_entry['year']}' title='{$lang_delete}'>";
 				}
 			}
 
@@ -1479,7 +1493,7 @@ die();
 														array('key' => 'budget_account','label'=>lang('budget account'),'sortable'=>false,'resizeable'=>true),
 														array('key' => 'budget','label'=>lang('budget'),'sortable'=>false,'resizeable'=>true),
 														array('key' => 'actual_cost','label'=>lang('actual cost'),'sortable'=>false,'resizeable'=>true),
-														array('key' => 'delete_year','label'=>lang('Delete budget'),'sortable'=>false,'resizeable'=>true,'formatter'=>'FormatterCenter')))
+														array('key' => 'delete_year','label'=>lang('Delete'),'sortable'=>false,'resizeable'=>true,'formatter'=>'FormatterCenter')))
 				);
 
 			//--------------------------------------------JSON CODE------------
@@ -1531,17 +1545,12 @@ die();
 					'select_name'						=> 'values[cat_id]',
 					'cat_list'							=> $this->bocommon->select_category_list(array('format'=>'select','selected' => $this->cat_id,'type' =>'s_agreement','order'=>'descr')),
 
-					'lang_member_of'					=> lang('member of'),
-					'member_of_name'					=> 'member_id',
-					'member_of_list'					=> $member_of_data['cat_list'],
+					'member_of_list2'					=> $member_of_list,
 
 					'attributes_group'					=> $attributes,
 					'lookup_functions'					=> $values['lookup_functions'],
 					'dateformat'						=> $dateformat,
 
-					'img_cal'							=> $GLOBALS['phpgw']->common->image('phpgwapi','cal'),
-					'lang_datetitle'					=> lang('Select date'),
-
 					'lang_start_date_statustext'		=> lang('Select the estimated end date for the Project'),
 					'lang_start_date'					=> lang('start date'),
 					'value_start_date'					=> $values['start_date'],
@@ -1616,20 +1625,36 @@ die();
 			$GLOBALS['phpgw']->js->validate_file( 'yahoo', 'uis_agreement.edit', 'property' );
 		}
 
+
+		function get_vendor_member_info($vendor_id = 0)
+		{
+			if(!$vendor_id)
+			{
+				$vendor_id =  phpgw::get_var('vendor_id', 'int');
+			}
+			$generic	= CreateObject('property.bogeneric');
+			$generic->get_location_info('vendor');
+			$vendor = $generic->read_single(array('id' => $vendor_id));
+			$member_of = explode(',', trim($vendor['member_of'],','));
+			$member_of_data	= $this->cats->formatted_xslt_list(array('selected' => $member_of,'globals' => true));
+			return isset($member_of_data['cat_list']) && $member_of_data['cat_list'] ? $member_of_data['cat_list'] : array();
+		}
+
+
 		function download()
 		{
 			if(!$this->acl_read)
 			{
 				return;
 			}
-			$id	= phpgw::get_var('id', 'int');
+			$id	= phpgw::get_var('id');
 			if($id)
 			{
 				$list = $this->bo->read_details($id);
 			}
 			else
 			{
-				$list = $this->bo->read($id);
+				$list = $this->bo->read();
 			}
 			$uicols		= $this->bo->uicols;
 			$this->bocommon->download($list,$uicols['name'],$uicols['descr'],$uicols['input_type']);
@@ -1761,8 +1786,7 @@ die();
 			if($id)
 			{
 				$list = $this->bo->read_prizing(array('s_agreement_id'=>$s_agreement_id,'item_id'=>$id));
-				$jscal = CreateObject('phpgwapi.jscalendar');
-				$jscal->add_listener('values_date');
+				$GLOBALS['phpgw']->jqcal->add_listener('values_date');
 			}
 
 			$uicols		= $this->bo->uicols;
@@ -1812,9 +1836,6 @@ die();
 
 			$table_update[] = array
 				(
-
-					'img_cal'						=> $GLOBALS['phpgw']->common->image('phpgwapi','cal'),
-					'lang_datetitle'				=> lang('Select date'),
 					'lang_new_index'				=> lang('New index'),
 					'lang_new_index_statustext'		=> lang('Enter a new index'),
 					'lang_date_statustext'			=> lang('Select the date for the update'),
@@ -2008,9 +2029,6 @@ die();
 					'attributes_group'				=> $attributes,
 					'lookup_functions'				=> $values['lookup_functions'],
 
-					//	'img_cal'						=> $GLOBALS['phpgw']->common->image('phpgwapi','cal'),
-					'lang_datetitle'				=> lang('Select date'),
-
 					'lang_agreement'				=> lang('Agreement'),
 					'agreement_name'				=> $s_agreement['name'],
 
@@ -2024,7 +2042,6 @@ die();
 					'img_check'						=> $GLOBALS['phpgw']->common->get_image_path('property').'/check.png',
 					'location_data'					=> $location_data,
 
-					'img_cal'						=> $GLOBALS['phpgw']->common->image('phpgwapi','cal'),
 					'lang_cost'						=> lang('cost'),
 					'lang_cost_statustext'			=> lang('cost'),
 					'value_cost'					=> $values['cost'],
