@@ -24,7 +24,7 @@
 	* @internal Development of this application was funded by http://www.bergen.kommune.no/bbb_/ekstern/
 	* @package property
 	* @subpackage project
- 	* @version $Id: class.uitemplate.inc.php 6718 2011-01-03 09:29:44Z sigurdne $
+ 	* @version $Id: class.uitemplate.inc.php 8283 2011-12-13 10:00:58Z sigurdne $
 	*/
 
 	/**
@@ -972,6 +972,17 @@
 					'hour_id'	=> $hour_id
 				);
 
+			$config				= CreateObject('phpgwapi.config','property');
+			$config->read();
+			
+			$_filter_buildingpart = array();
+			$filter_buildingpart = isset($config->config_data['filter_buildingpart']) ? $config->config_data['filter_buildingpart'] : array();
+			
+			if($filter_key = array_search('.project', $filter_buildingpart))
+			{
+				$_filter_buildingpart = array("filter_{$filter_key}" => 1);
+			}
+
 			$msgbox_data = $this->bocommon->msgbox_data($receipt);
 
 			$data = array
@@ -1051,12 +1062,7 @@
 					'lang_new_grouping'			=> lang('New grouping'),
 					'lang_new_grouping_statustext'	=> lang('Enter a new grouping for this activity if not found in the list'),
 
-					'lang_building_part'		=> lang('building_part'),
-					'building_part_list'		=> $this->bowo_hour->get_building_part_list(isset($values['building_part_id']) ? $values['building_part_id'] : ''),
-					'select_building_part'		=> 'values[building_part_id]',
-					'lang_no_building_part'		=> lang('Select building part'),
-					'lang_building_part_statustext'		=> lang('Select the building part for this activity.'),
-
+					'building_part_list'			=> array('options' => $this->bocommon->select_category_list(array('type'=> 'building_part','selected' =>$values['building_part_id'], 'order' => 'id', 'id_in_name' => 'num', 'filter' => $_filter_buildingpart))),
 
 					'ns3420_link'				=> $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> 'property.uilookup.ns3420')),
 					'lang_ns3420'				=> lang('NS3420'),
