@@ -24,7 +24,7 @@
 	* @internal Development of this application was funded by http://www.bergen.kommune.no/bbb_/ekstern/
 	* @package property
 	* @subpackage project
- 	* @version $Id: class.uitenant_claim.inc.php 6731 2011-01-05 14:53:57Z sigurdne $
+ 	* @version $Id: class.uitenant_claim.inc.php 11283 2013-09-09 08:44:38Z sigurdne $
 	*/
 
 	/**
@@ -307,7 +307,7 @@
 			$uicols['name'][7]['name'] = 'name';
 			$uicols['name'][7]['value'] = 'name';
 
-			$uicols['name'][8]['name'] = 'time created';
+			$uicols['name'][8]['name'] = 'entry date';
 			$uicols['name'][8]['value'] = 'entry_date';
 
 			$uicols['name'][9]['name'] = 'user';
@@ -669,7 +669,9 @@
 
 			//_debug_array($values);
 
-			$project_values	= $this->boproject->read_single($values['project_id']);
+			$project_values	= $this->boproject->read_single($values['project_id'], array(), true);
+			
+			$project_values['workorder_budget'] = $this->boproject->get_orders(array('project_id'=> $values['project_id'],'year'=> 0));
 
 			$soinvoice	= CreateObject('property.soinvoice');
 
@@ -795,10 +797,17 @@
 
 				if($project_values['workorder_budget'][$d]['selected']==1)
 				{
+					
+					$project_values['workorder_budget'][$d]['budget_hidden'] = $project_values['workorder_budget'][$d]['budget'];
+					$project_values['workorder_budget'][$d]['calculation_hidden'] = $project_values['workorder_budget'][$d]['calculation'];
+					$project_values['workorder_budget'][$d]['actual_cost_hidden'] = $project_values['workorder_budget'][$d]['actual_cost'];
 					$project_values['workorder_budget'][$d]['selected']='<input type="checkbox" name="values[workorder][]" checked value="'.$project_values['workorder_budget'][$d]['workorder_id'].'">';
 				}
 				else
 				{
+					$project_values['workorder_budget'][$d]['budget_hidden'] = 0;
+					$project_values['workorder_budget'][$d]['calculation_hidden'] = 0;
+					$project_values['workorder_budget'][$d]['actual_cost_hidden'] = 0;
 					$project_values['workorder_budget'][$d]['selected']='<input type="checkbox" name="values[workorder][]" value="'.$project_values['workorder_budget'][$d]['workorder_id'].'">';
 				}
 			}
@@ -821,16 +830,52 @@
 				(
 					'name'			=> "0",
 					'values'		=>	json_encode(array(	array('key' => 'workorder_id',	'label'=>'Workorder',	'sortable'=>true,'resizeable'=>true,'formatter'=>'YAHOO.widget.DataTable.formatLink'),
-															array('key' => 'budget',	'label'=>'Budget',	'sortable'=>true,'resizeable'=>true),
-															array('key' => 'calculation',	'label'=>'Calculation',	'sortable'=>true,'resizeable'=>true),
+															array('key' => 'budget',	'label'=>'Budget',	'sortable'=>true,'resizeable'=>true,'formatter'=>'FormatterAmount0'),
+															array('key' => 'budget_hidden','hidden'=>true),
+															array('key' => 'calculation',	'label'=>'Calculation',	'sortable'=>true,'resizeable'=>true,'formatter'=>'FormatterAmount0'),
+															array('key' => 'calculation_hidden','hidden'=>true),
+															array('key' => 'actual_cost','label'=>lang('actual cost'),'sortable'=>true,'resizeable'=>true,'formatter'=>'FormatterAmount0'),
+															array('key' => 'actual_cost_hidden','hidden'=>true),
 															array('key' => 'vendor_name','label'=>'Vendor','sortable'=>true,'resizeable'=>true),
-															array('key' => 'charge_tenant','label'=>'Charge tenant','sortable'=>true,'resizeable'=>true),
+															array('key' => 'charge_tenant','label'=>'Charge tenant','sortable'=>true,'resizeable'=>true,'formatter'=>'FormatterCenter'),
 															array('key' => 'status','label'=>'Status','sortable'=>true,'resizeable'=>true),
-															array('key' => 'actual_cost','label'=>lang('actual cost'),'sortable'=>true,'resizeable'=>true),
 															array('key' => 'voucher_id','label'=>lang('voucher'),'sortable'=>true,'resizeable'=>true),
 															array('key' => 'selected','label'=>'select',	'sortable'=>false,'resizeable'=>false)))
 				);
 
+
+			if($claim_id)
+			{
+				$record_history = $this->bo->read_record_history($claim_id);
+//_debug_array($content_budget);die();
+			}
+			else
+			{
+				$record_history = array();
+			}
+
+			$datavalues[1] = array
+				(
+					'name'					=> "1",
+					'values' 				=> json_encode($record_history),
+					'total_records'			=> count($record_history),
+					'edit_action'			=> "''",
+					'is_paginator'			=> 0,
+					'footer'				=> 0
+				);
+
+			$myColumnDefs[1] = array
+				(
+					'name'		=> "1",
+					'values'	=>	json_encode(array(	array('key' => 'value_date','label' => lang('Date'),'sortable'=>true,'resizeable'=>true),
+														array('key' => 'value_user','label' => lang('User'),'Action'=>true,'resizeable'=>true),
+														array('key' => 'value_action','label' => lang('Action'),'sortable'=>true,'resizeable'=>true),
+														array('key' => 'value_old_value','label' => lang('old value'), 'sortable'=>true,'resizeable'=>true),
+														array('key' => 'value_new_value','label' => lang('New Value'),'sortable'=>true,'resizeable'=>true)))
+				);
+
+
+
 			$data = array
 				(
 					'table_header_workorder'			=> $table_header_workorder,
@@ -838,6 +883,7 @@
 					'workorder_link'					=> $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> 'property.uiworkorder.view')),
 					'lang_start_date'					=> lang('Project start date'),
 					'value_start_date'					=> $project_values['start_date'],
+					'value_entry_date'					=> $values['entry_date'] ? $GLOBALS['phpgw']->common->show_date($values['entry_date'],$GLOBALS['phpgw_info']['user']['preferences']['common']['dateformat']) : '',
 
 					'property_js'						=> json_encode($GLOBALS['phpgw_info']['server']['webserver_url']."/property/js/yahoo/property2.js"),
 					'base_java_url'						=> json_encode(array(menuaction => "property.uitenant_claim.edit",claim_id=>$claim_id)),
@@ -1202,8 +1248,7 @@
 
 					'done_action'						=> $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> 'property.uitenant_claim.index')),
 					'lang_done'							=> lang('done'),
-					'value_date'						=> $GLOBALS['phpgw']->common->show_date($tenant_claim['entry_date'])
-
+					'value_entry_date'					=> $values['entry_date'] ? $GLOBALS['phpgw']->common->show_date($values['entry_date'],$GLOBALS['phpgw_info']['user']['preferences']['common']['dateformat']) : '',
 				);
 			$GLOBALS['phpgw_info']['flags']['app_header'] = lang('Tenant claim') . '::' . lang('view claim');
 
