@@ -24,7 +24,7 @@
 	* @internal Development of this application was funded by http://www.bergen.kommune.no/bbb_/ekstern/
 	* @package property
 	* @subpackage catch
- 	* @version $Id: catch_ppc.php 7200 2011-04-08 10:12:03Z sigurdne $
+ 	* @version $Id: catch_ppc.php 11573 2013-12-27 08:49:03Z sigurdne $
 	*/
 
 	/**
@@ -33,89 +33,23 @@
 	 * @package property
 	 */
 
-	class catch_ppc
-	{
-		var	$function_name = 'catch_ppc';
+	include_class('property', 'cron_parent', 'inc/cron/');
 
+	class catch_ppc extends property_cron_parent
+	{
 		public function __construct()
 		{
-			$this->db           = clone($GLOBALS['phpgw']->db);
-			$this->join			= & $this->db->join;
-			$this->like			= & $this->db->like;
-		}
+			parent::__construct();
 
-		function pre_run($data = array())
-		{
-			phpgwapi_cache::session_set('catch', 'data', $data);
+			$this->function_name = get_class($this);
+			$this->sub_location = lang('catch');
+			$this->function_msg	= 'Import info from files';
 
-			if(isset($data['enabled']) && $data['enabled']==1)
-			{
-				$confirm	= true;
-				$cron		= true;
-			}
-			else
-			{
-				$confirm	= phpgw::get_var('confirm', 'bool', 'POST');
-				$execute	= phpgw::get_var('execute', 'bool', 'GET');
-				$cron = false;
-			}
-
-			if ($confirm)
-			{
-				$this->execute($cron);
-			}
-			else
-			{
-				$this->confirm($execute=false);
-			}
+			set_time_limit(1000);
 		}
 
 
-		function confirm($execute='')
-		{
-			$data = phpgwapi_cache::session_get('catch', 'data');
-			$link_data = array
-			(
-				'menuaction' => 'property.custom_functions.index',
-				'data'		=> urlencode(serialize($data)),
-				'execute'	=> $execute,
-			);
-
-			if(!$execute)
-			{
-				$lang_confirm_msg 	= lang('do you want to perform this action');
-			}
-
-			$lang_yes			= lang('yes');
-
-			$GLOBALS['phpgw']->xslttpl->add_file(array('confirm_custom'));
-
-
-			$msgbox_data = $GLOBALS['phpgw']->common->msgbox_data($this->receipt);
-
-			$data = array
-			(
-				'msgbox_data'			=> $GLOBALS['phpgw']->common->msgbox($msgbox_data),
-				'done_action'			=> $GLOBALS['phpgw']->link('/admin/index.php'),
-				'run_action'			=> $GLOBALS['phpgw']->link('/index.php',$link_data),
-				'message'				=> $this->receipt['message'],
-				'lang_confirm_msg'		=> $lang_confirm_msg,
-				'lang_yes'				=> $lang_yes,
-				'lang_yes_statustext'	=> lang('Export info as files'),
-				'lang_no_statustext'	=> 'tilbake',
-				'lang_no'				=> lang('no'),
-				'lang_done'				=> 'Avbryt',
-				'lang_done_statustext'	=> 'tilbake'
-			);
-
-			$appname		= lang('location');
-			$function_msg	= lang('Export info as files');
-			$GLOBALS['phpgw_info']['flags']['app_header'] = lang('property') . ' - ' . $appname . ': ' . $function_msg;
-			$GLOBALS['phpgw']->xslttpl->set_var('phpgw',array('confirm' => $data));
-			$GLOBALS['phpgw']->xslttpl->pp();
-		}
-
-		function execute($cron='')
+		function execute()
 		{
 			try
 			{
@@ -125,26 +59,6 @@
 			{
 				$this->receipt['error'][]=array('msg'=>$e->getMessage());
 			}
-
-			if(!$cron)
-			{
-				$this->confirm($execute=false);
-			}
-
-			$msgbox_data = $GLOBALS['phpgw']->common->msgbox_data($this->receipt);
-
-			$insert_values= array(
-				$cron,
-				date($this->db->datetime_format()),
-				$this->function_name,
-				implode(',',(array_keys($msgbox_data)))
-				);
-
-			$insert_values	= $this->db->validate_insert($insert_values);
-
-			$sql = "INSERT INTO fm_cron_log (cron,cron_date,process,message) "
-					. "VALUES ($insert_values)";
-			$this->db->query($sql,__LINE__,__FILE__);
 		}
 
 		function import_ppc()
@@ -176,17 +90,31 @@
 					throw new Exception(lang('no valid target'));
 				}
 			
-				$xmlparse = CreateObject('property.XmlToArray');
-				$xmlparse->setEncoding('UTF-8');
+//				$xmlparse = CreateObject('property.XmlToArray');
+//				$xmlparse->setEncoding('UTF-8');
 
 				$file_list = $this->get_files();
 
  				$i = 0;
 				foreach ($file_list as $file)
 				{
-					$var_result = $xmlparse->parseFile($file);
-					$var_result = array_change_key_case($var_result, CASE_LOWER);
-				
+					$xml = new DOMDocument('1.0', 'utf-8');
+					$xml->load($file);
+
+					$var_result = array();
+					
+					//_debug_array($xml->getElementsByTagName('PPCC')->item(0)->getattribute('UUID'));die();
+					
+					foreach($metadata as $field => $field_info)
+					{
+						$var_result[$field] = $xml->getElementsByTagName($field)->item(0)->nodeValue;
+					}
+					$var_result['unitid'] = $xml->getElementsByTagName('UnitID')->item(0)->nodeValue;
+//					_debug_array($var_result);die();
+
+//					$var_result = $xmlparse->parseFile($file);
+//					$var_result = array_change_key_case($var_result, CASE_LOWER);
+
 					//data
 					$insert_values	= array();
 					$cols		= array();
@@ -217,11 +145,14 @@
 							case 'int4':
 								// Check if input starts with - (optional) and then only
 								// contains numbers
+								/*
 								if( preg_match('@^[-]?[0-9]+$@', $insert_value) !== 1 )
 								{
 									$val_errors[] = lang('Input for field "%1" is "%2", but should be int (%3)',
 										$field_info->name, $insert_value, $file);
 								}
+								*/
+								$insert_value = $insert_value ? (int) $insert_value : '';
 								break;
 							case 'numeric':
 								$insert_value = str_replace( ',', '.', $insert_value);
@@ -231,7 +162,7 @@
 								$insert_value = date( $this->db->date_format(), strtotime( $insert_value ) );
 								break;
 						}
-						$insert_values[] = utf8_encode($insert_value);
+						$insert_values[] = $insert_value;
 						$cols[]	= $field;
 					}
 
@@ -295,31 +226,7 @@
 
 						$i++;
 
-						// finishing
-						$criteria = array
-						(
-							'appname'	=> 'catch',
-							'location'	=> '.catch.' . str_replace('_','.',$target),
-							'allrows'	=> true
-						);
 
-						$custom_functions = $GLOBALS['phpgw']->custom_functions->find($criteria);
-
-						foreach ( $custom_functions as $entry )
-						{
-							// prevent path traversal
-							if ( preg_match('/\.\./', $entry['file_name']) )
-							{
-								continue;
-							}
-
-							$file = PHPGW_SERVER_ROOT . "/catch/inc/custom/{$GLOBALS['phpgw_info']['user']['domain']}/{$entry['file_name']}";
-							if ( $entry['active'] && is_file($file) )
-							{
-								require_once $file;
-							}
-						}
-						
 						$ok = false;
 						if($this->db->transaction_commit())
 						{
@@ -328,12 +235,41 @@
 								$ok = @rename($movefrom, $moveto);
 							}
 						}
+
 						if(!$ok)
 						{
 							$this->db->query("DELETE FROM $target_table WHERE id =" . (int)$id,__LINE__,__FILE__);
 							$i--;
 							$this->receipt['error'][]=array('msg'=>lang('There was a problem moving the file(s), imported records are reverted'));
 						}
+						else
+						{
+
+							// finishing
+							$criteria = array
+							(
+								'appname'	=> 'catch',
+								'location'	=> '.catch.' . str_replace('_','.',$target),
+								'allrows'	=> true
+							);
+
+							$custom_functions = $GLOBALS['phpgw']->custom_functions->find($criteria);
+
+							foreach ( $custom_functions as $entry )
+							{
+								// prevent path traversal
+								if ( preg_match('/\.\./', $entry['file_name']) )
+								{
+									continue;
+								}
+
+								$file = PHPGW_SERVER_ROOT . "/catch/inc/custom/{$GLOBALS['phpgw_info']['user']['domain']}/{$entry['file_name']}";
+								if ( $entry['active'] && is_file($file) )
+								{
+									require $file;
+								}
+							}
+						}
 					}
 				}
 				$this->receipt['message'][]=array('msg'=>lang('%1 records imported to %2', $i, $schema_text));
