@@ -24,7 +24,7 @@
 	* @internal Development of this application was funded by http://www.bergen.kommune.no/bbb_/ekstern/
 	* @package property
 	* @subpackage custom
- 	* @version $Id: import_from_scanner.php 6442 2010-10-05 17:29:58Z sigurdne $
+ 	* @version $Id: import_from_scanner.php 10585 2012-12-11 09:48:09Z sigurdne $
 	*/
 
 	/**
@@ -276,12 +276,12 @@
 
 						$insert_values= array(
 							$cron,
-							date($this->bocommon->datetimeformat),
+							date($this->db->datetime_format()),
 							$this->function_name,
 							implode(',',(array_keys($msgbox_data)))
 							);
 
-						$insert_values	= $this->bocommon->validate_db_insert($insert_values);
+						$insert_values	= $this->db->validate_insert($insert_values);
 
 						$sql = "INSERT INTO fm_cron_log (cron,cron_date,process,message) "
 								. "VALUES ($insert_values)";
@@ -485,7 +485,7 @@
 						$values['loc4'],
 						);
 
-					$insert_values	= $this->bocommon->validate_db_insert($insert_values);
+					$insert_values	= $this->db->validate_insert($insert_values);
 
 					$sql = "INSERT INTO fm_document (document_name,title,access,category,entry_date,document_date,version,coordinator,status,"
 						. "location_code,address,branch_id,vendor_id,user_id,loc1,loc2,loc3,loc4) "
