@@ -24,7 +24,7 @@
 	* @internal Development of this application was funded by http://www.bergen.kommune.no/bbb_/ekstern/
 	* @package property
 	* @subpackage custom
- 	* @version $Id: oppdater_namssakstatus_pr_leietaker.php 6442 2010-10-05 17:29:58Z sigurdne $
+ 	* @version $Id: oppdater_namssakstatus_pr_leietaker.php 11573 2013-12-27 08:49:03Z sigurdne $
 	*/
 
 	/**
@@ -32,12 +32,19 @@
 	 * @package property
 	 */
 
-	class oppdater_namssakstatus_pr_leietaker
-	{
-		var	$function_name = 'oppdater_namssakstatus_pr_leietaker';
+	include_class('property', 'cron_parent', 'inc/cron/');
 
-		function oppdater_namssakstatus_pr_leietaker()
+	class oppdater_namssakstatus_pr_leietaker extends property_cron_parent
+	{
+
+		function __construct()
 		{
+			parent::__construct();
+
+			$this->function_name = get_class($this);
+			$this->sub_location = lang('location');
+			$this->function_msg	= 'Oppdatere namssaksstatus pr leietater';
+
 			$this->bocommon			= CreateObject('property.bocommon');
 			$this->db 				= & $GLOBALS['phpgw']->db;
 			$this->db2				= clone($this->db);
@@ -68,105 +75,8 @@
 			}
 		}
 
-		function pre_run($data='')
-		{
-			if($data['enabled']==1)
-			{
-				$confirm	= true;
-				$cron		= true;
-			}
-			else
-			{
-				$confirm	= phpgw::get_var('confirm', 'bool', 'POST');
-				$execute	= phpgw::get_var('execute', 'bool', 'GET');
-			}
 
-			if ($confirm)
-			{
-				$this->execute($cron);
-			}
-			else
-			{
-				$this->confirm($execute=false);
-			}
-		}
-
-
-		function confirm($execute='')
-		{
-			$link_data = array
-			(
-				'menuaction' => 'property.custom_functions.index',
-				'function'	=>$this->function_name,
-				'execute'	=> $execute,
-			);
-
-
-			if(!$execute)
-			{
-				$lang_confirm_msg 	= lang('do you want to perform this action');
-			}
-
-			$lang_yes			= lang('yes');
-
-			$GLOBALS['phpgw']->xslttpl->add_file(array('confirm_custom'));
-
-
-			$msgbox_data = $this->bocommon->msgbox_data($this->receipt);
-
-			$data = array
-			(
-				'msgbox_data'			=> $GLOBALS['phpgw']->common->msgbox($msgbox_data),
-				'done_action'			=> $GLOBALS['phpgw']->link('/admin/index.php'),
-				'run_action'			=> $GLOBALS['phpgw']->link('/index.php',$link_data),
-				'message'				=> $this->receipt['message'],
-				'lang_confirm_msg'		=> $lang_confirm_msg,
-				'lang_yes'				=> $lang_yes,
-				'lang_yes_statustext'	=> lang('Update the category to not active based on if there is only nonactive apartments'),
-				'lang_no_statustext'	=> 'tilbake',
-				'lang_no'				=> lang('no'),
-				'lang_done'				=> 'Avbryt',
-				'lang_done_statustext'	=> 'tilbake'
-			);
-
-			$appname		= lang('location');
-			$function_msg	= 'Oppdatere namssaksstatus pr leietater';
-			$GLOBALS['phpgw_info']['flags']['app_header'] = lang('property') . ' - ' . $appname . ': ' . $function_msg;
-			$GLOBALS['phpgw']->xslttpl->set_var('phpgw',array('confirm' => $data));
-			$GLOBALS['phpgw']->xslttpl->pp();
-		}
-
-		function execute($cron='')
-		{
-
-			$receipt = $this->oppdater_namssakstatus();
-			$this->cron_log($receipt,$cron);
-
-			if(!$cron)
-			{
-				$this->confirm($execute=false);
-			}
-
-		}
-
-		function cron_log($receipt='',$cron='')
-		{
-
-			$insert_values= array(
-				$cron,
-				date($this->bocommon->datetimeformat),
-				$this->function_name,
-				$receipt
-				);
-
-			$insert_values	= $this->bocommon->validate_db_insert($insert_values);
-
-			$sql = "INSERT INTO fm_cron_log (cron,cron_date,process,message) "
-					. "VALUES ($insert_values)";
-			$this->db->query($sql,__LINE__,__FILE__);
-		}
-
-		function oppdater_namssakstatus()
+		function execute()
 		{
 
 			$sql = "SELECT TOP 100 PERCENT fm_tenant.id"
@@ -219,8 +129,5 @@
 
 			$msg = $i . ' namssakstatus er oppdatert';
 			$this->receipt['message'][]=array('msg'=> $msg);
-			return $msg;
-
 		}
 	}
-
