@@ -22,7 +22,7 @@
 		if($tenant_id == $values['extra']['tenant_id'] && !$innflyttetdato_old)
 		{
 			$value_set['innflyttet']	= $innflyttetdato;
-			$value_set	= $this->bocommon->validate_db_update($value_set);
+			$value_set	= $db->validate_update($value_set);
 			$db->transaction_begin();
 			$db->query("UPDATE fm_entity_2_11 set $value_set WHERE id=" . (int) $receipt['id'],__LINE__,__FILE__);
 			$db->transaction_commit();
