@@ -12,14 +12,16 @@
 	{order:4, var_URL:'criteria_id', name:'btn_criteria_id',style:'criteriabutton',dependiente:''}
 	]
 */
+
 	// define buttons
+/*
 	var oNormalButton_0, oNormalButton_1, oNormalButton_2;
 	var normalButtons = [
 	{order:0, name:'btn_search',funct:"onSearchClick"},
 	{order:1, name:'btn_new',	funct:"onNewClick"},
 	{order:2, name:'btn_export',funct:"onDownloadClick"}
 	]
-
+*/
     var toolTips = [
     {name:'btn_export', title:'download', description:'Download table to your browser',ColumnDescription:''}
     ]
@@ -109,6 +111,26 @@
 		}
 
 	}
+
+	var show_picture = function(elCell, oRecord, oColumn, oData)
+	{
+		if(oRecord.getData('img_id'))
+		{
+			var oArgs = {menuaction:'property.uigallery.view_file', file:oRecord.getData('directory') + '/' + oRecord.getData('file_name')};
+			var sUrl = phpGWLink('index.php', oArgs);
+			elCell.innerHTML =  "<a href=\""+sUrl+"\" title=\""+oRecord.getData('file_name')+"\" id=\""+oRecord.getData('img_id')+"\" rel=\"colorbox\" target=\"_blank\"><img src=\""+sUrl+"&thumb=1\" alt=\""+oRecord.getData('file_name')+"\" /></a>";
+		}
+	}
+
+	var oArgs_entity = {menuaction:'property.uientity.edit'};
+	var sUrl_entity = phpGWLink('index.php', oArgs_entity);
+	
+	var linktToEntity = function(elCell, oRecord, oColumn, oData)
+	{
+	  	elCell.innerHTML = "<a href="+sUrl_entity+"&entity_id="+oRecord.getData('entity_id')+"&cat_id="+oRecord.getData('cat_id')+"&id="+oRecord.getData('id')+"&type="+oRecord.getData('_type')+">" + oData + "</a>";
+	};
+
+
 /****************************************************************************************/
 
   	this.myParticularRenderEvent = function()
