@@ -20,14 +20,26 @@
 
 	// define Text buttons
 	var textImput = [
-		{order:0, name:'query',	id:'txt_query'}
+		{order:0, name:'workorder_id',	id:'txt_workorder'},
+		{order:1, name:'vendor_id',		id:'txt_vendor'},
+		{order:2, name:'invoice_id',	id:'txt_invoice'},
+		{order:3, name:'loc1',			id:'txt_loc1'},
+		{order:4, name:'voucher_id',	id:'txt_voucher'}
 	]
 
+	// define Link Buttons
+	var linktoolTips = [
+		  {name:'lnk_workorder', title:'Workorder ID', description:'enter the Workorder ID to search by workorder'},
+		  {name:'lnk_vendor', title:'Vendor', description:'Select the vendor by clicking this link'},
+		  {name:'lnk_invoice', title:'Invoice', description:'Enter the invoice id'},
+		  {name:'lnk_property', title:'Facilities Managements', description:'Select the property by clicking this link'},
+		  {name:'lnk_voucher', title:'Voucher', description:'enter the voucher ID to search by vouvher'}
+    ]
+
 	var toolTips = [
 		{name:'voucher_id_lnk',title:'Voucher ID', description:'click this link to enter the list of sub-invoices',ColumnDescription:''},
-	//	{name:'vendor_id_lnk', title:'', description:'',ColumnDescription: 'vendor_name'},
 		{name:'voucher_date_lnk', title:'Payment Date', description:'',ColumnDescription:'payment_date'},
-		//{name:'period', title:'Period', description:'click this button to edit the period',ColumnDescription:''},
+		{name:'approved_amount_lnk', title:'Sum', description:'',ColumnDescription:'amount'},
 		{name:'btn_export', title:'download', description:'Download table to your browser',ColumnDescription:''}
 	]
 
@@ -152,6 +164,7 @@
 							    { text:  Year +"02", value: Year +"02", onclick: { fn: onPeriodDropDownItemClick, idvoucher: voucher_id} },
 							    { text:  Year +"03", value: Year +"03", onclick: { fn: onPeriodDropDownItemClick, idvoucher: voucher_id} },
 							    { text:  Year +"04", value: Year +"04", onclick: { fn: onPeriodDropDownItemClick, idvoucher: voucher_id} },
+
 							    { text:  Year +"05", value: Year +"05", onclick: { fn: onPeriodDropDownItemClick, idvoucher: voucher_id} },
 							    { text:  Year +"06", value: Year +"06", onclick: { fn: onPeriodDropDownItemClick, idvoucher: voucher_id} },
 							    { text:  Year +"07", value: Year +"07", onclick: { fn: onPeriodDropDownItemClick, idvoucher: voucher_id} },
@@ -165,8 +178,27 @@
 
     }
 
+	/********************************************************************************
+	 * CLick option combobox Periodization
+
+	 */
+    this.onPeriodizationDropDownItemClick = function(p_sType, p_aArgs, p_oItem)
+	{
+	 //  	 alert(p_oItem.cfg.getProperty("onclick").id);
+	 //  	 console.log(p_oItem.id);
+	   	 //Use a diferente id for voucher. This variables wil be empty in PARTICULAR_SETTING
+	   	 path_values.voucher_id_for_periodization = p_oItem.cfg.getProperty("onclick").idvoucher;
+	   	 //'text' is the option selected
+//	   	 path_values.periodization = p_oItem.cfg.getProperty('value');
+	   	 path_values.periodization =  p_oItem.cfg.getProperty("onclick").id;
+	   	 maintain_pagination_order();
+	   	 //call INDEX. Update Periodization Method is inside of INDEX
+	   	 execute_ds();
+
+	}
 	/********************************************************************************
 	 * CLick option combobox PERIOD
+
 	 */
     this.onPeriodDropDownItemClick = function(p_sType, p_aArgs, p_oItem)
 	{
@@ -181,6 +213,61 @@
 
 	}
 
+
+	/********************************************************************************
+	* Format column myPeriodization_startDropDown
+	*/
+    var myPeriodization_startDropDown = function(elCell, oRecord, oColumn, oData)
+   	{
+		var d = new Date();
+		Year = d.getFullYear();
+		var _label = new String(oData);
+
+		tmp_count = oRecord._oData.counter_num;
+		voucher_id = oRecord._oData.voucher_id_num
+	    elCell.innerHTML = "<div id=\"divPeriodization_startDropDown"+tmp_count+"\"></div>";
+
+  	    	var tmp_button = new YAHOO.widget.Button({
+                          type:"menu",
+                          id:"oPeriodization_startDropDown"+tmp_count,
+                          label: "<en>" +_label.substring(4)+"</en>",
+                          value: oData,
+                          container: "divPeriodization_startDropDown"+tmp_count,
+                          menu: [
+                          		{ text: Year +"01", value: Year +"01", onclick: { fn: onPeriodization_startDropDownItemClick, idvoucher: voucher_id} },
+							    { text: Year +"02", value: Year +"02", onclick: { fn: onPeriodization_startDropDownItemClick, idvoucher: voucher_id} },
+							    { text: Year +"03", value: Year +"03", onclick: { fn: onPeriodization_startDropDownItemClick, idvoucher: voucher_id} },
+							    { text: Year +"04", value: Year +"04", onclick: { fn: onPeriodization_startDropDownItemClick, idvoucher: voucher_id} },
+							    { text: Year +"05", value: Year +"05", onclick: { fn: onPeriodization_startDropDownItemClick, idvoucher: voucher_id} },
+							    { text: Year +"06", value: Year +"06", onclick: { fn: onPeriodization_startDropDownItemClick, idvoucher: voucher_id} },
+							    { text: Year +"07", value: Year +"07", onclick: { fn: onPeriodization_startDropDownItemClick, idvoucher: voucher_id} },
+							    { text: Year +"08", value: Year +"08", onclick: { fn: onPeriodization_startDropDownItemClick, idvoucher: voucher_id} },
+							    { text: Year +"09", value: Year +"09", onclick: { fn: onPeriodization_startDropDownItemClick, idvoucher: voucher_id} },
+							    { text: Year +"10", value: Year +"10", onclick: { fn: onPeriodization_startDropDownItemClick, idvoucher: voucher_id} },
+							    { text: Year +"11", value: Year +"11", onclick: { fn: onPeriodization_startDropDownItemClick, idvoucher: voucher_id} },
+							    { text: Year +"12", value: Year +"12", onclick: { fn: onPeriodization_startDropDownItemClick, idvoucher: voucher_id} },
+                          		{ text: Year+1 +"01", value: Year+1 +"01", onclick: { fn: onPeriodization_startDropDownItemClick, idvoucher: voucher_id} }	]});
+	    //Define this variable in the window scope (GLOBAL)
+           eval("window.oPeriodization_startDropDown"+tmp_count+" = tmp_button");
+
+    }
+
+	/********************************************************************************
+	 * CLick option combobox Periodization_start
+	 */
+    this.onPeriodization_startDropDownItemClick = function(p_sType, p_aArgs, p_oItem)
+	{
+	   	 //Use a diferente id for voucher. This variables wil be empty in PARTICULAR_SETTING
+	   	 path_values.voucher_id_for_periodization_start = p_oItem.cfg.getProperty("onclick").idvoucher;
+	   	 //'text' is the option selected
+	   	 path_values.periodization_start = p_oItem.cfg.getProperty('text');
+	   	 
+	   	 maintain_pagination_order();
+	   	 //call INDEX. Update Periodization_start Method is inside of INDEX
+	   	 execute_ds();
+
+	}
+
 	/********************************************************************************
 	 *
 	 */
@@ -288,7 +375,7 @@
 		td_empty(14);
 		td_sum('Total');
 		td_sum(tmp_sum);
-		td_empty(7);
+		td_empty(9);
 		//RowChecked
 		CreateRowChecked("signClass");
 		CreateRowChecked("janitorClass");
@@ -334,6 +421,22 @@
 		}
 	}
 
+
+	this.showlightbox = function(sUrl)
+	{
+		var onDialogShow = function(e, args, o)
+		{
+			var frame = document.createElement('iframe');
+			frame.src = sUrl;
+			frame.width = "100%";
+			frame.height = "460";
+			o.setBody(frame);
+		};
+		lightbox.showEvent.subscribe(onDialogShow, lightbox);
+		lightbox.show();
+	}
+
+
 //----------------------------------------------------------
 	YAHOO.util.Event.addListener(window, "load", function()
 	{
@@ -353,9 +456,3 @@
 	    loader.insert();
 
 	});
-
-
-
-
-
-
