@@ -10,7 +10,7 @@
 		var oNormalButton_0,oNormalButton_1,oNormalButton_2;
 		var normalButtons = [
 			{order:0, name:'btn_save',	funct:"onSave"},
-			{order:1, name:'btn_done',	funct:"onDoneClick"},
+			{order:1, name:'btn_done',	funct:"_onDoneClick"},
 			{order:2, name:'btn_export',funct:"onDownloadClick"}
 		]
 
@@ -27,33 +27,44 @@
 
 		var config_values = {
 			PanelLoading : 1,
-			particular_download : "property.uiinvoice.download_sub"
+			particular_download : "property.uiinvoice.download_sub",
+			particular_done : "property.uiinvoice.index"
 		}
 
 		var tableYUI;
 
-
-	this.showlightbox = function(sUrl)//(parameters, oRecord)
+	this._onDoneClick = function()
 	{
+		//save initial value
+		path_values_menuaction_original = path_values.menuaction;
 
-//alert(sUrl);
-/*
-		var oArgs = {menuaction:'property.uiinvoice.edit'};
-		var sUrl = phpGWLink('index.php', oArgs);
-
-		for(f=0; f<parameters.parameter.length; f++)
+		// if exist "particular_done" in particular.js
+		if(config_values.particular_done)
 		{
-			param_name = parameters.parameter[f].name;
-			param_source = parameters.parameter[f].source;
-			sUrl = sUrl + "&"+param_name+"=" + oRecord.getData(param_source);
+			path_values.menuaction = config_values.particular_done;
 		}
-*/
+		else
+		{
+			tmp_array = path_values.menuaction.split(".")
+			tmp_array[2] = "index"; //set function INDEX
+			path_values.menuaction = tmp_array.join('.');
+		}
+		
+		path_values.voucher_id = '';
+		window.open(phpGWLink('index.php',path_values),'_self');
+		//come back to initial values
+		path_values.menuaction = path_values_menuaction_original;
+	}
+
+
+	this.showlightbox = function(sUrl)
+	{
 		var onDialogShow = function(e, args, o)
 		{
 			var frame = document.createElement('iframe');
 			frame.src = sUrl;
 			frame.width = "100%";
-			frame.height = "460";
+			frame.height = "500";
 			o.setBody(frame);
 		};
 		lightbox.showEvent.subscribe(onDialogShow, lightbox);
@@ -265,7 +276,7 @@
 			CreateRowChecked("transfer_idClass");
 			td_empty(4);
 			td_sum(values_ds.sum);
-			td_empty(7);
+			td_empty(8);
 			//Add to Table
 			myfoot = tableYUI.createTFoot();
 			myfoot.setAttribute("id","myfoot");
