@@ -21,23 +21,27 @@
 		var linktoolTips =
 		 [
 		  {name:'lnk_workorder', title:'Workorder ID', description:'enter the Workorder ID to search by workorder - at any Date'},
+		  {name:'lnk_project', title:'Project ID', description:'enter the project ID to search by project - at any Date'},
 		  {name:'lnk_vendor', title:'Vendor', description:'Select the vendor by clicking this link'},
+		  {name:'lnk_invoice', title:'Invoice', description:'Enter the invoice id - any Date'},
 		  {name:'lnk_property', title:'Facilities Managements', description:'Select the property by clicking this link'},
 		  {name:'lnk_voucher', title:'Voucher', description:'enter the voucher ID to search by vouvher - at any Date'}
 		 ]
 
-
 		var textImput = [
 			{order:0, name:'workorder_id',	id:'txt_workorder'},
-			{order:1, name:'vendor_id',		id:'txt_vendor'},
-			{order:1, name:'loc1',			id:'txt_loc1'},
-			{order:3, name:'voucher_id',	id:'txt_voucher'}
+			{order:1, name:'project_id',	id:'txt_project'},
+			{order:2, name:'vendor_id',		id:'txt_vendor'},
+			{order:3, name:'invoice_id',	id:'txt_invoice'},
+			{order:4, name:'loc1',			id:'txt_loc1'},
+			{order:5, name:'voucher_id',	id:'txt_voucher'}
 		]
 
 		var toolTips = [
 			{name:'voucher_id_lnk',title:'Voucher ID', description:'click this link to enter the list of sub-invoices',ColumnDescription:''},
 			{name:'vendor_id_lnk', title:'', description:'',ColumnDescription: 'vendor_name'},
-			{name:'voucher_date_lnk', title:'Payment Date', description:'',ColumnDescription:'voucher_date_lnk'}
+			{name:'voucher_date_lnk', title:'Payment Date', description:'',ColumnDescription:'voucher_date_lnk'},
+			{name:'approved_amount', title:'Sum', description:'',ColumnDescription:'amount'}
 		]
 
 		// define the hidden column in datatable
@@ -51,6 +55,22 @@
 	    }
 
 		var tableYUI;
+
+		this.onChangeSelect = function(type)
+		{
+			var myselect=document.getElementById("sel_"+ type);
+			for (var i=0; i<myselect.options.length; i++)
+			{
+				if (myselect.options[i].selected==true)
+				{
+					break;
+				}
+			}
+			eval("path_values." +type +"='"+myselect.options[i].value+"'");
+			execute_ds();
+		}
+
+
 	/********************************************************************************
 	* Delete all message un DIV 'message'
 	*/
@@ -68,7 +88,7 @@
 				path_values.user_lid='all';
 
 				//oMenuButton_0.focus();
-				YAHOO.util.Dom.get("start_date-trigger").focus();
+				//YAHOO.util.Dom.get("start_date-trigger").focus();
 
 			}
 			else if(flag_particular_setting=='update')
@@ -100,7 +120,7 @@
 		td_empty(14);
 		td_sum('Total');
 		td_sum(tmp_sum);
-		td_empty(12);
+		td_empty(14);
 
 		//Add to Table
 		myfoot = tableYUI.createTFoot();
@@ -130,9 +150,3 @@
 
 		    loader.insert();
 		});
-
-
-
-
-
-
