@@ -60,6 +60,7 @@
 		newTD.style.fontWeight = 'bolder';
 		newTD.style.textAlign = 'right';
 		newTD.style.paddingRight = '0.8em';
+		newTD.style.whiteSpace = 'nowrap';
 		newTD.appendChild(document.createTextNode(sum));
 		newTR.appendChild(newTD);
   	}
@@ -231,6 +232,7 @@
 	{
 		YAHOO.util.Dom.get("txt_query").value = query;
 		path_values.query = query;
+		path_values.start = 0;
 		execute_ds();
 		myPaginator.setPage(1,true);
 	}
@@ -674,6 +676,12 @@
 							//console.log(sUrl); // firebug
 							showlightbox(sUrl);
 						}
+						else if(substr_count(sUrl,'target=_tinybox')>0)
+						{
+							//have to be defined as a local function. Example in invoice.list_sub.js
+							//console.log(sUrl); // firebug
+							showtinybox(sUrl);
+						}
 						else
 						{
 							window.open(sUrl,'_self');
@@ -842,9 +850,10 @@
 		if(typeof(linktoolTips)=='object')
 		{
 			show_link_tooltips();
-			create_lightbox();
 		}
 
+		create_lightbox();
+
 		toolbars = YAHOO.util.Dom.getElementsByClassName('toolbar','div');
 		for(i=0;i<toolbars.length;i++)
 		{
@@ -893,19 +902,33 @@
 							}
 		myPaginator = new YAHOO.widget.Paginator(myPaginatorConfig);
 
+		if (typeof YAHOO.layout === 'undefined')
+		{
+			var tableHeight = "30em";
+		}
+		else
+		{
+			var tableHeight = (YAHOO.layout.getUnitByPosition('center').getSizes().wrap.h)/22 + "em";
+		}
+
+//		console.log(YAHOO.layout.getUnitByPosition('center').getSizes());
+//		alert(tableHeight);
+
 		var myTableConfig = {
 							initialRequest		: '',//la primera vez ya viene ordenado, por la columna respectiva y solo 15 registros
 							generateRequest		: buildQueryString,
 							dynamicData			: true,
 							sortedBy			: {key:values_ds.sort, dir:values_ds.dir/*dir:YAHOO.widget.DataTable.CLASS_DESC*/},
 							paginator			: myPaginator
+				//			width				: "100%",
+				//			height				: tableHeight //"30em",
 		};
 		//Create DataTable ; Second call JSON (GET)
 		myDataTable = new YAHOO.widget.DataTable(container[0], myColumnDefs, myDataSource, myTableConfig);
+	//	myDataTable = new YAHOO.widget.ScrollingDataTable(container[0], myColumnDefs, myDataSource, myTableConfig);
 
 		myDataTable.on('cellMouseoverEvent', function (oArgs)
 		{
-			{
 			if (showTimer)
 			{
 				window.clearTimeout(showTimer);
@@ -922,59 +945,61 @@
 			var rowspepage=0;
 			var param1=0;
 
-			for(var p=0;p<toolTips.length;p++)
+			if(values_ds.recordsReturned > 0)
 			{
-				if (column.key == toolTips[p].name)
+				for(var p=0;p<toolTips.length;p++)
 				{
-					var record = this.getRecord(target);
-					if(myPaginator.getCurrentPage() > 2 && myDataTable.getRecordSet().getRecords()[0]==null )
+					if (column.key == toolTips[p].name)
 					{
-						title = toolTips[p].title || myDataTable.getRecordSet().getRecords()[this.getRecordIndex(target)].getData(toolTips[p].name);
-						description = toolTips[p].description || myDataTable.getRecordSet().getRecords()[this.getRecordIndex(target)].getData(toolTips[p].ColumnDescription);
-					}
-
-					if(myPaginator.getCurrentPage() == 2 && myDataTable.getRecordSet().getRecords()[0]==null)
-					{
-						title = toolTips[p].title || myDataTable.getRecordSet().getRecords()[this.getRecordIndex(target)].getData(toolTips[p].name);
-						description = toolTips[p].description || myDataTable.getRecordSet().getRecords()[this.getRecordIndex(target)].getData(toolTips[p].ColumnDescription);
-					}
-					if(myPaginator.getCurrentPage() == 2 && myDataTable.getRecordSet().getRecords()[0]!=null)
-					{
-						rowspepage = myPaginator.getRowsPerPage();
-						num = this.getRecordIndex(target)-rowspepage;
-						title = toolTips[p].title || myDataTable.getRecordSet().getRecords()[num].getData(toolTips[p].name);
-						description = toolTips[p].description || myDataTable.getRecordSet().getRecords()[num].getData(toolTips[p].ColumnDescription);
-					}
-					if(myPaginator.getCurrentPage() == 1 && myDataTable.getRecordSet().getRecords()[0]!=null)
-					{
-						title = toolTips[p].title || myDataTable.getRecordSet().getRecords()[this.getRecordIndex(target)].getData(toolTips[p].name);
-						description = toolTips[p].description || myDataTable.getRecordSet().getRecords()[this.getRecordIndex(target)].getData(toolTips[p].ColumnDescription);
-					}
-					if(myPaginator.getCurrentPage() > 2 && myDataTable.getRecordSet().getRecords()[0]!=null)
-					{
-						pages = parseInt(myPaginator.getCurrentPage()-1);
-						rowspepage = myPaginator.getRowsPerPage();
-						param1 = parseInt(pages * rowspepage);
-						num = parseInt(this.getRecordIndex(target) - param1);
-						title = toolTips[p].title || myDataTable.getRecordSet().getRecords()[num].getData(toolTips[p].name);
-						description = toolTips[p].description || myDataTable.getRecordSet().getRecords()[num].getData(toolTips[p].ColumnDescription);
-					}
-
-					var xy = [parseInt(oArgs.event.clientX,10) + 10 ,parseInt(oArgs.event.clientY,10) + 10 ];
-
-					showTimer = window.setTimeout(function()
-					{
-						tt.setBody("<table class='tooltip-table'><tr class='tooltip'><td class='nolink'>"+title+"</td></tr><tr><td>"+description+"</td></tr></table>");
-						tt.cfg.setProperty('xy',xy);
-						tt.show();
-						hideTimer = window.setTimeout(function()
+						var record = this.getRecord(target);
+						if(myPaginator.getCurrentPage() > 2 && myDataTable.getRecordSet().getRecords()[0]==null )
 						{
-							tt.hide();
-						},5000);
-					},100);
+							title = toolTips[p].title || myDataTable.getRecordSet().getRecords()[this.getRecordIndex(target)].getData(toolTips[p].name);
+								description = toolTips[p].description || myDataTable.getRecordSet().getRecords()[this.getRecordIndex(target)].getData(toolTips[p].ColumnDescription);
+						}
+
+						if(myPaginator.getCurrentPage() == 2 && myDataTable.getRecordSet().getRecords()[0]==null)
+						{
+							title = toolTips[p].title || myDataTable.getRecordSet().getRecords()[this.getRecordIndex(target)].getData(toolTips[p].name);
+							description = toolTips[p].description || myDataTable.getRecordSet().getRecords()[this.getRecordIndex(target)].getData(toolTips[p].ColumnDescription);
+						}
+						if(myPaginator.getCurrentPage() == 2 && myDataTable.getRecordSet().getRecords()[0]!=null)
+						{
+							rowspepage = myPaginator.getRowsPerPage();
+							num = this.getRecordIndex(target)-rowspepage;
+							title = toolTips[p].title || myDataTable.getRecordSet().getRecords()[num].getData(toolTips[p].name);
+							description = toolTips[p].description || myDataTable.getRecordSet().getRecords()[num].getData(toolTips[p].ColumnDescription);
+						}
+						if(myPaginator.getCurrentPage() == 1 && myDataTable.getRecordSet().getRecords()[0]!=null)
+						{
+							title = toolTips[p].title || myDataTable.getRecordSet().getRecords()[this.getRecordIndex(target)].getData(toolTips[p].name);
+							description = toolTips[p].description || myDataTable.getRecordSet().getRecords()[this.getRecordIndex(target)].getData(toolTips[p].ColumnDescription);
+						}
+						if(myPaginator.getCurrentPage() > 2 && myDataTable.getRecordSet().getRecords()[0]!=null)
+						{
+							pages = parseInt(myPaginator.getCurrentPage()-1);
+							rowspepage = myPaginator.getRowsPerPage();
+							param1 = parseInt(pages * rowspepage);
+							num = parseInt(this.getRecordIndex(target) - param1);
+							title = toolTips[p].title || myDataTable.getRecordSet().getRecords()[num].getData(toolTips[p].name);
+							description = toolTips[p].description || myDataTable.getRecordSet().getRecords()[num].getData(toolTips[p].ColumnDescription);
+						}
+
+						var xy = [parseInt(oArgs.event.clientX,10) + 10 ,parseInt(oArgs.event.clientY,10) + 10 ];
+
+						showTimer = window.setTimeout(function()
+						{
+							tt.setBody("<table class='tooltip-table'><tr class='tooltip'><td class='nolink'>"+title+"</td></tr><tr><td>"+description+"</td></tr></table>");
+							tt.cfg.setProperty('xy',xy);
+							tt.show();
+							hideTimer = window.setTimeout(function()
+							{
+								tt.hide();
+							},5000);
+						},100);
+					}
 				}
 			}
-			}
 		});
 
 		 myDataTable.on('cellMouseoutEvent', function (oArgs)
@@ -1451,6 +1476,24 @@
 		}
 		return array_result;
 	}
+
+	this.showtinybox = function(sUrl)
+	{
+		TINY.box.show({
+		iframe:sUrl,
+		boxid:'frameless',
+		width:750,
+		height:500,
+		fixed:false,
+		maskid:'darkmask',
+		maskopacity:40,
+		mask:true,
+		animate:true,
+		close: true
+		});
+	}
+
+
 //----------------------------------------------------------------------------------------
 
 	CreateLoading();
