@@ -29,6 +29,31 @@
 		return tmp_sum = YAHOO.util.Number.format(tmp_sum, {decimalPlaces:round, decimalSeparator:",", thousandsSeparator:" "});
 	}
 
+/********************************************************************************/
+
+	this.getTotalSum = function(name_column,round,paginator,datatable)
+	{
+		if(!paginator.getPageRecords())
+		{
+			return '0,00';
+		}
+		begin = end = 0;
+		end = datatable.getRecordSet().getLength();
+
+		tmp_sum = 0;
+		for(i = begin; i < end; i++)
+		{
+			if(tmp_record = parseFloat(datatable.getRecordSet().getRecords(0)[i].getData(name_column)))
+			{
+				tmp_sum += tmp_record;
+			}
+			//tmp_sum = tmp_sum + parseFloat(datatable.getRecordSet().getRecords(0)[i].getData(name_column));
+		}
+
+		return tmp_sum = YAHOO.util.Number.format(tmp_sum, {decimalPlaces:round, decimalSeparator:",", thousandsSeparator:" "});
+	}
+
+
 /********************************************************************************/
 
   	this.td_empty = function(colspan)
@@ -324,6 +349,7 @@
 		newTD.style.fontWeight = 'bolder';
 		newTD.style.textAlign = 'right';
 		newTD.style.paddingRight = '0.8em';
+		newTD.style.whiteSpace = 'nowrap';
 		newTD.appendChild(document.createTextNode(sum));
 		newTR.appendChild(newTD);
   	}
@@ -348,12 +374,25 @@
 
 		if(data[0]["is_paginator"]==1)
 		{
+			var rows_per_page = 10;
+			if(typeof(data[0]['rows_per_page'])!= 'undefined' && data[0]['rows_per_page'])
+			{
+				rows_per_page = data[0]['rows_per_page'];
+			}
+
+			var initial_page = 1;
+
+			if(typeof(data[0]['initial_page'])!= 'undefined' && data[0]['initial_page'])
+			{
+				initial_page = data[0]['initial_page'];
+			}
 
 			myPaginatorConfig = {
 									containers			: pager,
 									totalRecords		: data[0]["total_records"],
 									pageLinks			: 10,
-									rowsPerPage			: 10
+									rowsPerPage			: rows_per_page,
+									initialPage			: initial_page
 								}
 
 			eval("myPaginator_"+num+" = new YAHOO.widget.Paginator(myPaginatorConfig)");
@@ -506,16 +545,15 @@
   	}
 /********************************************************************************/
 
-	this.execute_async = function(datatable)
+	this.execute_async = function(datatable, incoming_url)
 	{
-		try	{
-	 			ds = phpGWLink('index.php',base_java_url,true);
-	 			//ds = url;
-			}
-		catch(e)
-			{
-				alert(e);
-			}
+		if(typeof(incoming_url) != 'undefined')
+		{
+			base_java_url = incoming_url;
+		}
+
+ 		ds = phpGWLink('index.php',base_java_url,true);
+		
 		var callback =
 		{
 			success: function(o)
@@ -574,22 +612,25 @@
 		//delete quotes in myButtons, field: "fn"
 		for(k=0;k<myButtons.length;k++)
 		{
-			for(m=0;m<myButtons[k].length;m++)
+			if(typeof(myButtons[k])!="undefined")
 			{
-				if(myButtons[k][m]['type']=='menu')
+				for(m=0;m<myButtons[k].length;m++)
 				{
-					for(p=0;p<myButtons[k][m]['value'].length;p++)
+					if(myButtons[k][m]['type']=='menu')
 					{
-						try
-						  {
-							this.deletes_quotes(myButtons[k][m]['value'][p]['onclick'],"fn");
-						  }
-						catch(err)
-						  {
-							txt="There was an error on this page.\n\n";
-							txt+="Error description: " + err.description + "\n\n";
-							alert(txt);
-						  }
+						for(p=0;p<myButtons[k][m]['value'].length;p++)
+						{
+							try
+							  {
+								this.deletes_quotes(myButtons[k][m]['value'][p]['onclick'],"fn");
+							  }
+							catch(err)
+							  {
+								txt="There was an error on this page.\n\n";
+								txt+="Error description: " + err.description + "\n\n";
+								alert(txt);
+							  }
+						}
 					}
 				}
 			}
