@@ -2,21 +2,23 @@
 // Declaration of request.index vars
 //--------------------------------------------------------
 	//define SelectButton
- 	var oMenuButton_0, oMenuButton_1, oMenuButton_2, oMenuButton_3;
+ 	var oMenuButton_0, oMenuButton_1, oMenuButton_2, oMenuButton_3, oMenuButton_4, oMenuButton_5;
  	var selectsButtons = [
-	{order:0, var_URL:'district_id',name:'btn_district_id',style:'districtbutton',dependiente:''},
-	{order:1, var_URL:'cat_id',name:'btn_cat_id',style:'categorybutton',dependiente:''},
-	{order:2, var_URL:'status_id',name:'btn_status_id',style:'districtbutton',dependiente:''},
-	{order:3, var_URL:'filter', name:'btn_user_id',style:'ownerIdbutton',dependiente:''}
+    {order:0, var_URL:'property_cat_id', name:'btn_property_cat',	style:'categorybutton',	dependiente:[]},
+	{order:1, var_URL:'district_id',name:'btn_district_id',style:'districtbutton',dependiente:''},
+	{order:2, var_URL:'cat_id',name:'btn_cat_id',style:'categorybutton',dependiente:''},
+	{order:3, var_URL:'status_id',name:'btn_status_id',style:'districtbutton',dependiente:''},
+	{order:4, var_URL:'degree_id',name:'btn_degree_id',style:'districtbutton',dependiente:''},
+	{order:5, var_URL:'filter', name:'btn_user_id',style:'ownerIdbutton',dependiente:''}
 	]
 
 	// define buttons
 	var oNormalButton_0, oNormalButton_1, oNormalButton_2, oNormalButton_3;
 	var normalButtons = [
 	{order:0, name:'btn_search', funct:"onSearchClick"},
-	{order:1, name:'btn_export', funct:"onDownloadClick"},
-	{order:2, name:'btn_update', funct:"onUpdateProject"},
-	{order:3, name:'btn_new', funct:"onNewClick"}
+	{order:1, name:'btn_update', funct:"onUpdateProject"},
+	{order:2, name:'btn_new', funct:"onNewClick"},
+	{order:3, name:'btn_export', funct:"onDownloadClick"}
 	]
 
 	// define Text buttons
@@ -26,49 +28,98 @@
 
 	var toolTips =
 	[
-	 	{name:'btn_export', title:'Download', description:'Download table to your browser',ColumnDescription:''}
+	 	{name:'btn_export', title:'Download', description:'Download table to your browser',ColumnDescription:''},
+	 	{name:'btn_update', title:'Update Project', description:'Update project with selected',ColumnDescription:''}
 	]
 
 	var linktoolTips =
 	[
-	    {name:'btn_priority_key', title:'Priority key', description:'To alter the Priority key'}
+	    {name:'btn_priority_key', title:'Priority key', description:'To alter the Priority key'},
+		{name:'btn_date_search', title:'Date search', description:'Narrow the search by dates'}
 	]
 
 	// define the hidden column in datatable
 	var config_values = {
-		date_search : 0 //if search has link "Data search"
+		date_search : 1 //if search has link "Data search"
 	};
 /****************************************************************************************/
 
+	var oArgs_request = {menuaction:'property.uirequest.edit'};
+	var sUrl_request = phpGWLink('index.php', oArgs_request);
+	
+	var linktToRequest = function(elCell, oRecord, oColumn, oData)
+	{
+	  	elCell.innerHTML = "<a href="+sUrl_request+"&id="+oData+">" + oData + "</a>";
+//	  	elCell.innerHTML = "<a href=" + sUrl_request + "&id=" + oData + "&nonavbar=" + path_values.nonavbar + ">" + oData + "</a>";
+	};
+
+
+	var FormatterRight = function(elCell, oRecord, oColumn, oData)
+	{
+		elCell.innerHTML = "<div align=\"right\">"+YAHOO.util.Number.format(oData, {thousandsSeparator:" "})+"</div>";
+	}
+
+
+	this.onChangeSelect = function(type)
+	{
+		var myselect=document.getElementById("sel_"+ type);
+		for (var i=0; i<myselect.options.length; i++)
+		{
+			if (myselect.options[i].selected==true)
+			{
+				break;
+			}
+		}
+		eval("path_values." +type +"='"+myselect.options[i].value+"'");
+		execute_ds();
+	}
+
+	var tableYUI;
+
 	this.particular_setting = function()
 	{
 		if(flag_particular_setting=='init')
 		{
+			tableYUI = YAHOO.util.Dom.getElementsByClassName("yui-dt-data","tbody")[0].parentNode;
+			tableYUI.setAttribute("id","tableYUI");
+
 //	console.log(path_values);
-			//district
-			index = locate_in_array_options(0,"value",path_values.district_id);
+
+			index = locate_in_array_options(0,"value",path_values.property_cat_id);
 			if(index)
 			{
 				oMenuButton_0.set("label", ("<em>" + array_options[0][index][1] + "</em>"));
 			}
-			//category
-			index = locate_in_array_options(1,"value",path_values.cat_id);
+
+			//district
+			index = locate_in_array_options(1,"value",path_values.district_id);
 			if(index)
 			{
 				oMenuButton_1.set("label", ("<em>" + array_options[1][index][1] + "</em>"));
 			}
-			//status
-			index = locate_in_array_options(2,"value",path_values.status_id);
+			//category
+			index = locate_in_array_options(2,"value",path_values.cat_id);
 			if(index)
 			{
 				oMenuButton_2.set("label", ("<em>" + array_options[2][index][1] + "</em>"));
 			}
-			//user
-			index = locate_in_array_options(3,"value",path_values.filter);
+			//status
+			index = locate_in_array_options(3,"value",path_values.status_id);
 			if(index)
 			{
 				oMenuButton_3.set("label", ("<em>" + array_options[3][index][1] + "</em>"));
 			}
+			index = locate_in_array_options(4,"value",path_values.degree_id);
+			if(index)
+			{
+				oMenuButton_4.set("label", ("<em>" + array_options[4][index][1] + "</em>"));
+			}
+			//user
+			index = locate_in_array_options(5,"value",path_values.filter);
+			if(index)
+			{
+				oMenuButton_5.set("label", ("<em>" + array_options[5][index][1] + "</em>"));
+			}
 
 			oMenuButton_0.focus();
 		}
@@ -139,9 +190,52 @@
 
   	this.myParticularRenderEvent = function()
   	{
-  	//don't delete it
+			tableYUI.deleteTFoot();
+			addFooterDatatable();
   	}
 
+
+  	this.addFooterDatatable = function()
+  	{
+		tmp_sum_investment = YAHOO.util.Number.format(values_ds.sum_investment, {decimalPlaces:0, decimalSeparator:",", thousandsSeparator:" "});
+		tmp_sum_operation = YAHOO.util.Number.format(values_ds.sum_operation, {decimalPlaces:0, decimalSeparator:",", thousandsSeparator:" "});
+		tmp_sum_potential_grants = YAHOO.util.Number.format(values_ds.sum_potential_grants, {decimalPlaces:0, decimalSeparator:",", thousandsSeparator:" "});
+//		tmp_sum_budget = YAHOO.util.Number.format(values_ds.sum_budget, {decimalPlaces:0, decimalSeparator:",", thousandsSeparator:" "});
+		tmp_sum_consume = YAHOO.util.Number.format(values_ds.sum_consume, {decimalPlaces:0, decimalSeparator:",", thousandsSeparator:" "});
+
+
+		count_empty = 0;
+		for(i=0;i<myColumnDefs.length;i++)
+		{
+			if (myColumnDefs[i].key == 'amount_investment')
+			{
+				count_empty = i;
+				break;
+			}
+		}
+
+		count_empty_end = myColumnDefs.length - count_empty;
+
+		//Create ROW
+		newTR = document.createElement('tr');
+
+		td_empty(count_empty);
+		td_sum(tmp_sum_investment);
+		td_sum(tmp_sum_operation);
+		td_sum(tmp_sum_potential_grants);
+		td_sum(tmp_sum_consume);
+		td_empty(count_empty_end);
+		//Add to Table
+
+		myfoot = tableYUI.createTFoot();
+		myfoot.setAttribute("id","myfoot");
+		myfoot.appendChild(newTR.cloneNode(true));
+
+		//clean value for values_ds.message
+		//values_ds.message = null;
+  	}
+
+
  /****************************************************************************************/
 
   	this.myexecuteTEMP = function()
@@ -158,9 +252,6 @@
 
   	}
 
-
-
-
 /****************************************************************************************/
 
 	YAHOO.util.Event.addListener(window, "load", function()
