@@ -6,15 +6,24 @@
 	* @internal Idea by Jason Wies <jason@xc.net>
 	* @author Lars Kneschke <lkneschke@linux-at-work.de>
 	* @author Dave Hall <skwashd@phpgroupware.org>
-	* @copyright Copyright (C) 2004-2005 Free Software Foundation, Inc. http://www.fsf.org/
+	* @copyright Copyright (C) 2004-2010 Free Software Foundation, Inc. http://www.fsf.org/
 	* @license http://www.gnu.org/licenses/gpl.html GNU General Public License
 	* @package phpgroupware
-	* @version $Id: redirect.php 15834 2005-04-15 13:19:15Z powerstat $
+	* @version $Id: redirect.php 4804 2010-02-12 07:26:26Z sigurd $
 	*/
 
+
 	//Get the session variables set for non cookie based sessions
-	if (! (@isset($_COOKIES['PHPSESSID']) || @isset($_COOKIES['sessionid']) ) )
+	if ( !isset($_COOKIES['PHPSESSID']) 
+		|| isset($_COOKIES['sessionid']) ) 
 	{
+		// nothing else we can do
+		if ( !isset($_SERVER['HTTP_REFERER']) 
+				&& isset($_GET['go']) )
+		{
+			Header("Location: {$_GET['go']}");
+			exit;
+		}
 		$get = array();
 		$url = parse_url($_SERVER['HTTP_REFERER']);
 		parse_str($url['query'], $get);
@@ -25,31 +34,37 @@
 
 	}
 
-	$GLOBALS['phpgw_info']['flags'] = array(
-					'currentapp'	=> 'home',
-					'noheader'	=> True,
-					'nonavbar'	=> True,
-					'noappheader'	=> True,
-					'noappfooter'	=> True,
-					'nofooter'	=> True
-					);
+	$GLOBALS['phpgw_info']['flags'] = array
+	(
+		'currentapp'	=> 'home',
+		'noheader'		=> True,
+		'nonavbar'		=> True,
+		'noappheader'	=> True,
+		'noappfooter'	=> True,
+		'nofooter'		=> True
+	);
 
 	/**
 	* Include phpgroupware header
 	*/
 	include_once('header.inc.php');
 
-	if( @isset($_GET['go']) )
+	if( isset($_GET['go']) )
 	{
-		$_GET['go'] = html_entity_decode($_GET['go']);
+		$_GET['go'] = htmlspecialchars_decode(urldecode($_GET['go']));
+		Header("Location: {$_GET['go']}");
+		exit;
+
+/*
 		?>
-			<h2><?php lang('external link'); ?></h2>
-			<p><?php lang('lang you are about to visit an external site'); ?><br />
-			<?php lang('vist:'); ?> <a href="<?php echo $_GET['go']; ?>" 
+			<h2><?php echo lang('external link'); ?></h2>
+			<p><?php echo lang('lang you are about to visit an external site'); ?><br />
+			<?php echo lang('vist:'); ?> <a href="<?php echo $_GET['go']; ?>" 
 				target="_blank"><?php echo $_GET['go']; ?></a></p>
-			<script language="JavaScript" type="text/javascript">window.location='<?php echo$_GET['go']; ?>';</script>
+			<script language="JavaScript" type="text/javascript">window.location="<?php echo$_GET['go']; ?>";</script>
 		<?php
 	        exit;
+*/
 	}
 	else
 	{
