@@ -12,7 +12,18 @@
 	*  option) any later version.                                              *
 	\**************************************************************************/
 
-	/* $Id: hook_logout.inc.php 690 2008-02-02 10:11:33Z dave $ */
+	/* $Id: hook_logout.inc.php 9113 2012-04-10 11:06:41Z sigurdne $ */
 
-	$GLOBALS['phpgw']->db->query("delete from phpgw_reg_accounts where reg_dla <= '"
+	$c = createobject('phpgwapi.config','registration');
+	$c->read();
+
+	if($c->config_data['activate_account'] == 'pending_approval')
+	{
+		$GLOBALS['phpgw']->db->query("DELETE FROM phpgw_reg_accounts WHERE reg_dla <= '"
+		. (time() - 7200) . "' AND reg_info IS NULL",__LINE__,__FILE__);	
+	}
+	else
+	{
+		$GLOBALS['phpgw']->db->query("DELETE FROM phpgw_reg_accounts WHERE reg_dla <= '"
 		. (time() - 7200) . "'",__LINE__,__FILE__);
+	}
