@@ -1,6 +1,30 @@
 <?php
+	/**
+	 * Frontend : a simplified tool for end users.
+	 *
+	 * @copyright Copyright (C) 2010 Free Software Foundation, Inc. http://www.fsf.org/
+	 * @license http://www.gnu.org/licenses/gpl.html GNU General Public License
+	 * @package Frontend
+	 * @version $Id: class.soparty.inc.php 11387 2013-10-23 13:18:01Z sigurdne $
+	 */
+
+	/*
+	   This program is free software: you can redistribute it and/or modify
+	   it under the terms of the GNU General Public License as published by
+	   the Free Software Foundation, either version 2 of the License, or
+	   (at your option) any later version.
+
+	   This program is distributed in the hope that it will be useful,
+	   but WITHOUT ANY WARRANTY; without even the implied warranty of
+	   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+	   GNU General Public License for more details.
+
+	   You should have received a copy of the GNU General Public License
+	   along with this program.  If not, see <http://www.gnu.org/licenses/>.
+	*/
 
 phpgw::import_class('rental.socommon');
+phpgw::import_class('rental.bofellesdata');
 
 include_class('rental', 'agresso_cs15', 'inc/model/');
 include_class('rental', 'party', 'inc/model/');
@@ -9,6 +33,11 @@ include_class('rental', 'result_unit', 'inc/locations/');
 
 class rental_soparty extends rental_socommon
 {
+	const LOCATION_ROOT = '.';
+	const LOCATION_IN = '.RESPONSIBILITY.INTO';
+	const LOCATION_OUT = '.RESPONSIBILITY.OUT';
+	const LOCATION_INTERNAL = '.RESPONSIBILITY.INTERNAL';
+
 	protected static $so;
 
 	/**
@@ -123,20 +152,21 @@ class rental_soparty extends rental_socommon
 				$filter_clauses[] = "contract.location_id = {$party_type}";
 			}
 		}
-		
+
 		if(isset($filters['active']))
 		{
 			if($filters['active'] == 'active')
 			{
 				$filter_clauses[] = "NOT party.is_inactive";
-			} 
+			}
 			else if($filters['active'] == 'inactive')
 			{
 				$filter_clauses[] = "party.is_inactive = TRUE";
-			} 
+			}
 		}
 
-		if(isset($filters['contract_id'])){
+		if(isset($filters['contract_id']))
+		{
 			$contract_id = $this->marshal($filters['contract_id'],'int');
 			if(isset($contract_id) && $contract_id > 0)
 			{
@@ -144,7 +174,8 @@ class rental_soparty extends rental_socommon
 			}
 		}
 
-		if(isset($filters['not_contract_id'])){
+		if(isset($filters['not_contract_id']))
+		{
 			$contract_id = $this->marshal($filters['not_contract_id'],'int');
 			if(isset($contract_id) && $contract_id > 0)
 			{
@@ -152,14 +183,27 @@ class rental_soparty extends rental_socommon
 			}
 		}
 
-		if(isset($filters['org_unit_id'])){
+		if(isset($filters['org_unit_id']))
+		{
+			$bofelles = rental_bofellesdata::get_instance();
 			$org_unit_id = $this->marshal($filters['org_unit_id'],'string');
 			if(isset($org_unit_id))
 			{
-				$filter_clauses[] = "party.org_enhet_id = {$org_unit_id}";
+				//check if org_unit is on top level
+				if($bofelles->org_unit_is_top_level($org_unit_id))
+				{
+					//get connected units on level 4
+					$org_unit_ids_tmp = $bofelles->get_org_unit_ids_from_top($org_unit_id);
+					$org_unit_ids = implode(',',$org_unit_ids_tmp);
+					$filter_clauses[] = "party.org_enhet_id IN ({$org_unit_ids})";
+				}
+				else
+				{
+					$filter_clauses[] = "party.org_enhet_id = {$org_unit_id}";
+				}
 			}
 		}
-		
+
 		if(isset($filters['email'])){
 			$email = $this->marshal($filters['email'],'string');
 			if(isset($email))
@@ -171,7 +215,7 @@ class rental_soparty extends rental_socommon
 		if(isset($filters['sync']))
 		{
 			$filter_clauses[] = "NOT party.is_inactive";
-			
+
 			if($filters['sync'] == 'sync_parties')
 			{
 				// involved in contract with service- and responsibility identifiers
@@ -203,7 +247,7 @@ class rental_soparty extends rental_socommon
 				$filter_clauses[] = "party.result_unit_number IS NULL";
 			}
 		}
-		
+
 		if(count($filter_clauses))
 		{
 			$clauses[] = join(' AND ', $filter_clauses);
@@ -252,6 +296,7 @@ class rental_soparty extends rental_socommon
 		{$this->left_join} rental_contract contract ON (contract.id = c_p.contract_id)";
 
 		$joins = $join_contracts;
+
 		return "SELECT {$cols} FROM {$tables} {$joins} WHERE {$condition} {$order}";
 	}
 
@@ -290,19 +335,19 @@ class rental_soparty extends rental_socommon
 	function update($party)
 	{
 		$id = intval($party->get_id());
-		
-		
+
+
 		$location_id = $this->marshal($party->get_location_id(), 'int');
-		
+
 		if($location_id)
 		{
 			$loc = $GLOBALS['phpgw']->locations->get_name($location_id);
 			$name = $loc['location'];
 			$level_identifier = result_unit::get_identifier_from_name($name);
 		}
-		
+
 		$result_unit_number = $this->marshal($level_identifier, 'string');
-		
+
 		$values = array(
 			'identifier = '		. $this->marshal($party->get_identifier(), 'string'),
 			'first_name = '     . $this->marshal($party->get_first_name(), 'string'),
@@ -324,12 +369,13 @@ class rental_soparty extends rental_socommon
 			'is_inactive = '    . $this->marshal(($party->is_inactive() ? 'true' : 'false'), 'bool'),
 			'comment = '        . $this->marshal($party->get_comment(), 'string'),
 			'org_enhet_id = '	. $this->marshal($party->get_org_enhet_id(), 'int'),
+			'unit_leader = '	. $this->marshal($party->get_unit_leader(), 'string'),
 			'location_id = '	. $location_id,
 			'result_unit_number = ' . $result_unit_number
 		);
-		
+
 		$result = $this->db->query('UPDATE rental_party SET ' . join(',', $values) . " WHERE id=$id", __LINE__,__FILE__);
-			
+
 		return isset($result);
 	}
 
@@ -377,6 +423,7 @@ class rental_soparty extends rental_socommon
 			$party->set_title(          $this->unmarshal($this->db->f('title'), 'string'));
 			$party->set_url(            $this->unmarshal($this->db->f('url'), 'string'));
 			$party->set_org_enhet_id(   $this->unmarshal($this->db->f('org_enhet_id'), 'string'));
+			$party->set_unit_leader(   $this->unmarshal($this->db->f('unit_leader'), 'string'));
 			$sync_message = $party->set_sync_data(
 				array(
 					'responsibility_id' => $this->unmarshal($this->db->f('responsibility_id'), 'string'),
@@ -391,14 +438,14 @@ class rental_soparty extends rental_socommon
 		}
 		return $party;
 	}
-	
+
 	public function get_export_data()
 	{
 		$parties = rental_soparty::get_instance()->get(null, null, null, null, null, null, null);
 		$exportable = new rental_agresso_cs15($parties);
 		return $exportable->get_contents();
 	}
-	
+
 	public function get_number_of_parties()
 	{
 		$q ="SELECT COUNT(id) FROM rental_party";
@@ -407,6 +454,135 @@ class rental_soparty extends rental_socommon
 		$this->db->next_record();
 		return (int) $this->db->f('count',true);
 	}
-	
+
+	public function has_contract($party_id)
+	{
+		$sql = "SELECT * FROM rental_contract_party WHERE party_id={$party_id}";
+		$result = $this->db->query($sql);
+		if($this->db->next_record())
+		{
+			return true;
+		}
+		else
+		{
+			return false;
+		}
+	}
+
+	public function delete_party($party_id)
+	{
+		if($party_id)
+		{
+			$sql = "DELETE FROM rental_party WHERE id={$party_id}";
+			$this->db->query($sql, __LINE__, __FILE__);
+			return true;
+		}
+	}
+
+
+ 		/**
+		 * Check to see if this user is an administrator
+		 *
+		 * @return true if private permission on root, false otherwise
+		 */
+
+		protected function isAdministrator()
+		{
+			return $GLOBALS['phpgw']->acl->check(self::LOCATION_ROOT,PHPGW_ACL_PRIVATE,'rental');
+		}
+
+		/**
+		 * Check to see if the user is an executive officer
+		 *
+		 * @return true if at least add permission on fields of responsibilities (locations: .RESPONSIBIITY.*)
+		 */
+		protected function isExecutiveOfficer()
+		{
+			return (
+				$GLOBALS['phpgw']->acl->check(self::LOCATION_IN,PHPGW_ACL_ADD,'rental')	||
+				$GLOBALS['phpgw']->acl->check(self::LOCATION_OUT,PHPGW_ACL_ADD,'rental')	||
+				$GLOBALS['phpgw']->acl->check(self::LOCATION_INTERNAL,PHPGW_ACL_ADD,'rental')
+			);
+		}
+
+ 	/**
+ 	 * Synchronization job to update company name on contract parties which are connected to Fellesdata.
+ 	 *
+ 	 * Uses property org_enhet_id on party to link party with unit from Fellesdata.
+ 	 * To be run as a scheduled job
+ 	 */
+ 	function syncronize_party_name()
+ 	{
+ 		$config	= CreateObject('phpgwapi.config','rental');
+		$config->read();
+
+		$use_fellesdata = $config->config_data['use_fellesdata'];
+		if(!$use_fellesdata){
+			return;
+		}
+		$bofelles = rental_bofellesdata::get_instance();
+
+		$parties = rental_soparty::get_instance()->get();
+		$result_count = rental_soparty::get_instance()->get_count();
+		$updated_parties;
+
+		$updated_parties[] = "Total number of parties: {$result_count}";
+
+		if(($this->isExecutiveOfficer() || $this->isAdministrator()))
+		{
+			$count = 0;
+			$count_result_unit_number = 0;
+			$count_identifier = 0;
+			$count_responsibility = 0;
+
+			foreach ($parties as $party) {
+				$unit_found = false;
+				$fellesdata = NULL;
+
+				if(isset($party)) {
+					$sync_data = $party->get_sync_data();
+
+					$fellesdata = $bofelles->result_unit_exist($sync_data['result_unit_number'],4);
+					if ($fellesdata) {
+						$updated_parties[] = "Unit id found {$fellesdata['UNIT_ID']} by result unit number check. The unit name is {$fellesdata['UNIT_NAME']}<br />";
+						$count_result_unit_number++;
+					}
+
+					if ($fellesdata && isset($fellesdata['UNIT_ID']) && is_numeric($fellesdata['UNIT_ID'])) {
+						// We found a match, so store the new connection
+						$party->set_org_enhet_id($fellesdata['UNIT_ID']);
+						$old_party_name = $party->get_company_name();
+						$party->set_company_name($fellesdata['UNIT_NAME']);
+						$updated_parties[] = "Updated company name on party {$party->get_id()} with unit ID {$party->get_org_enhet_id} from {$old_party_name} to {$party->get_company_name()}";
+						$count++;
+					} else {
+						// No match was found. Do nothing
+						//$party->set_org_enhet_id(NULL);
+					}
+					rental_soparty::get_instance()->store($party);
+				}
+			}
+
+			$updated_parties[] = "Number of parties found through result unit number {$count_result_unit_number}";
+			$updated_parties[] = "Number of parties that have been updated {$count}";
+			$this->log_sync_messages($updated_parties);
+		}
+ 	}
+
+	private function log_sync_messages($messages)
+	{
+		$msgs = array_merge(
+			array('---------------Messages-------------------'),
+			$messages
+		);
+
+		//use PHPGW tmp-catalog to store log-file
+		$path = $GLOBALS['phpgw_info']['server']['temp_dir'];
+
+		//Write to the log-file
+		$date_now = date('Y-m-d');
+		file_put_contents("{$path}/FD_name_sync_{$date_now}.log", implode(PHP_EOL, $msgs));
+	}
+
 }
-?>
+
