@@ -23,7 +23,9 @@ class rental_uiparty extends rental_uicommon
 			'update_all_org_enhet_id'	=> true,
 			'syncronize_party'	=> true,
 			'syncronize_party_name'	=> true,
-			'create_user_based_on_email' => true
+			'create_user_based_on_email' => true,
+			'get_synchronize_party_info' => true,
+			'delete_party'		=> true
 	);
 
 	public function __construct()
@@ -80,7 +82,7 @@ class rental_uiparty extends rental_uicommon
 
 		$config	= CreateObject('phpgwapi.config','rental');
 		$config->read();
-		$use_fellesdata = $config->config_data['use_fellesdata'];	
+		$use_fellesdata = $config->config_data['use_fellesdata'];
 		switch($type)
 		{
 			case 'included_parties': // ... get all parties incolved in the contract
@@ -111,7 +113,6 @@ class rental_uiparty extends rental_uicommon
 		$result_objects = rental_soparty::get_instance()->get($start_index, $num_of_objects, $sort_field, $sort_ascending, $search_for, $search_type, $filters);
 		$result_count = rental_soparty::get_instance()->get_count($search_for, $search_type, $filters);
 		
-		
 		// Create an empty row set
 		$rows = array();
 		foreach ($result_objects as $party) {
@@ -141,13 +142,36 @@ class rental_uiparty extends rental_uicommon
 					{
 						$unit_id = $unit_name_and_id['UNIT_ID'];
 						$unit_name = $unit_name_and_id['UNIT_NAME'];
+						
 						if(isset($unit_id) && is_numeric($unit_id))
 						{
 							$serialized['org_unit_name'] =  isset($unit_name) ? $unit_name : lang('no_name');
 							$serialized['org_unit_id'] = $unit_id;
 						}
+
+						// Fetches data from Fellesdata
+						$org_unit_id = $sync_data['org_enhet_id'];
+				
+						$org_unit_with_leader = $bofelles->get_result_unit_with_leader($org_unit_id);
+						$org_department = $bofelles->get_department_for_org_unit($org_unit_id);
+				
+						$org_name = $org_unit_with_leader['ORG_UNIT_NAME'];
+						$org_email = $org_unit_with_leader['ORG_EMAIL'];
+						$unit_leader_fullname = $org_unit_with_leader['LEADER_FULLNAME'];
+						$dep_org_name = $org_department['DEP_ORG_NAME'];
+
+						// Fields are displayed in syncronization table
+						$serialized['org_unit_name'] = $org_name;
+						$serialized['unit_leader'] = $unit_leader_fullname;
+						$serialized['org_email'] = $org_email;
+						$serialized['dep_org_name'] = $dep_org_name;		
 					}
 				}
+				
+				//check if party is a part of a contract
+				$party_in_contract = rental_soparty::get_instance()->has_contract($party->get_id());
+				$serialized['party_in_contract'] = $party_in_contract ? true : false;
+				
 				$rows[] = $serialized;
 			}
 		}
@@ -165,12 +189,11 @@ class rental_uiparty extends rental_uicommon
 					$type,												// [2] The type of query
 					isset($contract) ? $contract->serialize() : null, 	// [3] Serialized contract
 					$editable,											// [4] Editable flag
-					$this->type_of_user									// [5] User role			
+					$this->type_of_user									// [5] User role
 				)
 			);
 		}
 		
-		
 		return $this->yui_results($party_data, 'total_records', 'results');
 	}
 	
@@ -246,86 +269,6 @@ class rental_uiparty extends rental_uicommon
 		}
  	}
  	
- 	/**
- 	 * Synchronization job to update company name on contract parties which are connected to Fellesdata.
- 	 * 
- 	 * Uses property org_enhet_id on party to link party with unit from Fellesdata.
- 	 * To be run as a scheduled job
- 	 */
- 	function syncronize_party_name()
- 	{
- 		$config	= CreateObject('phpgwapi.config','rental');
-		$config->read();
-
-		$use_fellesdata = $config->config_data['use_fellesdata'];	
-		if(!$use_fellesdata){
-			return;
-		}
-		$bofelles = rental_bofellesdata::get_instance();
-		
-		$parties = rental_soparty::get_instance()->get();
-		$result_count = rental_soparty::get_instance()->get_count();
-		$updated_parties;
-		
-		$updated_parties[] = "Total number of parties: {$result_count}";
-		
-		if(($this->isExecutiveOfficer() || $this->isAdministrator()))
-		{
-			$count = 0;
-			$count_result_unit_number = 0;
-			$count_identifier = 0;
-			$count_responsibility = 0;
-
-			foreach ($parties as $party) {
-				$unit_found = false;
-				$fellesdata = NULL;
-
-				if(isset($party)) {
-					$sync_data = $party->get_sync_data();
-
-					$fellesdata = $bofelles->result_unit_exist($sync_data['result_unit_number'],4);
-					if ($fellesdata) {
-						$updated_parties[] = "Unit id found {$fellesdata['UNIT_ID']} by result unit number check. The unit name is {$fellesdata['UNIT_NAME']}<br />";
-						$count_result_unit_number++;
-					}
-
-					if ($fellesdata && isset($fellesdata['UNIT_ID']) && is_numeric($fellesdata['UNIT_ID'])) {
-						// We found a match, so store the new connection
-						$party->set_org_enhet_id($fellesdata['UNIT_ID']);
-						$old_party_name = $party->get_company_name();
-						$party->set_company_name($fellesdata['UNIT_NAME']);
-						$updated_parties[] = "Updated company name on party {$party->get_id()} with unit ID {$party->get_org_enhet_id} from {$old_party_name} to {$party->get_company_name()}";
-						$count++;
-					} else {
-						// No match was found. Do nothing
-						//$party->set_org_enhet_id(NULL);
-					}
-					rental_soparty::get_instance()->store($party);
-				}
-			}
-
-			$updated_parties[] = "Number of parties found through result unit number {$count_result_unit_number}";
-			$updated_parties[] = "Number of parties that have been updated {$count}";
-			log_sync_messages($updated_parties);
-		}
- 	}
- 	
-        private function log_sync_messages($messages) {
-        	
-            $msgs = array_merge(
-            	array('---------------Messages-------------------'),
-            	$messages
-            );
-            
-            //use PHPGW tmp-catalog to store log-file
-            $path = $GLOBALS['phpgw_info']['server']['temp_dir'];
-            
-            //Write to the log-file
-            $date_now = date('Y-m-d');
-            file_put_contents("{$path}/FD_name_sync_{$date_now}.log", implode(PHP_EOL, $msgs));
-        }
-	
-
 	/**
 	 * Add action links for the context menu of the list item
 	 *
@@ -338,7 +281,8 @@ class rental_uiparty extends rental_uicommon
 		$value['ajax'] = array();
 		$value['actions'] = array();
 		$value['labels'] = array();
-
+		$value['alert'] = array();
+	
 		// Get parameters
 		$contract_id = $params[0];
 		$type = $params[1];
@@ -389,6 +333,20 @@ class rental_uiparty extends rental_uicommon
 					$value['actions'][] = html_entity_decode(self::link(array('menuaction' => 'rental.uiparty.edit', 'id' => $value['id'])));
 					$value['labels'][] = lang('edit');
 					
+					if((isset($value['party_in_contract']) && $value['party_in_contract'] == false) && (!isset($value['org_enhet_id']) || $value['org_enhet_id'] == ''))
+					{
+						$value['ajax'][] = true;
+						$value['alert'][] = true;
+						
+						$alertMessage_deleteParty = "Du er i ferd med å slette en kontraktspart.\n\n";
+						$alertMessage_deleteParty .= "Operasjonen kan ikke angres.\n\n";
+						$alertMessage_deleteParty .= "Vil du gjøre dette?";
+						
+						$value['alert'][] = $alertMessage_deleteParty;
+						$value['actions'][] = html_entity_decode(self::link(array('menuaction' => 'rental.uiparty.delete_party', 'id' => $value['id'])));
+						$value['labels'][] = lang('delete');
+					}
+					
 					if(isset($value['org_enhet_id']) && $value['org_enhet_id'] != '')
 					{
 						$value['ajax'][] = false;
@@ -396,18 +354,24 @@ class rental_uiparty extends rental_uicommon
 						$value['labels'][] = lang('frontend_access');
 					}
 					
-					if(isset($value['org_unit_id']))
+					if(isset($value['org_enhet_id']) && $value['org_enhet_id'] != '')
 					{
 						$value['ajax'][] = true;
-						$value['actions'][] = html_entity_decode(self::link(array('menuaction' => 'rental.uiparty.syncronize_party', 'org_unit_id' => $value['org_unit_id'], 'party_id' => $value['id'])));
+						$value['alert'][] = true;
+						
+						$alertMessage = "Du er i ferd med å overskrive data med informasjon hentet fra Fellesdata.\n\n";
+						$alertMessage .= "Følgende felt vil bli overskrevet: Foretak, Avdeling, Enhetsleder, Epost. \n\n";
+						$alertMessage .= "Vil du gjøre dette?";
+						
+						$value['alert'][] = $alertMessage; 
+						$value['actions'][] = html_entity_decode(self::link(array('menuaction' => 'rental.uiparty.syncronize_party', 'org_enhet_id' => $value['org_enhet_id'], 'party_id' => $value['id'])));
 						$value['labels'][] = lang('syncronize_party');
 					}
 				}
 				break;
 		}
 	}
-
-
+	
 	/**
 	 * Public method. View all contracts.
 	 */
@@ -487,7 +451,7 @@ class rental_uiparty extends rental_uicommon
 		{
 			$this->render('permission_denied.php',array('error' => lang('permission_denied_edit')));
 		}
-
+		
 		if(isset($_POST['save_party'])) // The user has pressed the save button
 		{
 			if(isset($party)) // If a party object is created
@@ -514,6 +478,7 @@ class rental_uiparty extends rental_uicommon
 				$party->set_comment(phpgw::get_var('comment'));
 				//$party->set_location_id(phpgw::get_var('location_id'));
 				$party->set_org_enhet_id(phpgw::get_var('org_enhet_id'));
+				$party->set_unit_leader(phpgw::get_var('unit_leader'));
 				
 				if(rental_soparty::get_instance()->store($party)) // ... and then try to store the object
 				{
@@ -576,19 +541,91 @@ class rental_uiparty extends rental_uicommon
 		if(($this->isExecutiveOfficer() || $this->isAdministrator()))
 		{
 			$party_id = phpgw::get_var('party_id');
-			$org_unit_id = phpgw::get_var('org_unit_id');
-			$org_unit_name = phpgw::get_var('org_unit_id');
+			$org_unit_id = phpgw::get_var('org_enhet_id');
+
 			if(isset($party_id) && $party_id > 0 && isset($org_unit_id) && $org_unit_id > 0)
 			{	
+				$config	= CreateObject('phpgwapi.config','rental');
+				$config->read();
+				
+				$use_fellesdata = $config->config_data['use_fellesdata'];
+				if(!$use_fellesdata){ 
+					return;
+				}
+				
+				$bofelles = rental_bofellesdata::get_instance();
+				
+				$org_unit_with_leader = $bofelles->get_result_unit_with_leader($org_unit_id);
+				$org_department = $bofelles->get_department_for_org_unit($org_unit_id);
+				
+				$org_name = $org_unit_with_leader['ORG_UNIT_NAME'];
+				$org_email = $org_unit_with_leader['ORG_EMAIL'];
+				$unit_leader_fullname = $org_unit_with_leader['LEADER_FULLNAME'];
+				$dep_org_name = $org_department['DEP_ORG_NAME'];
+					
 				$party = rental_soparty::get_instance()->get_single($party_id);
-				$party->set_org_enhet_id($org_unit_id);
-				$patry->set_company_name($org_unit_name);
-				// add log-statement for synchronization
+								
+				if(!empty($dep_org_name) & $dep_org_name != '')
+					$party->set_department($dep_org_name);
+				
+				if(!empty($unit_leader_fullname) & $unit_leader_fullname != '')
+					$party->set_unit_leader($unit_leader_fullname);
+					
+				if(!empty($org_name) & $org_name != '')
+					$party->set_company_name($org_name);
+
+				if(!empty($org_email) & $org_email != '')
+					$party->set_email($org_email);
+					
+				if(!empty($org_unit_id) & $org_unit_id != '')
+					$party->set_org_enhet_id($org_unit_id);
+	
 				rental_soparty::get_instance()->store($party);
+				
+				$party = rental_soparty::get_instance()->get_single($party_id);
 			}
 		}
 	}
 	
+	/**
+	 * Public method. Called when a user wants to sync data with Fellesdata. 
+	 * Returns a json string with the following fields: email, org_name, unit_leader_fullname and department
+	 */
+	public function get_synchronize_party_info()
+	{
+		if(($this->isExecutiveOfficer() || $this->isAdministrator()))
+		{
+			$org_unit_id = phpgw::get_var("org_enhet_id");
+					
+			if(isset($org_unit_id) && $org_unit_id > 0)
+			{	
+				$config	= CreateObject('phpgwapi.config','rental');
+				$config->read();
+				
+				$use_fellesdata = $config->config_data['use_fellesdata'];
+				if(!$use_fellesdata){ 
+					return;
+				}
+				
+				$bofelles = rental_bofellesdata::get_instance();
+				
+				$org_unit_with_leader = $bofelles->get_result_unit_with_leader($org_unit_id);
+				$org_department = $bofelles->get_department_for_org_unit($org_unit_id);
+				
+				$org_name = $org_unit_with_leader['ORG_UNIT_NAME'];
+				$org_email = $org_unit_with_leader['ORG_EMAIL'];
+				$unit_leader_fullname = $org_unit_with_leader['LEADER_FULLNAME'];
+				
+				$dep_org_name = $org_department['DEP_ORG_NAME'];
+									
+				$jsonArr = array("email" => trim($org_email), "org_name" => trim($org_name), 
+								 "unit_leader_fullname" => trim($unit_leader_fullname), "department" => trim($dep_org_name));
+				
+				return json_decode( json_encode($jsonArr) );		
+			}	
+		}
+	}	
+		
 	/**
 	 * Function to create Portico Estate users based on email, first- and lastname on contract parties.
 	 */
@@ -693,5 +730,28 @@ class rental_uiparty extends rental_uicommon
 		//Redirect to edit mode with error message if user reaches this point.
 		$GLOBALS['phpgw']->redirect_link('/index.php', array('menuaction' => 'rental.uiparty.edit','id' => $party_id, 'error' => lang('error_create_user_based_on_email')));
 	}
+	
+	public function delete_party()
+	{
+		$party_id = phpgw::get_var('id');
+		if(($this->isExecutiveOfficer() || $this->isAdministrator()))
+		{
+			if(isset($party_id) && $party_id > 0)
+			{
+				if(rental_soparty::get_instance()->delete_party($party_id)) // ... delete the party
+				{
+					$message = lang('messages_saved_form');	
+				}
+				else
+				{
+					$error = lang('messages_form_error');
+				} 
+			}
+		}
+		else
+		{
+			$this->render('permission_denied.php',array('error' => lang('permission_denied_edit')));
+		}
+	}	
 }
 ?>
