@@ -1,15 +1,14 @@
 <dt>
-	Organisasjonstilknytning
+	Organisasjonstilknytning 
 </dt>
 <dd>
 	<?php
 		if ($editable)
 		{
 	?>
-			<select name="org_enhet_id">
+			<select name="org_enhet_id" id="org_enhet_id">
 				<option value=""><?php echo lang('no_party_location') ?></option>
-		<?php
-			
+		<?php		
 			$result_units = rental_bofellesdata::get_instance()->get_result_units();
 			$party_org_enhet_id = $party->get_org_enhet_id();
 			foreach ($result_units as $result_unit)
