@@ -178,9 +178,10 @@
 					'url' =>            array('type' => 'varchar','precision' => '255','nullable' => true),
 					'account_number' =>	array('type' => 'varchar','precision' => '255','nullable' => true),
 					'reskontro' =>      array('type' => 'varchar','precision' => '255','nullable' => true),
-					'location_id' =>    array('type' => 'int', 'precision' => '4', 'nullable' => true),
+					'location_id' =>    	array('type' => 'int', 'precision' => '4', 'nullable' => true),
 					'result_unit_number' => array('type' => 'varchar','precision' => '255','nullable' => true),
-					'org_enhet_id' =>	array ('type' => 'int','precision' => 8, 'nullable' => true)
+					'org_enhet_id' =>		array ('type' => 'int','precision' => 8, 'nullable' => true),
+					'unit_leader' =>	array ('type' => 'varchar','precision' => '255', 'nullable' => true)
 				),
 				'pk' => array('id'),
 				'fk' => array(),
