@@ -253,4 +253,37 @@
 		$GLOBALS['setup_info']['rental']['currentver'] = '0.1.0.14';
 		return $GLOBALS['setup_info']['rental']['currentver'];
 	}
-?>
\ No newline at end of file
+	
+	$test[] = '0.1.0.14';
+	function rental_upgrade0_1_0_14()
+	{
+		// Add unit_leader column
+		$GLOBALS['phpgw_setup']->oProc->AddColumn('rental_party', 'unit_leader', array(
+			'type' => 'varchar', 
+			'nullable' => true,
+			'precision' => '255'
+		));
+				
+		$GLOBALS['setup_info']['rental']['currentver'] = '0.1.0.15';
+		return $GLOBALS['setup_info']['rental']['currentver'];
+	}
+
+	/*
+	* function moved to so-class
+	*/
+	$test[] = '0.1.0.15';
+	function rental_upgrade0_1_0_15()
+	{
+		$asyncservice = CreateObject('phpgwapi.asyncservice');
+		$asyncservice->delete('rental_sync_party_name');
+		$asyncservice->set_timer(
+			array('day' => "*/1"),
+			'rental_sync_party_name',
+			'rental.soparty.syncronize_party_name',
+			null
+			);
+		
+		$GLOBALS['setup_info']['rental']['currentver'] = '0.1.0.16';
+		return $GLOBALS['setup_info']['rental']['currentver'];
+	}
+
