@@ -43,7 +43,7 @@
 						if ($editable)
 						{
 						?>
-							<input type="text" name="identifier" id="identifier" value="<?php echo $party->get_identifier() ?>" />
+							<input type="text" name="identifier" id="identifier" class="medium_number" value="<?php echo $party->get_identifier() ?>" />
 						<?php
 						}
 						else
@@ -160,7 +160,7 @@
 						?>
 							<input type="text" name="address1" id="address1" value="<?php echo $party->get_address_1() ?>" />
 							<br/>
-							<input type="text" name="address2" id="address2" value="<?php echo $party->get_address_2() ?>" />
+							<input type="text" name="address2" id="address2" class="address_2" value="<?php echo $party->get_address_2() ?>" />
 						<?php
 						}
 						else
@@ -197,6 +197,38 @@
 					</dd>
 				</dl>
 				<dl class="proplist-col">
+					<?php if($editable) {?>
+						<dt>
+							<label for="is_inactive"><?php echo lang('inactive_party') ?></label>
+						</dt>
+						<dd>
+							<input type="checkbox" name="is_inactive" id="is_inactive" <?php if($party->is_inactive()) { echo "checked='checked'";} ?>/>
+						</dd>
+					<?php 
+					}else{ 
+					?>
+						<dt><label><?php if($party->is_inactive()){?><font style="color: red;"><?php echo lang('inactive_party');?></font><?php }else{ ?><font style="color: green;"><?php echo lang('active_party');?></font><?php } ?></label></dt>
+						<dd>&nbsp;</dd>
+					<?php }?>
+					<dt>
+						<?php if($party->get_account_number	() || $editable) { ?>
+						<label for="account_number"><?php echo lang('account_number') ?></label>
+						<?php } ?>
+					</dt>
+					<dd>
+						<?php
+						if ($editable)
+						{
+						?>
+							<input type="text" class="medium_number" name="account_number" id="account_number" value="<?php echo $party->get_account_number() ?>" />
+						<?php
+						}
+						else
+						{
+							echo $party->get_account_number();
+						}
+						?>
+					</dd>
 					<dt>
 						<?php if($party->get_phone() || $editable) { ?>
 						<label for="phone"><?php echo lang('phone') ?></label>
@@ -207,7 +239,7 @@
 						if ($editable)
 						{
 						?>
-							<input type="text" name="phone" id="phone" value="<?php echo $party->get_phone() ?>" />
+							<input type="text" name="phone" id="phone" class="medium_number" value="<?php echo $party->get_phone() ?>" />
 						<?php
 						}
 						else
@@ -226,7 +258,7 @@
 						if ($editable)
 						{
 						?>
-							<input type="text" name="mobile_phone" id="mobile_phone" value="<?php echo $party->get_mobile_phone() ?>" />
+							<input type="text" name="mobile_phone" id="mobile_phone" class="medium_number" value="<?php echo $party->get_mobile_phone() ?>" />
 						<?php
 						}
 						else
@@ -245,7 +277,7 @@
 						if ($editable)
 						{
 						?>
-							<input type="text" name="fax" id="fax" value="<?php echo $party->get_fax() ?>" />
+							<input type="text" name="fax" id="fax" class="medium_number" value="<?php echo $party->get_fax() ?>" />
 						<?php
 						}
 						else
@@ -264,7 +296,7 @@
 						if ($editable)
 						{
 						?>
-							<input type="text" name="email" id="email" value="<?php echo $party->get_email() ?>" />
+							<input type="text" name="email" class="email" id="email" value="<?php echo $party->get_email() ?>" />
 						<?php
 							$validator = CreateObject('phpgwapi.EmailAddressValidator');
 							$email = $party->get_email();
@@ -289,7 +321,7 @@
 						if ($editable)
 						{
 						?>
-							<input type="text" name="url" id="url" value="<?php echo $party->get_url() ?>" />
+							<input type="text" class="url" name="url" id="url" value="<?php echo $party->get_url() ?>" />
 						<?php
 						}
 						else
@@ -299,37 +331,45 @@
 						?>
 					</dd>
 					<dt>
-						<?php if($party->get_account_number	() || $editable) { ?>
-						<label for="account_number"><?php echo lang('account_number') ?></label>
-						<?php } ?>
+						<?php if($party->get_unit_leader() || $editable) { ?>
+						<label for="unit_leader"><?php echo lang('unit_leader') ?></label>
+						<?php  } ?>
 					</dt>
 					<dd>
 						<?php
 						if ($editable)
 						{
 						?>
-							<input type="text" name="account_number" id="account_number" value="<?php echo $party->get_account_number() ?>" />
+							<input type="text" name="unit_leader" id="unit_leader" value="<?php echo $party->get_unit_leader() ?>" />
 						<?php
 						}
 						else
 						{
-							echo $party->get_account_number();
+							echo $party->get_unit_leader();
+						}
+						?>
+					</dd>
+				</dl>
+		        <dl class="proplist-col">
+					<dt>
+						<?php if($party->get_comment() || $editable) { ?>
+						<label for="comment"><?php echo lang('comment') ?></label>
+						<?php } ?>
+					</dt>
+					<dd>
+						<?php
+						if ($editable)
+						{
+		                    ?>
+		                    <textarea cols="47" rows="7" name="comment" id="comment"><?php echo $party->get_comment(); ?></textarea>
+		                    <?php
+						}
+						else
+						{
+							echo $party->get_comment();
 						}
 						?>
 					</dd>
-					<?php if($editable) {?>
-						<dt>
-							<label for="is_inactive"><?php echo lang('inactive_party') ?></label>
-						</dt>
-						<dd>
-							<input type="checkbox" name="is_inactive" id="is_inactive" <?php if($party->is_inactive()) { echo "checked='checked'";} ?>/>
-						</dd>
-					<?php 
-					}else{ 
-					?>
-						<dt><label><?php if($party->is_inactive()){?><font style="color: red;"><?php echo lang('inactive_party');?></font><?php }else{ ?><font style="color: green;"><?php echo lang('active_party');?></font><?php } ?></label></dt>
-						<dd>&nbsp;</dd>
-					<?php }?>
 					<!--<dt>
 						<?php if($party->get_location_id() || $editable) {?>
 						<label for="location_id"><?php echo lang('party_location') ?></label>
@@ -340,7 +380,7 @@
 						if ($editable)
 						{
 						?>
-							<select name="location_id" id="location_id">
+							<select id="location_id" name="location_id">
 								<option value=""><?php echo lang('no_party_location') ?></option>
 								<?php 
 									$city_counsil_departments =  array_reverse(location_hierarchy::get_hierarchy());
@@ -394,34 +434,17 @@
 							include PHPGW_SERVER_ROOT . "/rental/inc/plugins/fellesdata/party.edit.php";
 						}
 					?>
-					
-				</dl>
-		        <dl class="proplist-col">
-					<dt>
-						<?php if($party->get_comment() || $editable) { ?>
-						<label for="comment"><?php echo lang('comment') ?></label>
-						<?php } ?>
-					</dt>
-					<dd>
-						<?php
-						if ($editable)
-						{
-		                    ?>
-		                    <textarea cols="40" rows="7" name="comment" id="comment"><?php echo $party->get_comment(); ?></textarea>
-		                    <?php
-						}
-						else
-						{
-							echo $party->get_comment();
-						}
-						?>
-					</dd>
 				</dl>
 				<div class="form-buttons">
+					<span id="unit_errorMsg">Du må velge organisasjonsenhet før du kan synkronisere</span>
 					<?php
 						if ($editable) {
 							echo '<input type="submit" name="save_party" value="' . lang('save') . '"/>';
 						}
+							
+						if ($use_fellesdata) {
+							echo '<input type="button" id="fetchSyncData" name="synchronize" value="' . lang('get_sync_data') . '"/>';
+						}
 					?>
 				</div>
 				
