@@ -5,7 +5,7 @@
 	* @copyright Portions Copyright (C) 2000-2005 Free Software Foundation, Inc. http://www.fsf.org/
 	* @license http://www.gnu.org/licenses/gpl.html GNU General Public License
 	* @package setup
-	* @version $Id: index.php 6048 2010-06-12 15:28:01Z sigurd $
+	* @version $Id: index.php 11471 2013-11-18 10:33:08Z sigurdne $
 	*/
 
 	/*
@@ -147,7 +147,7 @@
 	$setup_tpl->set_var('subaction', $subaction);
 
 	// Old PHP
-	if ( version_compare('5.2.0', phpversion()) === 1 )
+	if (version_compare(phpversion(), '5.2.0', '<'))
 	{
 		$GLOBALS['phpgw_setup']->html->show_header($GLOBALS['phpgw_info']['setup']['header_msg'],True);
 		$GLOBALS['phpgw_setup']->html->show_alert_msg('Error',
@@ -244,7 +244,7 @@
 			
 			flush();
 			//ob_start();
-			$GLOBALS['phpgw_setup']->db->Halt_On_Error = 'report';
+			$GLOBALS['phpgw_setup']->db->Halt_On_Error = 'yes';
 
 			switch ($GLOBALS['phpgw_info']['setup']['currentver']['phpgwapi'])
 			{
@@ -255,7 +255,10 @@
 					}
 					catch (Exception $e)
 					{
-						$setup_tpl->set_var('status',$e->getMessage());
+						if($e)
+						{
+							$setup_tpl->set_var('status','Error: ' . $e->getMessage());
+						}
 					}
 					break;
 				case 'drop':
