@@ -5,7 +5,7 @@
 	* @copyright Copyright (C) 2000-2005 Free Software Foundation, Inc. http://www.fsf.org/
 	* @license http://www.gnu.org/licenses/gpl.html GNU General Public License
 	* @package setup
-	* @version $Id: ldap.php 18358 2007-11-27 04:43:37Z skwashd $
+	* @version $Id: ldap.php 2295 2009-02-04 15:14:37Z sigurd $
 	*/
 
 	$GLOBALS['phpgw_info'] = array();
@@ -65,7 +65,7 @@
 	$setup_tpl->set_var('ldapmodify','ldapmodify.php');
 	$setup_tpl->set_var('ldapimport','ldapimport.php');
 	$setup_tpl->set_var('ldapexport','ldapexport.php');
-	$setup_tpl->set_var('ldapdummy','setup_demo.php');
+	$setup_tpl->set_var('ldapdummy','accounts.php');
 	$setup_tpl->set_var('action_url','index.php');
 	$setup_tpl->set_var('cancel',lang('Cancel'));
 
