@@ -5,7 +5,7 @@
 	* @copyright Copyright (C) 2000-2005 Free Software Foundation, Inc. http://www.fsf.org/
 	* @license http://www.gnu.org/licenses/gpl.html GNU General Public License
 	* @package setup
-	* @version $Id: schematoy.php 15836 2005-04-17 13:18:24Z powerstat $
+	* @version $Id: schematoy.php 690 2008-02-02 10:11:33Z dave $
 	*/
 
 	$GLOBALS['DEBUG'] = True;
@@ -132,7 +132,7 @@
 			$terror[$appname]['version'] = $version[$appname];
 			$terror[$appname]['status'] = 'U';
 
-			$appdir  = PHPGW_SERVER_ROOT . SEP . $appname . SEP . 'setup' . SEP;
+			$appdir  = PHPGW_SERVER_ROOT . "/{$appname}/setup/";
 
 			// Drop newest tables
 			$terror[$appname]['tables'] = $GLOBALS['setup_info'][$appname]['tables'];
