@@ -5,7 +5,7 @@
 	* @copyright Copyright (C) 2000-2005 Free Software Foundation, Inc. http://www.fsf.org/
 	* @license http://www.gnu.org/licenses/gpl.html GNU General Public License
 	* @package setup
-	* @version $Id: sqltoarray.php 15836 2005-04-17 13:18:24Z powerstat $
+	* @version $Id: sqltoarray.php 2983 2009-06-09 13:34:28Z sigurd $
 	*/
 
 	$phpgw_info = array();
@@ -41,7 +41,7 @@
 		$setup_tpl->set_file(array(
 			'sqlarr'   => 'arraydl.tpl'
 		));
-		$setup_tpl->set_var('idstring',"/* \$Id" . ": tables_current.inc.php" . ",v 1.0" . " 2001/05/28 08:42:04 username " . "Exp \$ */");
+		$setup_tpl->set_var('idstring',"/* \$Id" . ": tables_current.inc.php" . ",v 1.0 " . @date('Y/m/d',time()) .  " username " . "Exp \$ */");
 		$setup_tpl->set_block('sqlarr','sqlheader','sqlheader');
 		$setup_tpl->set_block('sqlarr','sqlbody','sqlbody');
 		$setup_tpl->set_block('sqlarr','sqlfooter','sqlfooter');
@@ -101,24 +101,34 @@
 
 		if (count($fk) > 1)
 		{
-			$GLOBALS['setup_tpl']->set_var('fks', "\n\t\t\t\t'" . implode(",\n\t\t\t\t'",$fk) );
+			$GLOBALS['setup_tpl']->set_var('fks', "\n\t\t\t\t" . implode(",\n\t\t\t\t",$fk) );
 		}
 		elseif($fk && !empty($fk))
 		{
-			$GLOBALS['setup_tpl']->set_var('fks', "'" . $fk[0]);
+			$GLOBALS['setup_tpl']->set_var('fks', $fk[0]);
 		}
 		else
 		{
 			$GLOBALS['setup_tpl']->set_var('fks','');
 		}
-
 		if (count($ix) > 1)
 		{
-			$GLOBALS['setup_tpl']->set_var('ixs', implode(",",$ix));
+			foreach($ix as $entry)
+			{
+				if(count($entry) > 1)
+				{
+					$ix_temp[] = "array('" . implode("','",$entry) . "')";
+				}
+				else
+				{
+					$ix_temp[] = "array('{$entry}')";
+				}
+			}
+			$GLOBALS['setup_tpl']->set_var('ixs', implode(",",$ix_temp));
 		}
 		elseif($ix && !empty($ix))
 		{
-			$GLOBALS['setup_tpl']->set_var('ixs', $ix[0]);
+			$GLOBALS['setup_tpl']->set_var('ixs', "'{$ix[0]}'");
 		}
 		else
 		{
