@@ -8,7 +8,7 @@
 	* @internal Development of this application was funded by http://www.bergen.kommune.no/bbb_/ekstern/
 	* @package sms
 	* @subpackage sms
- 	* @version $Id: class.sms.inc.php 6257 2010-08-22 14:40:02Z sigurd $
+ 	* @version $Id: class.sms.inc.php 9953 2012-08-31 11:06:27Z sigurdne $
 	*/
 
 	/**
@@ -420,6 +420,14 @@
 			{
 			//	$db_query = "SELECT uid,email,mobile FROM phpgw_sms_tblUser WHERE username='$target_user'";
 				$uid = $GLOBALS['phpgw']->accounts->name2id($target_user);
+				if(!$uid)
+				{
+					//Try lowercase
+					if($target_user == 'Admins')
+					{
+						$uid = $GLOBALS['phpgw']->accounts->name2id('admins');
+					}
+				}
 			//	$GLOBALS['phpgw']->preferences->account_id = $uid;
 			//	$GLOBALS['phpgw']->preferences->read();
 				$mobile = $GLOBALS['phpgw_info']['user']['preferences']['sms']['cellphone'];
@@ -427,11 +435,9 @@
 
 				if ($uid)
 				{
-					$db_query = "
-					INSERT INTO phpgw_sms_tbluserinbox
-					(in_sender,in_uid,in_msg,in_datetime)
-					VALUES ('$sms_sender','$uid','$message','$sms_datetime')
-					";
+					$message = $this->db->db_addslashes(ucfirst(strtolower($message)));
+
+					$db_query = "INSERT INTO phpgw_sms_tbluserinbox (in_sender,in_uid,in_msg,in_datetime) VALUES ('$sms_sender',$uid,'$message','$sms_datetime')";
 
 					$this->db->query($db_query,__LINE__,__FILE__);
 
@@ -468,21 +474,21 @@
 
 			while ($this->db->next_record())
 			{
-				$gpid = "";
-				$gp_code = "";
-				$uid = $this->db->f('uid');
-				$smslog_id = $this->db->f('smslog_id');
-				$p_datetime = $this->db->f('p_datetime');
-				$p_update = $this->db->f('p_update');
-				$gpid = $this->db->f('p_gpid');
-			//	$gp_code = gpid2gpcode($gpid);
+				$gpid			= "";
+				$gp_code		= "";
+				$uid			= $this->db->f('uid');
+				$smslog_id		= $this->db->f('smslog_id');
+				$p_datetime		= $this->db->f('p_datetime');
+				$p_update		= $this->db->f('p_update');
+				$gpid			= $this->db->f('p_gpid');
+			//	$gp_code		= gpid2gpcode($gpid);
+				$external_id	= $this->db->f('external_id');
 				if($gpid)
 				{
 					$gp_code = $GLOBALS['phpgw']->accounts->name2id($gpid);
 				}
-				$this->gw_set_delivery_status($gp_code,$uid,$smslog_id,$p_datetime,$p_update);
+				$this->gw_set_delivery_status($gp_code,$uid,$smslog_id,$p_datetime,$p_update,$external_id);
 			}
-		//	$this->gw_set_delivery_status($gp_code,$uid,$smslog_id,$p_datetime,$p_update);
 		}
 
 /*		function execgwcustomcmd()
@@ -498,11 +504,12 @@
 			@include $this->apps_path[inc]."/admin/commoncustomcmd.php";
 		}
 
-*/		function setsmsdeliverystatus($smslog_id,$uid,$p_status)
+*/		function setsmsdeliverystatus($smslog_id,$uid,$p_status,$external_id = 0)
 		{
+			$external_id = (int) $external_id;
 			$datetime_now = $this->datetime_now();
 			$ok = false;
-			$db_query = "UPDATE phpgw_sms_tblsmsoutgoing SET p_update='$datetime_now',p_status='$p_status' WHERE smslog_id='$smslog_id' AND uid='$uid'";
+			$db_query = "UPDATE phpgw_sms_tblsmsoutgoing SET p_update='{$datetime_now}',p_status='{$p_status}', external_id = {$external_id} WHERE smslog_id='$smslog_id' AND uid='$uid'";
 			$this->db->transaction_begin();
 			$this->db->query($db_query,__LINE__,__FILE__);
 
@@ -706,7 +713,7 @@
 			{
 				$url['port'] = 80;
 			}
-			$connection = fsockopen($url['host'],$url['port'],&$error_number,&$error_description,60);
+			$connection = fsockopen($url['host'],$url['port'],$error_number,$error_description,60);
 			if($connection)
 			{
 				socket_set_blocking($connection, false);
@@ -834,6 +841,11 @@
 		// and sets the action
 		function setsmsincomingaction($sms_datetime,$sms_sender,$target_code,$message)
 		{
+			if(!strtotime($sms_datetime))
+			{
+				$sms_datetime = $this->datetime_now();
+			}
+
 			$message = utf8_encode($message);
 			$target_code = utf8_encode($target_code);
 			$ok = false;
@@ -919,7 +931,7 @@
 			}
 			if (!$ok)
 			{
-				$message = $target_code." ".$message;
+				$message = "{$target_code} {$message}";
 				if ($this->insertsmstoinbox($sms_datetime,$sms_sender,"Admins",$message))
 				{
 					$ok = true;
