@@ -8,7 +8,7 @@
 	* @internal Development of this application was funded by http://www.bergen.kommune.no/bbb_/ekstern/
 	* @package sms
 	* @subpackage setup
- 	* @version $Id: tables_update.inc.php 6224 2010-08-11 13:21:39Z sigurd $
+ 	* @version $Id: tables_update.inc.php 9953 2012-08-31 11:06:27Z sigurdne $
 	*/
 
 	/**
@@ -425,3 +425,131 @@
 			return $GLOBALS['setup_info']['sms']['currentver'];
 		}
 	}
+
+	/**
+	* Update sms version from 0.9.17.510 to 0.9.17.511
+	* new to new config section
+	*/
+
+	$test[] = '0.9.17.510';
+	function sms_upgrade0_9_17_510()
+	{
+		$GLOBALS['phpgw_setup']->oProc->m_odb->transaction_begin();
+
+		$custom_config	= CreateObject('admin.soconfig',$GLOBALS['phpgw']->locations->get_id('sms', 'run'));
+
+		$receipt_section_bergen = $custom_config->add_section(array
+			(
+				'name' => 'bergen_kommune',
+				'descr' => 'bergen kommune SMS config-section'
+			)
+		);
+
+		$receipt = $custom_config->add_attrib(array
+			(
+				'section_id'	=> $receipt_section_bergen['section_id'],
+				'input_type'	=> 'text',
+				'name'			=> 'service_url',
+				'descr'			=> 'service_url'
+			)
+		);
+		$receipt = $custom_config->add_attrib(array
+			(
+				'section_id'	=> $receipt_section_bergen['section_id'],
+				'input_type'	=> 'text',
+				'name'			=> 'login',
+				'descr'			=> 'login'
+			)
+		);
+		$receipt = $custom_config->add_attrib(array
+			(
+				'section_id'	=> $receipt_section_bergen['section_id'],
+				'input_type'	=> 'password',
+				'name'			=> 'password',
+				'descr'			=> 'password'
+			)
+		);
+		$receipt = $custom_config->add_attrib(array
+			(
+				'section_id'	=> $receipt_section_bergen['section_id'],
+				'input_type'	=> 'text',
+				'name'			=> 'wsdl',
+				'descr'			=> 'wsdl'
+			)
+		);
+		$receipt = $custom_config->add_attrib(array
+			(
+				'section_id'	=> $receipt_section_bergen['section_id'],
+				'input_type'	=> 'text',
+				'name'			=> 'proxy_host',
+				'descr'			=> 'proxy_host'
+			)
+		);
+		$receipt = $custom_config->add_attrib(array
+			(
+				'section_id'	=> $receipt_section_bergen['section_id'],
+				'input_type'	=> 'text',
+				'name'			=> 'proxy_port',
+				'descr'			=> 'proxy_port'
+			)
+		);
+		$receipt = $custom_config->add_attrib(array
+			(
+				'section_id'	=> $receipt_section_bergen['section_id'],
+				'input_type'	=> 'text',
+				'name'			=> 'orgnr',
+				'descr'			=> 'orgnr'
+			)
+		);
+
+		$GLOBALS['phpgw_setup']->oProc->AddColumn('phpgw_sms_tblsmsoutgoing','external_id',
+			array
+			(
+				'type' => 'int',
+				'precision' => 4,
+				'nullable' => True
+			)
+		);
+
+		if($GLOBALS['phpgw_setup']->oProc->m_odb->transaction_commit())
+		{
+			$GLOBALS['setup_info']['sms']['currentver'] = '0.9.17.511';
+			return $GLOBALS['setup_info']['sms']['currentver'];
+		}
+	}
+
+
+	/**
+	* Update sms version from 0.9.17.511 to 0.9.17.512
+	* 
+	*/
+
+	$test[] = '0.9.17.511';
+	function sms_upgrade0_9_17_511()
+	{
+		$GLOBALS['phpgw_setup']->oProc->m_odb->transaction_begin();
+
+
+		$GLOBALS['phpgw_setup']->oProc->CreateTable(
+			'phpgw_sms_received_data', array(
+				'fd' => array(
+					'id' => array('type' => 'auto', 'nullable' => False),
+					'type' => array('type' => 'varchar', 'precision' => 15, 'nullable' => False),/*sms/mms/report*/
+					'data' => array('type' => 'text', 'nullable' => False),
+					'status' => array('type' => 'int', 'precision' => 4, 'nullable' => False, 'default' => '0'),
+					'entry_date' => array('type' => 'int', 'precision' => 4, 'nullable' => False, 'default' => '0'),
+					'modified_date' => array('type' => 'int', 'precision' => 4, 'nullable' => False, 'default' => '0'),
+				),
+				'pk' => array('id'),
+				'fk' => array(),
+				'ix' => array(),
+				'uc' => array()
+			)
+		);
+
+		if($GLOBALS['phpgw_setup']->oProc->m_odb->transaction_commit())
+		{
+			$GLOBALS['setup_info']['sms']['currentver'] = '0.9.17.512';
+			return $GLOBALS['setup_info']['sms']['currentver'];
+		}
+	}
